// Variables for Cyrillic with palochka transliteration tests.
// All the characters are very similar in appearance,
// so it's better to give them names to avoid confusion.
// eslint-disable-next-line no-implicit-globals
var palochkaVariants = {
		palochka: 'Ӏ',
		latinSmallL: 'l',
		latinCapitalI: 'I',
		ukrainianCapitalI: 'І',
		digitOne: '1'
	},
	// eslint-disable-next-line no-implicit-globals
	testFixtures = [ // eslint-disable-line no-unused-vars
	{
		description: 'Aja tilde test',
		inputmethod: 'ajg-tilde',
		tests: [
			{ input: 'fak~e FAK~E', output: 'fakɛ FAKƐ', description: 'Aja tilde fakɛ' },
			{ input: 'ab~ota AB~OTA', output: 'abɔta ABƆTA', description: 'Aja tilde abɔta' },
			{ input: 'e~du E~DU', output: 'eɖu EƉU', description: 'Aja tilde eɖu' },
			{ input: 'e~gi E~GI', output: 'eɣi EƔI', description: 'Aja tilde eɣi' },
			{ input: '~n~oci ~N~OCI', output: 'ŋɔci ŊƆCI', description: 'Aja tilde ŋɔci' },
			{ input: 'a~za A~ZA', output: 'aʒa AƷA', description: 'Aja tilde aʒa' },
			{ input: 's~o~/ e~\\gb~o~\\', output: 'sɔ́ ègbɔ̀', description: 'Aja tilde sɔ́ ègbɔ̀' }
		]
	},
	{
		description: 'Akan QX test',
		inputmethod: 'ak-qx',
		tests: [
			{ input: 'Q', output: 'Ɛ', description: 'Akan QX Q' },
			{ input: 'q', output: 'ɛ', description: 'Akan QX q' },
			{ input: 'X', output: 'Ɔ', description: 'Akan QX X' },
			{ input: 'x', output: 'ɔ', description: 'Akan QX x' },
			{ input: '\\Q', output: 'Q', description: 'Akan QX \\Q' },
			{ input: '\\q', output: 'q', description: 'Akan QX \\q' },
			{ input: '\\X', output: 'X', description: 'Akan QX \\X' },
			{ input: '\\x', output: 'x', description: 'Akan QX \\x' }
		]
	},
	{
		description: 'Akan tilde test',
		inputmethod: 'ak-tilde',
		tests: [
			{ input: '~E', output: 'Ɛ', description: 'Akan tilde ~E' },
			{ input: '~e', output: 'ɛ', description: 'Akan tilde ~e' },
			{ input: '~O', output: 'Ɔ', description: 'Akan tilde ~O' },
			{ input: '~o', output: 'ɔ', description: 'Akan tilde ~o' }
		]
	},
	{
		description: 'Afrikaans tilde test',
		inputmethod: 'af-tilde',
		tests: [
			{ input: 'na~/', output: 'ná', description: 'Afrikaans tilde na~/' },
			{ input: 'die~/', output: 'dié', description: 'Afrikaans tilde die~/' },
			{ input: 'de~\\', output: 'dè', description: 'Afrikaans tilde de~\\' },
			{ input: 'he~^', output: 'hê', description: 'Afrikaans tilde he~^' },
			{ input: 'gee~:et', output: 'geëet', description: 'Afrikaans tilde gee~:et' },
			{ input: 'di~/t', output: 'dít', description: 'Afrikaans tilde di~/t' },
			{ input: 'wi~^e', output: 'wîe', description: 'Afrikaans tilde wi~^e' },
			{ input: 'bei~:nvloed', output: 'beïnvloed', description: 'Afrikaans tilde bei~:nvloed' },
			{ input: 'o~/ns', output: 'óns', description: 'Afrikaans tilde o~/ns' },
			{ input: 'mo~^re', output: 'môre', description: 'Afrikaans tilde mo~^re' },
			{ input: 'hu~/l', output: 'húl', description: 'Afrikaans tilde hu~/l' },
			{ input: 'bru~^e', output: 'brûe', description: 'Afrikaans tilde bru~^e' },
			{ input: 'sy~/', output: 'sý', description: 'Afrikaans tilde sy~/' },
			{ input: "~'n", output: '’n', description: "Afrikaans tilde ~'n" }
		]
	},
	{
		description: 'Amharic Transliteration test',
		inputmethod: 'am-transliteration',
		tests: [
			{ input: 'k', output: 'ክ', description: 'Amharic k -> ክ' },
			{ input: 'N', output: 'ኝ', description: 'Amharic N -> ኝ' },
			{ input: 'neNu', output: 'ነኙ', description: 'Amharic neNu -> ነኙ' },
			{ input: 'Nu', output: 'ኙ', description: 'Amharic Nu -> ኙ' },
			{ input: 'cika', output: 'ቺካ', description: 'Amharic cika -> ቺካ' },
			{ input: '<<', output: '«', description: 'Amharic << -> «' },
			{ input: 'vee', output: 'ቬ', description: 'Amharic vee -> ቬ' },
			{ input: 'vE', output: 'ቬ', description: 'Amharic vE -> ቬ' },
			{ input: 'Vee', output: 'ቬ', description: 'Amharic Vee -> ቬ' },
			{ input: 'VE::', output: 'ቬ።', description: 'Amharic VE:: -> ቬ።' },
			{ input: 'to', output: 'ቶ', description: 'Amharic to -> ቶ' },
			{ input: 'dW', output: 'ዷ', description: 'Amharic dW -> ዷ' },
			{ input: 'ss', output: 'ሥ', description: 'Amharic ss -> ሥ' },
			{ input: 'gWi', output: 'ጒ', description: 'Amharic gWi -> ጒ' },
			{ input: 'hhW', output: 'ኋ', description: 'Amharic hhW -> ኋ' },
			{ input: 'FY', output: 'ፚ', description: 'Amharic FY -> ፚ' },
			{ input: '5', output: '፭', description: 'Amharic 5 -> ፭' },
			{ input: '60', output: '፷', description: 'Amharic 60 -> ፷' },
			{ input: '3005', output: '፫፻፭', description: 'Amharic 3005 -> ፫፻፭' },
			{ input: 'aa.m.', output: 'ዓ.ም.', description: 'Amharic aa.m. -> ዓ.ም.' },
			{ input: 'ea', output: 'ኧ', description: 'Amharic ea -> ኧ' }
		]
	},
	{
		description: 'Obolo tilde test',
		inputmethod: 'ann-tilde',
		tests: [
			{ input: '~O', output: 'Ọ', description: 'Obolo tilde Ọ (~O)' },
			{ input: 'o~.', output: 'ọ', description: 'Obolo tilde ọ (o~.)' },
			{ input: '~s', output: 'ṣ', description: 'Obolo tilde ṣ (~s)' },
			{ input: 'S~.', output: 'Ṣ', description: 'Obolo tilde Ṣ (S~.)' },
			{ input: 'M~/ N~/', output: 'Ḿ Ń', description: 'Obolo tilde Ḿ Ń' },
			{ input: 'Akpata~n', output: 'Akpatan̄', description: 'Obolo tilde Akpatan̄ (~n)' },
			{ input: 'Akpatan~-', output: 'Akpatan̄', description: 'Obolo tilde Akpatan̄ (n~-)' },
			{ input: 'ri~o~o~n', output: 'riọọn̄', description: 'Obolo tilde riọọn̄' },
			{ input: 'mo~^k~ot', output: 'môkọt', description: 'Obolo tilde môkọt' },
			{ input: 'Mi~^gobo', output: 'Mîgobo', description: 'Obolo tilde Mîgobo' },
			{ input: 'fu~vk', output: 'fǔk', description: 'Obolo tilde fǔk' },
			{ input: 'i~^fo~v', output: 'îfǒ', description: 'Obolo tilde îfǒ' },
			{ input: 'e~/gbe~\\', output: 'égbè', description: 'Obolo tilde égbè' },
			{ input: 'i~\\j~o~\\n', output: 'ìjọ̀n', description: 'Obolo tilde ìjọ̀n' }
		]
	},
	{
		description: 'Assamese InScript test',
		inputmethod: 'as-inscript',
		tests: [
			{ input: '1234567890', output: '১২৩৪৫৬৭৮৯০', description: 'Assamese InScript 1234567890' },
			{ input: 'k#', output: 'ক্ৰ', description: 'Assamese InScript k#' },
			{ input: '$k', output: 'ৰ্ক', description: 'Assamese InScript $k' },
			{ input: '%', output: 'জ্ঞ', description: 'Assamese InScript %' },
			{ input: '^', output: 'ত্র', description: 'Assamese InScript ^' },
			{ input: '&', output: 'ক্ষ', description: 'Assamese InScript &' },
			{ input: '*', output: 'শ্র', description: 'Assamese InScript *' },
			{ input: 'k_', output: 'কঃ', description: 'Assamese InScript k_' },
			{ input: '+', output: 'ঋ', description: 'Assamese InScript +' },
			{ input: 'QWERTYUIOP{}', output: 'ঔঐআঈঊভঙঘধঝঢঞ', description: 'Assamese InScript QWERTYIOP{}' },
			{ input: 'yq', output: 'বৌ', description: 'Assamese InScript yq' },
			{ input: 'uw', output: 'হৈ', description: 'Assamese InScript uw' },
			{ input: 'ie', output: 'গা', description: 'Assamese InScript ie' },
			{ input: 'or', output: 'দী', description: 'Assamese InScript or' },
			{ input: 'pt', output: 'জূ', description: 'Assamese InScript pt' },
			{ input: '[]', output: 'ড়', description: 'Assamese InScript []' },
			{ input: 'ASDFGHJKL:"', output: 'ওএঅইউফৎখথছঠ', description: 'Assamese InScript ASDFGHJKL:"' },
			{ input: 'ha', output: 'পো', description: 'Assamese InScript ha' },
			{ input: 'js', output: 'ৰে', description: 'Assamese InScript js' },
			{ input: 'kd', output: 'ক্', description: 'Assamese InScript kd' },
			{ input: 'lf', output: 'তি', description: 'Assamese InScript lf' },
			{ input: ';g', output: 'চু', description: 'Assamese InScript ;g' },
			{ input: '\'', output: 'ট', description: 'Assamese InScript \'' },
			{ input: 'cx', output: 'মং', description: 'Assamese InScript cx' },
			{ input: 'vnm', output: 'নলস', description: 'Assamese InScript vnm' },
			{ input: 'CX', output: 'ণঁ', description: 'Assamese InScript CX' },
			{ input: 'M<?', output: 'শষয', description: 'Assamese InScript M<?' }
		]
	},
	{
		description: 'Assamese InScript 2 test',
		inputmethod: 'as-inscript2',
		tests: [
			{ input: '1234567890', output: '১২৩৪৫৬৭৮৯০', description: 'Assamese InScript 2 1234567890' },
			{ input: 'k#', output: 'ক্ৰ', description: 'Assamese InScript 2 k#' },
			{ input: '$k', output: 'ৰ্ক', description: 'Assamese InScript 2 $k' },
			{ input: '%', output: 'জ্ঞ', description: 'Assamese InScript 2 %' },
			{ input: '^', output: 'ত্র', description: 'Assamese InScript 2 ^' },
			{ input: '&', output: 'ক্ষ', description: 'Assamese InScript 2 &' },
			{ input: '*', output: 'শ্র', description: 'Assamese InScript 2 *' },
			{ input: 'k_', output: 'কঃ', description: 'Assamese InScript 2 k_' },
			{ input: '+', output: 'ঋ', description: 'Assamese InScript 2 +' },
			{ input: 'QWERTYUIOP{}', output: 'ঔঐআঈঊভঙঘধঝঢঞ', description: 'Assamese InScript 2 QWERTYIOP{}' },
			{ input: 'yq', output: 'বৌ', description: 'Assamese InScript 2 yq' },
			{ input: 'uw', output: 'হৈ', description: 'Assamese InScript 2 uw' },
			{ input: 'ie', output: 'গা', description: 'Assamese InScript 2 ie' },
			{ input: 'or', output: 'দী', description: 'Assamese InScript 2 or' },
			{ input: 'pt', output: 'জূ', description: 'Assamese InScript 2 pt' },
			{ input: '[]', output: 'ড়', description: 'Assamese InScript 2 []' },
			{ input: 'ASDFGHKL:"', output: 'ওএঅইউফখথছঠ', description: 'Assamese InScript 2 ASDFGHKL:"' },
			{ input: 'ha', output: 'পো', description: 'Assamese InScript 2 ha' },
			{ input: 'js', output: 'ৰে', description: 'Assamese InScript 2 js' },
			{ input: 'kd', output: 'ক্', description: 'Assamese InScript 2 kd' },
			{ input: 'lf', output: 'তি', description: 'Assamese InScript 2 lf' },
			// { input: 'l', output: 'ৎ', description: 'Assamese InScript 2 l' }, // TODO fix broken rule
			{ input: ';g', output: 'চু', description: 'Assamese InScript 2 ;g' },
			{ input: '\'', output: 'ট', description: 'Assamese InScript 2 \'' },
			{ input: 'cx', output: 'মং', description: 'Assamese InScript 2 cx' },
			{ input: 'vnm', output: 'নলস', description: 'Assamese InScript 2 vnm' },
			{ input: 'CX', output: 'ণঁ', description: 'Assamese InScript 2 CX' },
			{ input: 'M<?', output: 'শষয', description: 'Assamese InScript 2 M<?' }
		]
	},
	{
		description: 'South Azerbaijani Keyboard test',
		inputmethod: 'azb-kbd',
		tests: [
			{ input: '`', output: '\u200d', description: 'South Azerbaijani Keyboard Layout: ` -> \u200d' },
			{ input: '1', output: '۱', description: 'South Azerbaijani Keyboard Layout: 1 -> ۱' },
			{ input: '2', output: '۲', description: 'South Azerbaijani Keyboard Layout: 2 -> ۲' },
			{ input: '3', output: '۳', description: 'South Azerbaijani Keyboard Layout: 3 -> ۳' },
			{ input: '4', output: '۴', description: 'South Azerbaijani Keyboard Layout: 4 -> ۴' },
			{ input: '5', output: '۵', description: 'South Azerbaijani Keyboard Layout: 5 -> ۵' },
			{ input: '6', output: '۶', description: 'South Azerbaijani Keyboard Layout: 6 -> ۶' },
			{ input: '7', output: '۷', description: 'South Azerbaijani Keyboard Layout: 7 -> ۷' },
			{ input: '8', output: '۸', description: 'South Azerbaijani Keyboard Layout: 8 -> ۸' },
			{ input: '9', output: '۹', description: 'South Azerbaijani Keyboard Layout: 9 -> ۹' },
			{ input: '0', output: '۰', description: 'South Azerbaijani Keyboard Layout: 0 -> ۰' },
			{ input: 'q', output: 'ض', description: 'South Azerbaijani Keyboard Layout: q -> ض' },
			{ input: 'w', output: 'ص', description: 'South Azerbaijani Keyboard Layout: w -> ص' },
			{ input: 'e', output: 'ث', description: 'South Azerbaijani Keyboard Layout: e -> ث' },
			{ input: 'r', output: 'ق', description: 'South Azerbaijani Keyboard Layout: r -> ق' },
			{ input: 't', output: 'ف', description: 'South Azerbaijani Keyboard Layout: t -> ف' },
			{ input: 'y', output: 'غ', description: 'South Azerbaijani Keyboard Layout: y -> غ' },
			{ input: 'u', output: 'ع', description: 'South Azerbaijani Keyboard Layout: u -> ع' },
			{ input: 'i', output: 'ه', description: 'South Azerbaijani Keyboard Layout: i -> ه' },
			{ input: 'o', output: 'خ', description: 'South Azerbaijani Keyboard Layout: o -> خ' },
			{ input: 'p', output: 'ح', description: 'South Azerbaijani Keyboard Layout: p -> ح' },
			{ input: '[', output: 'ج', description: 'South Azerbaijani Keyboard Layout: [ -> ج' },
			{ input: ']', output: 'چ', description: 'South Azerbaijani Keyboard Layout: ] -> چ' },
			{ input: 'a', output: 'ش', description: 'South Azerbaijani Keyboard Layout: a -> ش' },
			{ input: 's', output: 'س', description: 'South Azerbaijani Keyboard Layout: s -> س' },
			{ input: 'd', output: 'ی', description: 'South Azerbaijani Keyboard Layout: d -> ی' },
			{ input: 'f', output: 'ب', description: 'South Azerbaijani Keyboard Layout: f -> ب' },
			{ input: 'g', output: 'ل', description: 'South Azerbaijani Keyboard Layout: g -> ل' },
			{ input: 'h', output: 'ا', description: 'South Azerbaijani Keyboard Layout: h -> ا' },
			{ input: 'j', output: 'ت', description: 'South Azerbaijani Keyboard Layout: j -> ت' },
			{ input: 'k', output: 'ن', description: 'South Azerbaijani Keyboard Layout: k -> ن' },
			{ input: 'l', output: 'م', description: 'South Azerbaijani Keyboard Layout: l -> م' },
			{ input: ';', output: 'ک', description: 'South Azerbaijani Keyboard Layout: ; -> ک' },
			{ input: 'z', output: 'ظ', description: 'South Azerbaijani Keyboard Layout: z -> ظ' },
			{ input: 'x', output: 'ط', description: 'South Azerbaijani Keyboard Layout: x -> ط' },
			{ input: 'c', output: 'ز', description: 'South Azerbaijani Keyboard Layout: c -> ز' },
			{ input: 'v', output: 'ر', description: 'South Azerbaijani Keyboard Layout: v -> ر' },
			{ input: 'b', output: 'ذ', description: 'South Azerbaijani Keyboard Layout: b -> ذ' },
			{ input: 'n', output: 'د', description: 'South Azerbaijani Keyboard Layout: n -> د' },
			{ input: 'm', output: 'پ', description: 'South Azerbaijani Keyboard Layout: m -> پ' },
			{ input: ',', output: 'و', description: 'South Azerbaijani Keyboard Layout: , -> و' },
			{ input: '~', output: '\u200c', description: 'South Azerbaijani Keyboard Layout: ~ -> \u200c' },
			{ input: '@', output: '٬', description: 'South Azerbaijani Keyboard Layout: @ -> ٬' },
			{ input: '#', output: '٫', description: 'South Azerbaijani Keyboard Layout: # -> ٫' },
			{ input: '%', output: '٪', description: 'South Azerbaijani Keyboard Layout: % -> ٪' },
			{ input: '^', output: '×', description: 'South Azerbaijani Keyboard Layout: ^ -> ×' },
			{ input: '&', output: '،', description: 'South Azerbaijani Keyboard Layout: & -> ،' },
			{ input: '(', output: ')', description: 'South Azerbaijani Keyboard Layout: ( -> )' },
			{ input: ')', output: '(', description: 'South Azerbaijani Keyboard Layout: ) -> (' },
			{ input: '_', output: 'ـ', description: 'South Azerbaijani Keyboard Layout: _ -> ـ' },
			{ input: 'Q', output: 'ۇ', description: 'South Azerbaijani Keyboard Layout: Q -> ۇ' },
			{ input: 'W', output: 'ۆ', description: 'South Azerbaijani Keyboard Layout: W -> ۆ' },
			{ input: 'E', output: 'وْ', description: 'South Azerbaijani Keyboard Layout: E -> وْ' },
			{ input: 'R', output: 'ً', description: 'South Azerbaijani Keyboard Layout: R -> ً' },
			{ input: 'T', output: 'ُ', description: 'South Azerbaijani Keyboard Layout: T -> ُ' },
			{ input: 'Y', output: 'ِ', description: 'South Azerbaijani Keyboard Layout: Y -> ِ' },
			{ input: 'U', output: 'َ', description: 'South Azerbaijani Keyboard Layout: U -> َ' },
			{ input: 'I', output: 'ّ', description: 'South Azerbaijani Keyboard Layout: I -> ّ' },
			{ input: 'O', output: ']', description: 'South Azerbaijani Keyboard Layout: O -> ]' },
			{ input: 'P', output: '[', description: 'South Azerbaijani Keyboard Layout: P -> [' },
			{ input: '{', output: '}', description: 'South Azerbaijani Keyboard Layout: { -> }' },
			{ input: '}', output: '{', description: 'South Azerbaijani Keyboard Layout: } -> {' },
			{ input: 'A', output: 'ؤ', description: 'South Azerbaijani Keyboard Layout: A -> ؤ' },
			{ input: 'S', output: 'ئ', description: 'South Azerbaijani Keyboard Layout: S -> ئ' },
			{ input: 'D', output: 'ؽ', description: 'South Azerbaijani Keyboard Layout: D -> ؽ' },
			{ input: 'F', output: 'إ', description: 'South Azerbaijani Keyboard Layout: F -> إ' },
			{ input: 'G', output: 'أ', description: 'South Azerbaijani Keyboard Layout: G -> أ' },
			{ input: 'H', output: 'آ', description: 'South Azerbaijani Keyboard Layout: H -> آ' },
			{ input: 'J', output: 'ة', description: 'South Azerbaijani Keyboard Layout: J -> ة' },
			{ input: 'K', output: '»', description: 'South Azerbaijani Keyboard Layout: K -> »' },
			{ input: 'L', output: '«', description: 'South Azerbaijani Keyboard Layout: L -> «' },
			{ input: '"', output: '؛', description: 'South Azerbaijani Keyboard Layout: " -> ؛' },
			{ input: 'Z', output: 'ك', description: 'South Azerbaijani Keyboard Layout: Z -> ك' },
			{ input: 'X', output: 'ط', description: 'South Azerbaijani Keyboard Layout: X -> ط' },
			{ input: 'C', output: 'ژ', description: 'South Azerbaijani Keyboard Layout: C -> ژ' },
			{ input: 'V', output: 'ٰ', description: 'South Azerbaijani Keyboard Layout: V -> ٰ' },
			{ input: 'B', output: 'ڭ', description: 'South Azerbaijani Keyboard Layout: B -> ڭ' },
			{ input: 'N', output: 'ٔ', description: 'South Azerbaijani Keyboard Layout: N -> ٔ' },
			{ input: 'M', output: 'ء', description: 'South Azerbaijani Keyboard Layout: M -> ء' },
			{ input: '<', output: '>', description: 'South Azerbaijani Keyboard Layout: < -> >' },
			{ input: '>', output: '<', description: 'South Azerbaijani Keyboard Layout: > -> <' },
			{ input: '?', output: '؟', description: 'South Azerbaijani Keyboard Layout: ? -> ؟' }
		]
	},
	{
		description: 'Basaa tilde test',
		inputmethod: 'bas-tilde',
		tests: [
			{ input: 'Mb~e~/n~e~^', output: 'Mbɛ́nɛ̂', description: 'Basaa tilde: Mb~e~/n~e~^ -> Mbɛ́nɛ̂' },
			{ input: '~Basaa~/', output: 'Ɓasaá', description: 'Basaa tilde: ~Basaa~/ -> Ɓasaá' },
			{ input: '~Ba~\\sa~\\a', output: 'Ɓàsàa', description: 'Basaa tilde: ~Ba~\\sa~\\a -> Ɓàsàa' },
			{ input: 'l~o', output: 'lɔ', description: 'Basaa tilde: l~o -> lɔ' },
			{ input: 'a~/~n', output: 'áŋ', description: 'Basaa tilde: a~/~n -> áŋ' },
			{ input: '~ba~n', output: 'ɓaŋ', description: 'Basaa tilde: ~ba~n -> ɓaŋ' },
			{ input: 'ma~\\~bo~vn su~vglu~\\', output: 'màɓǒn sǔglù', description: 'Basaa tilde: ma~\\~bo~vn su~vglu~\\ -> màɓǒn sǔglù' },
			{ input: 'ki~n yada~-', output: 'kiŋ yadā', description: 'Basaa tilde: ki~n yada~- -> kiŋ yadā' }
		]
	},
	{
		description: 'Batak Toba Transliteration test',
		inputmethod: 'bbc-transliteration',
		tests: [
			{ input: 'q', output: 'ᯥ', description: 'Toba Transliteration - q - u' },
			{ input: 'w', output: 'ᯋ', description: 'Toba Transliteration - w' },
			{ input: 'e', output: 'ᯧ', description: 'Toba Transliteration - e' },
			{ input: 'r', output: 'ᯒ', description: 'Toba Transliteration - r' },
			{ input: 't', output: 'ᯖ', description: 'Toba Transliteration - t' },
			{ input: 'y', output: 'ᯛ', description: 'Toba Transliteration - y' },
			{ input: 'u', output: 'ᯮ', description: 'Toba Transliteration - u' },
			{ input: 'i', output: 'ᯪ', description: 'Toba Transliteration - i' },
			{ input: 'o', output: 'ᯬ', description: 'Toba Transliteration - o' },
			{ input: 'p', output: 'ᯇ', description: 'Toba Transliteration - p' },

			{ input: 'a', output: 'ᯀ', description: 'Toba Transliteration - a' },
			{ input: 's', output: 'ᯘ', description: 'Toba Transliteration - s' },
			{ input: 'd', output: 'ᯑ', description: 'Toba Transliteration - d' },
			{ input: 'f', output: '᯲', description: 'Toba Transliteration - f - pangolat/virama' },
			{ input: 'g', output: 'ᯎ', description: 'Toba Transliteration - g' },
			{ input: 'h', output: 'ᯂ', description: 'Toba Transliteration - h' },
			{ input: 'j', output: 'ᯐ', description: 'Toba Transliteration - j' },
			{ input: 'k', output: 'ᯤ', description: 'Toba Transliteration - k - i' },
			{ input: 'l', output: 'ᯞ', description: 'Toba Transliteration - l' },

			{ input: 'z', output: 'ᯝ', description: 'Toba Transliteration - z - nga' },
			{ input: 'x', output: 'ᯢ', description: 'Toba Transliteration - x - nda' },
			{ input: 'c', output: 'ᯡ', description: 'Toba Transliteration - c' },
			{ input: 'v', output: 'ᯣ', description: 'Toba Transliteration - v - mba' },
			{ input: 'b', output: 'ᯅ', description: 'Toba Transliteration - b' },
			{ input: 'n', output: 'ᯉ', description: 'Toba Transliteration - n' },
			{ input: 'm', output: 'ᯔ', description: 'Toba Transliteration - m' },

			{ input: 'Q', output: 'ᯍ', description: 'Toba Transliteration - Q - pakpak wa' },
			{ input: 'W', output: 'ᯌ', description: 'Toba Transliteration - W - simalungun wa' },
			{ input: 'E', output: 'ᯨ', description: 'Toba Transliteration - E - pakpak e' },
			{ input: 'R', output: 'ᯓ', description: 'Toba Transliteration - R - simalungun ra' },
			{ input: 'T', output: 'ᯗ', description: 'Toba Transliteration - T - northern ta' },
			{ input: 'Y', output: 'ᯜ', description: 'Toba Transliteration - Y - simalungun ya' },
			{ input: 'U', output: 'ᯯ', description: 'Toba Transliteration - U - u for simalungun sa' },
			{ input: 'I', output: 'ᯫ', description: 'Toba Transliteration - I - karo i' },
			{ input: 'O', output: 'ᯭ', description: 'Toba Transliteration - O - karo o' },
			{ input: 'P', output: 'ᯈ', description: 'Toba Transliteration - P - simalungun p' },

			{ input: 'A', output: 'ᯁ', description: 'Toba Transliteration - A - simalungun a' },
			{ input: 'S', output: 'ᯙ', description: 'Toba Transliteration - S - simalungun sa' },
			{ input: 'D', output: 'ᯩ', description: 'Toba Transliteration - D - talinga' },
			{ input: 'F', output: '᯳', description: 'Toba Transliteration - F - virama' },
			{ input: 'G', output: 'ᯏ', description: 'Toba Transliteration - G - simalungun ga' },
			{ input: 'H', output: 'ᯃ', description: 'Toba Transliteration - H - simalungun ha' },
			{ input: 'J', output: 'ᯄ', description: 'Toba Transliteration - J - mandailing ha' },
			{ input: 'K', output: 'ᯱ', description: 'Toba Transliteration - K - hajoringan -h' },
			{ input: 'L', output: 'ᯟ', description: 'Toba Transliteration - L - simalungun la' },

			{ input: 'Z', output: 'ᯚ', description: 'Toba Transliteration - Z - mandailing sa' },
			{ input: 'X', output: 'ᯰ', description: 'Toba Transliteration - X - amisara -ng' },
			{ input: 'C', output: 'ᯠ', description: 'Toba Transliteration - C - nya / karo ca' },
			{ input: 'V', output: '᯦', description: 'Toba Transliteration - V - tompi' },
			{ input: 'B', output: 'ᯆ', description: 'Toba Transliteration - B - karo ba' },
			{ input: 'N', output: 'ᯊ', description: 'Toba Transliteration - N - mandailing na' },
			{ input: 'M', output: 'ᯕ', description: 'Toba Transliteration - M - simalungun ma' },

			{ input: [ [ '4', true ] ], output: '᯼', description: 'Toba Transliteration - alt-4 - bindu na metek' },
			{ input: [ [ '5', true ] ], output: '᯽', description: 'Toba Transliteration - alt-5 - bindu pinarboras' },
			{ input: [ [ '6', true ] ], output: '᯾', description: 'Toba Transliteration - alt-6 - bindu judul' },
			{ input: [ [ '7', true ] ], output: '᯿', description: 'Toba Transliteration - alt-7 - bindu pangolat' }
		]
	},
	{
		description: 'Batak Mandailing transliteration test',
		inputmethod: 'btm-transliteration',
		tests: [
			{ input: 'a', output: 'ᯀ', description: 'Mandailing transliteration a' },
			{ input: 'ba', output: 'ᯅ', description: 'Mandailing transliteration ba' },
			{ input: 'ca', output: 'ᯚ᯦', description: 'Mandailing transliteration ca' },
			{ input: 'da', output: 'ᯑ', description: 'Mandailing transliteration da' },
			{ input: 'e', output: 'ᯀᯩ', description: 'Mandailing transliteration e' },
			{ input: 'f', output: '᯳', description: 'Mandailing transliteration PANONGONAN = virama' },
			{ input: 'ga', output: 'ᯎ', description: 'Mandailing transliteration ga' },
			{ input: 'h', output: 'ᯱ', description: 'Mandailing transliteration CONSONANT SIGN H = hajoringan (-h)' },
			{ input: 'ha', output: 'ᯄ', description: 'Mandailing transliteration ha' },
			{ input: 'i', output: 'ᯤ', description: 'Mandailing transliteration i' },
			{ input: 'ja', output: 'ᯐ', description: 'Mandailing transliteration ja' },
			{ input: 'ka', output: 'ᯄ᯦', description: 'Mandailing transliteration ka' },
			{ input: 'la', output: 'ᯞ', description: 'Mandailing transliteration la' },
			{ input: 'ma', output: 'ᯔ', description: 'Mandailing transliteration ma' },
			{ input: 'na', output: 'ᯊ', description: 'Mandailing transliteration na' },
			{ input: 'o', output: 'ᯀᯬ', description: 'Mandailing transliteration o' },
			{ input: 'pa', output: 'ᯇ', description: 'Mandailing transliteration pa' },
			{ input: 'q', output: '᯲', description: 'Mandailing transliteration PANGOLAT (PANGGOTAP) = virama' },
			{ input: 'ra', output: 'ᯒ', description: 'Mandailing transliteration ra' },
			{ input: 'sa', output: 'ᯚ', description: 'Mandailing transliteration sa' },
			{ input: 'ta', output: 'ᯖ', description: 'Mandailing transliteration ta' },
			{ input: 'u', output: 'ᯥ', description: 'Mandailing transliteration u' },
			{ input: 'v', output: '᯦', description: 'Mandailing transliteration TOMPI' },
			{ input: 'wa', output: 'ᯋ', description: 'Mandailing transliteration wa' },
			{ input: 'x', output: 'ᯀᯧ', description: 'Mandailing transliteration VOWEL SIGN E = kebereten' },
			{ input: 'ya', output: 'ᯛ', description: 'Mandailing transliteration ya' },
			{ input: 'z', output: 'ᯰ', description: 'Mandailing transliteration CONSONANT SIGN NG = amisara (-ng)' },
			{ input: 'Mandung sampe amu tuson Wikikamus saro Mandailing', output: 'ᯔᯊ᯲ᯑᯮᯰ ᯚᯔ᯲ᯇᯩ ᯀᯔᯮ ᯖᯮᯚᯬᯊ᯲ ᯋᯪᯄ᯦ᯪᯄ᯦ᯔᯮᯚ᯲ ᯚᯒᯬ ᯔᯊ᯲ᯑᯤᯞᯪᯰ', description: 'Mandailing transliteration' }
		]
	},
	{
		description: 'Batak Mandailing keyboard test',
		inputmethod: 'btm-keyboard',
		tests: [
			{ input: 'q', output: '᯲', description: 'Mandailing keyboard - q = pangolat' },
			{ input: 'w', output: 'ᯋ', description: 'Mandailing keyboard - wa' },
			{ input: 'e', output: 'ᯩ', description: 'Mandailing keyboard = -e' },
			{ input: 'r', output: 'ᯒ', description: 'Mandailing keyboard - ra' },
			{ input: 't', output: 'ᯖ', description: 'Mandailing keyboard - ta' },
			{ input: 'y', output: 'ᯛ', description: 'Mandailing keyboard - ya' },
			{ input: 'u', output: 'ᯮ', description: 'Mandailing keyboard = -u' },
			{ input: 'i', output: 'ᯪ', description: 'Mandailing keyboard = -i' },
			{ input: 'o', output: 'ᯬ', description: 'Mandailing keyboard = -o' },
			{ input: 'p', output: 'ᯇ', description: 'Mandailing keyboard - pa' },

			{ input: 'a', output: 'ᯀ', description: 'Mandailing keyboard - a' },
			{ input: 's', output: 'ᯚ', description: 'Mandailing keyboard - sa' },
			{ input: 'd', output: 'ᯑ', description: 'Mandailing keyboard - da' },
			{ input: 'f', output: '᯳', description: 'Mandailing keyboard - f = panongonan' },
			{ input: 'g', output: 'ᯎ', description: 'Mandailing keyboard - ga' },
			{ input: 'h', output: 'ᯂ', description: 'Mandailing keyboard - ha' },
			{ input: 'j', output: 'ᯐ', description: 'Mandailing keyboard - ja' },
			{ input: 'k', output: 'ᯄ᯦', description: 'Mandailing keyboard - ka = ha+tompi' },
			{ input: 'l', output: 'ᯞ', description: 'Mandailing keyboard - la' },

			{ input: 'z', output: 'ᯝ', description: 'Mandailing keyboard - z = nga' },
			{ input: 'x', output: 'ᯠ', description: 'Mandailing keyboard - x = nya' },
			{ input: 'c', output: 'ᯚ᯦', description: 'Mandailing keyboard - ca = sa+tompi' },
			{ input: 'v', output: '᯦', description: 'Mandailing keyboard - v = tompi' },
			{ input: 'b', output: 'ᯅ', description: 'Mandailing keyboard - ba' },
			{ input: 'n', output: 'ᯊ', description: 'Mandailing keyboard - na' },
			{ input: 'm', output: 'ᯔ', description: 'Mandailing keyboard - ma' },

			{ input: 'E', output: 'ᯧ', description: 'Mandailing keyboard - E - kebereten' },
			{ input: 'U', output: 'ᯥ', description: 'Mandailing keyboard - U - syllable "u"' },
			{ input: 'I', output: 'ᯤ', description: 'Mandailing keyboard - I - syllable "i"' },
			{ input: 'H', output: 'ᯱ', description: 'Mandailing keyboard - H - hajoringan "-h"' },
			{ input: 'Z', output: 'ᯰ', description: 'Mandailing keyboard - Z - amisara "-ng"' },

      { input: [ [ '4', true ] ], output: '᯼', description: 'Mandailing keyboard - alt-4 - bindu na metek' },
			{ input: [ [ '5', true ] ], output: '᯽', description: 'Mandailing keyboard - alt-5 - bindu pinarboras' },
			{ input: [ [ '6', true ] ], output: '᯾', description: 'Mandailing keyboard - alt-6 - bindu judul' },
			{ input: [ [ '7', true ] ], output: '᯿', description: 'Mandailing keyboard - alt-7 - bindu pangolat' }
		]
	},
	{
		description: 'Baoulé tilde test',
		inputmethod: 'bci-tilde',
		tests: [
			{ input: 'kl~o k~e', output: 'klɔ kɛ', description: 'Baoulé tilde - ~o, ~e -> ɔ, ɛ' },
			{ input: 'Djo~^', output: 'Djô', description: 'Baoulé tilde - o~^ -> ô' },
			{ input: '~e~/', output: 'ɛ́', description: 'Baoulé tilde - ~e~/ -> ɛ́' },
			{ input: '~N', output: 'Ɲ', description: 'Baoulé tilde - ~N -> Ɲ' }
		]
	},
	{
		description: 'Belarusian kbd keyboard test',
		inputmethod: 'be-kbd',
		tests: [
			{ input: '~!@#$%^&*()_+', output: 'Ё!"№;%:?*()_+', description: 'Belarusian kbd - numbers row shifted' },
			{ input: '`1234567890-=', output: 'ё1234567890-=', description: 'Belarusian kbd - numbers row not shifted' },
			{ input: 'QWERTYUIOP{}\\', output: 'ЙЦУКЕНГШЎЗХ\'\\', description: 'Belarusian kbd - QWERTY row shifted' },
			{ input: 'qwertyuiop[]\\', output: 'йцукенгшўзх\'\\', description: 'Belarusian kbd - qwerty row not shifted' },
			{ input: 'ASDFGHJKL:"', output: 'ФЫВАПРОЛДЖЭ', description: 'Belarusian kbd - ASDF row shifted' },
			{ input: 'asdfghjkl;\'', output: 'фывапролджэ', description: 'Belarusian kbd - asdf row not shifted' },
			{ input: 'ZXCVBNM<>?', output: 'ЯЧСМІТЬБЮ,', description: 'Belarusian kbd - ZXCV row shifted' },
			{ input: 'zxcvbnm,./', output: 'ячсмітьбю.', description: 'Belarusian kbd - zxcv row not shifted' }
		]
	},
	{
		description: 'Belarusian Łacinka test',
		inputmethod: 'be-latin',
		tests: [
			{ input: '=c', output: 'č', description: 'Belarusian Łacinka - =c -> č' },
			{ input: '-n', output: 'ń', description: 'Belarusian Łacinka - -n -> ń' },
			{ input: '=u', output: 'ŭ', description: 'Belarusian Łacinka - =u -> ŭ' },
			{ input: '-l', output: 'ł', description: 'Belarusian Łacinka - -l -> ł' }
		]
	},
	{
		description: 'Belarusian transliteration test',
		inputmethod: 'be-transliteration',
		tests: [
			{ input: '[];\',.`', output: 'х\'жэбюё', description: 'Belarusian transliteration - [];\',.` -> х\'жэбюё' },
			{ input: '{}:"<>~', output: 'Х\'ЖЭБЮЁ', description: 'Belarusian transliteration - {}:"<>~ -> Х\'ЖЭБЮЁ' }
		]
	},
	{
		description: 'Bari tilde test',
		inputmethod: 'bfa-tilde',
		tests: [
			{ input: '~N~n~O~o', output: 'ŊŋÖö', description: 'Bari tilde - ŊÖŋö' }
		]
	},
	{
		description: 'Western Baluchi Keyboard test',
		inputmethod: 'bgn-kbd',
		tests: [
			{ input: '`', output: '\u200c', description: 'Western Baluchi Keyboard Layout: ` -> \\u200c' },
			{ input: '1', output: '۱', description: 'Western Baluchi Keyboard Layout: 1 -> ١' },
			{ input: '2', output: '۲', description: 'Western Baluchi Keyboard Layout: 2 -> ٢' },
			{ input: '3', output: '۳', description: 'Western Baluchi Keyboard Layout: 3 -> ٣' },
			{ input: '4', output: '۴', description: 'Western Baluchi Keyboard Layout: 4 -> ۴' },
			{ input: '5', output: '۵', description: 'Western Baluchi Keyboard Layout: 5 -> ۵' },
			{ input: '6', output: '۶', description: 'Western Baluchi Keyboard Layout: 6 -> ۶' },
			{ input: '7', output: '۷', description: 'Western Baluchi Keyboard Layout: 7 -> ۷' },
			{ input: '8', output: '۸', description: 'Western Baluchi Keyboard Layout: 8 -> ۸' },
			{ input: '9', output: '۹', description: 'Western Baluchi Keyboard Layout: 9 -> ۹' },
			{ input: '0', output: '۰', description: 'Western Baluchi Keyboard Layout: 0 -> ۰' },

			{ input: 'q', output: 'ض', description: 'Western Baluchi Keyboard Layout: q -> ض' },
			{ input: 'w', output: 'ص', description: 'Western Baluchi Keyboard Layout: w -> ص' },
			{ input: 'e', output: 'ث', description: 'Western Baluchi Keyboard Layout: e -> ث' },
			{ input: 'r', output: 'ق', description: 'Western Baluchi Keyboard Layout: r -> ق' },
			{ input: 't', output: 'ف', description: 'Western Baluchi Keyboard Layout: t -> ف' },
			{ input: 'y', output: 'غ', description: 'Western Baluchi Keyboard Layout: y -> غ' },
			{ input: 'u', output: 'ع', description: 'Western Baluchi Keyboard Layout: u -> ع' },
			{ input: 'i', output: 'ه', description: 'Western Baluchi Keyboard Layout: i -> ه' },
			{ input: 'o', output: 'خ', description: 'Western Baluchi Keyboard Layout: o -> خ' },
			{ input: 'p', output: 'ح', description: 'Western Baluchi Keyboard Layout: p -> ح' },
			{ input: '[', output: 'ج', description: 'Western Baluchi Keyboard Layout: [ -> ج' },
			{ input: ']', output: 'چ', description: 'Western Baluchi Keyboard Layout: ] -> چ' },

			{ input: 'a', output: 'ش', description: 'Western Baluchi Keyboard Layout: a -> ش' },
			{ input: 's', output: 'س', description: 'Western Baluchi Keyboard Layout: s -> س' },
			{ input: 'd', output: 'ی', description: 'Western Baluchi Keyboard Layout: d -> ی' },
			{ input: 'f', output: 'ب', description: 'Western Baluchi Keyboard Layout: f -> ب' },
			{ input: 'g', output: 'ل', description: 'Western Baluchi Keyboard Layout: g -> ل' },
			{ input: 'h', output: 'ا', description: 'Western Baluchi Keyboard Layout: h -> ا' },
			{ input: 'j', output: 'ت', description: 'Western Baluchi Keyboard Layout: j -> ت' },
			{ input: 'k', output: 'ن', description: 'Western Baluchi Keyboard Layout: k -> ن' },
			{ input: 'l', output: 'م', description: 'Western Baluchi Keyboard Layout: l -> م' },
			{ input: ';', output: 'ک', description: 'Western Baluchi Keyboard Layout: ; -> ک' },
			{ input: '\'', output: 'گ', description: 'Western Baluchi Keyboard Layout: \' -> گ' },

			{ input: 'z', output: 'ظ', description: 'Western Baluchi Keyboard Layout: z -> ظ' },
			{ input: 'x', output: 'ط', description: 'Western Baluchi Keyboard Layout: x -> ط' },
			{ input: 'c', output: 'ز', description: 'Western Baluchi Keyboard Layout: c -> ز' },
			{ input: 'v', output: 'ر', description: 'Western Baluchi Keyboard Layout: v -> ر' },
			{ input: 'b', output: 'ڈ', description: 'Western Baluchi Keyboard Layout: b -> ڈ' },
			{ input: 'n', output: 'د', description: 'Western Baluchi Keyboard Layout: n -> د' },
			{ input: 'm', output: 'پ', description: 'Western Baluchi Keyboard Layout: m -> پ' },
			{ input: ',', output: 'و', description: 'Western Baluchi Keyboard Layout: , -> و' },

			{ input: '~', output: '÷', description: 'Western Baluchi Keyboard Layout: ~ -> ÷' },
			{ input: '@', output: '٬', description: 'Western Baluchi Keyboard Layout: @ -> ٬' },
			{ input: '#', output: '٫', description: 'Western Baluchi Keyboard Layout: # -> ٫' },
			{ input: '%', output: '٪', description: 'Western Baluchi Keyboard Layout: % -> ٪' },
			{ input: '^', output: '×', description: 'Western Baluchi Keyboard Layout: ^ -> ×' },
			{ input: '&', output: '،', description: 'Western Baluchi Keyboard Layout: & -> ،' },
			{ input: '(', output: ')', description: 'Western Baluchi Keyboard Layout: ( -> )' },
			{ input: ')', output: '(', description: 'Western Baluchi Keyboard Layout: ) -> (' },
			{ input: '_', output: 'ـ', description: 'Western Baluchi Keyboard Layout: _ -> ـ' },

			{ input: 'Q', output: 'ْ', description: 'Western Baluchi Keyboard Layout: Q -> ْ' },
			{ input: 'W', output: 'ٌ', description: 'Western Baluchi Keyboard Layout: W -> ٌ' },
			{ input: 'E', output: 'ٍ', description: 'Western Baluchi Keyboard Layout: E -> ٍ' },
			{ input: 'R', output: 'ً', description: 'Western Baluchi Keyboard Layout: R -> ً' },
			{ input: 'T', output: 'ُ', description: 'Western Baluchi Keyboard Layout: T -> ُ' },
			{ input: 'Y', output: 'ِ', description: 'Western Baluchi Keyboard Layout: Y -> ِ' },
			{ input: 'U', output: 'َ', description: 'Western Baluchi Keyboard Layout: U -> َ' },
			{ input: 'I', output: 'ّ', description: 'Western Baluchi Keyboard Layout: I -> ّ' },
			{ input: 'O', output: ']', description: 'Western Baluchi Keyboard Layout: O -> ]' },
			{ input: 'P', output: '[', description: 'Western Baluchi Keyboard Layout: P -> [' },
			{ input: '{', output: '}', description: 'Western Baluchi Keyboard Layout: { -> }' },
			{ input: '}', output: '{', description: 'Western Baluchi Keyboard Layout: } -> {' },

			{ input: 'A', output: 'ؤ', description: 'Western Baluchi Keyboard Layout: A -> ؤ' },
			{ input: 'S', output: 'ئ', description: 'Western Baluchi Keyboard Layout: S -> ئ' },
			{ input: 'D', output: 'ي', description: 'Western Baluchi Keyboard Layout: D -> ي' },
			{ input: 'F', output: 'إ', description: 'Western Baluchi Keyboard Layout: F -> إ' },
			{ input: 'G', output: 'أ', description: 'Western Baluchi Keyboard Layout: G -> أ' },
			{ input: 'H', output: 'آ', description: 'Western Baluchi Keyboard Layout: H -> آ' },
			{ input: 'J', output: 'ٹ', description: 'Western Baluchi Keyboard Layout: J -> ٹ' },
			{ input: 'K', output: '»', description: 'Western Baluchi Keyboard Layout: K -> »' },
			{ input: 'L', output: '«', description: 'Western Baluchi Keyboard Layout: L -> «' },
			{ input: '"', output: '؛', description: 'Western Baluchi Keyboard Layout: " -> ؛' },

			{ input: 'Z', output: 'ێ', description: 'Western Baluchi Keyboard Layout: Z -> ێ' },
			{ input: 'X', output: 'ط', description: 'Western Baluchi Keyboard Layout: X -> ط' },
			{ input: 'C', output: 'ژ', description: 'Western Baluchi Keyboard Layout: C -> ژ' },
			{ input: 'V', output: 'ڑ', description: 'Western Baluchi Keyboard Layout: V -> ڑ' },
			{ input: 'B', output: 'ۆ', description: 'Western Baluchi Keyboard Layout: B -> ۆ' },
			{ input: 'N', output: 'ٔ', description: 'Western Baluchi Keyboard Layout: N -> ٔ' },
			{ input: 'M', output: 'ء', description: 'Western Baluchi Keyboard Layout: M -> ء' },
			{ input: '<', output: '>', description: 'Western Baluchi Keyboard Layout: < -> >' },
			{ input: '>', output: '<', description: 'Western Baluchi Keyboard Layout: > -> <' },
			{ input: '?', output: '؟', description: 'Western Baluchi Keyboard Layout: ? -> ؟' }
		]
	},
	{
		description: 'Kom tilde test',
		inputmethod: 'bkm-tilde',
		tests: [
			{ input: 'nchwaes~i', output: 'nchwæsɨ', description: 'Kom tilde: nchwaes~i -> nchwæsɨ' },
			{ input: 'nchw~as~i', output: 'nchwæsɨ', description: 'Kom tilde: nchw~as~i -> nchwæsɨ' },
			{ input: 'NCHW~AS~I', output: 'NCHWÆSƗ', description: 'Kom tilde: NCHW~AS~I -> NCHWÆSƗ' },
			{ input: 'KAE', output: 'KÆ', description: 'Kom tilde: KAE -> KÆ' },
			{ input: 'KAe', output: 'KÆ', description: 'Kom tilde: KAe -> KÆ' },
			{ input: 'Refa~el', output: 'Refael', description: 'Kom tilde: Refael' },
			{ input: 'REFA~EL', output: 'REFAEL', description: 'Kom tilde: REFA~EL -> REFAEL' },
			{ input: 'A~eroflot', output: 'Aeroflot', description: 'Kom tilde: A~eroflot -> Aeroflot' },
			{ input: 'REFA~EL', output: 'REFAEL', description: 'Kom tilde: REFA~EL -> REFAEL' },

			{ input: 'ka~\\', output: 'kà', description: 'Kom tilde: ka~\\ -> kà' },
			{ input: 'KA~\\', output: 'KÀ', description: 'Kom tilde: KA~\\ -> KÀ' },
			{ input: 'lae~\\', output: 'læ̀', description: 'Kom tilde: lae~\\ -> læ̀' },
			{ input: 'l~a~\\', output: 'læ̀', description: 'Kom tilde: l~a~\\ -> læ̀' },
			{ input: 'LAE~\\', output: 'LÆ̀', description: 'Kom tilde: LAE~\\ -> LÆ̀' },
			{ input: 'ne~\\\'s~i~\\', output: 'nè\'sɨ̀', description: 'Kom tilde: ne~\\\'s~i~\\ -> nè\'sɨ̀' },
			{ input: 'ka~^~nt~i', output: 'kâŋtɨ', description: 'Kom tilde: ka~^~nt~i -> kâŋtɨ' },

			{ input: 'boes~i', output: 'bœsɨ', description: 'Kom tilde: boes~i -> bœsɨ' },
			{ input: 'b~os~i', output: 'bœsɨ', description: 'Kom tilde: b~os~i -> bœsɨ' },
			{ input: 'B~OS~I', output: 'BŒSƗ', description: 'Kom tilde: B~OS~I -> BŒSƗ' },
			{ input: '~IKOE', output: 'ƗKŒ', description: 'Kom tilde: A~eroflot -> ƗKŒ' },
			{ input: 'Oe', output: 'Œ', description: 'Kom tilde: Oe -> Œ' },
			{ input: 'O~ENO', output: 'OENO', description: 'Kom tilde: O~E -> OENO' },
			{ input: 'O~eno', output: 'Oeno', description: 'Kom tilde: O~e -> Oeno' },
			{ input: 'o~e', output: 'oe', description: 'Kom tilde: o~e -> oe' },

			{ input: 'ta~ni', output: 'taŋi', description: 'Kom tilde: ta~ni -> taŋi' },
			{ input: '~Neyn', output: 'Ŋeyn', description: 'Kom tilde: ~Neyn -> Ŋeyn' }
		]
	},
	{
		description: 'Bamanankan Alt layout test',
		inputmethod: 'bm-alt',
		tests: [
			{
				input: [
					[ 'N', true ],
					[ 'a', false ],
					[ 'h', true ],
					[ 'l', true ],
					[ 'a', false ],
					[ ' ', false ],
					[ 'a', true ],
					[ 'b', true ],
					[ ' ', true ],
					[ 't', false ],
					[ 'o', true ],
					[ 'h', true ],
					[ 'g', false ],
					[ 'o', true ],
					[ ' ', false ],
					[ 'N', false ],
					[ 'g', false ],
					[ 'a', false ],
					[ 'h', true ],
					[ 'l', false ],
					[ 'a', false ],
					[ ' ', false ],
					[ 'n', false ],
					[ 'i', false ],
					[ 'h', true ],
					[ ' ', false ],
					[ 't', false ],
					[ 'i', false ],
					[ 'b', true ],
					[ 'j', true ],
					[ 'e', false ]
				],
				output: 'Ŋála à tɔ́gɔ Ngála ní tìɲe',
				description: 'Bamanankan Alt - Ŋála à tɔ́gɔ Ngála ní tìɲe'
			},
			{
				input: [
					[ 'J', true ],
					[ 'h', true ],
					[ 'E', true ],
					[ 'H', true ],
					[ 'O', true ],
					[ 'B', true ]
				],
				output: 'Ɲ́Ɛ̂Ɔ̌',
				description: 'Bamanankan Alt - Ɲ́Ɛ̂Ɔ̌'
			}
		]
	},
	{
		description: 'Bamanankan tilde test',
		inputmethod: 'bm-tilde',
		tests: [
			{
				input: '~Ga~/la a~\\ t~o~/g~o Nga~/la ni~/ ti~\\~ne', output: 'Ŋála à tɔ́gɔ Ngála ní tìɲe', description: 'Bamanankan tilde - ~Ga~/la a~\\ t~o~/g~o Nga~/la ni~/ ti~\\~ne'
			},
			{
				input: '~N~/~E~^~O~v', output: 'Ɲ́Ɛ̂Ɔ̌', description: 'Bamanankan tilde - ~N~/~E~^~O~v'
			}
		]
	},
	{
		description: 'Bengali Avro layout test',
		inputmethod: 'bn-avro',
		tests: [
			{ input: 'ka', output: 'কা', description: 'Bengali Avro - ka' },
			{ input: 'rri', output: 'ঋ', description: 'Bengali Avro - rri' },
			{ input: 'drri', output: 'দৃ', description: 'Bengali Avro - drri' },
			{ input: 'kee', output: 'কী', description: 'Bengali Avro - kee' }
		]
	},
	{
		description: 'Bengali InScript test',
		inputmethod: 'bn-inscript',
		tests: [
			{ input: '1234567890', output: '১২৩৪৫৬৭৮৯০', description: 'Bengali InScript 1234567890' },
			{ input: 'k#', output: 'ক্র', description: 'Bengali InScript k#' },
			{ input: '$k', output: 'র্ক', description: 'Bengali InScript $k' },
			{ input: '%', output: 'জ্ঞ', description: 'Bengali InScript %' },
			{ input: '^', output: 'ত্র', description: 'Bengali InScript ^' },
			{ input: '&', output: 'ক্ষ', description: 'Bengali InScript &' },
			{ input: '*', output: 'শ্র', description: 'Bengali InScript *' },
			{ input: 'k_', output: 'কঃ', description: 'Bengali InScript k_' },
			{ input: '+', output: 'ঋ', description: 'Bengali InScript +' },
			{ input: 'QWERTYUIOP{}', output: 'ঔঐআঈঊভঙঘধঝঢঞ', description: 'Bengali InScript QWERTYIOP{}' },
			{ input: 'yq', output: 'বৌ', description: 'Bengali InScript yq' },
			{ input: 'uw', output: 'হৈ', description: 'Bengali InScript uw' },
			{ input: 'ie', output: 'গা', description: 'Bengali InScript ie' },
			{ input: 'or', output: 'দী', description: 'Bengali InScript or' },
			{ input: 'pt', output: 'জূ', description: 'Bengali InScript pt' },
			{ input: '[]', output: 'ড়', description: 'Bengali InScript ড়' },
			{ input: 'ASDFGHJKL:"', output: 'ওএঅইউফৎখথছঠ', description: 'Bengali InScript ASDFGHJKL:"' },
			{ input: 'ha', output: 'পো', description: 'Bengali InScript ha' },
			{ input: 'js', output: 'রে', description: 'Bengali InScript js' },
			{ input: 'kd', output: 'ক্', description: 'Bengali InScript kd' },
			{ input: 'lf', output: 'তি', description: 'Bengali InScript lf' },
			{ input: ';g', output: 'চু', description: 'Bengali InScript ;g' },
			{ input: '\'', output: 'ট', description: 'Bengali InScript \'' },
			{ input: 'cx', output: 'মং', description: 'Bengali InScript cx' },
			{ input: 'vnm', output: 'নলস', description: 'Bengali InScript vnm' },
			{ input: 'CX', output: 'ণঁ', description: 'Bengali InScript CX' },
			{ input: 'M<?', output: 'শষয', description: 'Bengali InScript M<?' }
		]
	},
	{
		description: 'Bengali InScript 2 test',
		inputmethod: 'bn-inscript2',
		tests: [
			{ input: '1234567890', output: '১২৩৪৫৬৭৮৯০', description: 'Bengali InScript 2 1234567890' },
			{ input: 'k#', output: 'ক্র', description: 'Bengali InScript 2 k#' },
			{ input: '$k', output: 'র্ক', description: 'Bengali InScript 2 $k' },
			{ input: '%', output: 'জ্ঞ', description: 'Bengali InScript 2 %' },
			{ input: '^', output: 'ত্র', description: 'Bengali InScript 2 ^' },
			{ input: '&', output: 'ক্ষ', description: 'Bengali InScript 2 &' },
			{ input: '*', output: 'শ্র', description: 'Bengali InScript 2 *' },
			{ input: 'k_', output: 'কঃ', description: 'Bengali InScript 2 k_' },
			{ input: '+', output: 'ঋ', description: 'Bengali InScript 2 +' },
			{ input: 'QWERTYUIOP{}', output: 'ঔঐআঈঊভঙঘধঝঢঞ', description: 'Bengali InScript 2 QWERTYIOP{}' },
			{ input: 'yq', output: 'বৌ', description: 'Bengali InScript 2 yq' },
			{ input: 'uw', output: 'হৈ', description: 'Bengali InScript 2 uw' },
			{ input: 'ie', output: 'গা', description: 'Bengali InScript 2 ie' },
			{ input: 'or', output: 'দী', description: 'Bengali InScript 2 or' },
			{ input: 'pt', output: 'জূ', description: 'Bengali InScript 2 pt' },
			{ input: '[]', output: 'ড়', description: 'Bengali InScript 2 []' },
			{ input: 'ASDFGHKL:"', output: 'ওএঅইউফখথছঠ', description: 'Bengali InScript 2 ASDFGHKL:"' },
			{ input: 'ha', output: 'পো', description: 'Bengali InScript 2 ha' },
			{ input: 'js', output: 'রে', description: 'Bengali InScript 2 js' },
			{ input: 'kd', output: 'ক্', description: 'Bengali InScript 2 kd' },
			{ input: 'lf', output: 'তি', description: 'Bengali InScript 2 lf' },
			// { input: 'l', output: 'ৎ', description: 'Bengali InScript 2 l' }, // TODO fix broken rule
			{ input: ';g', output: 'চু', description: 'Bengali InScript 2 ;g' },
			{ input: '\'', output: 'ট', description: 'Bengali InScript 2 \'' },
			{ input: 'cx', output: 'মং', description: 'Bengali InScript 2 cx' },
			{ input: 'vnm', output: 'নলস', description: 'Bengali InScript 2 vnm' },
			{ input: 'CX', output: 'ণঁ', description: 'Bengali InScript 2 CX' },
			{ input: 'M<?', output: 'শষয', description: 'Bengali InScript 2 M<?' }
		]
	},
	{
		description: 'Bengali Probhat layout test',
		inputmethod: 'bn-probhat',
		tests: [
			{ input: 'ka', output: 'কা', description: 'Bengali Probhat - ka' },
			{ input: 'ki', output: 'কি', description: 'Bengali Probhat - ki' },
			{ input: 'k/S', output: 'ক্ষ', description: 'Bengali Probhat - kha' },
			{ input: 'q<', output: 'দৃ', description: 'Bengali Probhat - drri' },
			{ input: 'r`/Z', output: 'র\u200d্য', description: 'Bengali Probhat - r`/Z - Testing RA-YAPHALA with ZWJ' },
			{ input: 'be', output: 'বী', description: 'Bengali Probhat - bee' }
		]
	},
	{
		description: 'Tibetan EWTS test',
		inputmethod: 'bo-ewts',
		tests: [
			{ input: 'brgyud', output: 'བརྒྱུད', description: 'Tibetan EWTS - brgyud' },
			{ input: 'brlab', output: 'བརླབ', description: 'Tibetan EWTS - brlab' },
			{ input: 'r-I', output: 'ཨྲཱྀ', description: 'Tibetan EWTS - r-I' },
			{ input: 'br-I', output: 'བྲཱྀ', description: 'Tibetan EWTS - br-I' },
			{ input: 'b+k+Sha', output: 'བྐྵ', description: 'Tibetan EWTS - b+k+Sha' },
			{ input: 'br-i', output: 'བྲྀ', description: 'Tibetan EWTS - br-i' },
			{ input: 'g.yak', output: 'གཡཀ', description: 'Tibetan EWTS - g.yak' },
			{ input: 'pad+ma', output: 'པདྨ', description: 'Tibetan EWTS - pad+ma' },
			{ input: 'bau', output: 'བཽ', description: 'Tibetan EWTS - bau' }
		]
	},
	{
		description: 'Tibetan Sambhota Keyboard test',
		inputmethod: 'bo-sambhota',
		tests: [
			{ input: 'bfrgyud', output: 'བརྒྱུད', description: 'Tibetan Sambhota - brgyud' },
			{ input: 'fAr\'I', output: 'ཨྲཱྀ', description: 'Tibetan Sambhota - fAr\'I' },
			{ input: 'fbkBa', output: 'བྐྵ', description: 'Tibetan Sambhota - fbkBa' },
			{ input: 'gyak', output: 'གཡཀ', description: 'Tibetan Sambhota - gyak' },
			{ input: 'pafdma', output: 'པདྨ', description: 'Tibetan Sambhota - pafdma' }
		]
	},
	{
		description: 'Bole tilde test',
		inputmethod: 'bol-tilde',
		tests: [
			{ input: '~B', output: 'Ɓ', description: 'Bole tilde ~B -> Ɓ' },
			{ input: '~b', output: 'ɓ', description: 'Bole tilde ~b -> ɓ' },
			{ input: '~D', output: 'Ɗ', description: 'Bole tilde ~D -> Ɗ' },
			{ input: '~d', output: 'ɗ', description: 'Bole tilde ~d -> ɗ' },
			{ input: 'E~\\', output: 'È', description: 'Bole tilde E~\\ -> È' },
			{ input: 'i~^', output: 'î', description: 'Bole tilde i~^ -> î' },
			{ input: 'o~-', output: 'ō', description: 'Bole tilde o~- -> ō' },
			{ input: 'a~v', output: 'ǎ', description: 'Bole tilde a~v -> ǎ' }
		]
	},
	{
		description: 'Berom tilde test',
		inputmethod: 'bom-tilde',
		tests: [
			{ input: '~E', output: 'Ɛ', description: 'Berom tilde ~E -> Ɛ' },
			{ input: '~e', output: 'ɛ', description: 'Berom tilde ~e -> ɛ' },
			{ input: '~O', output: 'Ɔ', description: 'Berom tilde ~O -> Ɔ' },
			{ input: '~o~\\', output: 'ɔ̀', description: 'Berom tilde ~o~\\ -> ɔ̀' },
			{ input: '~e~/', output: 'ɛ́', description: 'Berom tilde ~e~/ -> ɛ́' },
			{ input: 'o~^', output: 'ô', description: 'Berom tilde o~^ -> ô' },
			{ input: 'i~v', output: 'ǐ', description: 'Berom tilde i~v -> ǐ' }
		]
	},
	{
		description: 'Bodo InScript 2 test',
		inputmethod: 'brx-inscript2',
		tests: [
			{ input: '1234567890', output: '१२३४५६७८९०', description: 'Bodo InScript 2 1234567890' },
			{ input: '%', output: 'ज्ञ', description: 'Bodo InScript 2 %' },
			{ input: '^', output: 'त्र', description: 'Bodo InScript 2 ^' },
			{ input: '&', output: 'क्ष', description: 'Bodo InScript 2 &' },
			{ input: '*', output: 'श्र', description: 'Bodo InScript 2 *' },
			{ input: '+', output: 'ऋ', description: 'Bodo InScript 2 +' },
			{ input: 'QWERTYUIOP{}', output: 'औऐआईऊभङघधझढञ', description: 'Bodo InScript 2 QWERTYIOP{}' },
			{ input: 'yq', output: 'बौ', description: 'Bodo InScript 2 yq' },
			{ input: 'uw', output: 'है', description: 'Bodo InScript 2 uw' },
			{ input: 'ie', output: 'गा', description: 'Bodo InScript 2 ie' },
			{ input: 'or', output: 'दी', description: 'Bodo InScript 2 or' },
			{ input: 'pt', output: 'जू', description: 'Bodo InScript 2 pt' },
			// { input: '[]', output: 'ड़', description: 'Bodo InScript 2 []' }, // TODO fix broken rule
			{ input: 'ASDFGHKL:"', output: 'ओएअइउफखथछठ', description: 'Bodo InScript 2 ASDFGHKL:"' },
			{ input: 'ha', output: 'पो', description: 'Bodo InScript 2 ha' },
			{ input: 'js', output: 'रे', description: 'Bodo InScript 2 js' },
			{ input: 'kd', output: 'क्', description: 'Bodo InScript 2 kd' },
			{ input: 'lf', output: 'ति', description: 'Bodo InScript 2 lf' },
			{ input: ';\'', output: 'चट', description: 'Bodo InScript 2 ;\'' },
			{ input: 'CM<>?', output: 'णशष।?', description: 'Bodo InScript 2 CM<>?' },
			{ input: ';X', output: 'चँ', description: 'Bodo InScript 2 ;X' },
			{ input: 'z', output: 'ʼ', description: 'Bodo InScript 2 z' },
			{ input: 'mx', output: 'सं', description: 'Bodo InScript 2 mx' },
			{ input: 'cvb', output: 'मनव', description: 'Bodo InScript 2 cvb' },
			{ input: '/', output: 'य', description: 'Bodo InScript 2 /' }
		]
	},
	{
		description: 'Bura tilde test',
		inputmethod: 'bwr-tilde',
		tests: [
			{ input: '~B~D~E~K~b~d~e~k', output: 'ƁƊƏƘɓɗəƙ', description: 'Bura tilde ƁƊƏƘɓɗəƙ' }
		]
	},
	{
		description: 'Blin GeezIM test',
		inputmethod: 'byn-geezim',
		tests: [
			{ input: 'hie', output: 'ሄ', description: 'Blin hie -> ሄ' },
			{ input: 'lie', output: 'ሌ', description: 'Blin lie -> ሌ' },
			{ input: 'Hie', output: 'ሔ', description: 'Blin Hie -> ሔ' },
			{ input: 'mie', output: 'ሜ', description: 'Blin Hie -> ሜ' },
			{ input: 'arAaya', output: 'ኣርኣያ', description: 'Blin arAaya -> ኣርኣያ' },
			{ input: 'gua', output: 'ጓ', description: 'Blin gua -> ጓ' },
			{ input: 'gue', output: 'ጐ', description: 'Blin gue -> ጐ' },
			{ input: 'gui', output: 'ጒ', description: 'Blin gui -> ጒ' },
			{ input: 'guie', output: 'ጔ', description: 'Blin guie -> ጔ' },
			{ input: 'gW', output: 'ጕ', description: 'Blin gW -> ጕ' },
			{ input: 'Gui', output: 'ⶔ', description: 'Blin Gui -> ⶔ' },
			{ input: 'Guie', output: 'ⶕ', description: 'Blin Guie -> ⶕ' },
			{ input: 'GW', output: 'ⶖ', description: 'Blin GW -> ⶖ' },
			{ input: '.', output: '።', description: 'Blin . -> ።' },
			{ input: '..', output: '.', description: 'Blin .. -> .' },
			{ input: '.-', output: '፨', description: 'Blin .- -> ፨' },
			{ input: ';;', output: '።', description: 'Blin ;; -> ።' },
			{ input: 'Ge', output: 'ጘ', description: 'Blin Ge -> ጘ' },
			{ input: 'Gi', output: 'ጚ', description: 'Blin Gi -> ጚ' }
		]
	},
	{
		description: 'Chinook Jargon tilde test',
		inputmethod: 'chn-tilde',
		tests: [
			{ input: '~E~e~H~h~L~l~X~x~?~\'', output: 'ƏəʰʰꞭɬX̣x̣ʔ’', description: 'Chinook Jargon ƏəʰʰꞭɬX̣x̣ʔ’' }
		]
	},
	{
		description: 'Cherokee transliteration test',
		inputmethod: 'chr',
		tests: [
			{ input: 'nah\'na', output: 'ᏀᎾ', description: 'Cherokee nah\'na -> ᏀᎾ' },
			{ input: 'na\'hna', output: 'ᎾᎿ', description: 'Cherokee na\'hna -> ᎾᎿ' },
			{ input: 'naha', output: 'ᏀᎠ', description: 'Cherokee naha -> ᏀᎠ' },
			{ input: 'nah\'a', output: 'ᏀᎠ', description: 'Cherokee nah\'a -> ᏀᎠ' },
			{ input: 'na\'ha', output: 'ᎾᎭ', description: 'Cherokee na\'ha -> ᎾᎭ' },
			{ input: 'nahe', output: 'ᏀᎡ', description: 'Cherokee nahe -> ᏀᎡ' },
			{ input: 'nah\'e', output: 'ᏀᎡ', description: 'Cherokee nah\'e -> ᏀᎡ' },
			{ input: 'na\'he', output: 'ᎾᎮ', description: 'Cherokee na\'he -> ᎾᎮ' },
			{ input: 'nas\'iya', output: 'ᎾᏍᎢᏯ', description: 'Cherokee nas\'iya -> ᎾᏍᎢᏯ' },
			{ input: 'nasiya', output: 'ᎾᏏᏯ', description: 'nasiya -> ᎾᏏᏯ' },
			{ input: 'tsi', output: 'Ꮵ', description: 'Cherokee tsi -> Ꮵ' },
			{ input: 'tla', output: 'Ꮭ', description: 'Cherokee tla -> Ꮭ' },
			{ input: 'dla', output: 'Ꮬ', description: 'Cherokee dla -> Ꮬ' },
			{ input: 'itsalis\'anedi', output: 'ᎢᏣᎵᏍᎠᏁᏗ', description: 'Cherokee itsalis\'anedi -> ᎢᏣᎵᏍᎠᏁᏗ' },
			{ input: 'uligiyus\'anvne', output: 'ᎤᎵᎩᏳᏍᎠᏅᏁ', description: 'Cherokee uligiyus\'anvne -> ᎤᎵᎩᏳᏍᎠᏅᏁ' },
			{ input: 'uniyes\'iyi', output: 'ᎤᏂᏰᏍᎢᏱ', description: 'Cherokee uniyesiyi -> ᎾᏍᎢᏯ ' },
			{ input: 'aseno', output: 'ᎠᏎᏃ', description: 'Cherokee aseno -> ᎠᏎᏃ' },
			{ input: 'as\'eno', output: 'ᎠᏍᎡᏃ', description: 'Cherokee as\'eno -> ᎠᏍᎡᏃ' },
			{ input: 'gesvi', output: 'ᎨᏒᎢ', description: 'Cherokee gesvi -> ᎨᏒᎢ' },
			{ input: 'ges\'vi', output: 'ᎨᏍᎥᎢ', description: 'Cherokee ges\'vi -> ᎨᏍᎥᎢ' },
			{ input: 'qua', output: 'Ꮖ', description: 'Cherokee qua -> Ꮖ' },
			{ input: 'quequiquoquuquv', output: 'ᏇᏈᏉᏊᏋ', description: 'Cherokee quequiquoquuquv -> ᏇᏈᏉᏊᏋ' },
			{ input: 'tsatsetsitsotsutsv', output: 'ᏣᏤᏥᏦᏧᏨ', description: 'Cherokee tsatsetsitsotsutsv -> ᏣᏤᏥᏦᏧᏨ' },
			{ input: 'sasesisosusvs\'', output: 'ᏌᏎᏏᏐᏑᏒᏍ', description: 'Cherokee sasesisosusvs\' -> ᏌᏎᏏᏐᏑᏒᏍ' },
			{ input: 'wawewiwowuwv', output: 'ᏩᏪᏫᏬᏭᏮ', description: 'Cherokee wawewiwowuwv -> ᏩᏪᏫᏬᏭᏮ' },
			{ input: 'dadedidodudvtateti', output: 'ᏓᏕᏗᏙᏚᏛᏔᏖᏘ', description: 'Cherokee dadedidodudvtateti -> ᏓᏕᏗᏙᏚᏛᏔᏖᏘ' },
			{ input: 'yayeyiyoyuyv', output: 'ᏯᏰᏱᏲᏳᏴ', description: 'Cherokee yayeyiyoyuyv -> ᏯᏰᏱᏲᏳᏴ' },
			{ input: 'mamemimomumv', output: 'ᎹᎺᎻᎼᎽᏵ', description: 'Cherokee mamemimomumv -> ᎹᎺᎻᎼᎽᏵ' },
			{ input: 'lalelilolulv', output: 'ᎳᎴᎵᎶᎷᎸ', description: 'Cherokee lalelilolulv -> ᎳᎴᎵᎶᎷᎸ' },
			{ input: 'dlatlatletlitlotlutlv', output: 'ᏜᏝᏞᏟᏠᏡᏢ', description: 'Cherokee dlatlatletlitlotlutlv -> ᏜᏝᏞᏟᏠᏡᏢ' },
			{ input: 'hahehihohuhv', output: 'ᎭᎮᎯᎰᎱᎲ', description: 'Cherokee hahehihohuhv -> ᎭᎮᎯᎰᎱᎲ' },
			{ input: 'gakagegigogugv', output: 'ᎦᎧᎨᎩᎪᎫᎬ', description: 'Cherokee gakagegigogugv -> ᎦᎧᎨᎩᎪᎫᎬ' }
		]
	},
	{
		description: 'Central Kurdish keyboard based on Arabic keyboard test',
		inputmethod: 'ckb-transliteration-arkbd',
		tests: [
			{ input: '`', output: 'ژ', description: 'Central Kurdish keyboard based on Arabic: ` -> ژ' },
			{ input: '1', output: '١', description: 'Central Kurdish keyboard based on Arabic: 1 -> ١' },
			{ input: '2', output: '٢', description: 'Central Kurdish keyboard based on Arabic: 2 -> ٢' },
			{ input: '3', output: '٣', description: 'Central Kurdish keyboard based on Arabic: 3 -> ٣' },
			{ input: '4', output: '٤', description: 'Central Kurdish keyboard based on Arabic: 4 -> ٤' },
			{ input: '5', output: '٥', description: 'Central Kurdish keyboard based on Arabic: 5 -> ٥' },
			{ input: '6', output: '٦', description: 'Central Kurdish keyboard based on Arabic: 6 -> ٦' },
			{ input: '7', output: '٧', description: 'Central Kurdish keyboard based on Arabic: 7 -> ٧' },
			{ input: '8', output: '٨', description: 'Central Kurdish keyboard based on Arabic: 8 -> ٨' },
			{ input: '9', output: '٩', description: 'Central Kurdish keyboard based on Arabic: 9 -> ٩' },
			{ input: '0', output: '٠', description: 'Central Kurdish keyboard based on Arabic: 0 -> ٠' },

			{ input: 'q', output: 'چ', description: 'Central Kurdish keyboard based on Arabic: q -> چ' },
			{ input: 'w', output: 'ص', description: 'Central Kurdish keyboard based on Arabic: w -> ص' },
			{ input: 'e', output: 'پ', description: 'Central Kurdish keyboard based on Arabic: e -> پ' },
			{ input: 'r', output: 'ق', description: 'Central Kurdish keyboard based on Arabic: r -> ق' },
			{ input: 't', output: 'ف', description: 'Central Kurdish keyboard based on Arabic: t -> ف' },
			{ input: 'y', output: 'غ', description: 'Central Kurdish keyboard based on Arabic: y -> غ' },
			{ input: 'u', output: 'ع', description: 'Central Kurdish keyboard based on Arabic: u -> ع' },
			{ input: 'i', output: 'ھ', description: 'Central Kurdish keyboard based on Arabic: i -> ھ' },
			{ input: 'o', output: 'خ', description: 'Central Kurdish keyboard based on Arabic: o -> خ' },
			{ input: 'p', output: 'ح', description: 'Central Kurdish keyboard based on Arabic: p -> ح' },
			{ input: '[', output: 'ج', description: 'Central Kurdish keyboard based on Arabic: [ -> ج' },
			{ input: ']', output: 'د', description: 'Central Kurdish keyboard based on Arabic: ] -> د' },

			{ input: 'a', output: 'ش', description: 'Central Kurdish keyboard based on Arabic: a -> ش' },
			{ input: 's', output: 'س', description: 'Central Kurdish keyboard based on Arabic: s -> س' },
			{ input: 'd', output: 'ی', description: 'Central Kurdish keyboard based on Arabic: d -> ی' },
			{ input: 'f', output: 'ب', description: 'Central Kurdish keyboard based on Arabic: f -> ب' },
			{ input: 'g', output: 'ل', description: 'Central Kurdish keyboard based on Arabic: g -> ل' },
			{ input: 'h', output: 'ا', description: 'Central Kurdish keyboard based on Arabic: h -> ا' },
			{ input: 'j', output: 'ت', description: 'Central Kurdish keyboard based on Arabic: j -> ت' },
			{ input: 'k', output: 'ن', description: 'Central Kurdish keyboard based on Arabic: k -> ن' },
			{ input: 'l', output: 'م', description: 'Central Kurdish keyboard based on Arabic: l -> م' },
			{ input: ';', output: 'ک', description: 'Central Kurdish keyboard based on Arabic: ; -> ک' },
			{ input: '\'', output: 'گ', description: 'Central Kurdish keyboard based on Arabic: \' -> گ' },

			{ input: 'z', output: 'ئ', description: 'Central Kurdish keyboard based on Arabic: z -> ئ' },
			{ input: 'x', output: 'ء', description: 'Central Kurdish keyboard based on Arabic: x -> ء' },
			{ input: 'c', output: 'ۆ', description: 'Central Kurdish keyboard based on Arabic: c -> ۆ' },
			{ input: 'v', output: 'ر', description: 'Central Kurdish keyboard based on Arabic: v -> ر' },
			{ input: 'b', output: 'لا', description: 'Central Kurdish keyboard based on Arabic: b -> لا' },
			{ input: 'n', output: 'ى', description: 'Central Kurdish keyboard based on Arabic: n -> ى' },
			{ input: 'm', output: 'ە', description: 'Central Kurdish keyboard based on Arabic: m -> ە' },
			{ input: ',', output: 'و', description: 'Central Kurdish keyboard based on Arabic: , -> و' },
			{ input: '.', output: 'ز', description: 'Central Kurdish keyboard based on Arabic: . -> ز' },

			{ input: '%', output: '٪', description: 'Central Kurdish keyboard based on Arabic: % -> ٪' },
			{ input: '(', output: ')', description: 'Central Kurdish keyboard based on Arabic: ( -> )' },
			{ input: ')', output: '(', description: 'Central Kurdish keyboard based on Arabic: ) -> (' },

			{ input: 'Q', output: 'ض', description: 'Central Kurdish keyboard based on Arabic: Q -> ض' },
			{ input: 'W', output: '}', description: 'Central Kurdish keyboard based on Arabic: W -> }' },
			{ input: 'E', output: 'ث', description: 'Central Kurdish keyboard based on Arabic: E -> ث' },
			{ input: 'R', output: '{', description: 'Central Kurdish keyboard based on Arabic: R -> {' },
			{ input: 'T', output: 'ڤ', description: 'Central Kurdish keyboard based on Arabic: T -> ڤ' },
			{ input: 'Y', output: 'إ', description: 'Central Kurdish keyboard based on Arabic: Y -> إ' },
			{ input: 'U', output: 'ۊ', description: 'Central Kurdish keyboard based on Arabic: U -> ۊ' },
			{ input: 'I', output: '\'', description: 'Central Kurdish keyboard based on Arabic: I -> \'' },
			{ input: 'O', output: '"', description: 'Central Kurdish keyboard based on Arabic: O -> "' },
			{ input: 'P', output: '؛', description: 'Central Kurdish keyboard based on Arabic: P -> ؛' },
			{ input: '{', output: '>', description: 'Central Kurdish keyboard based on Arabic: { -> >' },
			{ input: '}', output: '<', description: 'Central Kurdish keyboard based on Arabic: } -> <' },

			{ input: 'A', output: '[', description: 'Central Kurdish keyboard based on Arabic: A -> [' },
			{ input: 'S', output: ']', description: 'Central Kurdish keyboard based on Arabic: S -> ]' },
			{ input: 'D', output: 'ێ', description: 'Central Kurdish keyboard based on Arabic: D -> ێ' },
			{ input: 'F', output: '', description: 'Central Kurdish keyboard based on Arabic: F -> ' },
			{ input: 'G', output: 'ڵ', description: 'Central Kurdish keyboard based on Arabic: G -> ڵ' },
			{ input: 'H', output: 'أ', description: 'Central Kurdish keyboard based on Arabic: H -> أ' },
			{ input: 'J', output: 'ـ', description: 'Central Kurdish keyboard based on Arabic: J -> ـ' },
			{ input: 'K', output: '،', description: 'Central Kurdish keyboard based on Arabic: K -> ،' },
			{ input: 'L', output: '\\', description: 'Central Kurdish keyboard based on Arabic: L -> \\' },
			{ input: '"', output: 'ط', description: 'Central Kurdish keyboard based on Arabic: " -> ط' },

			{ input: 'Z', output: 'ڎ', description: 'Central Kurdish keyboard based on Arabic: Z -> ڎ' },
			{ input: 'X', output: 'وو', description: 'Central Kurdish keyboard based on Arabic: X -> وو' },
			{ input: 'C', output: 'ؤ', description: 'Central Kurdish keyboard based on Arabic: C -> ؤ' },
			{ input: 'V', output: 'ڕ', description: 'Central Kurdish keyboard based on Arabic: V -> ڕ' },
			{ input: 'B', output: 'ڵا', description: 'Central Kurdish keyboard based on Arabic: B -> ڵا' },
			{ input: 'N', output: 'آ', description: 'Central Kurdish keyboard based on Arabic: N -> آ' },
			{ input: 'M', output: 'ة', description: 'Central Kurdish keyboard based on Arabic: M -> ة' },
			{ input: '<', output: '٫', description: 'Central Kurdish keyboard based on Arabic: < -> ٫' },
			{ input: '>', output: '.', description: 'Central Kurdish keyboard based on Arabic: > -> .' },
			{ input: '?', output: '؟', description: 'Central Kurdish keyboard based on Arabic: ? -> ؟' }
		]
	},
	{
		description: 'Central Kurdish keyboard based on Persian keyboard test',
		inputmethod: 'ckb-transliteration-fakbd',
		tests: [
			{ input: '`', output: 'پ', description: 'Central Kurdish keyboard based on Persian: ` -> پ' },
			{ input: '1', output: '١', description: 'Central Kurdish keyboard based on Persian: 1 -> ١' },
			{ input: '2', output: '٢', description: 'Central Kurdish keyboard based on Persian: 2 -> ٢' },
			{ input: '3', output: '٣', description: 'Central Kurdish keyboard based on Persian: 3 -> ٣' },
			{ input: '4', output: '٤', description: 'Central Kurdish keyboard based on Persian: 4 -> ٤' },
			{ input: '5', output: '٥', description: 'Central Kurdish keyboard based on Persian: 5 -> ٥' },
			{ input: '6', output: '٦', description: 'Central Kurdish keyboard based on Persian: 6 -> ٦' },
			{ input: '7', output: '٧', description: 'Central Kurdish keyboard based on Persian: 7 -> ٧' },
			{ input: '8', output: '٨', description: 'Central Kurdish keyboard based on Persian: 8 -> ٨' },
			{ input: '9', output: '٩', description: 'Central Kurdish keyboard based on Persian: 9 -> ٩' },
			{ input: '0', output: '٠', description: 'Central Kurdish keyboard based on Persian: 0 -> ٠' },

			{ input: 'q', output: 'ڵ', description: 'Central Kurdish keyboard based on Persian: q -> ڵ' },
			{ input: 'w', output: 'ۆ', description: 'Central Kurdish keyboard based on Persian: w -> ۆ' },
			{ input: 'e', output: 'ێ', description: 'Central Kurdish keyboard based on Persian: e -> ێ' },
			{ input: 'r', output: 'ق', description: 'Central Kurdish keyboard based on Persian: r -> ق' },
			{ input: 't', output: 'ف', description: 'Central Kurdish keyboard based on Persian: t -> ف' },
			{ input: 'y', output: 'غ', description: 'Central Kurdish keyboard based on Persian: y -> غ' },
			{ input: 'u', output: 'ع', description: 'Central Kurdish keyboard based on Persian: u -> ع' },
			{ input: 'i', output: 'ە', description: 'Central Kurdish keyboard based on Persian: i -> ە' },
			{ input: 'o', output: 'خ', description: 'Central Kurdish keyboard based on Persian: o -> خ' },
			{ input: 'p', output: 'ح', description: 'Central Kurdish keyboard based on Persian: p -> ح' },
			{ input: '[', output: 'ج', description: 'Central Kurdish keyboard based on Persian: [ -> ج' },
			{ input: ']', output: 'چ', description: 'Central Kurdish keyboard based on Persian: ] -> چ' },
			{ input: '\\', output: 'ژ', description: 'Central Kurdish keyboard based on Persian: \\ -> ژ' },

			{ input: 'a', output: 'ش', description: 'Central Kurdish keyboard based on Persian: a -> ش' },
			{ input: 's', output: 'س', description: 'Central Kurdish keyboard based on Persian: s -> س' },
			{ input: 'd', output: 'ی', description: 'Central Kurdish keyboard based on Persian: d -> ی' },
			{ input: 'f', output: 'ب', description: 'Central Kurdish keyboard based on Persian: f -> ب' },
			{ input: 'g', output: 'ل', description: 'Central Kurdish keyboard based on Persian: g -> ل' },
			{ input: 'h', output: 'ا', description: 'Central Kurdish keyboard based on Persian: h -> ا' },
			{ input: 'j', output: 'ت', description: 'Central Kurdish keyboard based on Persian: j -> ت' },
			{ input: 'k', output: 'ن', description: 'Central Kurdish keyboard based on Persian: k -> ن' },
			{ input: 'l', output: 'م', description: 'Central Kurdish keyboard based on Persian: l -> م' },
			{ input: ';', output: 'ک', description: 'Central Kurdish keyboard based on Persian: ; -> ک' },
			{ input: '\'', output: 'گ', description: 'Central Kurdish keyboard based on Persian: \' -> گ' },

			{ input: 'z', output: 'ڤ', description: 'Central Kurdish keyboard based on Persian: z -> ڤ' },
			{ input: 'x', output: 'ھ', description: 'Central Kurdish keyboard based on Persian: x -> ھ' },
			{ input: 'c', output: 'ز', description: 'Central Kurdish keyboard based on Persian: c -> ز' },
			{ input: 'v', output: 'ر', description: 'Central Kurdish keyboard based on Persian: v -> ر' },
			{ input: 'b', output: 'ڕ', description: 'Central Kurdish keyboard based on Persian: b -> ڕ' },
			{ input: 'n', output: 'د', description: 'Central Kurdish keyboard based on Persian: n -> د' },
			{ input: 'm', output: 'ئ', description: 'Central Kurdish keyboard based on Persian: m -> ئ' },
			{ input: ',', output: 'و', description: 'Central Kurdish keyboard based on Persian: , -> و' },
			{ input: '.', output: '.', description: 'Central Kurdish keyboard based on Persian: . -> .' },
			{ input: '/', output: '/', description: 'Central Kurdish keyboard based on Persian: / -> /' },

			{ input: '%', output: '٪', description: 'Central Kurdish keyboard based on Persian: % -> ٪' },
			{ input: '(', output: ')', description: 'Central Kurdish keyboard based on Persian: ( -> )' },
			{ input: ')', output: '(', description: 'Central Kurdish keyboard based on Persian: ) -> (' },

			{ input: 'Q', output: 'ض', description: 'Central Kurdish keyboard based on Persian: Q -> ض' },
			{ input: 'W', output: 'ص', description: 'Central Kurdish keyboard based on Persian: W -> ص' },
			{ input: 'E', output: 'ث', description: 'Central Kurdish keyboard based on Persian: E -> ث' },
			{ input: 'R', output: 'ك', description: 'Central Kurdish keyboard based on Persian: R -> ك' },
			{ input: 'T', output: '،', description: 'Central Kurdish keyboard based on Persian: T -> ،' },
			{ input: 'Y', output: '؛', description: 'Central Kurdish keyboard based on Persian: Y -> ؛' },
			{ input: 'U', output: '\\', description: 'Central Kurdish keyboard based on Persian: U -> \\' },
			{ input: 'I', output: ']', description: 'Central Kurdish keyboard based on Persian: I -> ]' },
			{ input: 'O', output: '[', description: 'Central Kurdish keyboard based on Persian: O -> [' },
			{ input: 'P', output: '\'', description: 'Central Kurdish keyboard based on Persian: P -> \'' },
			{ input: '{', output: '}', description: 'Central Kurdish keyboard based on Persian: { -> }' },
			{ input: '}', output: '{', description: 'Central Kurdish keyboard based on Persian: } -> {' },

			{ input: 'A', output: 'ڎ', description: 'Central Kurdish keyboard based on Persian: A -> ڎ' },
			{ input: 'S', output: 'إ', description: 'Central Kurdish keyboard based on Persian: S -> إ' },
			{ input: 'D', output: 'ي', description: 'Central Kurdish keyboard based on Persian: D -> ي' },
			{ input: 'F', output: 'ة', description: 'Central Kurdish keyboard based on Persian: F -> ة' },
			{ input: 'G', output: 'ۀ', description: 'Central Kurdish keyboard based on Persian: G -> ۀ' },
			{ input: 'H', output: 'آ', description: 'Central Kurdish keyboard based on Persian: H -> آ' },
			{ input: 'J', output: 'ـ', description: 'Central Kurdish keyboard based on Persian: J -> ـ' },
			{ input: 'K', output: '»', description: 'Central Kurdish keyboard based on Persian: K -> »' },
			{ input: 'L', output: '«', description: 'Central Kurdish keyboard based on Persian: L -> «' },

			{ input: 'Z', output: 'ظ', description: 'Central Kurdish keyboard based on Persian: Z -> ظ' },
			{ input: 'X', output: 'ط', description: 'Central Kurdish keyboard based on Persian: X -> ط' },
			{ input: 'C', output: 'ژ', description: 'Central Kurdish keyboard based on Persian: C -> ژ' },
			{ input: 'V', output: 'ؤ', description: 'Central Kurdish keyboard based on Persian: V -> ؤ' },
			{ input: 'B', output: 'ذ', description: 'Central Kurdish keyboard based on Persian: B -> ذ' },
			{ input: 'N', output: '\u200cأ', description: 'Central Kurdish keyboard based on Persian: N -> \u200cأ' },
			{ input: 'M', output: 'ء', description: 'Central Kurdish keyboard based on Persian: M -> ء' },
			{ input: '<', output: '>', description: 'Central Kurdish keyboard based on Persian: < -> >' },
			{ input: '>', output: '<', description: 'Central Kurdish keyboard based on Persian: > -> <' },
			{ input: '?', output: '؟', description: 'Central Kurdish keyboard based on Persian: ? -> ؟' }
		]
	},
	{
		description: 'Central Kurdish keyboard based on Latin keyboard test',
		inputmethod: 'ckb-transliteration-lakbd',
		tests: [
			{ input: '1', output: '١', description: 'Central Kurdish keyboard based on Latin: 1 -> ١' },
			{ input: '2', output: '٢', description: 'Central Kurdish keyboard based on Latin: 2 -> ٢' },
			{ input: '3', output: '٣', description: 'Central Kurdish keyboard based on Latin: 3 -> ٣' },
			{ input: '4', output: '٤', description: 'Central Kurdish keyboard based on Latin: 4 -> ٤' },
			{ input: '5', output: '٥', description: 'Central Kurdish keyboard based on Latin: 5 -> ٥' },
			{ input: '6', output: '٦', description: 'Central Kurdish keyboard based on Latin: 6 -> ٦' },
			{ input: '7', output: '٧', description: 'Central Kurdish keyboard based on Latin: 7 -> ٧' },
			{ input: '8', output: '٨', description: 'Central Kurdish keyboard based on Latin: 8 -> ٨' },
			{ input: '9', output: '٩', description: 'Central Kurdish keyboard based on Latin: 9 -> ٩' },
			{ input: '0', output: '٠', description: 'Central Kurdish keyboard based on Latin: 0 -> ٠' },

			{ input: 'q', output: 'ق', description: 'Central Kurdish keyboard based on Latin: q -> ق' },
			{ input: 'w', output: 'و', description: 'Central Kurdish keyboard based on Latin: w -> و' },
			{ input: 'e', output: 'ە', description: 'Central Kurdish keyboard based on Latin: e -> ە' },
			{ input: 'r', output: 'ر', description: 'Central Kurdish keyboard based on Latin: r -> ر' },
			{ input: 't', output: 'ت', description: 'Central Kurdish keyboard based on Latin: t -> ت' },
			{ input: 'y', output: 'ی', description: 'Central Kurdish keyboard based on Latin: y -> ی' },
			{ input: 'u', output: 'ئ', description: 'Central Kurdish keyboard based on Latin: u -> ئ' },
			{ input: 'i', output: 'ح', description: 'Central Kurdish keyboard based on Latin: i -> ح' },
			{ input: 'o', output: 'ۆ', description: 'Central Kurdish keyboard based on Latin: o -> ۆ' },
			{ input: 'p', output: 'پ', description: 'Central Kurdish keyboard based on Latin: p -> پ' },
			{ input: '[', output: ']', description: 'Central Kurdish keyboard based on Latin: [ -> ]' },
			{ input: ']', output: '[', description: 'Central Kurdish keyboard based on Latin: ] -> [' },

			{ input: 'a', output: 'ا', description: 'Central Kurdish keyboard based on Latin: a -> ا' },
			{ input: 's', output: 'س', description: 'Central Kurdish keyboard based on Latin: s -> س' },
			{ input: 'd', output: 'د', description: 'Central Kurdish keyboard based on Latin: d -> د' },
			{ input: 'f', output: 'ف', description: 'Central Kurdish keyboard based on Latin: f -> ف' },
			{ input: 'g', output: 'گ', description: 'Central Kurdish keyboard based on Latin: g -> گ' },
			{ input: 'h', output: 'ھ', description: 'Central Kurdish keyboard based on Latin: h -> ھ' },
			{ input: 'j', output: 'ژ', description: 'Central Kurdish keyboard based on Latin: j -> ژ' },
			{ input: 'k', output: 'ک', description: 'Central Kurdish keyboard based on Latin: k -> ک' },
			{ input: 'l', output: 'ل', description: 'Central Kurdish keyboard based on Latin: l -> ل' },
			{ input: ';', output: '؛', description: 'Central Kurdish keyboard based on Latin: ; -> ؛' },

			{ input: 'z', output: 'ز', description: 'Central Kurdish keyboard based on Latin: z -> ز' },
			{ input: 'x', output: 'خ', description: 'Central Kurdish keyboard based on Latin: x -> خ' },
			{ input: 'c', output: 'ج', description: 'Central Kurdish keyboard based on Latin: c -> ج' },
			{ input: 'v', output: 'ڤ', description: 'Central Kurdish keyboard based on Latin: v -> ڤ' },
			{ input: 'b', output: 'ب', description: 'Central Kurdish keyboard based on Latin: b -> ب' },
			{ input: 'n', output: 'ن', description: 'Central Kurdish keyboard based on Latin: n -> ن' },
			{ input: 'm', output: 'م', description: 'Central Kurdish keyboard based on Latin: m -> م' },
			{ input: ',', output: '،', description: 'Central Kurdish keyboard based on Latin: , -> ،' },
			{ input: '.', output: '.', description: 'Central Kurdish keyboard based on Latin: . -> .' },

			{ input: '%', output: '٪', description: 'Central Kurdish keyboard based on Latin: % -> ٪' },
			{ input: '(', output: ')', description: 'Central Kurdish keyboard based on Latin: ( -> )' },
			{ input: ')', output: '(', description: 'Central Kurdish keyboard based on Latin: ) -> (' },

			{ input: 'Q', output: 'ڎ', description: 'Central Kurdish keyboard based on Latin: Q -> ڎ' },
			{ input: 'W', output: 'وو', description: 'Central Kurdish keyboard based on Latin: W -> وو' },
			{ input: 'E', output: 'ێ', description: 'Central Kurdish keyboard based on Latin: E -> ێ' },
			{ input: 'R', output: 'ڕ', description: 'Central Kurdish keyboard based on Latin: R -> ڕ' },
			{ input: 'T', output: 'ط', description: 'Central Kurdish keyboard based on Latin: T -> ط' },
			{ input: 'Y', output: 'ي', description: 'Central Kurdish keyboard based on Latin: Y -> ي' },
			{ input: 'U', output: 'ء', description: 'Central Kurdish keyboard based on Latin: U -> ء' },
			{ input: 'I', output: 'ع', description: 'Central Kurdish keyboard based on Latin: I -> ع' },
			{ input: 'O', output: 'ؤ', description: 'Central Kurdish keyboard based on Latin: O -> ؤ' },
			{ input: 'P', output: 'ث', description: 'Central Kurdish keyboard based on Latin: P -> ث' },
			{ input: '{', output: '}', description: 'Central Kurdish keyboard based on Latin: { -> }' },
			{ input: '}', output: '{', description: 'Central Kurdish keyboard based on Latin: } -> {' },

			{ input: 'A', output: 'آ', description: 'Central Kurdish keyboard based on Latin: A -> آ' },
			{ input: 'S', output: 'ش', description: 'Central Kurdish keyboard based on Latin: S -> ش' },
			{ input: 'D', output: 'ذ', description: 'Central Kurdish keyboard based on Latin: D -> ذ' },
			{ input: 'F', output: 'إ', description: 'Central Kurdish keyboard based on Latin: F -> إ' },
			{ input: 'G', output: 'غ', description: 'Central Kurdish keyboard based on Latin: G -> غ' },
			{ input: 'H', output: 'ه', description: 'Central Kurdish keyboard based on Latin: H -> ه' },
			{ input: 'J', output: 'أ', description: 'Central Kurdish keyboard based on Latin: J -> أ' },
			{ input: 'K', output: 'ك', description: 'Central Kurdish keyboard based on Latin: K -> ك' },
			{ input: 'L', output: 'ڵ', description: 'Central Kurdish keyboard based on Latin: L -> ڵ' },

			{ input: 'Z', output: 'ض', description: 'Central Kurdish keyboard based on Latin: Z -> ض' },
			{ input: 'X', output: 'ص', description: 'Central Kurdish keyboard based on Latin: X -> ص' },
			{ input: 'C', output: 'چ', description: 'Central Kurdish keyboard based on Latin: C -> چ' },
			{ input: 'V', output: 'ظ', description: 'Central Kurdish keyboard based on Latin: V -> ظ' },
			{ input: 'B', output: 'ى', description: 'Central Kurdish keyboard based on Latin: B -> ى' },
			{ input: 'N', output: 'ة', description: 'Central Kurdish keyboard based on Latin: N -> ة' },
			{ input: 'M', output: 'ـ', description: 'Central Kurdish keyboard based on Latin: M -> ـ' },
			{ input: '<', output: '>', description: 'Central Kurdish keyboard based on Latin: < -> >' },
			{ input: '>', output: '<', description: 'Central Kurdish keyboard based on Latin: > -> <' },
			{ input: '?', output: '؟', description: 'Central Kurdish keyboard based on Latin: ? -> ؟' }
		]
	},
	{
		description: 'Chuvash (AltGr) with jcuken',
		inputmethod: 'cv-cyr-altgr',
		tests: [
			{ input: [ [ 'а', true ] ], output: 'ӑ', description: 'Alt + a (Cyrillic) -> a breve (Cyrillic), lower case' },
			{ input: [ [ 'А', true ] ], output: 'Ӑ', description: 'Alt + А (Cyrillic) -> A breve (Cyrillic), upper case' },
			{ input: [ [ 'е', true ] ], output: 'ӗ', description: 'Alt + е (Cyrillic) -> e breve (Cyrillic), lower case' },
			{ input: [ [ 'Е', true ] ], output: 'Ӗ', description: 'Alt + Е (Cyrillic) -> E breve (Cyrillic), upper case' },
			{ input: [ [ 'с', true ] ], output: 'ҫ', description: 'Alt + с (Cyrillic) -> с cedilla (Cyrillic), lower case' },
			{ input: [ [ 'С', true ] ], output: 'Ҫ', description: 'Alt + С (Cyrillic) -> C cedilla (Cyrillic), upper case' },
			{ input: [ [ 'у', true ] ], output: 'ӳ', description: 'Alt + у (Cyrillic) -> ue (Cyrillic), lower case' },
			{ input: [ [ 'У', true ] ], output: 'Ӳ', description: 'Alt + У (Cyrillic) -> Ue (Cyrillic), upper case' }
		]
	},
	{
		description: 'Chuvash (AltGr) with qwerty (en-US)',
		inputmethod: 'cv-cyr-altgr',
		tests: [
			{ input: [ [ 'f', true ] ], output: 'ӑ', description: 'Alt + f -> a breve (Cyrillic), lower case' },
			{ input: [ [ 'F', true ] ], output: 'Ӑ', description: 'Alt + F -> A breve (Cyrillic), upper case' },
			{ input: [ [ 't', true ] ], output: 'ӗ', description: 'Alt + t -> e breve (Cyrillic), lower case' },
			{ input: [ [ 'T', true ] ], output: 'Ӗ', description: 'Alt + T -> E breve (Cyrillic), upper case' },
			{ input: [ [ 'c', true ] ], output: 'ҫ', description: 'Alt + c (Latin) -> с cedilla (Cyrillic), lower case' },
			{ input: [ [ 'C', true ] ], output: 'Ҫ', description: 'Alt + C (Latin) -> C cedilla (Cyrillic), upper case' },
			{ input: [ [ 'e', true ] ], output: 'ӳ', description: 'Alt + e (Latin) -> ue (Cyrillic), lower case' },
			{ input: [ [ 'E', true ] ], output: 'Ӳ', description: 'Alt + E (Latin) -> Ue (Cyrillic), upper case' }
		]
	},
	{
		description: 'Chuvash (Number based) with qwerty (en-US)',
		inputmethod: 'cv-cyr-numbers',
		tests: [
			{ input: '1', output: '?', description: '1 -> ?' },
			{ input: '2', output: '\'', description: '2 -> \', simple quote' },
			{ input: '@', output: '"', description: '@ (shift + 2) -> ", double quote' },
			{ input: '3', output: 'ҫ', description: '3 -> c cedilla (Cyrillic), lower case' },
			{ input: '#', output: 'Ҫ', description: '# (shift + 3) -> C cedilla (Cyrillic), upper case case' },
			{ input: '4', output: '|', description: '4 -> | (for Wikipedia edits)' },
			{ input: '$', output: ';', description: '$ (shift + 4) -> semicolon (;) as in standard Russian' },
			{ input: '5', output: 'ӳ', description: '5 -> ue (Cyrillic), upper case' },
			{ input: '%', output: 'Ӳ', description: '% (shift + 5) -> Ue (Cyrillic), upper case' },
			{ input: '6', output: '—', description: '6 -> — (em dash)' },
			{ input: '^', output: ':', description: '^ (shift + 6) -> : (colon) as in standard Russian' },
			{ input: '7', output: 'ӗ', description: '7 -> e breve (Cyrillic), lower case' },
			{ input: '&', output: 'Ӗ', description: '& (shift + 7) -> E breve (Cyrillic), upper case' },
			{ input: '8', output: 'ӑ', description: '8 -> a breve (Cyrillic), lower case' },
			{ input: '*', output: 'Ӑ', description: '* (shift + 8) -> A breve (Cyrillic), upper case' },
			{ input: '9', output: '[', description: '9 -> [ (wiki format links)' },
			{ input: '0', output: ']', description: '0 -> [ (wiki format links)' }
		]
	},
	{
		description: 'Chuvash (Number based) with jcuken',
		inputmethod: 'cv-cyr-numbers',
		tests: [
			{ input: '1', output: '?', description: '1 -> ?' },
			{ input: '2', output: '\'', description: '2 -> \', simple quote' },
			{ input: '3', output: 'ҫ', description: '3 -> c cedilla (Cyrillic), lower case' },
			{ input: '№', output: 'Ҫ', description: '№ (shift + 3) -> C cedilla (Cyrillic), upper case case' },
			{ input: '4', output: '|', description: '4 -> | (for Wikipedia edits)' },
			{ input: '5', output: 'ӳ', description: '5 -> ue (Cyrillic), upper case' },
			{ input: '%', output: 'Ӳ', description: '% (shift + 5) -> Ue (Cyrillic), upper case' },
			{ input: '6', output: '—', description: '6 -> — (em dash)' },
			{ input: '7', output: 'ӗ', description: '7 -> e breve (Cyrillic), lower case' },
			// For now ? doesn't work. I should have context and know if Shift is pressed.
			// It only appears in jcuken scenario instead of E breve you'll get a comma
			// { input: '?', output: 'Ӗ', description: '? (shift + 7) -> E breve (Cyrillic), upper case' },
			{ input: '8', output: 'ӑ', description: '8 -> a breve (Cyrillic), lower case' },
			{ input: '*', output: 'Ӑ', description: '* (shift + 8) -> A breve (Cyrillic), upper case' },
			{ input: '9', output: '[', description: '9 -> [ (wiki format links)' },
			{ input: '0', output: ']', description: '0 -> [ (wiki format links)' }
		]
	},
	{
		description: 'Chuvash (Mercen): CVLat with qwerty (en-US)',
		inputmethod: 'cv-lat-altgr',
		tests: [
			{ input: [ [ 'a', true ] ], output: 'ă', description: 'Alt + a -> a breve, lower case' },
			{ input: [ [ 'A', true ] ], output: 'Ă', description: 'Alt + A -> A breve, upper case' },
			{ input: [ [ 's', true ] ], output: 'ş', description: 'Alt + s -> s cedilla, lower case' },
			{ input: [ [ 'S', true ] ], output: 'Ş', description: 'Alt + S -> S cedilla, upper case' },
			{ input: [ [ 'd', true ] ], output: 'š', description: 'Alt + d -> s caron, lower case' },
			{ input: [ [ 'D', true ] ], output: 'Š', description: 'Alt + D -> S caron , upper case' },
			{ input: [ [ 'e', true ] ], output: 'ĕ', description: 'Alt + e -> e breve, lower case' },
			{ input: [ [ 'E', true ] ], output: 'Ĕ', description: 'Alt + E -> E breve, upper case' },
			{ input: [ [ 'u', true ] ], output: 'ü', description: 'Alt + u -> ue, lower case' },
			{ input: [ [ 'U', true ] ], output: 'Ü', description: 'Alt + U -> Ue, upper case' },
			{ input: [ [ 'w', true ] ], output: 'ü', description: 'Alt + w -> ue, lower case' },
			{ input: [ [ 'W', true ] ], output: 'Ü', description: 'Alt + W -> Ue, upper case' }
		]
	},
	{
		description: 'Cyrillic with palochka transliteration test',
		inputmethod: 'cyrl-palochka',
		tests: [
			{ input: palochkaVariants.palochka, output: palochkaVariants.palochka, description: 'Palochka itself is unchanged' },

			{ input: 'L', output: 'L', description: 'Latin capital L is unchanged' },
			{ input: palochkaVariants.latinSmallL, output: palochkaVariants.palochka, description: 'Latin small l becomes palochka' },

			{ input: palochkaVariants.latinCapitalI, output: palochkaVariants.palochka, description: 'Latin capital I becomes palochka' },
			{ input: 'i', output: 'i', description: 'Latin small i is unchanged' },

			{ input: palochkaVariants.ukrainianCapitalI, output: palochkaVariants.palochka, description: 'Ukrainian capital І becomes palochka' },

			{ input: palochkaVariants.digitOne, output: palochkaVariants.digitOne, description: 'Digit one (1) is unchanged' },
			{ input: [ [ palochkaVariants.digitOne, true ] ], output: palochkaVariants.palochka, description: 'Extended digit one (1) becomes palochka' },

			{ input: 'Мях~1ячкъала', output: 'МяхӀячкъала', description: 'Tilde 1 produces palochka' },
			{ input: '~~100', output: '~100', description: 'Two tildes and 1 produce ~1 and not palochka' },
			{ input: '~~~~', output: '~~~~', description: 'Four tildes are unchanged' },

			{ input: 'д', output: 'д', description: 'Cyrillic small д is is unchanged' },
			{ input: [ [ 'д', true ] ], output: palochkaVariants.palochka, description: 'Extended Cyrillic д becomes palochka' },

			{ input: 'ш', output: 'ш', description: 'Cyrillic small ш is is unchanged' },
			{ input: [ [ 'ш', true ] ], output: palochkaVariants.palochka, description: 'Extended Cyrillic small ш becomes palochka' },

			{ input: 'Ш', output: 'Ш', description: 'Cyrillic capital Ш is is unchanged' },
			{ input: [ [ 'Ш', true ] ], output: palochkaVariants.palochka, description: 'Extended Cyrillic capital Ш becomes palochka' }
		]
	},
	/* XXX Disabled. For some reason it fails in contenteditable.
	{
		description: 'Dagbani Alt layout test',
		inputmethod: 'dag-alt',
		tests: [
			{
				input: [
					[ 'K', false ],
					[ 'p', false ],
					[ 'a', false ],
					[ 'g', true ],
					[ 'u', false ],
					[ 'z', true ],
					[ 'i', false ],
					[ 'e', true ],
					[ 'g', true ],
					[ 'u', false ],
					[ ' ', false ],
					[ 'z', true ],
					[ 'i', false ],
					[ ' ', false ],
					[ 'n', true ],
					[ 'o', true ],
					[ ' ', false ],
					[ 'n', false ],
					[ 'y', false ],
					[ 'e', true ],
					[ 'l', false ],
					[ 'a', false ]
				],
				output: 'Kpaɣuʒiɛɣu ʒi ŋɔ nyɛla',
				description: 'Dagbani Alt - Kpaɣuʒiɛɣu ʒi ŋɔ nyɛla'
			},
			{
				input: [
					[ 'y', false ],
					[ 'y', true ],
					[ 'Y', false ],
					[ 'Y', true ]
				],
				output: 'yɣYƔ',
				description: 'Dagbani Alt - yɣYƔ'
			}
		]
	},
	*/
	{
		description: 'Dagbani tilde test',
		inputmethod: 'dag-tilde',
		tests: [
			{ input: 'Kpa~gu~zi~e~yu ~Zi ~no ny~ela', output: 'Kpaɣuʒiɛɣu Ʒi ŋo nyɛla', description: 'Dagbani tilde Kpa~gu~zi~e~yu ~Zi ~no nyela' }
		]
	},
	{
		description: 'Dendi tilde test',
		inputmethod: 'ddn-tilde',
		tests: [
			{ input: '~E', output: 'Ɛ', description: 'Dendi ~E -> Ɛ' },
			{ input: '~e', output: 'ɛ', description: 'Dendi ~e -> ɛ' },
			{ input: '~N', output: 'Ŋ', description: 'Dendi ~N -> Ŋ' },
			{ input: '~n', output: 'ŋ', description: 'Dendi ~n -> ŋ' },
			{ input: '~O', output: 'Ɔ', description: 'Dendi ~O -> Ɔ' },
			{ input: '~o~\\', output: 'ɔ̀', description: 'Dendi ~o~\\ -> ɔ̀' },
			{ input: '~e~/', output: 'ɛ́', description: 'Dendi ~e~/ -> ɛ́' },
			{ input: 'u~-', output: 'ū', description: 'Dendi u~- -> ū' }
		]
	},
	{
		description: 'German Transliteration and keybuffer test',
		inputmethod: 'de-transliteration',
		tests: [
			{ input: '~o', output: 'ö', description: 'German ö' },
			{ input: '~O', output: 'Ö', description: 'German Ö' },
			{ input: '~s', output: 'ß', description: 'German ß' }
		]
	},
	{
		description: 'Dinka din-fqsx input method test',
		inputmethod: 'din-fqsx',
		tests: [
			{ input: 'ufu', output: 'uɣu', description: 'Dinka uɣu' },
			{ input: 'aqa', output: 'aŋa', description: 'Dinka aŋa' },
			{ input: 'ese', output: 'eɛe', description: 'Dinka eɛe' },
			{ input: 'oxo', output: 'oɔo', description: 'Dinka oɔo' },
			{ input: 'UFU', output: 'UƔU', description: 'Dinka UƔU' },
			{ input: 'AQA', output: 'AŊA', description: 'Dinka AŊA' },
			{ input: 'ESE', output: 'EƐE', description: 'Dinka EƐE' },
			{ input: 'OXO', output: 'OƆO', description: 'Dinka OƆO' },
			{ input: 'ka;k', output: 'käk', description: 'Dinka käk' },
			{ input: 'pe;p', output: 'pëp', description: 'Dinka pëp' },
			{ input: 'ds;d', output: 'dɛ̈d', description: 'Dinka dɛ̈d' },
			{ input: 'ki;k', output: 'kïk', description: 'Dinka kïk' },
			{ input: 'to;t', output: 'töt', description: 'Dinka töt' },
			{ input: 'rx;r', output: 'rɔ̈r', description: 'Dinka rɔ̈r' },
			{ input: 'code\\;', output: 'code;', description: 'Dinka code;' },
			{ input: 'C:\\\\File\\s', output: 'C:\\Files', description: 'Dinka C:\\Files' },
			{ input: '\\Fa\\f', output: 'Faf', description: 'Dinka Faf' },
			{ input: '\\Qu\\q', output: 'Quq', description: 'Dinka Quq' },
			{ input: '\\So\\s', output: 'Sos', description: 'Dinka Sos' },
			{ input: '\\Xi\\x', output: 'Xix', description: 'Dinka Xix' }
		]
	},
	{
		description: 'Dinka tilde input method test',
		inputmethod: 'din-tilde',
		tests: [
			{ input: 'a~:', output: 'ä', description: 'Dinka tilde a~:' },
			{ input: 'e~:', output: 'ë', description: 'Dinka tilde e~:' },
			{ input: '~e', output: 'ɛ', description: 'Dinka tilde ~e' },
			{ input: '~e~:', output: 'ɛ̈', description: 'Dinka tilde ~e~:' },
			{ input: '~g', output: 'ɣ', description: 'Dinka tilde ~g' },
			{ input: 'i~:', output: 'ï', description: 'Dinka tilde i~:' },
			{ input: '~n', output: 'ŋ', description: 'Dinka tilde ~n' },
			{ input: 'o~:', output: 'ö', description: 'Dinka tilde o~:' },
			{ input: '~o', output: 'ɔ', description: 'Dinka tilde ~o' },
			{ input: '~o~:', output: 'ɔ̈', description: 'Dinka tilde ~o~:' }
		]
	},
	{
		description: 'Dogri InScript 2 test',
		inputmethod: 'doi-inscript2',
		tests: [
			{ input: '1234567890', output: '१२३४५६७८९०', description: 'Dogri InScript 2 1234567890' },
			{ input: '%', output: 'ज्ञ', description: 'Dogri InScript 2 %' },
			{ input: '^', output: 'त्र', description: 'Dogri InScript 2 ^' },
			{ input: '&', output: 'क्ष', description: 'Dogri InScript 2 &' },
			{ input: '*', output: 'श्र', description: 'Dogri InScript 2 *' },
			{ input: 'k_', output: 'कः', description: 'Dogri InScript 2 k_' },
			{ input: '+', output: 'ऋ', description: 'Dogri InScript 2 +' },
			{ input: 'QWERTYUIOP{}', output: 'औऐआईऊभङघधझढञ', description: 'Dogri InScript 2 QWERTYIOP{}' },
			// { input: 'yq', output: 'बौ', description: 'Dogri InScript 2 yq' }, // TODO fix broken rule
			{ input: 'uw', output: 'है', description: 'Dogri InScript 2 uw' },
			{ input: 'ie', output: 'गा', description: 'Dogri InScript 2 ie' },
			{ input: 'or', output: 'दी', description: 'Dogri InScript 2 or' },
			{ input: 'pt', output: 'जू', description: 'Dogri InScript 2 pt' },
			// { input: '[]', output: 'ड़', description: 'Dogri InScript 2 []' }, // TODO fix broken rule
			{ input: 'ASDFGHKL:"', output: 'ओएअइउफखथछठ', description: 'Dogri InScript 2 ASDFGHKL:"' },
			// { input: 'J', output: 'ऱ', description: 'Dogri InScript 2 J' }, // TODO fix missing rule
			{ input: 'ha', output: 'पो', description: 'Dogri InScript 2 ha' },
			{ input: 'js', output: 'रे', description: 'Dogri InScript 2 js' },
			{ input: 'kd', output: 'क्', description: 'Dogri InScript 2 kd' },
			{ input: 'lf', output: 'ति', description: 'Dogri InScript 2 lf' },
			{ input: ';\'', output: 'चट', description: 'Dogri InScript 2 ;\'' },
			{ input: 'CM<>?', output: 'णशष।?', description: 'Dogri InScript 2 CM<>?' },
			{ input: ';X', output: 'चँ', description: 'Dogri InScript 2 ;X' },
			{ input: 'z', output: 'ʼ', description: 'Dogri InScript 2 z' },
			// { input: 'mx', output: 'सं', description: 'Dogri InScript 2 mx' }, // TODO fix missing rule
			{ input: 'cvb', output: 'मनव', description: 'Dogri InScript 2 cvb' },
			{ input: '/', output: 'य', description: 'Dogri InScript 2 /' }
		]
	},
	{
		description: 'Ewe tilde test',
		inputmethod: 'ee-tilde',
		tests: [
			{ input: '~D', output: 'Ɖ', description: 'Ewe ~D -> Ɖ' },
			{ input: '~d', output: 'ɖ', description: 'Ewe ~d -> ɖ' },
			{ input: '~E', output: 'Ɛ', description: 'Ewe ~E -> Ɛ' },
			{ input: '~e', output: 'ɛ', description: 'Ewe ~e -> ɛ' },
			{ input: '~F', output: 'Ƒ', description: 'Ewe ~F -> Ƒ' },
			{ input: '~f', output: 'ƒ', description: 'Ewe ~f -> ƒ' },
			{ input: '~G', output: 'Ɣ', description: 'Ewe ~G -> Ɣ' },
			{ input: '~g', output: 'ɣ', description: 'Ewe ~g -> ɣ' },
			{ input: '~N', output: 'Ŋ', description: 'Ewe ~N -> Ŋ' },
			{ input: '~n', output: 'ŋ', description: 'Ewe ~n -> ŋ' },
			{ input: '~O', output: 'Ɔ', description: 'Ewe ~O -> Ɔ' },
			{ input: '~o', output: 'ɔ', description: 'Ewe ~o -> ɔ' },
			{ input: '~V', output: 'Ʋ', description: 'Ewe ~V -> Ʋ' },
			{ input: '~v', output: 'ʋ', description: 'Ewe ~v -> ʋ' },
			{ input: '~~~~', output: '~~~~', description: 'Ewe ~~~~ -> ~~~~' },
			{ input: '~e~-', output: 'ɛ̄', description: 'Ewe ~e~- -> ɛ̄' },
			{ input: 'mi~/', output: 'mí', description: 'Ewe mi~/ -> mí' },
			{ input: 'wo~\\', output: 'wò', description: 'Ewe wo~\\ -> wò' },
			{ input: '~E~{', output: 'Ɛ̃', description: 'Ewe ~E~{ -> Ɛ̃' },
			{ input: 'to~^', output: 'tǒ', description: 'Ewe to~^ -> tǒ' }
		]
	},
	{
		description: 'Efik tilde test',
		inputmethod: 'efi-tilde',
		tests: [
			{ input: '~E', output: 'Ẹ', description: 'Efik tilde ~E -> Ẹ' },
			{ input: '~e', output: 'ẹ', description: 'Efik tilde ~e -> ẹ' },
			{ input: '~I', output: 'Ị', description: 'Efik tilde ~I -> Ị' },
			{ input: '~i', output: 'ị', description: 'Efik tilde ~i -> ị' },
			{ input: '~N', output: 'N̄', description: 'Efik tilde ~N -> N̄' },
			{ input: '~n', output: 'n̄', description: 'Efik tilde ~n -> n̄' },
			{ input: '~O', output: 'Ọ', description: 'Efik tilde ~O -> Ọ' },
			{ input: '~o', output: 'ọ', description: 'Efik tilde ~o -> ọ' },
			{ input: '~U', output: 'Ụ', description: 'Efik tilde ~U -> Ụ' },
			{ input: '~u', output: 'ụ', description: 'Efik tilde ~u -> ụ' },
			{ input: 'E~\\', output: 'È', description: 'Efik tilde E~\\ -> È' },
			{ input: 'i~/', output: 'í', description: 'Efik tilde i~/ -> í' }
		]
	},
	{
		description: 'Ekpeye tilde test',
		inputmethod: 'ekp-tilde',
		tests: [
			{ input: '~E', output: 'Ẹ', description: 'Ekpeye tilde ~E -> Ẹ' },
			{ input: '~e', output: 'ẹ', description: 'Ekpeye tilde ~e -> ẹ' },
			{ input: '~I', output: 'Ị', description: 'Ekpeye tilde ~I -> Ị' },
			{ input: '~i', output: 'ị', description: 'Ekpeye tilde ~i -> ị' },
			{ input: '~O', output: 'Ọ', description: 'Ekpeye tilde ~O -> Ọ' },
			{ input: '~o', output: 'ọ', description: 'Ekpeye tilde ~o -> ọ' },
			{ input: '~U', output: 'Ụ', description: 'Ekpeye tilde ~U -> Ụ' },
			{ input: 'E~\\', output: 'È', description: 'Ekpeye tilde E~\\ -> È' },
			{ input: 'i~^', output: 'î', description: 'Ekpeye tilde i~^ -> î' },
			{ input: 'o~-', output: 'ō', description: 'Ekpeye tilde o~- -> ō' }
		]
	},
	{
		description: 'Modern Greek Std Kbd test',
		inputmethod: 'el-kbd',
		tests: [
			{ input: 'S', output: 'Σ', description: 'S to Sigma' },
			{ input: 's', output: 'σ', description: 's to sigma' },
			{ input: 'W', output: 'Σ', description: 'W to Sigma' },
			{ input: 'w', output: 'ς', description: 'w to final sigma' },
			{ input: 'U', output: 'Θ', description: 'U to Theta' },
			{ input: 'u', output: 'θ', description: 'U to theta' },
			{ input: 'c', output: 'ψ', description: 'c to psi' },
			{ input: 'v', output: 'ω', description: 'v to omega' },
			{ input: 'Q', output: ':', description: 'q to colon' },
			{ input: 'q', output: ';', description: 'q to Greek question mark' },
			{ input: ':', output: '¨', description: ': to diaresis' },
			{ input: ';', output: '΄', description: '; to tonos/oxia' },
			{ input: '΄h', output: 'ή', description: 'combo to precomposed' },
			{ input: '¨I', output: 'Ϊ', description: 'combo to precomposed' },
			{ input: '¨΄i', output: 'ΐ', description: 'multi combo to precomposed' },
			{ input: '΄¨y', output: 'ΰ', description: 'reverse multi combo to precomposed' }
		]
	},
	{
		description: 'Esperanto x-sistemo test',
		inputmethod: 'eo-x',
		tests: [
			{ input: 'cx', output: 'ĉ', description: 'Esperanto cx' },
			{ input: 'gx', output: 'ĝ', description: 'Esperanto gx' },
			{ input: 'hx', output: 'ĥ', description: 'Esperanto hx' },
			{ input: 'jx', output: 'ĵ', description: 'Esperanto jx' },
			{ input: 'sx', output: 'ŝ', description: 'Esperanto sx' },
			{ input: 'ux', output: 'ŭ', description: 'Esperanto ux' },
			{ input: 'cxx', output: 'cx', description: 'Esperanto cxx' },
			{ input: 'gxx', output: 'gx', description: 'Esperanto gxx' },
			{ input: 'hxx', output: 'hx', description: 'Esperanto hxx' },
			{ input: 'jxx', output: 'jx', description: 'Esperanto jxx' },
			{ input: 'sxx', output: 'sx', description: 'Esperanto sxx' },
			{ input: 'uxx', output: 'ux', description: 'Esperanto uxx' },
			{ input: 'CX', output: 'Ĉ', description: 'Esperanto CX' },
			{ input: 'GX', output: 'Ĝ', description: 'Esperanto GX' },
			{ input: 'HX', output: 'Ĥ', description: 'Esperanto HX' },
			{ input: 'JX', output: 'Ĵ', description: 'Esperanto JX' },
			{ input: 'SX', output: 'Ŝ', description: 'Esperanto SX' },
			{ input: 'UX', output: 'Ŭ', description: 'Esperanto UX' },
			{ input: 'CXX', output: 'CX', description: 'Esperanto CXX' },
			{ input: 'GXX', output: 'GX', description: 'Esperanto GXX' },
			{ input: 'HXX', output: 'HX', description: 'Esperanto HXX' },
			{ input: 'JXX', output: 'JX', description: 'Esperanto JXX' },
			{ input: 'SXX', output: 'SX', description: 'Esperanto SXX' },
			{ input: 'UXX', output: 'UX', description: 'Esperanto UXX' },
			{
				input: 'ehxosxangxo cxiujxauxde',
				output: 'eĥoŝanĝo ĉiuĵaŭde',
				description: 'Esperanto eĥoŝanĝo ĉiuĵaŭde'
			}
		]
	},
	{
		description: 'Persian Standard keyboard test',
		inputmethod: 'fa-kbd',
		tests: [
			{ input: '`', output: '\u200d', description: 'Persian Standard keyboard - ` -> ZWJ' },
			{ input: '1', output: '۱', description: 'Persian Standard keyboard - 1 -> ۱' },
			{ input: '2', output: '۲', description: 'Persian Standard keyboard - 2 -> ۲' },
			{ input: '3', output: '۳', description: 'Persian Standard keyboard - 3 -> ۳' },
			{ input: '4', output: '۴', description: 'Persian Standard keyboard - 4 -> ۴' },
			{ input: '5', output: '۵', description: 'Persian Standard keyboard - 5 -> ۵' },
			{ input: '6', output: '۶', description: 'Persian Standard keyboard - 6 -> ۶' },
			{ input: '7', output: '۷', description: 'Persian Standard keyboard - 7 -> ۷' },
			{ input: '8', output: '۸', description: 'Persian Standard keyboard - 8 -> ۸' },
			{ input: '9', output: '۹', description: 'Persian Standard keyboard - 9 -> ۹' },
			{ input: '0', output: '۰', description: 'Persian Standard keyboard - 0 -> ۰' },

			{ input: 'q', output: 'ض', description: 'Persian Standard keyboard - q -> ض' },
			{ input: 'w', output: 'ص', description: 'Persian Standard keyboard - w -> ص' },
			{ input: 'e', output: 'ث', description: 'Persian Standard keyboard - e -> ث' },
			{ input: 'r', output: 'ق', description: 'Persian Standard keyboard - r -> ق' },
			{ input: 't', output: 'ف', description: 'Persian Standard keyboard - t -> ف' },
			{ input: 'y', output: 'غ', description: 'Persian Standard keyboard - y -> غ' },
			{ input: 'u', output: 'ع', description: 'Persian Standard keyboard - u -> ع' },
			{ input: 'i', output: 'ه', description: 'Persian Standard keyboard - i -> ه' },
			{ input: 'o', output: 'خ', description: 'Persian Standard keyboard - o -> خ' },
			{ input: 'p', output: 'ح', description: 'Persian Standard keyboard - p -> ح' },
			{ input: '[', output: 'ج', description: 'Persian Standard keyboard - [ -> ج' },
			{ input: ']', output: 'چ', description: 'Persian Standard keyboard - ] -> چ' },

			{ input: 'a', output: 'ش', description: 'Persian Standard keyboard - a -> ش' },
			{ input: 's', output: 'س', description: 'Persian Standard keyboard - s -> س' },
			{ input: 'd', output: 'ی', description: 'Persian Standard keyboard - d -> ی' },
			{ input: 'f', output: 'ب', description: 'Persian Standard keyboard - f -> ب' },
			{ input: 'g', output: 'ل', description: 'Persian Standard keyboard - g -> ل' },
			{ input: 'h', output: 'ا', description: 'Persian Standard keyboard - h -> ا' },
			{ input: 'j', output: 'ت', description: 'Persian Standard keyboard - j -> ت' },
			{ input: 'k', output: 'ن', description: 'Persian Standard keyboard - k -> ن' },
			{ input: 'l', output: 'م', description: 'Persian Standard keyboard - l -> م' },
			{ input: ';', output: 'ک', description: 'Persian Standard keyboard - ; -> ک' },
			{ input: '\'', output: 'گ', description: 'Persian Standard keyboard - \' -> گ' },

			{ input: 'z', output: 'ظ', description: 'Persian Standard keyboard - z -> ظ' },
			{ input: 'x', output: 'ط', description: 'Persian Standard keyboard - x -> ط' },
			{ input: 'c', output: 'ز', description: 'Persian Standard keyboard - c -> ز' },
			{ input: 'v', output: 'ر', description: 'Persian Standard keyboard - v -> ر' },
			{ input: 'b', output: 'ذ', description: 'Persian Standard keyboard - b -> ذ' },
			{ input: 'n', output: 'د', description: 'Persian Standard keyboard - n -> د' },
			{ input: 'm', output: 'پ', description: 'Persian Standard keyboard - m -> پ' },
			{ input: ',', output: 'و', description: 'Persian Standard keyboard - , -> و' },
			{ input: '.', output: '.', description: 'Persian Standard keyboard - . -> .' },
			{ input: '/', output: '/', description: 'Persian Standard keyboard - / -> /' },

			{ input: '~', output: '÷', description: 'Persian Standard keyboard - ~ -> ÷' },
			{ input: '!', output: '!', description: 'Persian Standard keyboard - ! -> !' },
			{ input: '@', output: '٬', description: 'Persian Standard keyboard - @ -> ٬' },
			{ input: '#', output: '٫', description: 'Persian Standard keyboard - # -> ٫' },
			{ input: '$', output: '﷼', description: 'Persian Standard keyboard - $ -> ﷼' },
			{ input: '%', output: '٪', description: 'Persian Standard keyboard - % -> ٪' },
			{ input: '^', output: '×', description: 'Persian Standard keyboard - ^ -> ×' },
			{ input: '&', output: '،', description: 'Persian Standard keyboard - & -> ،' },
			{ input: '*', output: '*', description: 'Persian Standard keyboard - * -> *' },
			{ input: '(', output: ')', description: 'Persian Standard keyboard - ( -> )' },
			{ input: ')', output: '(', description: 'Persian Standard keyboard - ) -> (' },
			{ input: '_', output: 'ـ', description: 'Persian Standard keyboard - _ -> ـ' },

			{ input: 'Q', output: 'ْ', description: 'Persian Standard keyboard - Q -> ْ_' },
			{ input: 'W', output: 'ٌ', description: 'Persian Standard keyboard - W -> ٌ_' },
			{ input: 'E', output: 'ٍ', description: 'Persian Standard keyboard - E -> ٍ_' },
			{ input: 'R', output: 'ً', description: 'Persian Standard keyboard - R -> ً_' },
			{ input: 'T', output: 'ُ', description: 'Persian Standard keyboard - T -> ُ_' },
			{ input: 'Y', output: 'ِ', description: 'Persian Standard keyboard - Y -> ِ_' },
			{ input: 'U', output: 'َ', description: 'Persian Standard keyboard - U -> َ_' },
			{ input: 'I', output: 'ّ', description: 'Persian Standard keyboard - I -> ّ_' },
			{ input: 'O', output: ']', description: 'Persian Standard keyboard - O -> ]' },
			{ input: 'P', output: '[', description: 'Persian Standard keyboard - P -> [' },
			{ input: '{', output: '}', description: 'Persian Standard keyboard - { -> }' },
			{ input: '}', output: '{', description: 'Persian Standard keyboard - } -> {' },

			{ input: 'A', output: 'ؤ', description: 'Persian Standard keyboard - A -> ؤ' },
			{ input: 'S', output: 'ئ', description: 'Persian Standard keyboard - S -> ئ' },
			{ input: 'D', output: 'ي', description: 'Persian Standard keyboard - D -> ي' },
			{ input: 'F', output: 'إ', description: 'Persian Standard keyboard - F -> إ' },
			{ input: 'G', output: 'أ', description: 'Persian Standard keyboard - G -> أ' },
			{ input: 'H', output: 'آ', description: 'Persian Standard keyboard - H -> آ' },
			{ input: 'J', output: 'ة', description: 'Persian Standard keyboard - J -> ة' },
			{ input: 'K', output: '»', description: 'Persian Standard keyboard - K -> »' },
			{ input: 'L', output: '«', description: 'Persian Standard keyboard - L -> «' },
			{ input: ':', output: ':', description: 'Persian Standard keyboard - : -> :' },
			{ input: '"', output: '؛', description: 'Persian Standard keyboard - " -> ؛' },

			{ input: 'Z', output: 'ك', description: 'Persian Standard keyboard - Z -> ك' },
			{ input: 'X', output: 'ٓ', description: 'Persian Standard keyboard - X -> ٓ_' },
			{ input: 'C', output: 'ژ', description: 'Persian Standard keyboard - C -> ژ' },
			{ input: 'V', output: 'ٰ', description: 'Persian Standard keyboard - V -> ٰ_' },
			{ input: 'B', output: '\u200c', description: 'Persian Standard keyboard - B -> ZWNJ' },
			{ input: 'N', output: 'ٔ', description: 'Persian Standard keyboard - N -> ٔ_' },
			{ input: 'M', output: 'ء', description: 'Persian Standard keyboard - M -> ء' },
			{ input: '<', output: '>', description: 'Persian Standard keyboard - < -> >' },
			{ input: '>', output: '<', description: 'Persian Standard keyboard - > -> <' },
			{ input: '?', output: '؟', description: 'Persian Standard keyboard - ? -> ؟' },
			{ input: [ [ '?', false, true ] ], output: '؟', description: 'Persian Standard keyboard with shift key pressed - ? -> ؟' },

			{ input: [ [ '`', true ] ], output: '~', description: 'Persian Standard keyboard - AltGr+` -> ~' },
			{ input: [ [ '1', true ] ], output: '`', description: 'Persian Standard keyboard - AltGr+1 -> `' },
			{ input: [ [ '2', true ] ], output: '@', description: 'Persian Standard keyboard - AltGr+2 -> @' },
			{ input: [ [ '3', true ] ], output: '#', description: 'Persian Standard keyboard - AltGr+3 -> #' },
			{ input: [ [ '4', true ] ], output: '$', description: 'Persian Standard keyboard - AltGr+4 -> $' },
			{ input: [ [ '5', true ] ], output: '%', description: 'Persian Standard keyboard - AltGr+5 -> %' },
			{ input: [ [ '6', true ] ], output: '^', description: 'Persian Standard keyboard - AltGr+6 -> ^' },
			{ input: [ [ '7', true ] ], output: '&', description: 'Persian Standard keyboard - AltGr+7 -> &' },
			{ input: [ [ '8', true ] ], output: '•', description: 'Persian Standard keyboard - AltGr+8 -> •' },
			{ input: [ [ '9', true ] ], output: '\u200e', description: 'Persian Standard keyboard - AltGr+9 -> LRM' },
			{ input: [ [ '0', true ] ], output: '\u200f', description: 'Persian Standard keyboard - AltGr+0 -> RLM' },

			{ input: [ [ 'q', true ] ], output: '°', description: 'Persian Standard keyboard - AltGr+q -> °' },
			{ input: [ [ 'e', true ] ], output: '€', description: 'Persian Standard keyboard - AltGr+e -> €' },
			{ input: [ [ 'i', true ] ], output: '\u202d', description: 'Persian Standard keyboard - AltGr+i -> LRO' },
			{ input: [ [ 'o', true ] ], output: '\u202e', description: 'Persian Standard keyboard - AltGr+o -> RLO' },
			{ input: [ [ 'p', true ] ], output: '\u202c', description: 'Persian Standard keyboard - AltGr+p -> POP' },
			{ input: [ [ '[', true ] ], output: '\u202a', description: 'Persian Standard keyboard - AltGr+[ -> LRE' },
			{ input: [ [ ']', true ] ], output: '\u202b', description: 'Persian Standard keyboard - AltGr+] -> RLE' },

			{ input: [ [ 'd', true ] ], output: 'ى', description: 'Persian Standard keyboard - AltGr+d -> ى' },
			{ input: [ [ 'h', true ] ], output: 'ٱ', description: 'Persian Standard keyboard - AltGr+h -> ٱ' },
			{ input: [ [ 'k', true ] ], output: '﴾', description: 'Persian Standard keyboard - AltGr+k -> ﴾' },
			{ input: [ [ 'l', true ] ], output: '﴿', description: 'Persian Standard keyboard - AltGr+l -> ﴿' },
			{ input: [ [ ';', true ] ], output: ';', description: 'Persian Standard keyboard - AltGr+; -> ;' },
			{ input: [ [ '\'', true ] ], output: '"', description: 'Persian Standard keyboard - AltGr+\' -> "' },

			{ input: [ [ 'b', true ] ], output: '\u200d', description: 'Persian Standard keyboard - AltGr+b -> ZWJ' },
			{ input: [ [ 'n', true ] ], output: 'ٕ', description: 'Persian Standard keyboard - AltGr+n -> ٕ_' },
			{ input: [ [ 'm', true ] ], output: '…', description: 'Persian Standard keyboard - AltGr+m -> …' },
			{ input: [ [ ',', true ] ], output: ',', description: 'Persian Standard keyboard - AltGr+, -> ,' },
			{ input: [ [ '.', true ] ], output: '\'', description: 'Persian Standard keyboard - AltGr+. -> \'' },
			{ input: [ [ '/', true ] ], output: '?', description: 'Persian Standard keyboard - AltGr+/ -> ?' },
			/* XXX Disabled. For some reason it fails in contenteditable.
			{ input: 'thvsd advdk hsj', output: 'فارسی شیرین است', description: 'Persian Standard keyboard - text test' },
			*/
			{ input: [ [ ' ', true ] ], output: '\xa0', description: 'Persian Standard keyboard - AltGr+Space -> NBSP' },
			{ input: [ [ ' ', false, true ] ], output: '\u200c', description: 'Persian Standard keyboard - Shift space is ZWNJ' }
		]
	},
	{
		description: 'Fula Alt input method test',
		inputmethod: 'ff-alt',
		tests: [
			{ input: [ [ 'b', true ] ], output: 'ɓ', description: 'Fula ɓ' },
			{ input: [ [ 'B', true ] ], output: 'Ɓ', description: 'Fula Ɓ' },
			{ input: [ [ 'd', true ] ], output: 'ɗ', description: 'Fula ɗ' },
			{ input: [ [ 'D', true ] ], output: 'Ɗ', description: 'Fula Ɗ' },
			{ input: [ [ 'g', true ] ], output: 'ɠ', description: 'Fula ɠ' },
			{ input: [ [ 'G', true ] ], output: 'Ɠ', description: 'Fula Ɠ' },
			{ input: [ [ 'j', true ] ], output: 'ɲ', description: 'Fula ɲ' },
			{ input: [ [ 'J', true ] ], output: 'Ɲ', description: 'Fula Ɲ' },
			{ input: [ [ 'n', true ] ], output: 'ŋ', description: 'Fula ŋ' },
			{ input: [ [ 'N', true ] ], output: 'Ŋ', description: 'Fula Ŋ' },
			{ input: [ [ 'y', true ] ], output: 'ƴ', description: 'Fula ƴ' },
			{ input: [ [ 'Y', true ] ], output: 'Ƴ', description: 'Fula Ƴ' },
			{ input: 'b', output: 'b', description: 'Fula b' },
			{ input: 'B', output: 'B', description: 'Fula B' },
			{ input: 'd', output: 'd', description: 'Fula d' },
			{ input: 'D', output: 'D', description: 'Fula D' },
			{ input: 'g', output: 'g', description: 'Fula g' },
			{ input: 'G', output: 'G', description: 'Fula G' },
			{ input: 'n', output: 'n', description: 'Fula n' },
			{ input: 'N', output: 'N', description: 'Fula N' },
			{ input: 'j', output: 'j', description: 'Fula j' },
			{ input: 'J', output: 'J', description: 'Fula J' },
			{ input: 'y', output: 'y', description: 'Fula y' },
			{ input: 'Y', output: 'Y', description: 'Fula Y' },
			{ input: 'N~', output: 'Ñ', description: 'Fula Ñ' },
			{ input: 'n~', output: 'ñ', description: 'Fula ñ' },
			{ input: 'N~~', output: 'N~', description: 'Fula N~' },
			{ input: 'n~~', output: 'n~', description: 'Fula n~' }
		]
	},
	{
		description: 'Fula tilde input method test',
		inputmethod: 'ff-tilde',
		tests: [
			{ input: '~b', output: 'ɓ', description: 'Fula tilde ~b' },
			{ input: '~B', output: 'Ɓ', description: 'Fula tilde ~B' },
			{ input: '~d', output: 'ɗ', description: 'Fula tilde ~d' },
			{ input: '~D', output: 'Ɗ', description: 'Fula tilde ~D' },
			{ input: '~g', output: 'ɠ', description: 'Fula tilde ~g' },
			{ input: '~G', output: 'Ɠ', description: 'Fula tilde ~G' },
			{ input: '~n', output: 'ñ', description: 'Fula tilde ~n' },
			{ input: '~N', output: 'Ñ', description: 'Fula tilde ~N' },
			{ input: '~j', output: 'ɲ', description: 'Fula tilde ~n' },
			{ input: '~J', output: 'Ɲ', description: 'Fula tilde ~N' },
			{ input: '~q', output: 'ŋ', description: 'Fula tilde ~q' },
			{ input: '~Q', output: 'Ŋ', description: 'Fula tilde ~Q' },
			{ input: '~y', output: 'ƴ', description: 'Fula tilde ~y' },
			{ input: '~Y', output: 'Ƴ', description: 'Fula tilde ~Y' }
		]
	},
	{
		description: 'Fon tilde test',
		inputmethod: 'fon-tilde',
		tests: [
			{ input: '~D', output: 'Ɖ', description: 'fon ~D -> Ɖ' },
			{ input: '~d', output: 'ɖ', description: 'fon ~d -> ɖ' },
			{ input: '~E', output: 'Ɛ', description: 'fon ~E -> Ɛ' },
			{ input: '~e', output: 'ɛ', description: 'fon ~e -> ɛ' },
			{ input: '~O', output: 'Ɔ', description: 'fon ~O -> Ɔ' },
			{ input: '~o~\\', output: 'ɔ̀', description: 'fon ~o~\\ -> ɔ̀' },
			{ input: '~e~/', output: 'ɛ́', description: 'fon ~e~/ -> ɛ́' },
			{ input: 'i~v', output: 'ǐ', description: 'fon i~v -> ǐ' },
			{ input: 'u~-', output: 'ū', description: 'fon u~- -> ū' },
			{ input: 'o~^', output: 'ô', description: 'fon o~^ -> ô' }
		]
	},
	{
		description: 'Ga CQX test',
		inputmethod: 'gaa-cqx',
		tests: [
			{ input: 'C', output: 'Ŋ', description: 'Ga CQX C' },
			{ input: 'c', output: 'ŋ', description: 'Ga CQX c' },
			{ input: 'Q', output: 'Ɛ', description: 'Ga CQX Q' },
			{ input: 'q', output: 'ɛ', description: 'Ga CQX q' },
			{ input: 'X', output: 'Ɔ', description: 'Ga CQX X' },
			{ input: 'x', output: 'ɔ', description: 'Ga CQX x' },
			{ input: '\\C', output: 'C', description: 'Ga CQX \\C' },
			{ input: '\\c', output: 'c', description: 'Ga CQX \\c' },
			{ input: '\\Q', output: 'Q', description: 'Ga CQX \\Q' },
			{ input: '\\q', output: 'q', description: 'Ga CQX \\q' },
			{ input: '\\X', output: 'X', description: 'Ga CQX \\X' },
			{ input: '\\x', output: 'x', description: 'Ga CQX \\x' }
		]
	},
	{
		description: 'Ga tilde test',
		inputmethod: 'gaa-tilde',
		tests: [
			{ input: '~e~\\~e~/~e~{', output: 'ɛ̀ɛ́ɛ̃', description: 'Ga tilde ɛ̀ɛ́ɛ̃' },
			{ input: '~E', output: 'Ɛ', description: 'Ga tilde ~E' },
			{ input: '~e', output: 'ɛ', description: 'Ga tilde ~e' },
			{ input: '~N', output: 'Ŋ', description: 'Ga tilde ~N' },
			{ input: '~n', output: 'ŋ', description: 'Ga tilde ~n' },
			{ input: '~O', output: 'Ɔ', description: 'Ga tilde ~O' },
			{ input: '~o', output: 'ɔ', description: 'Ga tilde ~o' }
		]
	},
	{
		description: 'Gothic Standard',
		inputmethod: 'got-standard',
		tests: [
			{ input: 'anastodeinilaufs', output: '𐌰𐌽𐌰𐍃𐍄𐍉𐌳𐌴𐌹𐌽𐌹𐌻𐌰𐌿𐍆𐍃', description: 'Gothic 𐌰𐌽𐌰𐍃𐍄𐍉𐌳𐌴𐌹𐌽𐌹𐌻𐌰𐌿𐍆𐍃' },
			{ input: 'veilos', output: '𐍈𐌴𐌹𐌻𐍉𐍃', description: 'Gothic 𐍈𐌴𐌹𐌻𐍉𐍃' },
			{ input: 'Tis', output: '𐌸𐌹𐍃', description: 'Gothic 𐌸𐌹𐍃' }
		]
	},
	{
		description: 'Gujarati Inscript',
		inputmethod: 'gu-inscript',
		tests: [
			{ input: '""d"a', output: 'ઠઠ્ઠો', description: 'Gujarati Inscript test' }
		]
	},
	{
		description: 'Gujarati Inscript 2',
		inputmethod: 'gu-inscript2',
		tests: [
			{ input: 'ke$lfk', output: 'કાર્તિક', description: 'Gujarati Kartik - Testing Ref' },
			{ input: '"eie"w/e', output: 'ઠાગાઠૈયા', description: 'Gujarati ThagaaThaiya - Testing Tha' }
		]
	},
	{
		description: 'Gujarati Phonetic',
		inputmethod: 'gu-phonetic',
		tests: [
			{ input: '\\', output: 'ૉ', description: 'Gujarati - O Matra' },
			{ input: 'k\\mfpyuwr', output: 'કૉમ્પયુટર', description: 'Gujarati - Computer' }
		]
	},
	{
		description: 'Gujarati Transliteration',
		inputmethod: 'gu-transliteration',
		tests: [
			{ input: '~', output: '~', description: 'Gujarati - tilde must not change' },
			{ input: 'hiMmata', output: 'હિંમત', description: 'Gujarati hiMmata' },
			{ input: 'aM^bara', output: 'અઁબર', description: 'Gujarati aM^bara - testing candrabindu' },
			{ input: '_', output: '_', description: 'Gujarati - underscore must not change' },
			{ input: 'oM', output: 'ઓં', description: 'Gujarati oM' },
			{ input: 'OM', output: 'ૐ', description: 'Gujarati OM' },
			{ input: 'K', output: '।', description: 'Gujarati K - testing danda' },
			{ input: 'KK', output: '॥', description: 'Gujarati KK - testing double danda' },
			{ input: 'ai', output: 'ઐ', description: 'Gujarati ai' },
			{ input: 'eka', output: 'એક', description: 'Gujarati eka' },
			{ input: 'aikya', output: 'ઐક્ય', description: 'Gujarati aikya' },
			{ input: 'kailaasa', output: 'કૈલાસ', description: 'Gujarati kailaasa' },
			{ input: 'EMjiiniyara', output: 'ઍંજીનિયર', description: 'Gujarati EMjiiniyara - testing candra e' },
			{ input: 'sad`bhaava', output: 'સદ્\u200cભાવ', description: 'Gujarati sad`bhaava - testing ZWNJ' }, // (with ZWNJ)
			{ input: 'caDJaavo', output: 'ચડ઼ાવો', description: 'Gujarati caDJaavo - testing nukta' },
			{ input: 'gnaati', output: 'જ્ઞાતિ', description: 'Gujarati gnaati - testing gn a new combination' }
		]
	},
	{
		description: 'Farefare tilde',
		inputmethod: 'gur-tilde',
		tests: [
			{ input: '~E', output: 'Ɛ', description: 'Farefare ~E -> Ɛ' },
			{ input: '~e', output: 'ɛ', description: 'Farefare ~e -> ɛ' },
			{ input: '~G', output: 'Ɣ', description: 'Farefare ~G -> Ɣ' },
			{ input: '~g', output: 'ɣ', description: 'Farefare ~g -> ɣ' },
			{ input: '~I', output: 'Ɩ', description: 'Farefare ~I -> Ɩ' },
			{ input: '~i', output: 'ɩ', description: 'Farefare ~i -> ɩ' },
			{ input: '~N', output: 'Ŋ', description: 'Farefare ~N -> Ŋ' },
			{ input: '~n', output: 'ŋ', description: 'Farefare ~n -> ŋ' },
			{ input: '~O', output: 'Ɔ', description: 'Farefare ~O -> Ɔ' },
			{ input: '~o', output: 'ɔ', description: 'Farefare ~O -> Ɔ' },
			{ input: '~U', output: 'Ʋ', description: 'Farefare ~U -> Ʋ' },
			{ input: '~u', output: 'ʋ', description: 'Farefare ~u -> ʋ' },
			{ input: '~o~\\', output: 'ɔ̀', description: 'Farefare ~o~\\ -> ɔ̀' },
			{ input: '~e~/', output: 'ɛ́', description: 'Farefare ~e~/ -> ɛ́' },
			{ input: 'o~^', output: 'ô', description: 'Farefare o~^ -> ô' },
			{ input: 'i~v', output: 'ǐ', description: 'Farefare i~v -> ǐ' },
			{ input: 'u~-', output: 'ū', description: 'Farefare u~- -> ū' },
			{ input: 'a~{', output: 'ã', description: 'Farefare a~{ -> ã' }
		]
	},
	{
		description: 'Hausa tilde test',
		inputmethod: 'ha-tilde',
		tests: [
			{ input: '~B', output: 'Ɓ', description: 'Hausa tilde ~B -> Ɓ' },
			{ input: '~b', output: 'ɓ', description: 'Hausa tilde ~b -> ɓ' },
			{ input: '~D', output: 'Ɗ', description: 'Hausa tilde ~D -> Ɗ' },
			{ input: '~d', output: 'ɗ', description: 'Hausa tilde ~d -> ɗ' },
			{ input: '~K', output: 'Ƙ', description: 'Hausa tilde ~K -> Ƙ' },
			{ input: '~k', output: 'ƙ', description: 'Hausa tilde ~k -> ƙ' },
			{ input: '~R', output: 'R̃', description: 'Hausa tilde ~R -> R̃' },
			{ input: '~r', output: 'r̃', description: 'Hausa tilde ~r -> r̃' },
			{ input: '~Y', output: 'Ƴ', description: 'Hausa tilde ~Y -> Ƴ' },
			{ input: '~y', output: 'ƴ', description: 'Hausa tilde ~y -> ƴ' },
			{ input: 'E~\\', output: 'È', description: 'Hausa tilde E~\\ -> È' },
			{ input: 'i~^', output: 'î', description: 'Hausa tilde i~^ -> î' }
		]
	},
	{
		description: 'Hebrew layout and extended keys test',
		inputmethod: 'he-standard-2012-extonly',
		tests: [
			// The output is the LRM control character
			{ input: [ [ '9', true ] ], output: '\u200e', description: 'Hebrew Alt-9 -> LRM' },
			// The output is the RLM control character
			{ input: [ [ '0', true ] ], output: '\u200f', description: 'Hebrew Alt-0 -> RLM' },
			// The first case is a regular hyphen-minus ('-'), which is the same
			// when it is pressed by itself without Alt.
			// The second case is hyphen-minus with Alt, which produces the Hebrew
			// hyphen (maqaf).
			{ input: [ [ '-', false ] ], output: '-', description: 'Hebrew regular -' },
			{ input: [ [ '-', true ] ], output: '־', description: 'Hebrew extended -' }
		]
	},
	{
		description: 'Hindi InScript layout test',
		inputmethod: 'hi-inscript',
		tests: [
			{ input: [ [ 'F', true ] ], output: '\u090C', description: 'Hindi inscript - ALTGR+F' }
		]
	},
	{
		description: 'Hindi InScript 2 test',
		inputmethod: 'hi-inscript2',
		tests: [
			{ input: '1234567890', output: '१२३४५६७८९०', description: 'Hindi InScript 2 1234567890' },
			{ input: '%', output: 'ज्ञ', description: 'Hindi InScript 2 %' },
			{ input: '^', output: 'त्र', description: 'Hindi InScript 2 ^' },
			{ input: '&', output: 'क्ष', description: 'Hindi InScript 2 &' },
			{ input: '*', output: 'श्र', description: 'Hindi InScript 2 *' },
			{ input: 'k_', output: 'कः', description: 'Hindi InScript 2 k_' },
			{ input: '+', output: 'ऋ', description: 'Hindi InScript 2 +' },
			{ input: 'QWERTYUIOP{}', output: 'औऐआईऊभङघधझढञ', description: 'Hindi InScript 2 QWERTYIOP{}' },
			{ input: 'yq', output: 'बौ', description: 'Hindi InScript 2 yq' },
			{ input: 'uw', output: 'है', description: 'Hindi InScript 2 uw' },
			{ input: 'ie', output: 'गा', description: 'Hindi InScript 2 ie' },
			{ input: 'or', output: 'दी', description: 'Hindi InScript 2 or' },
			{ input: 'pt', output: 'जू', description: 'Hindi InScript 2 pt' },
			// { input: '[]', output: 'ड़', description: 'Hindi InScript 2 []' }, // TODO fix broken rule
			{ input: 'ASDFGHKL:"', output: 'ओएअइउफखथछठ', description: 'Hindi InScript 2 ASDFGHKL:"' },
			// { input: 'J', output: 'ऱ', description: 'Hindi InScript 2 J' }, // TODO fix missing rule
			{ input: 'ha', output: 'पो', description: 'Hindi InScript 2 ha' },
			{ input: 'js', output: 'रे', description: 'Hindi InScript 2 js' },
			{ input: 'kd', output: 'क्', description: 'Hindi InScript 2 kd' },
			{ input: 'lf', output: 'ति', description: 'Hindi InScript 2 lf' },
			{ input: ';\'', output: 'चट', description: 'Hindi InScript 2 ;\'' },
			// { input: 'ZVBN', output: 'ऎऩऴळ', description: 'Hindi InScript 2 ;\'' }, // TODO fix missing rule
			{ input: 'CM<>?', output: 'णशष।?', description: 'Hindi InScript 2 CM<>?' },
			{ input: ';X', output: 'चँ', description: 'Hindi InScript 2 ;X' },
			// { input: 'nz', output: 'लॆ', description: 'Hindi InScript 2 nz' }, // TODO fix missing rule
			{ input: 'mx', output: 'सं', description: 'Hindi InScript 2 mx' },
			{ input: 'cvb', output: 'मनव', description: 'Hindi InScript 2 cvb' },
			{ input: '/', output: 'य', description: 'Hindi InScript 2 /' },
			// { input: '!', output: 'ऍ', description: 'Hindi InScript 2 !' }, // TODO fix missing rule
			{ input: 'k@', output: 'कॅ', description: 'Hindi InScript 2 k@' }
		]
	},
	{
		description: 'Hindi Phonetic tests',
		inputmethod: 'hi-phonetic',
		tests: [
			{ input: 'dffB', output: 'द्\u200cभ', description: 'Hindi Phonetic ZWNJ character' },
			{ input: 'p$wr', output: 'पॉटर', description: 'Hindi Phonetic Poter' },
			{ input: 'k`k', output: 'कॆक', description: 'Hindi Phonetic Cake' }
		]
	},
	{
		description: 'Hindi transliteration tests - for textarea',
		inputmethod: 'hi-transliteration',
		inputType: 'textarea',
		tests: [
			// The regex returns \n for \r.
			{ input: 'raam\r', output: 'राम\n', description: 'Hindi transliteration - raam<line-break> (\\r)' }
		]
	},
	{
		description: 'Hindi transliteration tests',
		inputmethod: 'hi-transliteration',
		tests: [
			{ input: '\\~', output: '~', description: 'Hindi transliteration - \\~ -> ~' },
			{ input: 'agar ', output: 'अगर ', description: 'Hindi transliteration - virama autoremoval on space' }, // bug 35990
			{ input: 'agar~ ', output: 'अगर् ', description: 'Hindi transliteration - virama retention' }, // bug 35990

			{ input: 'namaH', output: 'नमः', description: 'Hindi transliteration - namaH (visarga)' },
			{ input: 'madhumaChiyoM', output: 'मधुमक्खियों', description: 'Hindi transliteration - madhumaChiyoM (anusvara)' },
			{ input: '//', output: 'ऽ', description: 'Hindi transliteration - // (avagraha)' },
			{ input: 'raama', output: 'राम', description: 'Hindi transliteration - raama' },
			{ input: 'raama ', output: 'राम ', description: 'Hindi transliteration - raama<space> (backwards compatibility)' },
			{ input: 'raama~ ', output: 'राम् ', description: 'Hindi transliteration - raama<viram><space>' },
			{ input: 'raam ', output: 'राम ', description: 'Hindi transliteration - raam<space>' },
			{ input: 'raam~ ', output: 'राम् ', description: 'Hindi transliteration - raam<viram><space>' },
			{ input: 'raam,', output: 'राम,', description: 'Hindi transliteration - raam,' },
			{ input: 'raam~,', output: 'राम्,', description: 'Hindi transliteration - raam<viram>,' },
			{ input: 'raam?', output: 'राम?', description: 'Hindi transliteration - raam?' },
			{ input: 'raam~?', output: 'राम्?', description: 'Hindi transliteration - raam<viram>?' },
			{ input: 'raam!', output: 'राम!', description: 'Hindi transliteration - raam!' },
			{ input: 'raam~!', output: 'राम्!', description: 'Hindi transliteration - raam<viram>!' },
			{ input: 'raam-', output: 'राम-', description: 'Hindi transliteration - raam-' },
			{ input: 'raam~-', output: 'राम्-', description: 'Hindi transliteration - raam<viram>-' },
			{ input: 'raam:', output: 'राम:', description: 'Hindi transliteration - raam:' },
			{ input: 'raam~:', output: 'राम्:', description: 'Hindi transliteration - raam<viram>:' },
			{ input: 'raam;', output: 'राम;', description: 'Hindi transliteration - raam;' },
			{ input: 'raam~;', output: 'राम्;', description: 'Hindi transliteration - raam<viram>;' },
			{ input: 'raam5', output: 'राम५', description: 'Hindi transliteration - raam5' },
			{ input: 'raam~5', output: 'राम्५', description: 'Hindi transliteration - raam<viram>5' },
			{ input: 'santoSh.', output: 'सन्तोष।', description: 'Hindi transliteration - santoSh. (testing clusters and danda)' },
			{ input: 'santoSh~.', output: 'सन्तोष्।', description: 'Hindi transliteration - santoSh<viram>. (testing clusters and danda)' },
			{ input: 'raam..', output: 'राम॥', description: 'Hindi transliteration - raam..' },
			{ input: 'raam~..', output: 'राम्॥', description: 'Hindi transliteration - raam<viram>..' },
			{ input: 'laxmii', output: 'लक्ष्मी', description: 'Hindi transliteration - laxmii (testing ksh)' },
			{ input: 'veeNaa', output: 'वीणा', description: 'Hindi transliteration - veeNaa' },
			{ input: 'soorya', output: 'सूर्य', description: 'Hindi transliteration - soorya' },
			{ input: 'amRtaa', output: 'अमृता', description: 'Hindi transliteration - amRtaa' },
			{ input: 'bauThate', output: 'बौठते', description: 'Hindi transliteration - bauThate' },
			{ input: '.', output: '।', description: 'Hindi transliteration - . (danda)' },
			{ input: '..', output: '॥', description: 'Hindi transliteration - .. (double danda)' },

			// bug 38238
			{ input: 'AUMkaara', output: 'ॐकार', description: 'Hindi transliteration - auMkaara' },
			{ input: 'auMsa', output: 'औंस', description: 'Hindi transliteration - auMsa (ounce)' },
			{ input: 'bhaaShaaoM', output: 'भाषाओं', description: 'Hindi transliteration - bhaaShaaoM (testing correct typing of oM as a simple anusvara)' },
			{ input: 'a', output: 'अ', description: 'a for अ translitration' },
			{ input: 'aa', output: 'आ', description: 'aa for आ translitration' },
			{ input: 'i', output: 'इ', description: 'i for इ translitration' },
			{ input: 'I', output: 'ई', description: 'I for ई translitration' },
			{ input: 'u', output: 'उ', description: 'u for U translitration' },
			{ input: 'U', output: 'ऊ', description: 'U for ऊ translitration' },
			{ input: 'e', output: 'ए', description: 'e for ए translitration' },
			{ input: 'ai', output: 'ऐ', description: 'ai for ऐ translitration' },
			{ input: 'o', output: 'ओ', description: 'o for ओ translitration' },
			{ input: 'au', output: 'औ', description: 'au for औ translitration' },
			{ input: 'O', output: 'ऑ', description: 'O for ऑ translitration' },
			{ input: 'E', output: 'ऍ', description: 'E for ऍ translitration' },
			{ input: 'aM', output: 'अं', description: 'aM for अं translitration' },
			{ input: 'aH', output: 'अः', description: 'aH for अः translitration' },
			{ input: 'ka', output: 'क', description: 'ka for क translitration' },
			{ input: 'kha', output: 'ख', description: 'kha for ख translitration' },
			{ input: 'ga', output: 'ग', description: 'ga for ग translitration' },
			{ input: 'gha', output: 'घ', description: 'gha for घ translitration' },
			{ input: 'nga', output: 'ङ', description: 'nga for ङ translitration' },
			{ input: 'ca', output: 'च', description: 'cha for च translitration' },
			{ input: 'cha', output: 'छ', description: 'chha for छ translitration' },
			{ input: 'ja', output: 'ज', description: 'ja for ज translitration' },
			{ input: 'jha', output: 'झ', description: 'jha for झ translitration' },
			{ input: 'nja', output: 'ञ', description: 'nja for ञ translitration' },
			{ input: 'Ta', output: 'ट', description: 'Ta for ट translitration' },
			{ input: 'Tha', output: 'ठ', description: 'Tha for ठ translitration' },
			{ input: 'Da', output: 'ड', description: 'Da for ड translitration' },
			{ input: 'Dha', output: 'ढ', description: 'Dha for ढ translitration' },
			{ input: 'Na', output: 'ण', description: 'Na for ण translitration' },
			{ input: 'ta', output: 'त', description: 'ta for त translitration' },
			{ input: 'tha', output: 'थ', description: 'tha for थ translitration' },
			{ input: 'da', output: 'द', description: 'da for द translitration' },
			{ input: 'dha', output: 'ध', description: 'dha for ध translitration' },
			{ input: 'na', output: 'न', description: 'na for न translitration' },
			{ input: 'pha', output: 'फ', description: 'pha for फ translitration' },
			{ input: 'tha', output: 'थ', description: 'tha for थ translitration' },
			{ input: 'ba', output: 'ब', description: 'ba for ब translitration' },
			{ input: 'bha', output: 'भ', description: 'bha for भ translitration' },
			{ input: 'ma', output: 'म', description: 'ma for म translitration' },
			{ input: 'ya', output: 'य', description: 'ya for य translitration' },
			{ input: 'ra', output: 'र', description: 'ra for र translitration' },
			{ input: 'la', output: 'ल', description: 'la for ल translitration' },
			{ input: 'va', output: 'व', description: 'va for व translitration' },
			{ input: 'sha', output: 'श', description: 'sha for श translitration' },
			{ input: 'ya', output: 'य', description: 'ya for य translitration' },
			{ input: 'Sha', output: 'ष', description: 'Sha for ष translitration' },
			{ input: 'sa', output: 'स', description: 'sa for स translitration' },
			{ input: 'ha', output: 'ह', description: 'ha for ह translitration' },
			{ input: 'sha', output: 'श', description: 'sha for श translitration' },
			{ input: 'R', output: 'ऋ', description: 'R for ऋ translitration' },
			{ input: '0', output: '०', description: '0 for ० translitration' },
			{ input: '1', output: '१', description: '1 for १ translitration' },
			{ input: '2', output: '२', description: '2 for २ translitration' },
			{ input: '3', output: '३', description: '3 for ३ translitration' },
			{ input: '4', output: '४', description: '4 for ४ translitration' },
			{ input: '5', output: '५', description: '5 for ५ translitration' },
			{ input: '6', output: '६', description: '6 for ६ translitration' },
			{ input: '7', output: '७', description: '7 for ७ translitration' },
			{ input: '8', output: '८', description: '8 for ८ translitration' },
			{ input: '9', output: '९', description: '9 for ९ translitration' },
			{ input: '0', output: '०', description: '0 for ० translitration' }
		]
	},
	{
		description: 'Ho Transliteration test',
		inputmethod: 'hoc-transliteration',
		tests: [
			{ input: 'abcdeghijklmnopqrstuvwxy', output: '𑣁𑣗c𑣑𑣈𑣋𑣙𑣂𑣎𑣌𑣚𑣖𑣓𑣉𑣘𑣄𑣜𑣞𑣒𑣃𑣀𑣟𑣝𑣅', description: 'Ho abcdeghijklmnopqrst' },
			{ input: 'ABCDEGHIJKLMNOPQRSTUVWXY', output: '𑢡𑢷C𑢱𑢨𑢫𑢹𑢢𑢮𑢬𑢺𑢶𑢳𑢩𑢸𑢤𑢼𑢾𑢲𑢣𑢠𑢿𑢽𑢥', description: 'Ho ABCDEGHIJKLMNOPQRSTUVWXY' },
			{ input: '1234567890', output: '𑣡𑣢𑣣𑣤𑣥𑣦𑣧𑣨𑣩𑣠', description: 'Ho 1234567890' },
			{ input: '@', output: '𑣿', description: 'Ho @ -> 𑣿' },
			{ input: '\\@', output: '@', description: 'Ho \\@ -> @' },
			{ input: '\\a', output: 'a', description: 'Ho \\a -> a' },
			{ input: 'aiauchdhngnjnnrrth', output: '𑣆𑣇𑣏𑣔𑣊𑣍𑣐𑣛𑣕', description: 'Ho aiauchdhngnjnnrrth' },
			{ input: 'AIAUCHDHNGNJNNRRTH', output: '𑢦𑢧𑢯𑢴𑢪𑢭𑢰𑢻𑢵', description: 'Ho AIAUCHDHNGNJNNRRTH' },
			{ input: 'AiAuChDhNgNjNnRrTh', output: '𑢦𑢧𑢯𑢴𑢪𑢭𑢰𑢻𑢵', description: 'Ho AiAuChDhNgNjNnRrTh' }
		]
	},
	{
		description: 'Croatian kbd test',
		inputmethod: 'hr-kbd',
		tests: [
			{ input: 'ABCabc', output: 'ABCabc', description: 'Croatian kbd - ABCabc' },
			{ input: ';:', output: 'čČ', description: 'Croatian kbd - čČ' },
			{ input: '\'"', output: 'ćĆ', description: 'Croatian kbd - ćĆ' },
			{ input: 'D\\D|', output: 'DžDŽ', description: 'Croatian kbd - DžDŽ' },
			{ input: ']}', output: 'đĐ', description: 'Croatian kbd - đĐ' },
			{ input: 'EFGHIJKLMNOPRSefghijklmnoprs', output: 'EFGHIJKLMNOPRSefghijklmnoprs', description: 'Croatian kbd - EFGHIJKLMNOPRSefghijklmnoprs' },
			{ input: '[{', output: 'šŠ', description: 'Croatian kbd - šŠ' },
			{ input: 'TUVtuv', output: 'TUVtuv', description: 'Croatian kbd - TUVtuv' },
			{ input: '`c`C`s`S', output: 'çÇşŞ', description: 'Croatian kbd - çÇşŞ' },
			{ input: '~a~A~e~E~o~O~u~U', output: 'äÄëËöÖüÜ', description: 'Croatian kbd - äÄëËöÖüÜ' },
			{ input: '@^&*()-_=+', output: '"&/()=\'?+*', description: 'Croatian kbd - "&/()=\'?+*' },
			{ input: 'yY', output: 'zZ', description: 'Croatian kbd - zZ' },
			{ input: 'zZ', output: 'yY', description: 'Croatian kbd - yY' },
			{ input: '<>/?', output: ';:-_', description: 'Croatian kbd - ;:-_' }
		]
	},
	{
		description: 'Armenian MS legacy Eastern layout with extended keys test',
		inputmethod: 'hy-emslegacy',
		tests: [
			{ input: [ [ '7', false ] ], output: '․', description: 'Armenian MS legacy Eastern layout: Armenian mijaket ․' },
			{ input: [ [ '.', true ] ], output: '.', description: 'Armenian MS legacy Eastern layout: Latin dot .' },
			{ input: [ [ '"', true ] ], output: '"', description: 'Armenian MS legacy Eastern layout: Latin double quote "' },
			{ input: '`1234567890-=', output: '՝։ձյ՛,-․«»օռժ', description: 'Armenian MS legacy Eastern digits row No Shift' },
			{ input: '~!@#$%^&*()_+', output: '՜1ՁՅ֏49և()ՕՌԺ', description: 'Armenian MS legacy Eastern digits row With Shift' },
			{ input: 'qwertyuiop[]', output: 'խւէրտեըիոպչջ', description: 'Armenian MS legacy Eastern 1st row No Shift' },
			{ input: 'QWERTYUIOP{}', output: 'ԽՒԷՐՏԵԸԻՈՊՉՋ', description: 'Armenian MS legacy Eastern 1st row With Shift' },
			{ input: 'asdfghjkl;\'\\', output: 'ասդֆքհճկլթփ\'', description: 'Armenian MS legacy Eastern 2nd row No Shift' },
			{ input: 'ASDFGHJKL:"|', output: 'ԱՍԴՖՔՀՃԿԼԹՓ՞', description: 'Armenian MS legacy Eastern 2nd row With Shift' },
			{ input: 'zxcvbnm,./', output: 'զցգվբնմշղծ', description: 'Armenian MS legacy Eastern 3rd row No Shift' },
			{ input: 'ZXCVBNM<>?', output: 'ԶՑԳՎԲՆՄՇՂԾ', description: 'Armenian MS legacy Eastern 3rd row With Shift' }
		]
	},
	{
		description: 'Armenian phonetic layout with extended keys test',
		inputmethod: 'hy-ephonetic',
		tests: [
			{ input: [ [ '.', false ] ], output: '․', description: 'Armenian phonetic: Armenian mijaket ․' },
			{ input: [ [ '.', true ] ], output: '.', description: 'Armenian phonetic: Latin dot .' },
			{ input: [ [ ':', false ] ], output: '։', description: 'Armenian phonetic: Armenian verjaket ։' },
			{ input: [ [ ':', true ] ], output: ':', description: 'Armenian phonetic: colon :' },
			{ input: [ [ '"', false ] ], output: '"', description: 'Armenian phonetic: Latin double quote " without alt' },
			{ input: [ [ '"', true ] ], output: '"', description: 'Armenian phonetic: Latin double quote " with alt' },
			{ input: '`1234567890-=', output: '՝էթփձջ֏ևրչճ–ժ', description: 'Armenian phonetic digits row No Shift' },
			{ input: '~!@#$%^&*()_+', output: '՜ԷԹՓՁՋ()ՐՉՃ—Ժ', description: 'Armenian phonetic digits row With Shift' },
			{ input: 'qwertyuiop[]', output: 'քոեռտըւիօպխծ', description: 'Armenian phonetic 1st row No Shift' },
			{ input: 'QWERTYUIOP{}', output: 'ՔՈԵՌՏԸՒԻՕՊԽԾ', description: 'Armenian phonetic 1st row With Shift' },
			{ input: 'asdfghjkl;\'\\', output: 'ասդֆգհյկլ;՛շ', description: 'Armenian phonetic 2nd row No Shift' },
			{ input: 'ASDFGHJKL:"|', output: 'ԱՍԴՖԳՀՅԿԼ։"Շ', description: 'Armenian phonetic 2nd row With Shift' },
			{ input: 'zxcvbnm,./', output: 'զղցվբնմ,․…', description: 'Armenian phonetic 3rd row No Shift' },
			{ input: 'ZXCVBNM<>?', output: 'ԶՂՑՎԲՆՄ«»՞', description: 'Armenian phonetic 3rd row With Shift' }
		]
	},
	{
		description: 'Armenian alternative phonetic layout with extended keys test',
		inputmethod: 'hy-ephoneticalt',
		tests: [
			{ input: [ [ '.', false ] ], output: '․', description: 'Armenian phonetic alt: Armenian mijaket ․' },
			{ input: [ [ '.', true ] ], output: '.', description: 'Armenian phonetic alt: Latin dot .' },
			{ input: [ [ ':', false ] ], output: '։', description: 'Armenian phonetic alt: Armenian verjaket ։' },
			{ input: [ [ ':', true ] ], output: ':', description: 'Armenian phonetic alt: colon :' },
			{ input: [ [ '"', false ] ], output: '"', description: 'Armenian alt: Latin double quote " without alt' },
			{ input: [ [ '"', true ] ], output: '"', description: 'Armenian alt: Latin double quote " with alt' },
			{ input: '`1234567890-=', output: '՝էֆփձջ֏ևռչճ–ժ', description: 'Armenian phonetic digits row No Shift' },
			{ input: '~!@#$%^&*()_+', output: '՜ԷՖՓՁՋ()ՌՉՃ—Ժ', description: 'Armenian phonetic digits row With Shift' },
			{ input: 'qwertyuiop[]', output: 'քոերտըւիօպխծ', description: 'Armenian phonetic 1st row No Shift' },
			{ input: 'QWERTYUIOP{}', output: 'ՔՈԵՐՏԸՒԻՕՊԽԾ', description: 'Armenian phonetic 1st row With Shift' },
			{ input: 'asdfghjkl;\'\\', output: 'ասդթգհյկլ;՛շ', description: 'Armenian phonetic 2nd row No Shift' },
			{ input: 'ASDFGHJKL:"|', output: 'ԱՍԴԹԳՀՅԿԼ։"Շ', description: 'Armenian phonetic 2nd row With Shift' },
			{ input: 'zxcvbnm,./', output: 'զղցվբնմ,․…', description: 'Armenian phonetic 3rd row No Shift' },
			{ input: 'ZXCVBNM<>?', output: 'ԶՂՑՎԲՆՄ«»՞', description: 'Armenian phonetic 3rd row With Shift' }
		]
	},
	{
		description: 'Armenian typewriter layout with extended keys test',
		inputmethod: 'hy-typewriter',
		tests: [
			{ input: [ [ '7', false ] ], output: '․', description: 'Armenian mijaket ․' },
			{ input: [ [ '.', true ] ], output: '.', description: 'Latin dot .' },
			{ input: [ [ '"', true ] ], output: '"', description: 'Armenian typewriter: Latin double quote " with alt' },
			{ input: '`1234567890-=', output: '՝ֆձ-,։՞․՛)օէղ', description: 'Armenian typewriter digits row No Shift' },
			{ input: '~!@#$%^&*()_+', output: '՜ՖՁ֏֊—և՚(ՕԷՂ', description: 'Armenian typewriter digits row With Shift' },
			{ input: 'qwertyuiop[]', output: 'ճփբսմուկըթծց', description: 'Armenian typewriter 1st row No Shift' },
			{ input: 'QWERTYUIOP{}', output: 'ՃՓԲՍՄՈՒԿԸԹԾՑ', description: 'Armenian typewriter 1st row With Shift' },
			{ input: 'asdfghjkl;\'\\', output: 'ջվգեանիտհպր»', description: 'Armenian typewriter 2nd row No Shift' },
			{ input: 'ASDFGHJKL:"|', output: 'ՋՎԳԵԱՆԻՏՀՊՐ«', description: 'Armenian typewriter 2nd row With Shift' },
			{ input: 'zxcvbnm,./', output: 'ժդչյզլքխշռ', description: 'Armenian typewriter 3rd row No Shift' },
			{ input: 'ZXCVBNM<>?', output: 'ԺԴՉՅԶԼՔԽՇՌ', description: 'Armenian typewriter 3rd row With Shift' }
		]
	},
	{
		description: 'Armenian MS legacy Westerm layout with extended keys test',
		inputmethod: 'hy-wmslegacy',
		tests: [
			{ input: [ [ '7', false ] ], output: '․', description: 'Armenian MS legacy Western Armenian mijaket ․' },
			{ input: [ [ '.', true ] ], output: '.', description: 'Armenian MS legacy Western Latin dot .' },
			{ input: [ [ '"', true ] ], output: '"', description: 'Armenian MS legacy Western Latin double quote " with alt' },
			{ input: '`1234567890-=', output: '՝։ձյ՛,-․«»օռժ', description: 'Armenian MS legacy Western digits row No Shift' },
			{ input: '~!@#$%^&*()_+', output: '՜1ՁՅ֏49և()ՕՌԺ', description: 'Armenian MS legacy Western digits row With Shift' },
			{ input: 'qwertyuiop[]', output: 'խվէրդեըիոբչջ', description: 'Armenian MS legacy Western 1st row No Shift' },
			{ input: 'QWERTYUIOP{}', output: 'ԽՎԷՐԴԵԸԻՈԲՉՋ', description: 'Armenian MS legacy Western 1st row With Shift' },
			{ input: 'asdfghjkl;\'\\', output: 'աստֆկհճքլթփ\'', description: 'Armenian MS legacy Western 2nd row No Shift' },
			{ input: 'ASDFGHJKL:"|', output: 'ԱՍՏՖԿՀՃՔԼԹՓ՞', description: 'Armenian MS legacy Western 2nd row With Shift' },
			{ input: 'zxcvbnm,./', output: 'զցգւպնմշղծ', description: 'Armenian MS legacy Western 3rd row No Shift' },
			{ input: 'ZXCVBNM<>?', output: 'ԶՑԳՒՊՆՄՇՂԾ', description: 'Armenian MS legacy Western 3rd row With Shift' }
		]
	},
	{
		description: 'Ibibio tilde test',
		inputmethod: 'ibb-tilde',
		tests: [
			{ input: '~e~i~n~o~a~u~E~I~N~O~A~U', output: 'ǝịñọʌụƎỊÑỌɅỤ', description: 'Ibibio tilde ǝịñọʌụƎỊÑỌɅỤ' },
			{ input: 'a~/e~\\i~^o~-u~v', output: 'áèîōǔ', description: 'Ibibio tilde áèîōǔ' }
		]
	},
	{
		description: 'Igbo tilde test',
		inputmethod: 'ig-tilde',
		tests: [
			{ input: '~I', output: 'Ị', description: 'Igbo tilde ~I -> Ị' },
			{ input: '~i', output: 'ị', description: 'Igbo tilde ~i -> ị' },
			{ input: '~N', output: 'Ṅ', description: 'Igbo tilde ~N -> Ṅ' },
			{ input: '~n', output: 'ṅ', description: 'Igbo tilde ~n -> ṅ' },
			{ input: '~O', output: 'Ọ', description: 'Igbo tilde ~O -> Ọ' },
			{ input: '~o', output: 'ọ', description: 'Igbo tilde ~o -> ọ' },
			{ input: '~U', output: 'Ụ', description: 'Igbo tilde ~U -> Ụ' },
			{ input: '~u', output: 'ụ', description: 'Igbo tilde ~u -> ụ' },
			{ input: 'm~/ma~-', output: 'ḿmā', description: 'Igbo tilde m~/ma~- -> ḿmā' },
			{ input: 'E~\\', output: 'È', description: 'Igbo tilde E~\\ -> È' },
			{ input: 'i~/', output: 'í', description: 'Igbo tilde i~/ -> í' }
		]
	},
	{
		description: 'Igala tilde test',
		inputmethod: 'igl-tilde',
		tests: [
			{ input: '~E', output: 'Ẹ', description: 'Igala tilde ~E -> Ẹ' },
			{ input: '~e', output: 'ẹ', description: 'Igala tilde ~e -> ẹ' },
			{ input: '~N', output: 'Ñ', description: 'Igala tilde ~N -> Ñ' },
			{ input: '~n', output: 'ñ', description: 'Igala tilde ~n -> ñ' },
			{ input: '~O', output: 'Ọ', description: 'Igala tilde ~O -> Ọ' },
			{ input: '~o', output: 'ọ', description: 'Igala tilde ~o -> ọ' },
			{ input: '~e~-', output: 'ẹ̄', description: 'Igala tilde ~e~- -> ẹ̄' },
			{ input: '~E~\\', output: 'Ẹ̀', description: 'Igala tilde ~E~\\ -> Ẹ̀' },
			{ input: '~e~/', output: 'ẹ́', description: 'Igala tilde ~e~/ -> ẹ́' },
			{ input: '~O~^', output: 'Ộ', description: 'Igala tilde ~O~^ -> Ộ' },
			{ input: '~o~v', output: 'ọ̌', description: 'Igala tilde ~o~v -> ọ̌' }
		]
	},
	{
		description: 'SIL IPA keyboard test',
		inputmethod: 'ipa-sil',
		tests: [
			// This test suite follows the layout description document of
			// of SIL's IPA keyboard, including plaing characters like '.' and 'v'.
			// The test names are mostly based on IPA character descriptions.

			// Bilabial consonants
			{ input: 'p', output: 'p', description: 'Voiceless bilabial stop' },
			{ input: 'b', output: 'b', description: 'Voiced bilabial stop' },
			{ input: 'm', output: 'm', description: 'Bilabial nasal' },
			{ input: 'B=', output: 'ʙ', description: 'Voiced bilabial trill' },
			{ input: 'f=', output: 'ɸ', description: 'Voiceless bilabial fricative' },
			{ input: 'b=', output: 'β', description: 'Voiced bilabial fricative' },

			// Labiodental consonants
			{ input: 'm>', output: 'ɱ', description: 'Labiodental nasal' },
			{ input: 'v<', output: 'ⱱ', description: 'Labiodental flap' },
			{ input: 'f', output: 'f', description: 'Voiceless abiodental fricative' },
			{ input: 'v', output: 'v', description: 'Voiced labiodental fricative' },
			{ input: 'v=', output: 'ʋ', description: 'Labiodental approximant' },

			// Dental consonants
			{ input: 't=', output: 'θ', description: 'Voiceless dental fricative' },
			{ input: 'd=', output: 'ð', description: 'Voiced dental fricative' },

			// Alveolar consonants
			{ input: 't', output: 't', description: 'Voiceless alveolar stop' },
			{ input: 'd', output: 'd', description: 'Voiced alveolar stop' },
			{ input: 'n', output: 'n', description: 'Alveolar nasal' },
			{ input: 'r', output: 'r', description: 'Alveolar trill' },
			{ input: 'r>', output: 'ɾ', description: 'Alveolar flap' },
			{ input: 's', output: 's', description: 'Voiceless alveolar fricative' },
			{ input: 'z', output: 'z', description: 'Voiced alveolar fricative' },
			{ input: 'l=', output: 'ɬ', description: 'Voiceless alveolar lateral fricative' },
			{ input: 'l>', output: 'ɮ', description: 'Voiced alveolar lateral fricative' },
			{ input: 'r=', output: 'ɹ', description: 'Alveolar approximant' },
			{ input: 'l', output: 'l', description: 'Alveolar lateral approximant' },

			// Postalveolar consonants
			{ input: 's=', output: 'ʃ', description: 'Voiceless postalveolar fricative' },
			{ input: 'z=', output: 'ʒ', description: 'Voiced postalveolar fricative' },

			// Retroflex consonants
			{ input: 't<', output: 'ʈ', description: 'Voiceless retroflex stop' },
			{ input: 'd<', output: 'ɖ', description: 'Voiced retroflex stop' },
			{ input: 'n<', output: 'ɳ', description: 'Retroflex nasal' },
			{ input: 'r<', output: 'ɽ', description: 'Retroflex flap' },
			{ input: 's<', output: 'ʂ', description: 'Voiceless retroflex fricative' },
			{ input: 'z<', output: 'ʐ', description: 'Voiced retroflex fricative' },
			{ input: 'R<', output: 'ɻ', description: 'Retroflex approximant' },
			{ input: 'l<', output: 'ɭ', description: 'Retroflex lateral approximant' },

			// Palatal consonants
			{ input: 'c', output: 'c', description: 'Voiceless palatal stop' },
			{ input: 'j=', output: 'ɟ', description: 'Voiced palatal stop' },
			{ input: 'n=', output: 'ɲ', description: 'Palatal nasal' },
			{ input: 'c=', output: 'ç', description: 'Voiceless palatal fricative' },
			{ input: 'j<', output: 'ʝ', description: 'Voiced palatal fricative' },
			{ input: 'j', output: 'j', description: 'Palatal approximant' },
			{ input: 'L<', output: 'ʎ', description: 'Palatal lateral approximant' },

			// Velar consonants
			{ input: 'k', output: 'k', description: 'Voiceless velar stop' },
			{ input: 'g<', output: 'ɡ', description: 'Voiced velar stop' },
			{ input: 'n>', output: 'ŋ', description: 'Velar nasal' },
			{ input: 'x', output: 'x', description: 'Voiceless velar fricative' },
			{ input: 'g=', output: 'ɣ', description: 'Voiced velar fricative' },
			{ input: 'w>', output: 'ɰ', description: 'Velar approximant' },
			{ input: 'L=', output: 'ʟ', description: 'Velar lateral approximant' },

			// Uvular consonants
			{ input: 'q', output: 'q', description: 'Voiceless uvular stop' },
			{ input: 'G=', output: 'ɢ', description: 'Voiced uvular stop' },
			{ input: 'N=', output: 'ɴ', description: 'Uvular nasal' },
			{ input: 'R=', output: 'ʀ', description: 'Uvular trill' },
			{ input: 'x=', output: 'χ', description: 'Voiceless uvular fricative' },
			{ input: 'R>', output: 'ʁ', description: 'Voiced uvular fricative' },

			// Pharyngeal consonants
			{ input: 'h>', output: 'ħ', description: 'Voiceless pharyngeal fricative' },
			{ input: '?<', output: 'ʕ', description: 'Voiced pharyngeal fricative' },

			// Glottal consonants
			{ input: '?=', output: 'ʔ', description: 'Glottal stop' },
			{ input: 'h', output: 'h', description: 'Voiceless glottal fricative' },
			{ input: 'h<', output: 'ɦ', description: 'Voiced glottal fricative' },

			// Clicks
			{ input: 'p=', output: 'ʘ', description: 'Bilabial click' },
			{ input: '!<', output: 'ǀ', description: 'Dental click' },
			{ input: '!', output: 'ǃ', description: 'Postalveolar click (retroflex click character)' },
			{ input: '!=', output: 'ǂ', description: 'Palatoalveolar click' },
			{ input: '!>', output: 'ǁ', description: 'Alveolar lateral click' },

			// Implosive
			{ input: 'b>', output: 'ɓ', description: 'Bilabial voiced implosive' },
			{ input: 'd>', output: 'ɗ', description: 'Dental/alveolar voiced implosive' },
			{ input: 'j>', output: 'ʄ', description: 'Palatal voiced implosive' },
			{ input: 'g>', output: 'ɠ', description: 'Velar voiced implosive' },
			{ input: 'G>', output: 'ʛ', description: 'Uvular voiced implosive' },

			// Other symbols
			{ input: 'w=', output: 'ʍ', description: 'Voiceless labial-velar fricative' },
			{ input: 'w', output: 'w', description: 'Voiced labial-velar approximant' },

			// Two variants
			{ input: 'y<', output: 'ɥ', description: 'Voiced labial-palatal approximant (y<)' },
			{ input: 'h=', output: 'ɥ', description: 'Voiced labial-palatal approximant (h=)' },
			{ input: 'H=', output: 'ʜ', description: 'Voiceless epiglottal fricative' },
			{ input: 'Q<', output: 'ʢ', description: 'Voiced epiglottal fricative' },
			{ input: 'Q=', output: 'ʡ', description: 'Voiced epiglottal stop' },

			{ input: 'c<', output: 'ɕ', description: 'Voiceless alveolo-palatal fricative' },
			{ input: 'z>', output: 'ʑ', description: 'Voiced alveolo-palatal fricative' },
			{ input: 'L>', output: 'ɺ', description: 'Voiced alveolar lateral flap' },
			{ input: 'H<', output: 'ɧ', description: 'Simultaneous ʃ and x' },

			// Front unrounded vowels
			{ input: 'i', output: 'i', description: 'Close front unrounded vowel' },
			{ input: 'i=', output: 'ɪ', description: 'Near-close near-front unrounded vowel' },
			{ input: 'e', output: 'e', description: 'Close-mid front unrounded vowel' },
			{ input: 'e<', output: 'ɛ', description: 'Open-mid front unrounded vowel' },
			{ input: 'a<', output: 'æ', description: 'Near-open front unrounded vowel' },
			{ input: 'a', output: 'a', description: 'Open front unrounded vowel' },

			// Front rounded vowels
			{ input: 'y', output: 'y', description: 'Close front rounded vowel' },
			{ input: 'y=', output: 'ʏ', description: 'Near-close near-front rounded vowel' },
			{ input: 'o>', output: 'ø', description: 'Close-mid front rounded vowel' },
			{ input: 'E<', output: 'œ', description: 'Open-mid front rounded vowel' },
			{ input: 'E>', output: 'ɶ', description: 'Open front rounded vowel' },

			// Central vowels
			{ input: 'I=', output: 'ɨ', description: 'Close central unrounded vowel' },
			{ input: 'E=', output: 'ɘ', description: 'Close-mid central unrounded vowel' },
			{ input: 'e=', output: 'ə', description: 'Mid-central vowel' },
			{ input: 'e>', output: 'ɜ', description: 'Open-mid central unrounded vowel' },
			{ input: 'a>', output: 'ɐ', description: 'Near-open central vowel' },
			{ input: 'U=', output: 'ʉ', description: 'Close central rounded vowel' },
			{ input: 'O=', output: 'ɵ', description: 'Close-mid central rounded vowel' },
			{ input: 'O<', output: 'ɞ', description: 'Open-mid central rounded vowel' },

			// Back vowels
			{ input: 'u=', output: 'ɯ', description: 'Close back unrounded vowel' },
			{ input: 'O>', output: 'ɤ', description: 'Close-mid back unrounded vowel' },
			{ input: 'u>', output: 'ʌ', description: 'Open-mid back unrounded vowel' },
			{ input: 'a=', output: 'ɑ', description: 'Open back unrounded vowel' },
			{ input: 'u', output: 'u', description: 'Close back rounded vowel' },
			{ input: 'u<', output: 'ʊ', description: 'Near-close near-back vowel' },
			{ input: 'o', output: 'o', description: 'Close-mid back rounded vowel' },
			{ input: 'o<', output: 'ɔ', description: 'Open-mid back rounded vowel' },
			{ input: 'o=', output: 'ɒ', description: 'Open back rounded vowel' },

			// Suprasegmentals
			{ input: '}', output: 'ˈ', description: 'Primary stress' },
			{ input: '}}', output: 'ˌ', description: 'Secondary stress' }, // }}
			{ input: ':', output: 'ː', description: 'Long' },
			{ input: '::', output: 'ˑ', description: 'Half long' },
			{ input: ':::', output: 'ːː', description: 'Extra long' }, // Not IPA sanctioned
			// Extra short is tested below with other similar diacritics
			{ input: '.<', output: '|', description: 'Minor (foot) group' },
			{ input: '.=', output: '‖', description: 'Major (intonation) group' },
			{ input: '.', output: '.', description: 'Syllable break' },
			{ input: '#=', output: '‿', description: 'Linking (absence of a break)' },

			// Tones
			{ input: '#4', output: '˥', description: 'Extra-high tone bar' },
			{ input: '#3', output: '˦', description: 'High tone bar' },
			{ input: '#2', output: '˧', description: 'Mid tone bar' },
			{ input: '#1', output: '˨', description: 'Low tone bar' },
			{ input: '#0', output: '˩', description: 'Extra-low tone bar' },
			{ input: 'e@4', output: 'e̋', description: 'Extra-high tone diacritic' },
			{ input: 'e@3', output: 'é', description: 'High tone diacritic' },
			{ input: 'e@2', output: 'ē', description: 'Mid tone diacritic' },
			{ input: 'e@1', output: 'è', description: 'Low tone diacritic' },
			{ input: 'e@0', output: 'ȅ', description: 'Extra-low tone diacritic' },

			// Tone combinations
			// The following tone bar tests are taken from the layout description.
			// Any combination of three tones is possible.
			{ input: '#04', output: '˩˥', description: 'Rising tone bar (04)' },
			{ input: '#40', output: '˥˩', description: 'Falling tone bar (40)' },
			{ input: '#24', output: '˧˥', description: 'High rising tone bar (24)' },
			{ input: '#12', output: '˨˧', description: 'Low rising tone bar (12)' },
			{ input: '#141', output: '˨˥˨', description: 'Rising-falling tone bar (141)' },

			{ input: 'e@13', output: 'ě', description: 'Rising tone diacritic' },
			{ input: 'e@31', output: 'ê', description: 'Falling tone diacritic' },
			{ input: 'e@23', output: 'e᷄', description: 'High rising tone diacritic' },
			{ input: 'e@12', output: 'e᷅', description: 'Low rising tone diacritic' },
			{ input: 'e@131', output: 'e᷈', description: 'Rising-falling tone diacritic' },
			{ input: 'e@21', output: 'e᷆', description: 'Low falling tone diacritic' }, // Not IPA sanctioned
			{ input: 'e@32', output: 'e᷇', description: 'High falling tone diacritic' }, // Not IPA sanctioned
			{ input: 'e@313', output: 'e᷉', description: 'Falling-rising tone diacritic' }, // Not IPA sanctioned

			{ input: '#<', output: 'ꜜ', description: 'Downstep' },
			{ input: '#>', output: 'ꜛ', description: 'Upstep' },
			{ input: '#>>', output: '↗', description: 'Global rise' },
			{ input: '#<<', output: '↘', description: 'Global fall' },

			// Tone numbers (non-IPA)
			{ input: '^0', output: '⁰', description: 'Tone number 0' }, // Not IPA sanctioned
			{ input: '^1', output: '¹', description: 'Tone number 1' }, // Not IPA sanctioned
			{ input: '^2', output: '²', description: 'Tone number 2' }, // Not IPA sanctioned
			{ input: '^3', output: '³', description: 'Tone number 3' }, // Not IPA sanctioned
			{ input: '^4', output: '⁴', description: 'Tone number 4' }, // Not IPA sanctioned
			{ input: '^5', output: '⁵', description: 'Tone number 5' }, // Not IPA sanctioned
			{ input: '^6', output: '⁶', description: 'Tone number 6' }, // Not IPA sanctioned
			{ input: '^7', output: '⁷', description: 'Tone number 7' }, // Not IPA sanctioned
			{ input: '^8', output: '⁸', description: 'Tone number 8' }, // Not IPA sanctioned
			{ input: '^9', output: '⁹', description: 'Tone number 9' }, // Not IPA sanctioned
			{ input: '^-', output: '⁻', description: 'Superscript hyphen' }, // Not IPA sanctioned

			// Diacritics and suprasegmentals
			{ input: 'h^', output: 'ʰ', description: 'Aspirated' },
			{ input: 'w^', output: 'ʷ', description: 'Labialised' },
			{ input: 'j^', output: 'ʲ', description: 'Palatalised' },
			{ input: 'g=^', output: 'ˠ', description: 'Velarised' },
			{ input: '?<^', output: 'ˤ', description: 'Pharyngealised' },
			{ input: 'n^', output: 'ⁿ', description: 'Nasal release' }, // "Pre/post nasalised" in the layout document
			{ input: 'l^', output: 'ˡ', description: 'Lateral release' },

			// TODO non-IPA superscripts

			{ input: '[[', output: 'ʽ', description: 'Light aspiration' }, // Not IPA sanctioned
			{ input: 'e[[[', output: 'e˞', description: 'Rhoticity' },
			{ input: 'p]]', output: 'pʼ', description: 'Ejective' },
			{ input: 'd]]]', output: 'd̚', description: 'No audible release' },
			{ input: ']]]]', output: '‘', description: 'Weak aspiration' }, // Not IPA sanctioned
			{ input: 'n$', output: 'n̩', description: 'Syllabic' },
			{ input: 'e$$', output: 'e̯', description: 'Non-syllabic' },
			{ input: 'a$$$', output: 'a̰', description: 'Creaky voiced' },

			// TODO non-IPA retroflex hooks

			{ input: 'n%', output: 'n̥', description: 'Voiceless' },
			{ input: 's%%', output: 's̬', description: 'Voiced' },
			{ input: 'b%%%', output: 'b̤', description: 'Breathy voiced' },

			// TODO non-IPA palatal hooks

			{ input: 'n>@', output: 'ŋ̊', description: 'Voiceless with diacritic above' },
			{ input: 't{', output: 't̪', description: 'Dental' },
			{ input: 't{{', output: 't̺', description: 'Apical' },
			{ input: 't{{{', output: 't̻', description: 'Laminal' },
			{ input: 't{{{{', output: 't̼', description: 'Linguolabial' },
			{ input: 's{{{{{', output: 'ṣ', description: 'Closer variety / Fricative' }, // TODO Find out how standard this is
			{ input: 'e~', output: 'ẽ', description: 'Nasalised' },
			{ input: 'l~~', output: 'l̴', description: 'Velarized or pharyngealized' },
			{ input: 'e*', output: 'ë', description: 'Centralised' },
			{ input: 'e**', output: 'e̽', description: 'Mid centralised' },
			{ input: 'e***', output: 'ĕ', description: 'Extra short' },
			{ input: 'e****', output: 'ė', description: 'Palatalization/Centralization' }, // TODO Find out how standard this is
			// TODO Find out what the m with the five asterisks is.

			{ input: 'k#&p', output: 'k͡p', description: 'Double articulation above' },
			{ input: 't@&s', output: 't͜s', description: 'Double articulation below' },

			{ input: 'u+', output: 'u̟', description: 'Advanced' },
			{ input: 'i_', output: 'i̠', description: 'Retracted' },
			{ input: 'e++', output: 'e̝', description: 'Raised' },
			{ input: 'e__', output: 'e̞', description: 'Lowered' },
			{ input: 'e+++', output: 'e̘', description: 'Advanced tongue root' },
			{ input: 'e___', output: 'e̙', description: 'Retracted tongue root' },
			{ input: 'e++++', output: 'e̹', description: 'More rounded' },
			{ input: 'e____', output: 'e̜', description: 'Less rounded' },

			// TODO Non-IPA open vowel, fortis and lenis

			// Addition non-IPA characters
			{ input: '=>', output: '→', description: 'Is realized as (arrow)' }, // Not IPA sanctioned
			{ input: 's>', output: 'σ', description: 'Syllable (sigma)' }, // Not IPA sanctioned
			{ input: '=<', output: '\u200d', description: 'Combining Grapheme Joiner' }, // Not IPA sanctioned

			{ input: '[}e:i=ja}}fjatl%a}}jE<:ky=tl%]', output: '[ˈeːɪjaˌfjatl̥aˌjœːkʏtl̥]', description: 'Eyjafjallajökull' }
		]
	},
	{
		description: 'X-SAMPA IPA keyboard test',
		inputmethod: 'ipa-x-sampa',
		tests: [
			// Bilabial consonants
			{ input: 'p', output: 'p', description: 'Voiceless bilabial stop' },
			{ input: 'b', output: 'b', description: 'Voiced bilabial stop' },
			{ input: 'm', output: 'm', description: 'Bilabial nasal' },
			{ input: 'B\\', output: 'ʙ', description: 'Voiced bilabial trill' },
			{ input: 'p\\', output: 'ɸ', description: 'Voiceless bilabial fricative' },
			{ input: 'B', output: 'β', description: 'Voiced bilabial fricative' },

			// Labiodental consonants
			{ input: 'F', output: 'ɱ', description: 'Labiodental nasal' },
			// { input: '*', output: 'ⱱ', description: 'Labiodental flap' }, // not in X-SAMPA
			{ input: 'f', output: 'f', description: 'Voiceless abiodental fricative' },
			{ input: 'v', output: 'v', description: 'Voiced labiodental fricative' },
			// Two variants
			{ input: 'P', output: 'ʋ', description: 'Labiodental approximant (P)' },
			{ input: 'v\\', output: 'ʋ', description: 'Labiodental approximant (v\\)' },

			// Dental consonants
			{ input: 'T', output: 'θ', description: 'Voiceless dental fricative' },
			{ input: 'D', output: 'ð', description: 'Voiced dental fricative' },

			// Alveolar consonants
			{ input: 't', output: 't', description: 'Voiceless alveolar stop' },
			{ input: 'd', output: 'd', description: 'Voiced alveolar stop' },
			{ input: 'n', output: 'n', description: 'Alveolar nasal' },
			{ input: 'r', output: 'r', description: 'Alveolar trill' },
			{ input: '4', output: 'ɾ', description: 'Alveolar flap' },
			{ input: 's', output: 's', description: 'Voiceless alveolar fricative' },
			{ input: 'z', output: 'z', description: 'Voiced alveolar fricative' },
			{ input: 'K', output: 'ɬ', description: 'Voiceless alveolar lateral fricative' },
			{ input: 'K\\', output: 'ɮ', description: 'Voiced alveolar lateral fricative' },
			{ input: 'r\\', output: 'ɹ', description: 'Alveolar approximant' },
			{ input: 'l', output: 'l', description: 'Alveolar lateral approximant' },

			// Postalveolar consonants
			{ input: 'S', output: 'ʃ', description: 'Voiceless postalveolar fricative' },
			{ input: 'Z', output: 'ʒ', description: 'Voiced postalveolar fricative' },

			// Retroflex consonants
			{ input: 't`', output: 'ʈ', description: 'Voiceless retroflex stop' },
			{ input: 'd`', output: 'ɖ', description: 'Voiced retroflex stop' },
			{ input: 'n`', output: 'ɳ', description: 'Retroflex nasal' },
			{ input: 'r`', output: 'ɽ', description: 'Retroflex flap' },
			{ input: 's`', output: 'ʂ', description: 'Voiceless retroflex fricative' },
			{ input: 'z`', output: 'ʐ', description: 'Voiced retroflex fricative' },
			{ input: 'r\\`', output: 'ɻ', description: 'Retroflex approximant' },
			{ input: 'l`', output: 'ɭ', description: 'Retroflex lateral approximant' },

			// Palatal consonants
			{ input: 'c', output: 'c', description: 'Voiceless palatal stop' },
			{ input: 'J\\', output: 'ɟ', description: 'Voiced palatal stop' },
			{ input: 'J', output: 'ɲ', description: 'Palatal nasal' },
			{ input: 'C', output: 'ç', description: 'Voiceless palatal fricative' },
			{ input: 'j\\', output: 'ʝ', description: 'Voiced palatal fricative' },
			{ input: 'j', output: 'j', description: 'Palatal approximant' },
			{ input: 'L', output: 'ʎ', description: 'Palatal lateral approximant' },

			// Velar consonants
			{ input: 'k', output: 'k', description: 'Voiceless velar stop' },
			{ input: 'g', output: 'ɡ', description: 'Voiced velar stop' },
			{ input: 'N', output: 'ŋ', description: 'Velar nasal' },
			{ input: 'x', output: 'x', description: 'Voiceless velar fricative' },
			{ input: 'G', output: 'ɣ', description: 'Voiced velar fricative' },
			{ input: 'M\\', output: 'ɰ', description: 'Velar approximant' },
			{ input: 'L\\', output: 'ʟ', description: 'Velar lateral approximant' },

			// Uvular consonants
			{ input: 'q', output: 'q', description: 'Voiceless uvular stop' },
			{ input: 'G\\', output: 'ɢ', description: 'Voiced uvular stop' },
			{ input: 'N\\', output: 'ɴ', description: 'Uvular nasal' },
			{ input: 'R\\', output: 'ʀ', description: 'Uvular trill' },
			{ input: 'X', output: 'χ', description: 'Voiceless uvular fricative' },
			{ input: 'R', output: 'ʁ', description: 'Voiced uvular fricative' },

			// Pharyngeal consonants
			{ input: 'X\\', output: 'ħ', description: 'Voiceless pharyngeal fricative' },
			{ input: '?\\', output: 'ʕ', description: 'Voiced pharyngeal fricative' },

			// Glottal consonants
			{ input: '?', output: 'ʔ', description: 'Glottal stop' },
			{ input: 'h', output: 'h', description: 'Voiceless glottal fricative' },
			{ input: 'h\\', output: 'ɦ', description: 'Voiced glottal fricative' },

			// Clicks
			{ input: 'O\\', output: 'ʘ', description: 'Bilabial click' },
			{ input: '|\\', output: 'ǀ', description: 'Dental click' },
			{ input: '!\\', output: 'ǃ', description: 'Postalveolar click (retroflex click character)' },
			{ input: '=\\', output: 'ǂ', description: 'Palatoalveolar click' },
			{ input: '|\\|\\', output: 'ǁ', description: 'Alveolar lateral click' },

			// Implosive
			{ input: 'b_<', output: 'ɓ', description: 'Bilabial voiced implosive' },
			{ input: 'd_<', output: 'ɗ', description: 'Dental/alveolar voiced implosive' },
			{ input: 'J\\_<', output: 'ʄ', description: 'Palatal voiced implosive' },
			{ input: 'g_<', output: 'ɠ', description: 'Velar voiced implosive' },
			{ input: 'G\\_<', output: 'ʛ', description: 'Uvular voiced implosive' },

			// Other symbols
			{ input: 'W', output: 'ʍ', description: 'Voiceless labial-velar fricative' },
			{ input: 'w', output: 'w', description: 'Voiced labial-velar approximant' },
			{ input: 'H', output: 'ɥ', description: 'Voiced labial-palatal approximant (y<)' },
			{ input: 'H\\', output: 'ʜ', description: 'Voiceless epiglottal fricative' },
			{ input: '<\\', output: 'ʢ', description: 'Voiced epiglottal fricative' },
			{ input: '>\\', output: 'ʡ', description: 'Voiced epiglottal stop' },

			{ input: 's\\', output: 'ɕ', description: 'Voiceless alveolo-palatal fricative' },
			{ input: 'z\\', output: 'ʑ', description: 'Voiced alveolo-palatal fricative' },
			{ input: 'l\\', output: 'ɺ', description: 'Voiced alveolar lateral flap' },
			{ input: 'x\\', output: 'ɧ', description: 'Simultaneous ʃ and x' },

			// Front unrounded vowels
			{ input: 'i', output: 'i', description: 'Close front unrounded vowel' },
			{ input: 'I', output: 'ɪ', description: 'Near-close near-front unrounded vowel' },
			{ input: 'e', output: 'e', description: 'Close-mid front unrounded vowel' },
			{ input: 'E', output: 'ɛ', description: 'Open-mid front unrounded vowel' },
			{ input: '{', output: 'æ', description: 'Near-open front unrounded vowel' },
			{ input: 'a', output: 'a', description: 'Open front unrounded vowel' },

			// Front rounded vowels
			{ input: 'y', output: 'y', description: 'Close front rounded vowel' },
			{ input: 'Y', output: 'ʏ', description: 'Near-close near-front rounded vowel' },
			{ input: '2', output: 'ø', description: 'Close-mid front rounded vowel' },
			{ input: '9', output: 'œ', description: 'Open-mid front rounded vowel' },
			{ input: '&', output: 'ɶ', description: 'Open front rounded vowel' },

			// Central vowels
			{ input: '1', output: 'ɨ', description: 'Close central unrounded vowel' },
			{ input: '@\\', output: 'ɘ', description: 'Close-mid central unrounded vowel' },
			{ input: '@', output: 'ə', description: 'Mid-central vowel' },
			{ input: '3', output: 'ɜ', description: 'Open-mid central unrounded vowel' },
			{ input: '6', output: 'ɐ', description: 'Near-open central vowel' },
			{ input: '}', output: 'ʉ', description: 'Close central rounded vowel' },
			{ input: '8', output: 'ɵ', description: 'Close-mid central rounded vowel' },
			{ input: '3\\', output: 'ɞ', description: 'Open-mid central rounded vowel' },

			// Back vowels
			{ input: 'M', output: 'ɯ', description: 'Close back unrounded vowel' },
			{ input: '7', output: 'ɤ', description: 'Close-mid back unrounded vowel' },
			{ input: 'V', output: 'ʌ', description: 'Open-mid back unrounded vowel' },
			{ input: 'A', output: 'ɑ', description: 'Open back unrounded vowel' },
			{ input: 'u', output: 'u', description: 'Close back rounded vowel' },
			{ input: 'U', output: 'ʊ', description: 'Near-close near-back vowel' },
			{ input: 'o', output: 'o', description: 'Close-mid back rounded vowel' },
			{ input: 'O', output: 'ɔ', description: 'Open-mid back rounded vowel' },
			{ input: 'Q', output: 'ɒ', description: 'Open back rounded vowel' },

			// Suprasegmentals
			{ input: '"', output: 'ˈ', description: 'Primary stress' },
			{ input: '%', output: 'ˌ', description: 'Secondary stress' }, // }}
			{ input: ':', output: 'ː', description: 'Long' },
			{ input: ':\\', output: 'ˑ', description: 'Half long' },
			{ input: '|', output: '|', description: 'Minor (foot) group' },
			{ input: '||', output: '‖', description: 'Major (intonation) group' },
			{ input: '.', output: '.', description: 'Syllable break' },
			{ input: '-\\', output: '‿', description: 'Linking (absence of a break)' },

			// No full-width tones in X-SAMPA

			{ input: 'e_/', output: 'ě', description: 'Rising tone diacritic' },
			{ input: 'e_\\', output: 'ê', description: 'Falling tone diacritic' },
			{ input: 'e_H_T', output: 'e᷄', description: 'High rising tone diacritic' },
			{ input: 'e_B_L', output: 'e᷅', description: 'Low rising tone diacritic' },
			{ input: 'e_R_F', output: 'e᷈', description: 'Rising-falling tone diacritic' },

			{ input: '!', output: 'ꜜ', description: 'Downstep' },
			{ input: '^', output: 'ꜛ', description: 'Upstep' },
			{ input: '<R>', output: '↗', description: 'Global rise' },
			{ input: '<F>', output: '↘', description: 'Global fall' },

			// Diacritics and suprasegmentals
			{ input: '_h', output: 'ʰ', description: 'Aspirated' },
			{ input: '_w', output: 'ʷ', description: 'Labialised' },
			{ input: '_j', output: 'ʲ', description: 'Palatalised' },
			{ input: '_G', output: 'ˠ', description: 'Velarised' },
			{ input: '_?\\', output: 'ˤ', description: 'Pharyngealised' },
			{ input: '_n', output: 'ⁿ', description: 'Nasal release' },
			{ input: '_l', output: 'ˡ', description: 'Lateral release' },

			{ input: 'e`', output: 'e˞', description: 'Rhoticity' },
			{ input: 'p_>', output: 'pʼ', description: 'Ejective' },
			{ input: 'd_}', output: 'd̚', description: 'No audible release' },
			// Two variants
			{ input: 'n=', output: 'n̩', description: 'Syllabic =' },
			{ input: 'n_=', output: 'n̩', description: 'Syllabic _=' },
			{ input: 'e_^', output: 'e̯', description: 'Non-syllabic' },
			{ input: 'a_k', output: 'a̰', description: 'Creaky voiced' },

			{ input: 'n_0', output: 'n̥', description: 'Voiceless' },
			{ input: 'N_0', output: 'ŋ̊', description: 'Voiceless with diacritic above' },
			{ input: 's_v', output: 's̬', description: 'Voiced' },
			{ input: 'b_t', output: 'b̤', description: 'Breathy voiced' },

			{ input: 't_d', output: 't̪', description: 'Dental' },
			{ input: 't_a', output: 't̺', description: 'Apical' },
			{ input: 't_m', output: 't̻', description: 'Laminal' },
			{ input: 't_N', output: 't̼', description: 'Linguolabial' },
			// Two variants
			{ input: 'e~', output: 'ẽ', description: 'Nasalised ~' },
			{ input: 'e_~', output: 'ẽ', description: 'Nasalised _~' },
			{ input: 'l_e', output: 'l̴', description: 'Velarized or pharyngealized' },
			{ input: 'e_"', output: 'ë', description: 'Centralised' },
			{ input: 'e_x', output: 'e̽', description: 'Mid centralised' },
			{ input: 'e_X', output: 'ĕ', description: 'Extra short' },

			{ input: 'u_+', output: 'u̟', description: 'Advanced' },
			{ input: 'i_-', output: 'i̠', description: 'Retracted' },
			{ input: 'e_r', output: 'e̝', description: 'Raised' },
			{ input: 'e_o', output: 'e̞', description: 'Lowered' },
			{ input: 'e_A', output: 'e̘', description: 'Advanced tongue root' },
			{ input: 'e_q', output: 'e̙', description: 'Retracted tongue root' },
			{ input: 'e_O', output: 'e̹', description: 'More rounded' },
			{ input: 'e_c', output: 'e̜', description: 'Less rounded' },

			{
				input: '["e:Ija%fjatl_0a%j9:kYtl_0]',
				output: '[ˈeːɪjaˌfjatl̥aˌjœːkʏtl̥]',
				description: 'Eyjafjallajökull'
			}
		]
	},
	{
		description: 'Esan Awain tilde test',
		inputmethod: 'ish-tilde',
		tests: [
			{ input: '~E', output: 'Ẹ', description: 'Esan Awain tilde ~E -> Ẹ' },
			{ input: '~e', output: 'ẹ', description: 'Esan Awain tilde ~e -> ẹ' },
			{ input: '~O', output: 'Ọ', description: 'Esan Awain tilde ~O -> Ọ' },
			{ input: '~o', output: 'ọ', description: 'Esan Awain tilde ~o -> ọ' }
		]
	},
	{
		description: 'Javanese transliteration test',
		inputmethod: 'jv-transliteration',
		tests: [
			{ input: '\\A', output: 'A', description: 'Javanese transliteration escape mode - A' },
			{ input: 'AEIOUX', output: 'ꦄꦌꦆꦎꦈꦄꦼ', description: 'standalone vowels "AEIOUÊ" - for foreign vowel syllables' },
			{ input: 'aeioux', output: 'ꦲꦲꦺꦲꦶꦲꦺꦴꦲꦸꦲꦼ', description: 'vowels (sandhangan swara)' },
			{ input: 'AiAuUuIiII', output: 'ꦍꦎꦴꦈꦴꦇꦅ', description: 'long standalone owels' },
			{ input: 'aHiiuuai', output: 'ꦲꦴꦲꦷꦲꦹꦲꦻ', description: 'long vowels (sandhangan swara)' },
			{ input: '1234567890', output: '꧑꧒꧓꧔꧕꧖꧗꧘꧙꧐', description: 'numbers' },
			{ input: 'KaGaCaJaNyanYaNYaThatHaTHaDhadHaDHaNaTaDaPaBaRaSaZa', output: 'ꦑꦓꦖꦙꦘꦘꦘꦜꦜꦜꦞꦞꦞꦟꦡꦣꦦꦨꦬꦯꦰ', description: 'murda letters' },
			{ input: 'h', output: 'ꦲ꧀', description: 'ha with a virama' },
			{ input: 'ha', output: 'ꦲ', description: '"ha", also used to write "a", used to write Javanese word' },
			{ input: 'a', output: 'ꦲ', description: '"ha", also used to write "a", used to write Javanese word' },
			{ input: 'eioux', output: 'ꦲꦺꦲꦶꦲꦺꦴꦲꦸꦲꦼ', description: '"ha" + sandhangan swara - to write Javanese vowel syllables' },
			{ input: 'q', output: '꧀', description: 'virama' },
			{ input: 'lxqlxrxslXrXs', output: 'ꦋꦊꦉꦱ꧀ꦭꦼꦫꦼꦱ꧀', description: 'leres - testing special consonants - "nga lelet" and "pa cerek"' },
			{ input: 'sangmarwah', output: 'ꦱꦁꦩꦂꦮꦃ', description: 'sang marwah - testing panyigeg ng/r/h' },
			{ input: 'slaswasyasrasrx', output: 'ꦱ꧀ꦭꦱ꧀ꦮꦱꦾꦱꦿꦱꦽ', description: 'testing panjingan "la" and "wa", "pengkal", "cakra", and "cakra keret"' },
			{ input: 'naHniinuunai', output: 'ꦤꦴꦤꦷꦤꦹꦤꦻ', description: 'testing long vowels "tarung", "wulu melik", "suku mendut", "dirga mure"' },
			{ input: 'kahxndak', output: 'ꦏꦲꦼꦤ꧀ꦢꦏ꧀', description: '"wignyan" + "pepet"' },
			{ input: 'arxp', output: 'ꦲꦉꦥ꧀', description: '"layar" + "pepet"' },
			{ input: 'sangxt', output: 'ꦱꦔꦼꦠ꧀', description: '"cecak" + "pepet" https://jv.wikisource.org/wiki/Parembugan_Kaca:Serat_Pararaton.pdf/34 by Empat Tilda' },
			{ input: 'pxpengxttan', output: 'ꦥꦼꦥꦺꦔꦼꦠ꧀ꦠꦤ꧀', description: 'pepengetan https://jv.wikisource.org/wiki/Parembugan_Kaca:Serat_Pararaton.pdf/16 by Empat Tilda' },
			{ input: 'harYahangYahYang', output: 'ꦲꦫꦾꦲꦔꦾꦲꦾꦁ', description: '"cecak" + "pengkal"' },
			{ input: 'ngYxktossake', output: 'ꦔꦾꦼꦏ꧀ꦠꦺꦴꦱ꧀ꦱꦏꦺ', description: 'ngyektosake: https://jv.wikisource.org/wiki/Parembugan_Kaca:Serat_Pararaton.pdf/22 by Empat Tilda' },
			{ input: 'harRahangRahRa', output: 'ꦲꦫꦿꦲꦔꦿꦲꦿ', description: '"cecak" + "cakra"' },
			{ input: 'ngwa', output: 'ꦔ꧀ꦮ', description: '"cecak" + "panjingan wa"' },
			{ input: 'ngla', output: 'ꦔ꧀ꦭ', description: '"cecak" + "panjingan la"' },
			{ input: 'krekrikrokrukrx', output: 'ꦏꦿꦺꦏꦿꦶꦏꦿꦺꦴꦏꦿꦸꦏꦽ', description: '"cakra" + sandhangan' },
			{ input: 'tyetyityotyutyx', output: 'ꦠꦾꦺꦠꦾꦶꦠꦾꦺꦴꦠꦾꦸꦠꦾꦼ', description: '"pengkal" + sandhangan' },
			{ input: 'mas yayi', output: 'ꦩꦱ꧀ꦪꦪꦶ', description: '<consonant> + ZWS + y' },
			{ input: 'pak raden', output: 'ꦥꦏ꧀ꦫꦢꦺꦤ꧀', description: '<consonant> + ZWS + r' },
			{ input: 'suryasurYa', output: 'ꦱꦸꦂꦪꦱꦸꦫꦾ', description: '"layar" + "pengkal"' },
			{ input: 'karyakarYa', output: 'ꦏꦂꦪꦏꦫꦾ', description: 'layar + y vs. layar + Y' },
			{ input: 'ingsunCidrakxna', output: 'ꦲꦶꦁꦱꦸꦤ꧀ꦕꦶꦢꦿꦏꦼꦤ', description: 'n + ZWS + c' },
			{ input: 'nJa', output: 'ꦤ꧀ꦗ', description: 'n + ZWS + j' },
			{ input: 'nGa', output: 'ꦤ꧀ꦒ', description: 'n + ZWS + g' },
			{ input: 'n ya', output: 'ꦤ꧀ꦪ', description: 'n + ZWS + y' },
			{ input: ',.', output: '꧈꧉', description: 'important punctuations test' },
			{ input: ')', output: '꧍', description: 'last line test' }
		]
	},
	{
		description: 'Jawa Latin extended test',
		inputmethod: 'jv-keyboard',
		tests: [
			{ input: '`En`ek', output: 'Ènèk', description: 'Jawa Latin extended È' },
			{ input: '~Enak~e', output: 'Énaké', description: 'Jawa Latin extended É' },
			{ input: '^En^eg', output: 'Ênêg', description: 'Jawa Latin extended Ê' },
			{ input: '^An^a', output: 'Ånå', description: 'Jawa Latin extended Å' },
			{ input: '~An~a', output: 'Ånå', description: 'Jawa Latin extended Å - alternate' },
			{ input: 'tula.da .Da .Ta .ta', output: 'tulaḍa Ḍa Ṭa ṭa', description: 'Jawa Latin extended Ḍ and Ṭ' },
			{ input: 'tula~da ~Da ~Ta ~ta', output: 'tulaḍa Ḍa Ṭa ṭa', description: 'Jawa Latin extended Ḍ and Ṭ - alternate' }

		]
	},
	{
		description: 'Georgian Transliteration test',
		inputmethod: 'ka-transliteration',
		tests: [
			{ input: 'vikipedia\\`', output: 'ვიკიპედია`', description: 'Georgian vikipedia with `' },
			{ input: '\\~\\~\\~\\~', output: '~~~~', description: 'Wiki Signature test' },
			{ input: 'abcdefghijklmnopqrstuvwxyz', output: 'აბცდეფგჰიჯკლმნოპქრსტუვწხყზ', description: 'a-z in Georgian' },
			{ input: 'WRTSJZC`~', output: 'ჭღთშჟძჩ„“', description: 'WRTSJZC`~ in Georgian' }
		]
	},
	{
		description: 'Kabyle tilde test',
		inputmethod: 'kab-tilde',
		tests: [
			{ input: '~C', output: 'Č', description: 'Kabyle tilde Č direct' },
			{ input: '~c', output: 'č', description: 'Kabyle tilde č direct' },
			{ input: 'C~v', output: 'Č', description: 'Kabyle tilde Č combining' },
			{ input: 'c~v', output: 'č', description: 'Kabyle tilde č combining' },
			{ input: '~D', output: 'Ḍ', description: 'Kabyle tilde Ḍ direct' },
			{ input: '~d', output: 'ḍ', description: 'Kabyle tilde ḍ direct' },
			{ input: 'D~.', output: 'Ḍ', description: 'Kabyle tilde Ḍ combining' },
			{ input: 'd~.', output: 'ḍ', description: 'Kabyle tilde ḍ combining' },
			{ input: '~E', output: 'Ɛ', description: 'Kabyle tilde Ɛ' },
			{ input: '~e', output: 'ɛ', description: 'Kabyle tilde ɛ' },
			{ input: '~G', output: 'Ǧ', description: 'Kabyle tilde Ǧ direct' },
			{ input: '~g', output: 'ǧ', description: 'Kabyle tilde ǧ direct' },
			{ input: 'G~v', output: 'Ǧ', description: 'Kabyle tilde Ǧ combining' },
			{ input: 'g~v', output: 'ǧ', description: 'Kabyle tilde ǧ combining' },
			{ input: '~Y', output: 'Ɣ', description: 'Kabyle tilde Ɣ' },
			{ input: '~y', output: 'ɣ', description: 'Kabyle tilde ɣ' },
			{ input: '~H', output: 'Ḥ', description: 'Kabyle tilde Ḥ direct' },
			{ input: '~h', output: 'ḥ', description: 'Kabyle tilde ḥ direct' },
			{ input: 'H~.', output: 'Ḥ', description: 'Kabyle tilde Ḥ combining' },
			{ input: 'h~.', output: 'ḥ', description: 'Kabyle tilde ḥ combining' },
			{ input: '~R', output: '~R', description: 'Kabyle tilde ~R - no direct' },
			{ input: '~r', output: '~r', description: 'Kabyle tilde ~r - no direct' },
			{ input: '~S', output: 'Ṣ', description: 'Kabyle tilde Ṣ direct' },
			{ input: '~s', output: 'ṣ', description: 'Kabyle tilde ṣ direct' },
			{ input: 'S~.', output: 'Ṣ', description: 'Kabyle tilde Ṣ combining' },
			{ input: 's~.', output: 'ṣ', description: 'Kabyle tilde ṣ combining' },
			{ input: '~T', output: 'Ṭ', description: 'Kabyle tilde Ṭ direct' },
			{ input: '~t', output: 'ṭ', description: 'Kabyle tilde ṭ direct' },
			{ input: 'T~.', output: 'Ṭ', description: 'Kabyle tilde Ṭ combining' },
			{ input: 't~.', output: 'ṭ', description: 'Kabyle tilde ṭ combining' },
			{ input: 'T~,', output: 'Ţ', description: 'Kabyle tilde Ţ combining' },
			{ input: 't~,', output: 'ţ', description: 'Kabyle tilde ţ combining' },
			{ input: '~Z', output: 'Ẓ', description: 'Kabyle tilde Ẓ direct' },
			{ input: '~z', output: 'ẓ', description: 'Kabyle tilde ẓ direct' },
			{ input: 'Z~.', output: 'Ẓ', description: 'Kabyle tilde Ẓ combining' },
			{ input: 'z~.', output: 'ẓ', description: 'Kabyle tilde ẓ combining' },
			{ input: 'Z~,', output: 'Z̧', description: 'Kabyle tilde Z̧ combining' },
			{ input: 'z~,', output: 'z̧', description: 'Kabyle tilde z̧ combining' },
			{ input: '~y~w', output: 'ɣʷ', description: 'Kabyle tilde ɣʷ' }
		]
	},
	{
		description: 'Kabiye tilde test',
		inputmethod: 'kbp-tilde',
		tests: [
			{ input: 'N~{~i~gl~im', output: 'Ñɩɣlɩm', description: 'Kabiye tilde Ñɩɣlɩm' },
			{ input: 'Tal~i ~deu', output: 'Talɩ ɖeu', description: 'Kabiye tilde Talɩ ɖeu' },
			{ input: 'T~om c~o~d~i~n t~i~na', output: 'Tɔm cɔɖɩŋ tɩŋa', description: 'Kabiye tilde Tɔm cɔɖɩŋ tɩŋa' },
			{ input: '~Dajaa', output: 'Ɖajaa', description: 'Kabiye tilde Ɖajaa' },
			{ input: 'P~ina~g', output: 'Pɩnaɣ', description: 'Kabiye tilde Pɩnaɣ' },
			{ input: '~EL~E~GZ~I', output: 'ƐLƐƔZƖ', description: 'Kabiye tilde ƐLƐƔZƖ' },
			{ input: 'W~is~i~d~i~d~vy~e', output: 'Wɩsɩɖɩɖʋyɛ', description: 'Kabiye tilde Wɩsɩɖɩɖʋyɛ' }
		]
	},
	{
		description: 'Tyap tilde test',
		inputmethod: 'kcg-tilde',
		tests: [
			{ input: '~Alyem', output: 'A̱lyem', description: 'Tyap tilde A̱lyem' },
			{ input: '~a~/pyi~a', output: 'á̱pyia̱', description: 'Tyap tilde á̱pyia̱ with ~' },
			{ input: 'a~_~/pyia~_', output: 'á̱pyia̱', description: 'Tyap tilde á̱pyia̱ with _' },
			{ input: 'wusika~/', output: 'wusiká', description: 'Tyap tilde wusiká' },
			{ input: '~at~itak', output: 'a̱ti̱tak', description: 'Tyap tilde a̱ti̱tak' },
			{ input: 'kwi~/', output: 'kwí', description: 'Tyap tilde kwí' },
			{ input: 'ji~_~/p', output: 'jí̱p', description: 'Tyap tilde jí̱p' },
			{ input: 'KWI~/', output: 'KWÍ', description: 'Tyap tilde KWÍ' },
			{ input: 'JI~_~/P', output: 'JÍ̱P', description: 'Tyap tilde JÍ̱P' }
		]
	},
	{
		description: 'Kikuyu tilde test',
		inputmethod: 'ki-tilde',
		tests: [
			{ input: 'Ng~ug~i wa Thiong\'o', output: 'Ngũgĩ wa Thiong\'o', description: 'Kikuyu Ngũgĩ wa Thiong\'o' },
			{ input: 'NG~UG~I', output: 'NGŨGĨ', description: 'Kikuyu NGŨGĨ' }
		]
	},
	{
		description: 'Kazakh Cyrillic test',
		inputmethod: 'kk-kbd',
		tests: [
			{ input: '~!@#$%^&*()_+', output: ')!ӘІӉҒ;:ҮҰҚӨҺ', description: 'Kazakh kbd - numbers row shifted' },
			{ input: '`1234567890-=', output: '("әіӊғ,.үұқөһ', description: 'Kazakh kbd - numbers row not shifted' },
			{ input: 'QWERTYUIOP{}', output: 'ЙЦУКЕНГШЩЗХЪ', description: 'Kazakh kbd - QWERTY row shifted' },
			{ input: 'qwertyuiop[]', output: 'йцукенгшщзхъ', description: 'Kazakh kbd - qwerty row not shifted' },
			{ input: 'ASDFGHJKL:"', output: 'ФЫВАПРОЛДЖЭ', description: 'Kazakh kbd - ASDF row shifted' },
			{ input: 'asdfghjkl;\'', output: 'фывапролджэ', description: 'Kazakh kbd - asdf row not shifted' },
			{ input: 'ZXCVBNM<>?', output: 'ЯЧСМИТЬБЮ?', description: 'Kazakh kbd - ZXCV row shifted' },
			{ input: 'zxcvbnm,./', output: 'ячсмитьбю№', description: 'Kazakh kbd - zxcv row not shifted' }
		]
	},
	{
		description: 'Khmer NiDA standard Unicode keyboard test',
		inputmethod: 'km-nidakyk',
		tests: [
			{ input: 'xjmEr', output: 'ខ្មែរ', description: 'Khmer: xjmEr -> ខ្មែរ' },
			{ input: 'q', output: 'ឆ', description: 'Consonant: q -> ឆ' },
			{ input: 'JjG', output: 'ញ្អ', description: 'Consonant subscript: JjG -> ញ្អ' },

			// test common combinations
			{ input: 'GA', output: 'អាំ', description: 'combination (A): GA -> អាំ' },
			{ input: 'GaM', output: 'អាំ', description: 'combination (am as A): GaM -> អាំ' },
			{ input: 'GMa', output: 'អាំ', description: 'normalization (Ma to aM): GMa -> អាំ' },
			{ input: 'GV', output: 'អេះ', description: 'combination (V): GV -> អេះ' },
			{ input: 'GeH', output: 'អេះ', description: 'combination (eH as V): GeH -> អេះ' },
			{ input: 'GHe', output: 'អេះ', description: 'normalization (He to eH): GHe -> អេះ' },
			{ input: 'G,', output: 'អុំ', description: 'combination (,): G, -> អុំ' },
			{ input: 'GuM', output: 'អុំ', description: 'combination (uH as ,): GeH -> អុំ' },
			{ input: 'GMu', output: 'អុំ', description: 'normalization (Mu to uM): GMu -> អុំ' },
			{ input: 'G:', output: 'អោះ', description: 'combination (:): G: -> អោះ' },
			{ input: 'GoH', output: 'អោះ', description: 'combination (oH as :): GoH -> អោះ' },
			{ input: 'GHo', output: 'អោះ', description: 'normalization (Ho to oH): GHo -> អោះ' },
			{ input: 'G<', output: 'អុះ', description: 'combination (<): G< -> អុះ' },
			{ input: 'GuH', output: 'អុះ', description: 'combination (uH as <): GeH -> អុះ' },
			{ input: 'GHu', output: 'អុះ', description: 'normalization (Hu to uH): GHu -> អុះ' },

			// test normalization for consonant shifters
			// { input: 'Gjn/', output: 'អ៊្ន', description: 'normalization (consonant shifter): Gjn/ -> អ៊្ន' },
			// { input: 'Gjrjn/', output: 'អ៊្រ្ន', description: 'normalization (consonant shifter): Gjrjn/ -> អ៊្រ្ន' },

			// test corrections
			{ input: 'Gea', output: 'អោ', description: 'correction (ea to o): Gea -> អោ' },
			{ input: 'Gae', output: 'អោ', description: 'correction (ae to o): Gae -> អោ' },
			{ input: 'GeI', output: 'អើ', description: 'correction (eI to :): GeI -> អើ' },
			{ input: 'GIe', output: 'អើ', description: 'correction (Ie to :): GIe -> អើ' },

			// test AltGr
			{ input: [ [ 'e', true ] ], output: 'ឯ', description: 'AltGr: AltGr-e -> ឯ' },
			{ input: [ [ '2', true ] ], output: '@', description: 'AltGr: AltGr-2 -> @' },
			{ input: [ 'G', [ '3', true ] ], output: 'អ៑', description: 'AltGr: G AltGr-3 -> អ៑' },
			{ input: [ [ 'Q', true ] ], output: '᧠', description: 'AltGr-Shift: AltGr-Shift-q -> ᧠' },
			{ input: [ [ '%', true ] ], output: '៵', description: 'AltGr-Shift: AltGr-Shift-5 -> ៵' },
			{ input: [ [ '>', true ] ], output: '᧿', description: 'AltGr-Shift: AltGr-Shift-. -> ᧿' },

			// test special characters
			// !
			{ input: '!', output: '!', description: 'special: ! -> !' },
			{ input: [ [ '!', true ] ], output: '៱', description: 'special: AltGr-! -> ៱' },
			// $
			{ input: '$', output: '៛', description: 'special: $ -> ៛' },
			{ input: [ [ '$', true ] ], output: '៴', description: 'special: AltGr-$ -> ៴' },
			// ^
			{ input: 'G^', output: 'អ៍', description: 'special: G^ -> អ៍' },
			{ input: [ [ '^', true ] ], output: '៶', description: 'special: AltGr-^ -> ៶' },
			// &
			{ input: 'G&', output: 'អ័', description: 'special: G& -> អ័' },
			{ input: [ [ '&', true ] ], output: '៷', description: 'special: AltGr-& -> ៷' },
			// *
			{ input: 'G*', output: 'អ៏', description: 'special: G* -> អ៏' },
			{ input: [ [ '*', true ] ], output: '៸', description: 'special: AltGr-* -> ៸' },
			// (
			{ input: '(', output: '(', description: 'special: ( -> (' },
			{ input: [ [ '(', true ] ], output: '៹', description: 'special: AltGr-( -> ៹' },
			// )
			{ input: ')', output: ')', description: 'special: ) -> )' },
			{ input: [ [ ')', true ] ], output: '៰', description: 'special: AltGr-) -> ៰' },
			// -
			{ input: '-', output: 'ឥ', description: 'special: - -> ឥ' },
			{ input: [ [ '-', true ] ], output: 'x', description: 'special: AltGr-- -> x' },
			// =
			{ input: '=', output: 'ឲ', description: 'special: = -> ឲ' },
			{ input: [ 'G', [ '=', true ] ], output: 'អ៎', description: 'special: G AltGr-= H -> អ៎' },
			// +
			{ input: '+', output: '=', description: 'special: + -> =' },
			// backslash
			{ input: '\\', output: 'ឮ', description: 'special: \\ -> ឮ' },
			{ input: [ [ '\\', true ] ], output: '\\', description: 'special: AltGr-\\ -> \\' },
			// |
			{ input: '|', output: 'ឭ', description: 'special: | -> ឭ' },
			// [
			{ input: 'G[', output: 'អៀ', description: 'special: G[ -> អៀ' },
			{ input: [ [ '[ ', true ] ], output: 'ឩ', description: 'special: AltGr-[ -> ឩ' },
			// {
			{ input: 'G{', output: 'អឿ', description: 'special: G{ -> អឿ' },
			{ input: [ [ '{', true ] ], output: '᧪', description: 'special: AltGr-{ -> ᧪' },
			// ]
			{ input: ']', output: 'ឪ', description: 'special: ] -> ឪ' },
			{ input: [ [ ']', true ] ], output: 'ឳ', description: 'special: AltGr-] -> ឳ' },
			// }
			{ input: '}', output: 'ឧ', description: 'special: } -> ឧ' },
			{ input: [ [ '}', true ] ], output: '᧫', description: 'special: AltGr-} -> ᧫' },
			// ;
			{ input: 'G;', output: 'អើ', description: 'special: G; -> អើ' },
			{ input: [ [ ';', true ] ], output: '៖', description: 'special: AltGr-; -> ៖' },
			// :
			{ input: 'G:', output: 'អោះ', description: 'special: G: -> អោះ' },
			{ input: [ [ ':', true ] ], output: '᧵', description: 'special: AltGr-: -> ᧵' },
			// '
			{ input: 'G\'', output: 'អ់', description: 'special: G\' -> អ់' },
			{ input: [ 'G', [ '\'', true ] ], output: 'អៈ', description: 'special: G AltGr-: -> អៈ' },
			// "
			{ input: 'G"', output: 'អ៉', description: 'special: G" -> អ៉' },
			{ input: [ [ '"', true ] ], output: '᧶', description: 'special: AltGr-" -> ᧶' },
			// ,
			{ input: 'G,', output: 'អុំ', description: 'special: G, -> អុំ' },
			{ input: [ [ ',', true ] ], output: ',', description: 'special: AltGr-, -> ,' },
			// <
			{ input: 'G<', output: 'អុះ', description: 'special: G< -> អុះ' },
			{ input: [ [ '<', true ] ], output: '᧾', description: 'special: AltGr-< -> ᧾' },
			// .
			{ input: '.', output: '។', description: 'special: . -> ។' },
			{ input: [ [ '.', true ] ], output: '.', description: 'special: AltGr-. -> .' },
			// >
			{ input: '>', output: '៕', description: 'special: > -> ៕' },
			{ input: [ [ '>', true ] ], output: '᧿', description: 'special: AltGr-> -> ᧿' },
			// /
			{ input: 'G/', output: 'អ៊', description: 'special: G/ -> អ៊' },
			{ input: [ [ '/', true ] ], output: '/', description: 'special: AltGr-/ -> /' },
			// ?
			{ input: '?', output: '?', description: 'special: ? -> ?' },

			// tests from How_to_type_Khmer_Unicode_ver1_1km.pdf (NiDA)
			{ input: 'li', output: 'លិ', description: 'NiDA: li -> លិ' },
			{ input: 'Ke', output: 'គេ', description: 'NiDA: li -> គេ' },
			{ input: 'nO', output: 'នៅ', description: 'NiDA: nO -> នៅ' },
			{ input: 'l;', output: 'លើ', description: 'NiDA: l; -> លើ' },
			{ input: 'ctjt', output: 'ចត្ត', description: 'NiDA: ctjt -> ចត្ត' },
			{ input: 'sjrI', output: 'ស្រី', description: 'NiDA: sjrI -> ស្រី' },
			{ input: 'sjrE', output: 'ស្រែ', description: 'NiDA: sjrE -> ស្រែ' },
			{ input: 'sjtjrI', output: 'ស្ត្រី', description: 'NiDA: sjtjrI -> ស្ត្រី' },
			{ input: 'TaJ', output: 'ទាញ', description: 'NiDA: TaJ -> ទាញ' },
			{ input: 'sJjJa', output: 'សញ្ញា', description: 'NiDA: sJjJa -> សញ្ញា' },
			{ input: 'xjJ,', output: 'ខ្ញុំ', description: 'NiDA: xjJ, -> ខ្ញុំ' },
			{ input: 'bJjceJ', output: 'បញ្ចេញ', description: 'NiDA: bJjceJ -> បញ្ចេញ' },
			{ input: 'kEH', output: 'កែះ', description: 'NiDA: kEH -> កែះ' },
			{ input: 'y"ak', output: 'យ៉ាក', description: 'NiDA: y"ak -> យ៉ាក' },
			{ input: 'b"egb":', output: 'ប៉េងប៉ោះ', description: 'NiDA: b"egb": -> ប៉េងប៉ោះ' },
			{ input: 'kjrumh/un', output: 'ក្រុមហ៊ុន', description: 'NiDA: kjrumh/un -> ក្រុមហ៊ុន' },
			{ input: 'b/ut', output: 'ប៊ុត', description: 'NiDA: b/ut -> ប៊ុត' },
			{ input: 'sjr/ub', output: 'ស្រ៊ុប', description: 'NiDA: sjr/ub -> ស្រ៊ុប' },
			// { input: 's/jrub', output: 'ស៊្រុប', description: 'NiDA (Unicode 3.0 -> 4.0): s/jrub -> ស៊្រុប' },
			{ input: 's/jrub', output: 'ស៊្រុប', description: 'NiDA (Unicode 4.0): s/jrub -> ស៊្រុប' },
			{ input: 'mjh/Et', output: 'ម្ហ៊ែត', description: 'NiDA: mjh/Et -> ម្ហ៊ែត' },
			// { input: 'mjh/Et', output: 'ម៊្ហែត', description: 'NiDA (Unicode 3.0 -> 4.0): mjh/Et -> ម៊្ហែត' },
			{ input: 'm/jhEt', output: 'ម៊្ហែត', description: 'NiDA (Unicode 4.0): m/jhEt -> ម៊្ហែត' },
			{ input: 's/', output: 'ស៊', description: 'NiDA: s/ -> ស៊' },
			{ input: 's/I', output: 'ស៊ី', description: 'NiDA: s/I -> ស៊ី' },
			{ input: 'b"I', output: 'ប៉ី', description: 'NiDA: b"I -> ប៉ី' },
			{ input: 'bnjs/I', output: 'បន្ស៊ី', description: 'NiDA: bnjs/I -> បន្ស៊ី' },
			// { input: 'bnjs/I', output: 'បន៊្សី', description: 'NiDA (Unicode 3.0 -> 4.0): bnjs/I -> បន៊្សី' },
			{ input: 'bn/jsI', output: 'បន៊្សី', description: 'NiDA (Unicode 4.0): bn/js/I -> បន៊្សី' },
			{ input: 'G/M', output: 'អ៊ំ', description: 'NiDA: G/M -> អ៊ំ' },
			{ input: 'b/ik', output: 'ប៊ិក', description: 'NiDA: b/ik -> ប៊ិក' },

			// with some fonts it may looks like អ្ហុិះ (GjhuiH) instead
			{ input: 'Gjh/iH', output: 'អ្ហ៊ិះ', description: 'NiDA: Gjh/iH -> អ្ហ៊ិះ' },
			// { input: 'Gjh/iH', output: 'អ៊្ហិះ', description: 'NiDA (Unicode 3.0 -> 4.0): Gjh/iH -> អ៊្ហិះ' },
			{ input: 'G/jhiH', output: 'អ៊្ហិះ', description: 'NiDA (Unicode 4.0): G/jhiH -> អ៊្ហិះ' },

			{ input: 'BN_', output: 'ពណ៌', description: 'NiDA: BN_ -> ពណ៌' },
			{ input: [ 's', 'K', '_', [ '\'', true ] ], output: 'សគ៌ៈ', description: 'NiDA: sK_ AltGr-\' -> សគ៌ៈ' },
			{ input: 'kb_Ur', output: 'កប៌ូរ', description: 'NiDA: kb_Ur -> កប៌ូរ' },
			{ input: 'kab_as', output: 'កាប៌ាស', description: 'NiDA: kab_as -> កាប៌ាស' },
			{ input: 'sB_eCjJ', output: 'សព៌េជ្ញ', description: 'NiDA: sB_eCjJ -> សព៌េជ្ញ' },
			{ input: 'lk\'', output: 'លក់', description: 'NiDA: lk\' -> លក់' },
			{ input: 'TMB&r', output: 'ទំព័រ', description: 'NiDA: TMB&r -> ទំព័រ' },
			{ input: [ 'N', [ '=', true ], 'H' ], output: 'ណ៎ះ', description: 'NiDA: N AltGr-= H -> ណ៎ះ' },
			{ input: [ 'n', 'u', [ '=', true ], 'H' ], output: 'នុ៎ះ', description: 'NiDA: nu AltGr-= H -> នុ៎ះ' },
			{ input: [ 'G', 'I', [ '=', true ], 'H' ], output: 'អី៎ះ', description: 'NiDA: GI AltGr-= H -> អី៎ះ' },
			{ input: 'kEH', output: 'កែះ', description: 'NiDA: kEH -> កែះ' },

			{ input: '#', output: '"', description: 'NiDA: # -> "' },
			{ input: ' ', output: '\u200b', description: 'NiDA: SP -> ZWSP' },
			{ input: [ [ ' ', false, true ] ], output: ' ', description: 'NiDA: Shift-SP -> SP' },
			{ input: [ [ ' ', true ] ], output: '\u00a0', description: 'NiDA: AltGr-SP -> NBSP' },

			// check (non-)joiners, from Unicode 8.0 chapter 16
			{ input: [ 'b', [ '1', true ], '/', 'I', 'y', 'E', 'r' ], output: 'ប‌៊ីយែរ', description: 'ZWNJ (beer): b AltGr-1 /IyEr -> ប‌៊ីយែរ' },
			{ input: [ 'b', 'j', 'r', 't', 'W', 'g', 'G', [ '1', true ], '/', 'w', 'H' ], output: 'ប្រតឺងអ‌៊ឹះ', description: 'ZWNJ (urgent, too busy): bjrtWgG AltGr-1 /wH -> ប្រតឺងអ‌៊ឹះ' },
			// these two should looks different with a Moul font
			{ input: [ 'v', [ '1', true ], 'i', 'T', 'U' ], output: 'វ‌ិទូ', description: 'ZWNJ (savant): v AltGr-1 iTU -> វ‌ិទូ' },
			{ input: [ 'v', [ '`', true ], 'i', 'T', 'U' ], output: 'វ‍ិទូ', description: 'ZWJ (savant): v AltGr-` iTU -> វ‍ិទូ' }
		]
	},
	{
		description: 'Kannada InScript 2 test',
		inputmethod: 'kn-inscript2',
		tests: [
			{ input: [ [ '.', true ] ], output: '॥', description: 'Kannada InScript 2 AltGr-. -> ॥' }
		]
	},
	{
		description: 'Kannada KGP test',
		inputmethod: 'kn-kgp',
		tests: [
			{ input: 'aAiIuURRXeEYoOVaMaH', output: 'ಅಆಇಈಉಊಋೠಎಏಐಒಓಔಅಂಅಃ', description: 'vowels ಅಆಇಈಉಊಋೠಎಏಐಒಓಔಅಂಅಃ' },
			{ input: 'kKgGZ', output: 'ಕಖಗಘಙ', description: 'Consonants ಕಖಗಘಙ' },
			{ input: 'cCjJz', output: 'ಚಛಜಝಞ', description: 'Consonants ಚಛಜಝಞ' },
			{ input: 'qQwWN', output: 'ಟಠಡಢಣ', description: 'Consonants ಟಠಡಢಣ' },
			{ input: 'tTdDn', output: 'ತಥದಧನ', description: 'Consonants ತಥದಧನ' },
			{ input: 'pPbBm', output: 'ಪಫಬಭಮ', description: 'Consonants ಪಫಬಭಮ' },
			{ input: 'yrrXlvSxshLLX', output: 'ಯರಱಲವಶಷಸಹಳೞ', description: 'Consonants ಯರಲವಶಷಸಹಳ' },
			{ input: 'kf', output: 'ಕ್', description: 'kf => ಕ್' },
			{ input: 'kA', output: 'ಕಾ', description: 'kA => ಕಾ' },
			{ input: 'ki', output: 'ಕಿ', description: 'ki => ಕಿ' },
			{ input: 'kI', output: 'ಕೀ', description: 'kI => ಕೀ' },
			{ input: 'ku', output: 'ಕು', description: 'ku => ಕು' },
			{ input: 'kU', output: 'ಕೂ', description: 'kU => ಕೂ' },
			{ input: 'kR', output: 'ಕೃ', description: 'kR => ಕೃ' },
			{ input: 'kRX', output: 'ಕೄ', description: 'kRX => ಕೄ' },
			{ input: 'ke', output: 'ಕೆ', description: 'ke => ಕೆ' },
			{ input: 'kE', output: 'ಕೇ', description: 'kE => ಕೇ' },
			{ input: 'kY', output: 'ಕೈ', description: 'kY => ಕೈ' },
			{ input: 'ko', output: 'ಕೊ', description: 'ko => ಕೊ' },
			{ input: 'kO', output: 'ಕೋ', description: 'kO => ಕೋ' },
			{ input: 'kV', output: 'ಕೌ', description: 'kV => ಕೌ' },
			{ input: 'kM', output: 'ಕಂ', description: 'kM => ಕಂ' },
			{ input: 'kH', output: 'ಕಃ', description: 'kH => ಕಃ' },
			{ input: 'rAxfqfrIy', output: 'ರಾಷ್ಟ್ರೀಯ', description: 'complex consonants ರಾಷ್ಟ್ರೀಯ' },
			{ input: 'rFfyAMkf', output: 'ರ\u200d್ಯಾಂಕ್', description: 'ZWJ ರ\u200d್ಯಾಂಕ್' } // with ZWJ
		]
	},
	{
		description: 'Kannada Transliteration test',
		inputmethod: 'kn-transliteration',
		tests: [
			{ input: 'd~ha', output: 'ದ್ಹ', description: 'd~ha for ದ್ಹ in Kannada transliteration' },
			{ input: 'W', output: 'ಔ', description: 'W for ಔ in Kannada transliteration' },
			{ input: 'Y', output: 'ಐ', description: 'Y for ಐ in Kannada transliteration' },
			{ input: 'Yeso', output: 'ಐಎಸೊ', description: 'Yeso for ಐಎಸೊ in Kannada transliteration' },
			{ input: 'nAkYdu', output: 'ನಾಕೈದು', description: 'nAkYdu for ನಾಕೈದು in Kannada transliteration' },
			{ input: 'gautam', output: 'ಗೌತಮ್', description: 'gautam for ಗೌತಮ್ in Kannada transliteration' },
			{ input: 'nAkaidu', output: 'ನಾಕೈದು', description: 'nAkaidu for ನಾಕೈದು in Kannada transliteration' },
			{ input: 'gWtam', output: 'ಗೌತಮ್', description: 'gWtam for ಗೌತಮ್ in Kannada transliteration' },
			{ input: 'WShadhi', output: 'ಔಷಧಿ', description: 'WShadhi for ಔಷಧಿ in Kannada transliteration' },
			{ input: 'auShadhi', output: 'ಔಷಧಿ', description: 'auShadhi for ಔಷಧಿ in Kannada transliteration' },
			{ input: 'Ydu', output: 'ಐದು', description: 'Ydu for ಐದು in Kannada transliteration' },
			{ input: 'kY', output: 'ಕೈ', description: 'kY for ಕೈ in Kannada transliteration' },
			{ input: 'kW', output: 'ಕೌ', description: 'kW for ಐದು in Kannada transliteration' },
			{ input: 'kR', output: 'ಕೃ', description: 'kR for ಕೃ in Kannada transliteration' },
			{ input: 'kai', output: 'ಕೈ', description: 'kai for ಕೈ in Kannada transliteration' },
			{ input: 'nya', output: 'ನ್ಯ', description: 'nya for ಧನ್ಯವಾದ in Kannada transliteration' },
			{ input: 'rAShTRIya', output: 'ರಾಷ್ಟ್ರೀಯ', description: 'complex consonants rAShTRIya for ರಾಷ್ಟ್ರೀಯ in Kannada transliteration' },
			{ input: 'raaShTRIya', output: 'ರಾಷ್ಟ್ರೀಯ', description: 'complex consonants raaShTRIya for ರಾಷ್ಟ್ರೀಯ in Kannada transliteration' },
			{ input: 'j~na', output: 'ಜ್ಞ', description: 'j~n for ಜ್ಞ in Kannada transliteration ' },
			{ input: 'mu', output: 'ಮು', description: 'mu for ಮು in Kannada transliteration ' },
			{ input: 'mU', output: 'ಮೂ', description: 'mU for ಮೂ in Kannada transliteration ' },
			{ input: 'mo', output: 'ಮೊ', description: 'mo for ಮೊ in Kannada transliteration ' },
			{ input: 'rAjxkumAr', output: 'ರಾಜ್\u200dಕುಮಾರ್', description: 'rAjxkumAr for ರಾಜ್\u200dಕುಮಾರ್ in Kannada transliteration ' }, // with ZWJ
			{ input: 'arha', output: 'ಅರ್ಹ', description: 'arha for ಅರ್ಕಾವತ್ತು in ಅರ್ಹ for Kannada transliteration ' },
			{ input: 'dhvani', output: 'ಧ್ವನಿ', description: 'dhvani for ಧ್ವನಿ for Kannada transliteration ' },
			{ input: 'marmara', output: 'ಮರ್ಮರ', description: 'marmara for ಮರ್ಮರ for Kannada transliteration ' },
			{ input: 'svaataMtrya', output: 'ಸ್ವಾತಂತ್ರ್ಯ', description: 'svaataMtrya for ಸ್ವಾತಂತ್ರ್ಯ for Kannada transliteration ' },
			{ input: 'sarvaj~na', output: 'ಸರ್ವಜ್ಞ', description: 'sarvadnya for ಸರ್ವಜ್ಞ for Kannada transliteration ' },
			{ input: 'sarvaj~na', output: 'ಸರ್ವಜ್ಞ', description: 'sarvaj~na for ಸರ್ವಜ್ಞ for Kannada transliteration ' },
			{ input: 'O~M', output: 'ॐ', description: 'O~M for ॐ for Kannada transliteration ' },
			{ input: 'byaaskeT', output: 'ಬ್ಯಾಸ್ಕೆಟ್', description: 'byaaskeT for ಬ್ಯಾಸ್ಕೆಟ್ for Kannada transliteration ' },
			{ input: 'braakeT', output: 'ಬ್ರಾಕೆಟ್', description: 'braakeT for ಬ್ರ್ಯಾಕೆಟ್ for Kannada transliteration ' },
			{ input: 'nOTna', output: 'ನೋಟ್ನ', description: 'noTna for ನೋಟ್ನ for Kannada transliteration ' },
			{ input: 'saMskRta', output: 'ಸಂಸ್ಕೃತ', description: 'saMskRta for ಸಂಸ್ಕೃತ for Kannada transliteration ' },
			{ input: 'aalTarxnETIv', output: 'ಆಲ್ಟರ್\u200dನೇಟೀವ್', description: 'aalTarxnETIv for ಆಲ್ಟರ್\u200dನೇಟೀವ್ for Kannada transliteration ' }, // with ZWJ
			{ input: 'kaarxnalli', output: 'ಕಾರ್\u200dನಲ್ಲಿ', description: 'kaarxnalli for ಕಾರ್\u200dನಲ್ಲಿ for Kannada transliteration ' }, // with ZWJ
			{ input: 'a', output: 'ಅ', description: 'a for ಅ in Kannada transliteration' },
			{ input: 'ka', output: 'ಕ', description: 'ka for ಕ in Kannada transliteration' },
			{ input: 'Ka', output: 'ಖ', description: 'Ka for ಖ in Kannada transliteration' },
			{ input: 'ga', output: 'ಗ', description: 'ga for ಗ in Kannada transliteration' },
			{ input: 'Ga', output: 'ಘ', description: 'Ga for ಘ in Kannada transliteration' },
			{ input: '~ga', output: 'ಙ', description: '~ga for ಙ in Kannada transliteration' },
			{ input: 'ca', output: 'ಚ', description: 'ca for ಚ in Kannada transliteration' },
			{ input: 'Ca', output: 'ಛ', description: 'Ca for ಛ in Kannada transliteration' },
			{ input: 'ja', output: 'ಜ', description: 'ja for ಜ in Kannada transliteration' },
			{ input: 'Ja', output: 'ಝ', description: 'Ja for ಝ in Kannada transliteration' },
			{ input: '~ja', output: 'ಞ', description: '~ja for ಞ in Kannada transliteration' },
			{ input: 'Ta', output: 'ಟ', description: 'Ta for ಟ in Kannada transliteration' },
			{ input: 'Tha', output: 'ಠ', description: 'Tha for ಠ in Kannada transliteration' },
			{ input: 'Da', output: 'ಡ', description: 'Da for ಡ in Kannada transliteration' },
			{ input: 'Dha', output: 'ಢ', description: 'Dha for ಢ in Kannada transliteration' },
			{ input: 'Na', output: 'ಣ', description: 'Na for ಣ in Kannada transliteration' },
			{ input: 'ta', output: 'ತ', description: 'ta for ತ in Kannada transliteration' },
			{ input: 'tha', output: 'ಥ', description: 'tha for ಥ in Kannada transliteration' },
			{ input: 'da', output: 'ದ', description: 'da for ದ in Kannada transliteration' },
			{ input: 'dha', output: 'ಧ', description: 'dha for ಧ in Kannada transliteration' },
			{ input: 'na', output: 'ನ', description: 'na for ನ in Kannada transliteration' },
			{ input: 'pa', output: 'ಪ', description: 'pa for ಪ in Kannada transliteration' },
			{ input: 'Pa', output: 'ಫ', description: 'Pa for ಫ in Kannada transliteration' },
			{ input: 'ba', output: 'ಬ', description: 'ba for ಬ in Kannada transliteration' },
			{ input: 'Ba', output: 'ಭ', description: 'Ba for ಭ in Kannada transliteration' },
			{ input: 'ma', output: 'ಮ', description: 'ma for ಮ in Kannada transliteration' },
			{ input: 'ya', output: 'ಯ', description: 'ya for ಯ in Kannada transliteration' },
			{ input: 'ra', output: 'ರ', description: 'ra for ರ in Kannada transliteration' },
			{ input: 'qa', output: 'ಱ', description: 'qa for ಱ in Kannada transliteration' },
			{ input: 'la', output: 'ಲ', description: 'la for ಲ in Kannada transliteration' },
			{ input: 'va', output: 'ವ', description: 'va for ವ in Kannada transliteration' },
			{ input: 'Sa', output: 'ಶ', description: 'Sa for ಶ in Kannada transliteration' },
			{ input: 'Sha', output: 'ಷ', description: 'Sha for ಷ in Kannada transliteration' },
			{ input: 'sa', output: 'ಸ', description: 'sa for ಸ in Kannada transliteration' },
			{ input: 'ha', output: 'ಹ', description: 'ha for ಹ in Kannada transliteration' },
			{ input: 'La', output: 'ಳ', description: 'La for ಳ in Kannada transliteration' },
			{ input: 'Qa', output: 'ೞ', description: 'Qa for ೞ in Kannada transliteration' },
			{ input: 'A', output: 'ಆ', description: 'A for ಆ in Kannada transliteration' },
			{ input: 'kA', output: 'ಕಾ', description: 'kA for ಕಾ in Kannada transliteration' },
			{ input: 'KA', output: 'ಖಾ', description: 'KA for ಖಾ in Kannada transliteration' },
			{ input: 'gA', output: 'ಗಾ', description: 'gA for ಗಾ in Kannada transliteration' },
			{ input: 'GA', output: 'ಘಾ', description: 'GA for ಘಾ in Kannada transliteration' },
			{ input: '~gA', output: 'ಙಾ', description: '~gA for ಙಾ in Kannada transliteration' },
			{ input: 'cA', output: 'ಚಾ', description: 'cA for ಚಾ in Kannada transliteration' },
			{ input: 'CA', output: 'ಛಾ', description: 'CA for ಛಾ in Kannada transliteration' },
			{ input: 'jA', output: 'ಜಾ', description: 'jA for ಜಾ in Kannada transliteration' },
			{ input: 'JA', output: 'ಝಾ', description: 'JA for ಝಾ in Kannada transliteration' },
			{ input: '~jA', output: 'ಞಾ', description: '~jA for ಞಾ in Kannada transliteration' },
			{ input: 'TA', output: 'ಟಾ', description: 'TA for ಟಾ in Kannada transliteration' },
			{ input: 'ThA', output: 'ಠಾ', description: 'ThA for ಠಾ in Kannada transliteration' },
			{ input: 'DA', output: 'ಡಾ', description: 'DA for ಡಾ in Kannada transliteration' },
			{ input: 'DhA', output: 'ಢಾ', description: 'DhA for ಢಾ in Kannada transliteration' },
			{ input: 'NA', output: 'ಣಾ', description: 'NA for ಣಾ in Kannada transliteration' },
			{ input: 'tA', output: 'ತಾ', description: 'tA for ತಾ in Kannada transliteration' },
			{ input: 'thA', output: 'ಥಾ', description: 'thA for ಥಾ in Kannada transliteration' },
			{ input: 'dA', output: 'ದಾ', description: 'dA for ದಾ in Kannada transliteration' },
			{ input: 'dhA', output: 'ಧಾ', description: 'dhA for ಧಾ in Kannada transliteration' },
			{ input: 'nA', output: 'ನಾ', description: 'nA for ನಾ in Kannada transliteration' },
			{ input: 'pA', output: 'ಪಾ', description: 'pA for ಪಾ in Kannada transliteration' },
			{ input: 'PA', output: 'ಫಾ', description: 'PA for ಫಾ in Kannada transliteration' },
			{ input: 'bA', output: 'ಬಾ', description: 'bA for ಬಾ in Kannada transliteration' },
			{ input: 'BA', output: 'ಭಾ', description: 'BA for ಭಾ in Kannada transliteration' },
			{ input: 'mA', output: 'ಮಾ', description: 'mA for ಮಾ in Kannada transliteration' },
			{ input: 'yA', output: 'ಯಾ', description: 'yA for ಯಾ in Kannada transliteration' },
			{ input: 'rA', output: 'ರಾ', description: 'rA for ರಾ in Kannada transliteration' },
			{ input: 'qA', output: 'ಱಾ', description: 'qA for ಱಾ in Kannada transliteration' },
			{ input: 'lA', output: 'ಲಾ', description: 'lA for ಲಾ in Kannada transliteration' },
			{ input: 'vA', output: 'ವಾ', description: 'vA for ವಾ in Kannada transliteration' },
			{ input: 'SA', output: 'ಶಾ', description: 'SA for ಶಾ in Kannada transliteration' },
			{ input: 'ShA', output: 'ಷಾ', description: 'ShA for ಷಾ in Kannada transliteration' },
			{ input: 'sA', output: 'ಸಾ', description: 'sA for ಸಾ in Kannada transliteration' },
			{ input: 'hA', output: 'ಹಾ', description: 'hA for ಹಾ in Kannada transliteration' },
			{ input: 'LA', output: 'ಳಾ', description: 'LA for ಳಾ in Kannada transliteration' },
			{ input: 'QA', output: 'ೞಾ', description: 'QA for ೞಾ in Kannada transliteration' },
			{ input: 'i', output: 'ಇ', description: 'i for ಇ in Kannada transliteration' },
			{ input: 'ki', output: 'ಕಿ', description: 'ki for ಕಿ in Kannada transliteration' },
			{ input: 'Ki', output: 'ಖಿ', description: 'Ki for ಖಿ in Kannada transliteration' },
			{ input: 'gi', output: 'ಗಿ', description: 'gi for ಗಿ in Kannada transliteration' },
			{ input: 'Gi', output: 'ಘಿ', description: 'Gi for ಘಿ in Kannada transliteration' },
			{ input: '~gi', output: 'ಙಿ', description: '~gi for ಙಿ in Kannada transliteration' },
			{ input: 'ci', output: 'ಚಿ', description: 'ci for ಚಿ in Kannada transliteration' },
			{ input: 'Ci', output: 'ಛಿ', description: 'Ci for ಛಿ in Kannada transliteration' },
			{ input: 'ji', output: 'ಜಿ', description: 'ji for ಜಿ in Kannada transliteration' },
			{ input: 'Ji', output: 'ಝಿ', description: 'Ji for ಝಿ in Kannada transliteration' },
			{ input: '~ji', output: 'ಞಿ', description: '~ji for ಞಿ in Kannada transliteration' },
			{ input: 'Ti', output: 'ಟಿ', description: 'Ti for ಟಿ in Kannada transliteration' },
			{ input: 'Thi', output: 'ಠಿ', description: 'Thi for ಠಿ in Kannada transliteration' },
			{ input: 'Di', output: 'ಡಿ', description: 'Di for ಡಿ in Kannada transliteration' },
			{ input: 'Dhi', output: 'ಢಿ', description: 'Dhi for ಢಿ in Kannada transliteration' },
			{ input: 'Ni', output: 'ಣಿ', description: 'Ni for ಣಿ in Kannada transliteration' },
			{ input: 'ti', output: 'ತಿ', description: 'ti for ತಿ in Kannada transliteration' },
			{ input: 'thi', output: 'ಥಿ', description: 'thi for ಥಿ in Kannada transliteration' },
			{ input: 'di', output: 'ದಿ', description: 'di for ದಿ in Kannada transliteration' },
			{ input: 'dhi', output: 'ಧಿ', description: 'dhi for ಧಿ in Kannada transliteration' },
			{ input: 'ni', output: 'ನಿ', description: 'ni for ನಿ in Kannada transliteration' },
			{ input: 'pi', output: 'ಪಿ', description: 'pi for ಪಿ in Kannada transliteration' },
			{ input: 'Pi', output: 'ಫಿ', description: 'Pi for ಫಿ in Kannada transliteration' },
			{ input: 'bi', output: 'ಬಿ', description: 'bi for ಬಿ in Kannada transliteration' },
			{ input: 'Bi', output: 'ಭಿ', description: 'Bi for ಭಿ in Kannada transliteration' },
			{ input: 'mi', output: 'ಮಿ', description: 'mi for ಮಿ in Kannada transliteration' },
			{ input: 'yi', output: 'ಯಿ', description: 'yi for ಯಿ in Kannada transliteration' },
			{ input: 'ri', output: 'ರಿ', description: 'ri for ರಿ in Kannada transliteration' },
			{ input: 'qi', output: 'ಱಿ', description: 'qi for ಱಿ in Kannada transliteration' },
			{ input: 'li', output: 'ಲಿ', description: 'li for ಲಿ in Kannada transliteration' },
			{ input: 'vi', output: 'ವಿ', description: 'vi for ವಿ in Kannada transliteration' },
			{ input: 'Si', output: 'ಶಿ', description: 'Si for ಶಿ in Kannada transliteration' },
			{ input: 'Shi', output: 'ಷಿ', description: 'Shi for ಷಿ in Kannada transliteration' },
			{ input: 'si', output: 'ಸಿ', description: 'si for ಸಿ in Kannada transliteration' },
			{ input: 'hi', output: 'ಹಿ', description: 'hi for ಹಿ in Kannada transliteration' },
			{ input: 'Li', output: 'ಳಿ', description: 'Li for ಳಿ in Kannada transliteration' },
			{ input: 'Qi', output: 'ೞಿ', description: 'Qi for ೞಿ in Kannada transliteration' },
			{ input: 'I', output: 'ಈ', description: 'I for ಈ in Kannada transliteration' },
			{ input: 'kI', output: 'ಕೀ', description: 'kI for ಕೀ in Kannada transliteration' },
			{ input: 'KI', output: 'ಖೀ', description: 'KI for ಖೀ in Kannada transliteration' },
			{ input: 'gI', output: 'ಗೀ', description: 'gI for ಗೀ in Kannada transliteration' },
			{ input: 'GI', output: 'ಘೀ', description: 'GI for ಘೀ in Kannada transliteration' },
			{ input: '~gI', output: 'ಙೀ', description: '~gI for ಙೀ in Kannada transliteration' },
			{ input: 'cI', output: 'ಚೀ', description: 'cI for ಚೀ in Kannada transliteration' },
			{ input: 'CI', output: 'ಛೀ', description: 'CI for ಛೀ in Kannada transliteration' },
			{ input: 'jI', output: 'ಜೀ', description: 'jI for ಜೀ in Kannada transliteration' },
			{ input: 'JI', output: 'ಝೀ', description: 'JI for ಝೀ in Kannada transliteration' },
			{ input: '~jI', output: 'ಞೀ', description: '~jI for ಞೀ in Kannada transliteration' },
			{ input: 'TI', output: 'ಟೀ', description: 'TI for ಟೀ in Kannada transliteration' },
			{ input: 'ThI', output: 'ಠೀ', description: 'ThI for ಠೀ in Kannada transliteration' },
			{ input: 'DI', output: 'ಡೀ', description: 'DI for ಡೀ in Kannada transliteration' },
			{ input: 'DhI', output: 'ಢೀ', description: 'DhI for ಢೀ in Kannada transliteration' },
			{ input: 'NI', output: 'ಣೀ', description: 'NI for ಣೀ in Kannada transliteration' },
			{ input: 'tI', output: 'ತೀ', description: 'tI for ತೀ in Kannada transliteration' },
			{ input: 'thI', output: 'ಥೀ', description: 'thI for ಥೀ in Kannada transliteration' },
			{ input: 'dI', output: 'ದೀ', description: 'dI for ದೀ in Kannada transliteration' },
			{ input: 'dhI', output: 'ಧೀ', description: 'dhI for ಧೀ in Kannada transliteration' },
			{ input: 'nI', output: 'ನೀ', description: 'nI for ನೀ in Kannada transliteration' },
			{ input: 'pI', output: 'ಪೀ', description: 'pI for ಪೀ in Kannada transliteration' },
			{ input: 'PI', output: 'ಫೀ', description: 'PI for ಫೀ in Kannada transliteration' },
			{ input: 'bI', output: 'ಬೀ', description: 'bI for ಬೀ in Kannada transliteration' },
			{ input: 'BI', output: 'ಭೀ', description: 'BI for ಭೀ in Kannada transliteration' },
			{ input: 'mI', output: 'ಮೀ', description: 'mI for ಮೀ in Kannada transliteration' },
			{ input: 'yI', output: 'ಯೀ', description: 'yI for ಯೀ in Kannada transliteration' },
			{ input: 'rI', output: 'ರೀ', description: 'rI for ರೀ in Kannada transliteration' },
			{ input: 'qI', output: 'ಱೀ', description: 'qI for ಱೀ in Kannada transliteration' },
			{ input: 'lI', output: 'ಲೀ', description: 'lI for ಲೀ in Kannada transliteration' },
			{ input: 'vI', output: 'ವೀ', description: 'vI for ವೀ in Kannada transliteration' },
			{ input: 'SI', output: 'ಶೀ', description: 'SI for ಶೀ in Kannada transliteration' },
			{ input: 'ShI', output: 'ಷೀ', description: 'ShI for ಷೀ in Kannada transliteration' },
			{ input: 'sI', output: 'ಸೀ', description: 'sI for ಸೀ in Kannada transliteration' },
			{ input: 'hI', output: 'ಹೀ', description: 'hI for ಹೀ in Kannada transliteration' },
			{ input: 'LI', output: 'ಳೀ', description: 'LI for ಳೀ in Kannada transliteration' },
			{ input: 'QI', output: 'ೞೀ', description: 'QI for ೞೀ in Kannada transliteration' },
			{ input: 'u', output: 'ಉ', description: 'u for ಉ in Kannada transliteration' },
			{ input: 'ku', output: 'ಕು', description: 'ku for ಕು in Kannada transliteration' },
			{ input: 'Ku', output: 'ಖು', description: 'Ku for ಖು in Kannada transliteration' },
			{ input: 'gu', output: 'ಗು', description: 'gu for ಗು in Kannada transliteration' },
			{ input: 'Gu', output: 'ಘು', description: 'Gu for ಘು in Kannada transliteration' },
			{ input: '~gu', output: 'ಙು', description: '~gu for ಙು in Kannada transliteration' },
			{ input: 'cu', output: 'ಚು', description: 'cu for ಚು in Kannada transliteration' },
			{ input: 'Cu', output: 'ಛು', description: 'Cu for ಛು in Kannada transliteration' },
			{ input: 'ju', output: 'ಜು', description: 'ju for ಜು in Kannada transliteration' },
			{ input: 'Ju', output: 'ಝು', description: 'Ju for ಝು in Kannada transliteration' },
			{ input: '~ju', output: 'ಞು', description: '~ju for ಞು in Kannada transliteration' },
			{ input: 'Tu', output: 'ಟು', description: 'Tu for ಟು in Kannada transliteration' },
			{ input: 'Thu', output: 'ಠು', description: 'Thu for ಠು in Kannada transliteration' },
			{ input: 'Du', output: 'ಡು', description: 'Du for ಡು in Kannada transliteration' },
			{ input: 'Dhu', output: 'ಢು', description: 'Dhu for ಢು in Kannada transliteration' },
			{ input: 'Nu', output: 'ಣು', description: 'Nu for ಣು in Kannada transliteration' },
			{ input: 'tu', output: 'ತು', description: 'tu for ತು in Kannada transliteration' },
			{ input: 'thu', output: 'ಥು', description: 'thu for ಥು in Kannada transliteration' },
			{ input: 'du', output: 'ದು', description: 'du for ದು in Kannada transliteration' },
			{ input: 'dhu', output: 'ಧು', description: 'dhu for ಧು in Kannada transliteration' },
			{ input: 'nu', output: 'ನು', description: 'nu for ನು in Kannada transliteration' },
			{ input: 'pu', output: 'ಪು', description: 'pu for ಪು in Kannada transliteration' },
			{ input: 'Pu', output: 'ಫು', description: 'Pu for ಫು in Kannada transliteration' },
			{ input: 'bu', output: 'ಬು', description: 'bu for ಬು in Kannada transliteration' },
			{ input: 'Bu', output: 'ಭು', description: 'Bu for ಭು in Kannada transliteration' },
			{ input: 'mu', output: 'ಮು', description: 'mu for ಮು in Kannada transliteration' },
			{ input: 'yu', output: 'ಯು', description: 'yu for ಯು in Kannada transliteration' },
			{ input: 'ru', output: 'ರು', description: 'ru for ರು in Kannada transliteration' },
			{ input: 'qu', output: 'ಱು', description: 'qu for ಱು in Kannada transliteration' },
			{ input: 'lu', output: 'ಲು', description: 'lu for ಲು in Kannada transliteration' },
			{ input: 'vu', output: 'ವು', description: 'vu for ವು in Kannada transliteration' },
			{ input: 'Su', output: 'ಶು', description: 'Su for ಶು in Kannada transliteration' },
			{ input: 'Shu', output: 'ಷು', description: 'Shu for ಷು in Kannada transliteration' },
			{ input: 'su', output: 'ಸು', description: 'su for ಸು in Kannada transliteration' },
			{ input: 'hu', output: 'ಹು', description: 'hu for ಹು in Kannada transliteration' },
			{ input: 'Lu', output: 'ಳು', description: 'Lu for ಳು in Kannada transliteration' },
			{ input: 'Qu', output: 'ೞು', description: 'Qu for ೞು in Kannada transliteration' },
			{ input: 'U', output: 'ಊ', description: 'U for ಊ in Kannada transliteration' },
			{ input: 'kU', output: 'ಕೂ', description: 'kU for ಕೂ in Kannada transliteration' },
			{ input: 'KU', output: 'ಖೂ', description: 'KU for ಖೂ in Kannada transliteration' },
			{ input: 'gU', output: 'ಗೂ', description: 'gU for ಗೂ in Kannada transliteration' },
			{ input: 'GU', output: 'ಘೂ', description: 'GU for ಘೂ in Kannada transliteration' },
			{ input: '~gU', output: 'ಙೂ', description: '~gU for ಙೂ in Kannada transliteration' },
			{ input: 'cU', output: 'ಚೂ', description: 'cU for ಚೂ in Kannada transliteration' },
			{ input: 'CU', output: 'ಛೂ', description: 'CU for ಛೂ in Kannada transliteration' },
			{ input: 'jU', output: 'ಜೂ', description: 'jU for ಜೂ in Kannada transliteration' },
			{ input: 'JU', output: 'ಝೂ', description: 'JU for ಝೂ in Kannada transliteration' },
			{ input: '~jU', output: 'ಞೂ', description: '~jU for ಞೂ in Kannada transliteration' },
			{ input: 'TU', output: 'ಟೂ', description: 'TU for ಟೂ in Kannada transliteration' },
			{ input: 'ThU', output: 'ಠೂ', description: 'ThU for ಠೂ in Kannada transliteration' },
			{ input: 'DU', output: 'ಡೂ', description: 'DU for ಡೂ in Kannada transliteration' },
			{ input: 'DhU', output: 'ಢೂ', description: 'DhU for ಢೂ in Kannada transliteration' },
			{ input: 'NU', output: 'ಣೂ', description: 'NU for ಣೂ in Kannada transliteration' },
			{ input: 'tU', output: 'ತೂ', description: 'tU for ತೂ in Kannada transliteration' },
			{ input: 'thU', output: 'ಥೂ', description: 'thU for ಥೂ in Kannada transliteration' },
			{ input: 'dU', output: 'ದೂ', description: 'dU for ದೂ in Kannada transliteration' },
			{ input: 'dhU', output: 'ಧೂ', description: 'dhU for ಧೂ in Kannada transliteration' },
			{ input: 'nU', output: 'ನೂ', description: 'nU for ನೂ in Kannada transliteration' },
			{ input: 'pU', output: 'ಪೂ', description: 'pU for ಪೂ in Kannada transliteration' },
			{ input: 'PU', output: 'ಫೂ', description: 'PU for ಫೂ in Kannada transliteration' },
			{ input: 'bU', output: 'ಬೂ', description: 'bU for ಬೂ in Kannada transliteration' },
			{ input: 'BU', output: 'ಭೂ', description: 'BU for ಭೂ in Kannada transliteration' },
			{ input: 'mU', output: 'ಮೂ', description: 'mU for ಮೂ in Kannada transliteration' },
			{ input: 'yU', output: 'ಯೂ', description: 'yU for ಯೂ in Kannada transliteration' },
			{ input: 'rU', output: 'ರೂ', description: 'rU for ರೂ in Kannada transliteration' },
			{ input: 'qU', output: 'ಱೂ', description: 'qU for ಱೂ in Kannada transliteration' },
			{ input: 'lU', output: 'ಲೂ', description: 'lU for ಲೂ in Kannada transliteration' },
			{ input: 'vU', output: 'ವೂ', description: 'vU for ವೂ in Kannada transliteration' },
			{ input: 'SU', output: 'ಶೂ', description: 'SU for ಶೂ in Kannada transliteration' },
			{ input: 'ShU', output: 'ಷೂ', description: 'ShU for ಷೂ in Kannada transliteration' },
			{ input: 'sU', output: 'ಸೂ', description: 'sU for ಸೂ in Kannada transliteration' },
			{ input: 'hU', output: 'ಹೂ', description: 'hU for ಹೂ in Kannada transliteration' },
			{ input: 'LU', output: 'ಳೂ', description: 'LU for ಳೂ in Kannada transliteration' },
			{ input: 'QU', output: 'ೞೂ', description: 'QU for ೞೂ in Kannada transliteration' },
			{ input: 'R', output: 'ಋ', description: 'R for ಋ in Kannada transliteration' },
			{ input: 'kR', output: 'ಕೃ', description: 'kR for ಕೃ in Kannada transliteration' },
			{ input: 'KR', output: 'ಖೃ', description: 'KR for ಖೃ in Kannada transliteration' },
			{ input: 'gR', output: 'ಗೃ', description: 'gR for ಗೃ in Kannada transliteration' },
			{ input: 'GR', output: 'ಘೃ', description: 'GR for ಘೃ in Kannada transliteration' },
			{ input: '~gR', output: 'ಙೃ', description: '~gR for ಙೃ in Kannada transliteration' },
			{ input: 'cR', output: 'ಚೃ', description: 'cR for ಚೃ in Kannada transliteration' },
			{ input: 'CR', output: 'ಛೃ', description: 'CR for ಛೃ in Kannada transliteration' },
			{ input: 'jR', output: 'ಜೃ', description: 'jR for ಜೃ in Kannada transliteration' },
			{ input: 'JR', output: 'ಝೃ', description: 'JR for ಝೃ in Kannada transliteration' },
			{ input: '~jR', output: 'ಞೃ', description: '~jR for ಞೃ in Kannada transliteration' },
			{ input: 'TR', output: 'ಟೃ', description: 'TR for ಟೃ in Kannada transliteration' },
			{ input: 'ThR', output: 'ಠೃ', description: 'ThR for ಠೃ in Kannada transliteration' },
			{ input: 'DR', output: 'ಡೃ', description: 'DR for ಡೃ in Kannada transliteration' },
			{ input: 'DhR', output: 'ಢೃ', description: 'DhR for ಢೃ in Kannada transliteration' },
			{ input: 'NR', output: 'ಣೃ', description: 'NR for ಣೃ in Kannada transliteration' },
			{ input: 'tR', output: 'ತೃ', description: 'tR for ತೃ in Kannada transliteration' },
			{ input: 'thR', output: 'ಥೃ', description: 'thR for ಥೃ in Kannada transliteration' },
			{ input: 'dR', output: 'ದೃ', description: 'dR for ದೃ in Kannada transliteration' },
			{ input: 'dhR', output: 'ಧೃ', description: 'dhR for ಧೃ in Kannada transliteration' },
			{ input: 'nR', output: 'ನೃ', description: 'nR for ನೃ in Kannada transliteration' },
			{ input: 'pR', output: 'ಪೃ', description: 'pR for ಪೃ in Kannada transliteration' },
			{ input: 'PR', output: 'ಫೃ', description: 'PR for ಫೃ in Kannada transliteration' },
			{ input: 'bR', output: 'ಬೃ', description: 'bR for ಬೃ in Kannada transliteration' },
			{ input: 'BR', output: 'ಭೃ', description: 'BR for ಭೃ in Kannada transliteration' },
			{ input: 'mR', output: 'ಮೃ', description: 'mR for ಮೃ in Kannada transliteration' },
			{ input: 'yR', output: 'ಯೃ', description: 'yR for ಯೃ in Kannada transliteration' },
			{ input: 'rR', output: 'ರೃ', description: 'rR for ರೃ in Kannada transliteration' },
			{ input: 'qR', output: 'ಱೃ', description: 'qR for ಱೃ in Kannada transliteration' },
			{ input: 'lR', output: 'ಲೃ', description: 'lR for ಲೃ in Kannada transliteration' },
			{ input: 'vR', output: 'ವೃ', description: 'vR for ವೃ in Kannada transliteration' },
			{ input: 'SR', output: 'ಶೃ', description: 'SR for ಶೃ in Kannada transliteration' },
			{ input: 'ShR', output: 'ಷೃ', description: 'ShR for ಷೃ in Kannada transliteration' },
			{ input: 'sR', output: 'ಸೃ', description: 'sR for ಸೃ in Kannada transliteration' },
			{ input: 'hR', output: 'ಹೃ', description: 'hR for ಹೃ in Kannada transliteration' },
			{ input: 'LR', output: 'ಳೃ', description: 'LR for ಳೃ in Kannada transliteration' },
			{ input: 'QR', output: 'ೞೃ', description: 'QR for ೞೃ in Kannada transliteration' },
			{ input: 'e', output: 'ಎ', description: 'e for ಎ in Kannada transliteration' },
			{ input: 'ke', output: 'ಕೆ', description: 'ke for ಕೆ in Kannada transliteration' },
			{ input: 'Ke', output: 'ಖೆ', description: 'Ke for ಖೆ in Kannada transliteration' },
			{ input: 'ge', output: 'ಗೆ', description: 'ge for ಗೆ in Kannada transliteration' },
			{ input: 'Ge', output: 'ಘೆ', description: 'Ge for ಘೆ in Kannada transliteration' },
			{ input: '~ge', output: 'ಙೆ', description: '~ge for ಙೆ in Kannada transliteration' },
			{ input: 'ce', output: 'ಚೆ', description: 'ce for ಚೆ in Kannada transliteration' },
			{ input: 'Ce', output: 'ಛೆ', description: 'Ce for ಛೆ in Kannada transliteration' },
			{ input: 'je', output: 'ಜೆ', description: 'je for ಜೆ in Kannada transliteration' },
			{ input: 'Je', output: 'ಝೆ', description: 'Je for ಝೆ in Kannada transliteration' },
			{ input: '~je', output: 'ಞೆ', description: '~je for ಞೆ in Kannada transliteration' },
			{ input: 'Te', output: 'ಟೆ', description: 'Te for ಟೆ in Kannada transliteration' },
			{ input: 'The', output: 'ಠೆ', description: 'The for ಠೆ in Kannada transliteration' },
			{ input: 'De', output: 'ಡೆ', description: 'De for ಡೆ in Kannada transliteration' },
			{ input: 'Dhe', output: 'ಢೆ', description: 'Dhe for ಢೆ in Kannada transliteration' },
			{ input: 'Ne', output: 'ಣೆ', description: 'Ne for ಣೆ in Kannada transliteration' },
			{ input: 'te', output: 'ತೆ', description: 'te for ತೆ in Kannada transliteration' },
			{ input: 'the', output: 'ಥೆ', description: 'the for ಥೆ in Kannada transliteration' },
			{ input: 'de', output: 'ದೆ', description: 'de for ದೆ in Kannada transliteration' },
			{ input: 'dhe', output: 'ಧೆ', description: 'dhe for ಧೆ in Kannada transliteration' },
			{ input: 'ne', output: 'ನೆ', description: 'ne for ನೆ in Kannada transliteration' },
			{ input: 'pe', output: 'ಪೆ', description: 'pe for ಪೆ in Kannada transliteration' },
			{ input: 'Pe', output: 'ಫೆ', description: 'Pe for ಫೆ in Kannada transliteration' },
			{ input: 'be', output: 'ಬೆ', description: 'be for ಬೆ in Kannada transliteration' },
			{ input: 'Be', output: 'ಭೆ', description: 'Be for ಭೆ in Kannada transliteration' },
			{ input: 'me', output: 'ಮೆ', description: 'me for ಮೆ in Kannada transliteration' },
			{ input: 'ye', output: 'ಯೆ', description: 'ye for ಯೆ in Kannada transliteration' },
			{ input: 're', output: 'ರೆ', description: 're for ರೆ in Kannada transliteration' },
			{ input: 'qe', output: 'ಱೆ', description: 'qe for ಱೆ in Kannada transliteration' },
			{ input: 'le', output: 'ಲೆ', description: 'le for ಲೆ in Kannada transliteration' },
			{ input: 've', output: 'ವೆ', description: 've for ವೆ in Kannada transliteration' },
			{ input: 'Se', output: 'ಶೆ', description: 'Se for ಶೆ in Kannada transliteration' },
			{ input: 'She', output: 'ಷೆ', description: 'She for ಷೆ in Kannada transliteration' },
			{ input: 'se', output: 'ಸೆ', description: 'se for ಸೆ in Kannada transliteration' },
			{ input: 'he', output: 'ಹೆ', description: 'he for ಹೆ in Kannada transliteration' },
			{ input: 'Le', output: 'ಳೆ', description: 'Le for ಳೆ in Kannada transliteration' },
			{ input: 'Qe', output: 'ೞೆ', description: 'Qe for ೞೆ in Kannada transliteration' },
			{ input: 'E', output: 'ಏ', description: 'E for ಏ in Kannada transliteration' },
			{ input: 'kE', output: 'ಕೇ', description: 'kE for ಕೇ in Kannada transliteration' },
			{ input: 'KE', output: 'ಖೇ', description: 'KE for ಖೇ in Kannada transliteration' },
			{ input: 'gE', output: 'ಗೇ', description: 'gE for ಗೇ in Kannada transliteration' },
			{ input: 'GE', output: 'ಘೇ', description: 'GE for ಘೇ in Kannada transliteration' },
			{ input: '~gE', output: 'ಙೇ', description: '~gE for ಙೇ in Kannada transliteration' },
			{ input: 'cE', output: 'ಚೇ', description: 'cE for ಚೇ in Kannada transliteration' },
			{ input: 'CE', output: 'ಛೇ', description: 'CE for ಛೇ in Kannada transliteration' },
			{ input: 'jE', output: 'ಜೇ', description: 'jE for ಜೇ in Kannada transliteration' },
			{ input: 'JE', output: 'ಝೇ', description: 'JE for ಝೇ in Kannada transliteration' },
			{ input: '~jE', output: 'ಞೇ', description: '~jE for ಞೇ in Kannada transliteration' },
			{ input: 'TE', output: 'ಟೇ', description: 'TE for ಟೇ in Kannada transliteration' },
			{ input: 'ThE', output: 'ಠೇ', description: 'ThE for ಠೇ in Kannada transliteration' },
			{ input: 'DE', output: 'ಡೇ', description: 'DE for ಡೇ in Kannada transliteration' },
			{ input: 'DhE', output: 'ಢೇ', description: 'DhE for ಢೇ in Kannada transliteration' },
			{ input: 'NE', output: 'ಣೇ', description: 'NE for ಣೇ in Kannada transliteration' },
			{ input: 'tE', output: 'ತೇ', description: 'tE for ತೇ in Kannada transliteration' },
			{ input: 'thE', output: 'ಥೇ', description: 'thE for ಥೇ in Kannada transliteration' },
			{ input: 'dE', output: 'ದೇ', description: 'dE for ದೇ in Kannada transliteration' },
			{ input: 'dhE', output: 'ಧೇ', description: 'dhE for ಧೇ in Kannada transliteration' },
			{ input: 'nE', output: 'ನೇ', description: 'nE for ನೇ in Kannada transliteration' },
			{ input: 'pE', output: 'ಪೇ', description: 'pE for ಪೇ in Kannada transliteration' },
			{ input: 'PE', output: 'ಫೇ', description: 'PE for ಫೇ in Kannada transliteration' },
			{ input: 'bE', output: 'ಬೇ', description: 'bE for ಬೇ in Kannada transliteration' },
			{ input: 'BE', output: 'ಭೇ', description: 'BE for ಭೇ in Kannada transliteration' },
			{ input: 'mE', output: 'ಮೇ', description: 'mE for ಮೇ in Kannada transliteration' },
			{ input: 'yE', output: 'ಯೇ', description: 'yE for ಯೇ in Kannada transliteration' },
			{ input: 'rE', output: 'ರೇ', description: 'rE for ರೇ in Kannada transliteration' },
			{ input: 'qE', output: 'ಱೇ', description: 'qE for ಱೇ in Kannada transliteration' },
			{ input: 'lE', output: 'ಲೇ', description: 'lE for ಲೇ in Kannada transliteration' },
			{ input: 'vE', output: 'ವೇ', description: 'vE for ವೇ in Kannada transliteration' },
			{ input: 'SE', output: 'ಶೇ', description: 'SE for ಶೇ in Kannada transliteration' },
			{ input: 'ShE', output: 'ಷೇ', description: 'ShE for ಷೇ in Kannada transliteration' },
			{ input: 'sE', output: 'ಸೇ', description: 'sE for ಸೇ in Kannada transliteration' },
			{ input: 'hE', output: 'ಹೇ', description: 'hE for ಹೇ in Kannada transliteration' },
			{ input: 'LE', output: 'ಳೇ', description: 'LE for ಳೇ in Kannada transliteration' },
			{ input: 'QE', output: 'ೞೇ', description: 'QE for ೞೇ in Kannada transliteration' },
			{ input: 'Y', output: 'ಐ', description: 'Y for ಐ in Kannada transliteration' },
			{ input: 'kY', output: 'ಕೈ', description: 'kY for ಕೈ in Kannada transliteration' },
			{ input: 'KY', output: 'ಖೈ', description: 'KY for ಖೈ in Kannada transliteration' },
			{ input: 'gY', output: 'ಗೈ', description: 'gY for ಗೈ in Kannada transliteration' },
			{ input: 'GY', output: 'ಘೈ', description: 'GY for ಘೈ in Kannada transliteration' },
			{ input: '~gY', output: 'ಙೈ', description: '~gY for ಙೈ in Kannada transliteration' },
			{ input: 'cY', output: 'ಚೈ', description: 'cY for ಚೈ in Kannada transliteration' },
			{ input: 'CY', output: 'ಛೈ', description: 'CY for ಛೈ in Kannada transliteration' },
			{ input: 'jY', output: 'ಜೈ', description: 'jY for ಜೈ in Kannada transliteration' },
			{ input: 'JY', output: 'ಝೈ', description: 'JY for ಝೈ in Kannada transliteration' },
			{ input: '~jY', output: 'ಞೈ', description: '~jY for ಞೈ in Kannada transliteration' },
			{ input: 'TY', output: 'ಟೈ', description: 'TY for ಟೈ in Kannada transliteration' },
			{ input: 'ThY', output: 'ಠೈ', description: 'ThY for ಠೈ in Kannada transliteration' },
			{ input: 'DY', output: 'ಡೈ', description: 'DY for ಡೈ in Kannada transliteration' },
			{ input: 'DhY', output: 'ಢೈ', description: 'DhY for ಢೈ in Kannada transliteration' },
			{ input: 'NY', output: 'ಣೈ', description: 'NY for ಣೈ in Kannada transliteration' },
			{ input: 'tY', output: 'ತೈ', description: 'tY for ತೈ in Kannada transliteration' },
			{ input: 'thY', output: 'ಥೈ', description: 'thY for ಥೈ in Kannada transliteration' },
			{ input: 'dY', output: 'ದೈ', description: 'dY for ದೈ in Kannada transliteration' },
			{ input: 'dhY', output: 'ಧೈ', description: 'dhY for ಧೈ in Kannada transliteration' },
			{ input: 'nY', output: 'ನೈ', description: 'nY for ನೈ in Kannada transliteration' },
			{ input: 'pY', output: 'ಪೈ', description: 'pY for ಪೈ in Kannada transliteration' },
			{ input: 'PY', output: 'ಫೈ', description: 'PY for ಫೈ in Kannada transliteration' },
			{ input: 'bY', output: 'ಬೈ', description: 'bY for ಬೈ in Kannada transliteration' },
			{ input: 'BY', output: 'ಭೈ', description: 'BY for ಭೈ in Kannada transliteration' },
			{ input: 'mY', output: 'ಮೈ', description: 'mY for ಮೈ in Kannada transliteration' },
			{ input: 'yY', output: 'ಯೈ', description: 'yY for ಯೈ in Kannada transliteration' },
			{ input: 'rY', output: 'ರೈ', description: 'rY for ರೈ in Kannada transliteration' },
			{ input: 'qY', output: 'ಱೈ', description: 'qY for ಱೈ in Kannada transliteration' },
			{ input: 'lY', output: 'ಲೈ', description: 'lY for ಲೈ in Kannada transliteration' },
			{ input: 'vY', output: 'ವೈ', description: 'vY for ವೈ in Kannada transliteration' },
			{ input: 'SY', output: 'ಶೈ', description: 'SY for ಶೈ in Kannada transliteration' },
			{ input: 'ShY', output: 'ಷೈ', description: 'ShY for ಷೈ in Kannada transliteration' },
			{ input: 'sY', output: 'ಸೈ', description: 'sY for ಸೈ in Kannada transliteration' },
			{ input: 'hY', output: 'ಹೈ', description: 'hY for ಹೈ in Kannada transliteration' },
			{ input: 'LY', output: 'ಳೈ', description: 'LY for ಳೈ in Kannada transliteration' },
			{ input: 'QY', output: 'ೞೈ', description: 'QY for ೞೈ in Kannada transliteration' },
			{ input: 'o', output: 'ಒ', description: 'o for ಒ in Kannada transliteration' },
			{ input: 'ko', output: 'ಕೊ', description: 'ko for ಕೊ in Kannada transliteration' },
			{ input: 'Ko', output: 'ಖೊ', description: 'Ko for ಖೊ in Kannada transliteration' },
			{ input: 'go', output: 'ಗೊ', description: 'go for ಗೊ in Kannada transliteration' },
			{ input: 'Go', output: 'ಘೊ', description: 'Go for ಘೊ in Kannada transliteration' },
			{ input: '~go', output: 'ಙೊ', description: '~go for ಙೊ in Kannada transliteration' },
			{ input: 'co', output: 'ಚೊ', description: 'co for ಚೊ in Kannada transliteration' },
			{ input: 'Co', output: 'ಛೊ', description: 'Co for ಛೊ in Kannada transliteration' },
			{ input: 'jo', output: 'ಜೊ', description: 'jo for ಜೊ in Kannada transliteration' },
			{ input: 'Jo', output: 'ಝೊ', description: 'Jo for ಝೊ in Kannada transliteration' },
			{ input: '~jo', output: 'ಞೊ', description: '~jo for ಞೊ in Kannada transliteration' },
			{ input: 'To', output: 'ಟೊ', description: 'To for ಟೊ in Kannada transliteration' },
			{ input: 'Tho', output: 'ಠೊ', description: 'Tho for ಠೊ in Kannada transliteration' },
			{ input: 'Do', output: 'ಡೊ', description: 'Do for ಡೊ in Kannada transliteration' },
			{ input: 'Dho', output: 'ಢೊ', description: 'Dho for ಢೊ in Kannada transliteration' },
			{ input: 'No', output: 'ಣೊ', description: 'No for ಣೊ in Kannada transliteration' },
			{ input: 'to', output: 'ತೊ', description: 'to for ತೊ in Kannada transliteration' },
			{ input: 'tho', output: 'ಥೊ', description: 'tho for ಥೊ in Kannada transliteration' },
			{ input: 'do', output: 'ದೊ', description: 'do for ದೊ in Kannada transliteration' },
			{ input: 'dho', output: 'ಧೊ', description: 'dho for ಧೊ in Kannada transliteration' },
			{ input: 'no', output: 'ನೊ', description: 'no for ನೊ in Kannada transliteration' },
			{ input: 'po', output: 'ಪೊ', description: 'po for ಪೊ in Kannada transliteration' },
			{ input: 'Po', output: 'ಫೊ', description: 'Po for ಫೊ in Kannada transliteration' },
			{ input: 'bo', output: 'ಬೊ', description: 'bo for ಬೊ in Kannada transliteration' },
			{ input: 'Bo', output: 'ಭೊ', description: 'Bo for ಭೊ in Kannada transliteration' },
			{ input: 'mo', output: 'ಮೊ', description: 'mo for ಮೊ in Kannada transliteration' },
			{ input: 'yo', output: 'ಯೊ', description: 'yo for ಯೊ in Kannada transliteration' },
			{ input: 'ro', output: 'ರೊ', description: 'ro for ರೊ in Kannada transliteration' },
			{ input: 'qo', output: 'ಱೊ', description: 'qo for ಱೊ in Kannada transliteration' },
			{ input: 'lo', output: 'ಲೊ', description: 'lo for ಲೊ in Kannada transliteration' },
			{ input: 'vo', output: 'ವೊ', description: 'vo for ವೊ in Kannada transliteration' },
			{ input: 'So', output: 'ಶೊ', description: 'So for ಶೊ in Kannada transliteration' },
			{ input: 'Sho', output: 'ಷೊ', description: 'Sho for ಷೊ in Kannada transliteration' },
			{ input: 'so', output: 'ಸೊ', description: 'so for ಸೊ in Kannada transliteration' },
			{ input: 'ho', output: 'ಹೊ', description: 'ho for ಹೊ in Kannada transliteration' },
			{ input: 'Lo', output: 'ಳೊ', description: 'Lo for ಳೊ in Kannada transliteration' },
			{ input: 'Qo', output: 'ೞೊ', description: 'Qo for ೞೊ in Kannada transliteration' },
			{ input: 'O', output: 'ಓ', description: 'O for ಓ in Kannada transliteration' },
			{ input: 'kO', output: 'ಕೋ', description: 'kO for ಕೋ in Kannada transliteration' },
			{ input: 'KO', output: 'ಖೋ', description: 'KO for ಖೋ in Kannada transliteration' },
			{ input: 'gO', output: 'ಗೋ', description: 'gO for ಗೋ in Kannada transliteration' },
			{ input: 'GO', output: 'ಘೋ', description: 'GO for ಘೋ in Kannada transliteration' },
			{ input: '~gO', output: 'ಙೋ', description: '~gO for ಙೋ in Kannada transliteration' },
			{ input: 'cO', output: 'ಚೋ', description: 'cO for ಚೋ in Kannada transliteration' },
			{ input: 'CO', output: 'ಛೋ', description: 'CO for ಛೋ in Kannada transliteration' },
			{ input: 'jO', output: 'ಜೋ', description: 'jO for ಜೋ in Kannada transliteration' },
			{ input: 'JO', output: 'ಝೋ', description: 'JO for ಝೋ in Kannada transliteration' },
			{ input: '~jO', output: 'ಞೋ', description: '~jO for ಞೋ in Kannada transliteration' },
			{ input: 'TO', output: 'ಟೋ', description: 'TO for ಟೋ in Kannada transliteration' },
			{ input: 'ThO', output: 'ಠೋ', description: 'ThO for ಠೋ in Kannada transliteration' },
			{ input: 'DO', output: 'ಡೋ', description: 'DO for ಡೋ in Kannada transliteration' },
			{ input: 'DhO', output: 'ಢೋ', description: 'DhO for ಢೋ in Kannada transliteration' },
			{ input: 'NO', output: 'ಣೋ', description: 'NO for ಣೋ in Kannada transliteration' },
			{ input: 'tO', output: 'ತೋ', description: 'tO for ತೋ in Kannada transliteration' },
			{ input: 'thO', output: 'ಥೋ', description: 'thO for ಥೋ in Kannada transliteration' },
			{ input: 'dO', output: 'ದೋ', description: 'dO for ದೋ in Kannada transliteration' },
			{ input: 'dhO', output: 'ಧೋ', description: 'dhO for ಧೋ in Kannada transliteration' },
			{ input: 'nO', output: 'ನೋ', description: 'nO for ನೋ in Kannada transliteration' },
			{ input: 'pO', output: 'ಪೋ', description: 'pO for ಪೋ in Kannada transliteration' },
			{ input: 'PO', output: 'ಫೋ', description: 'PO for ಫೋ in Kannada transliteration' },
			{ input: 'bO', output: 'ಬೋ', description: 'bO for ಬೋ in Kannada transliteration' },
			{ input: 'BO', output: 'ಭೋ', description: 'BO for ಭೋ in Kannada transliteration' },
			{ input: 'mO', output: 'ಮೋ', description: 'mO for ಮೋ in Kannada transliteration' },
			{ input: 'yO', output: 'ಯೋ', description: 'yO for ಯೋ in Kannada transliteration' },
			{ input: 'rO', output: 'ರೋ', description: 'rO for ರೋ in Kannada transliteration' },
			{ input: 'qO', output: 'ಱೋ', description: 'qO for ಱೋ in Kannada transliteration' },
			{ input: 'lO', output: 'ಲೋ', description: 'lO for ಲೋ in Kannada transliteration' },
			{ input: 'vO', output: 'ವೋ', description: 'vO for ವೋ in Kannada transliteration' },
			{ input: 'SO', output: 'ಶೋ', description: 'SO for ಶೋ in Kannada transliteration' },
			{ input: 'ShO', output: 'ಷೋ', description: 'ShO for ಷೋ in Kannada transliteration' },
			{ input: 'sO', output: 'ಸೋ', description: 'sO for ಸೋ in Kannada transliteration' },
			{ input: 'hO', output: 'ಹೋ', description: 'hO for ಹೋ in Kannada transliteration' },
			{ input: 'LO', output: 'ಳೋ', description: 'LO for ಳೋ in Kannada transliteration' },
			{ input: 'QO', output: 'ೞೋ', description: 'QO for ೞೋ in Kannada transliteration' },
			{ input: 'W', output: 'ಔ', description: 'W for ಔ in Kannada transliteration' },
			{ input: 'kW', output: 'ಕೌ', description: 'kW for ಕೌ in Kannada transliteration' },
			{ input: 'KW', output: 'ಖೌ', description: 'KW for ಖೌ in Kannada transliteration' },
			{ input: 'gW', output: 'ಗೌ', description: 'gW for ಗೌ in Kannada transliteration' },
			{ input: 'GW', output: 'ಘೌ', description: 'GW for ಘೌ in Kannada transliteration' },
			{ input: '~gW', output: 'ಙೌ', description: '~gW for ಙೌ in Kannada transliteration' },
			{ input: 'cW', output: 'ಚೌ', description: 'cW for ಚೌ in Kannada transliteration' },
			{ input: 'CW', output: 'ಛೌ', description: 'CW for ಛೌ in Kannada transliteration' },
			{ input: 'jW', output: 'ಜೌ', description: 'jW for ಜೌ in Kannada transliteration' },
			{ input: 'JW', output: 'ಝೌ', description: 'JW for ಝೌ in Kannada transliteration' },
			{ input: '~jW', output: 'ಞೌ', description: '~jW for ಞೌ in Kannada transliteration' },
			{ input: 'TW', output: 'ಟೌ', description: 'TW for ಟೌ in Kannada transliteration' },
			{ input: 'ThW', output: 'ಠೌ', description: 'ThW for ಠೌ in Kannada transliteration' },
			{ input: 'DW', output: 'ಡೌ', description: 'DW for ಡೌ in Kannada transliteration' },
			{ input: 'DhW', output: 'ಢೌ', description: 'DhW for ಢೌ in Kannada transliteration' },
			{ input: 'NW', output: 'ಣೌ', description: 'NW for ಣೌ in Kannada transliteration' },
			{ input: 'tW', output: 'ತೌ', description: 'tW for ತೌ in Kannada transliteration' },
			{ input: 'thW', output: 'ಥೌ', description: 'thW for ಥೌ in Kannada transliteration' },
			{ input: 'dW', output: 'ದೌ', description: 'dW for ದೌ in Kannada transliteration' },
			{ input: 'dhW', output: 'ಧೌ', description: 'dhW for ಧೌ in Kannada transliteration' },
			{ input: 'nW', output: 'ನೌ', description: 'nW for ನೌ in Kannada transliteration' },
			{ input: 'pW', output: 'ಪೌ', description: 'pW for ಪೌ in Kannada transliteration' },
			{ input: 'PW', output: 'ಫೌ', description: 'PW for ಫೌ in Kannada transliteration' },
			{ input: 'bW', output: 'ಬೌ', description: 'bW for ಬೌ in Kannada transliteration' },
			{ input: 'BW', output: 'ಭೌ', description: 'BW for ಭೌ in Kannada transliteration' },
			{ input: 'mW', output: 'ಮೌ', description: 'mW for ಮೌ in Kannada transliteration' },
			{ input: 'yW', output: 'ಯೌ', description: 'yW for ಯೌ in Kannada transliteration' },
			{ input: 'rW', output: 'ರೌ', description: 'rW for ರೌ in Kannada transliteration' },
			{ input: 'qW', output: 'ಱೌ', description: 'qW for ಱೌ in Kannada transliteration' },
			{ input: 'lW', output: 'ಲೌ', description: 'lW for ಲೌ in Kannada transliteration' },
			{ input: 'vW', output: 'ವೌ', description: 'vW for ವೌ in Kannada transliteration' },
			{ input: 'SW', output: 'ಶೌ', description: 'SW for ಶೌ in Kannada transliteration' },
			{ input: 'ShW', output: 'ಷೌ', description: 'ShW for ಷೌ in Kannada transliteration' },
			{ input: 'sW', output: 'ಸೌ', description: 'sW for ಸೌ in Kannada transliteration' },
			{ input: 'hW', output: 'ಹೌ', description: 'hW for ಹೌ in Kannada transliteration' },
			{ input: 'LW', output: 'ಳೌ', description: 'LW for ಳೌ in Kannada transliteration' },
			{ input: 'QW', output: 'ೞೌ', description: 'QW for ೞೌ in Kannada transliteration' },
			{ input: 'aM', output: 'ಅಂ', description: 'aM for ಅಂ in Kannada transliteration' },
			{ input: 'kaM', output: 'ಕಂ', description: 'kM for ಕಂ in Kannada transliteration' },
			{ input: 'KaM', output: 'ಖಂ', description: 'KM for ಖಂ in Kannada transliteration' },
			{ input: 'gaM', output: 'ಗಂ', description: 'gM for ಗಂ in Kannada transliteration' },
			{ input: 'GaM', output: 'ಘಂ', description: 'GM for ಘಂ in Kannada transliteration' },
			{ input: '~gaM', output: 'ಙಂ', description: '~gM for ಙಂ in Kannada transliteration' },
			{ input: 'caM', output: 'ಚಂ', description: 'cM for ಚಂ in Kannada transliteration' },
			{ input: 'CaM', output: 'ಛಂ', description: 'CM for ಛಂ in Kannada transliteration' },
			{ input: 'jaM', output: 'ಜಂ', description: 'jM for ಜಂ in Kannada transliteration' },
			{ input: 'JaM', output: 'ಝಂ', description: 'JM for ಝಂ in Kannada transliteration' },
			{ input: '~jaM', output: 'ಞಂ', description: '~jM for ಞಂ in Kannada transliteration' },
			{ input: 'TaM', output: 'ಟಂ', description: 'TM for ಟಂ in Kannada transliteration' },
			{ input: 'ThaM', output: 'ಠಂ', description: 'ThM for ಠಂ in Kannada transliteration' },
			{ input: 'DaM', output: 'ಡಂ', description: 'DM for ಡಂ in Kannada transliteration' },
			{ input: 'DhaM', output: 'ಢಂ', description: 'DhM for ಢಂ in Kannada transliteration' },
			{ input: 'NaM', output: 'ಣಂ', description: 'NM for ಣಂ in Kannada transliteration' },
			{ input: 'taM', output: 'ತಂ', description: 'tM for ತಂ in Kannada transliteration' },
			{ input: 'thaM', output: 'ಥಂ', description: 'thM for ಥಂ in Kannada transliteration' },
			{ input: 'daM', output: 'ದಂ', description: 'dM for ದಂ in Kannada transliteration' },
			{ input: 'dhaM', output: 'ಧಂ', description: 'dhM for ಧಂ in Kannada transliteration' },
			{ input: 'naM', output: 'ನಂ', description: 'nM for ನಂ in Kannada transliteration' },
			{ input: 'paM', output: 'ಪಂ', description: 'pM for ಪಂ in Kannada transliteration' },
			{ input: 'PaM', output: 'ಫಂ', description: 'PM for ಫಂ in Kannada transliteration' },
			{ input: 'baM', output: 'ಬಂ', description: 'bM for ಬಂ in Kannada transliteration' },
			{ input: 'BaM', output: 'ಭಂ', description: 'BM for ಭಂ in Kannada transliteration' },
			{ input: 'maM', output: 'ಮಂ', description: 'mM for ಮಂ in Kannada transliteration' },
			{ input: 'yaM', output: 'ಯಂ', description: 'yM for ಯಂ in Kannada transliteration' },
			{ input: 'raM', output: 'ರಂ', description: 'rM for ರಂ in Kannada transliteration' },
			{ input: 'qaM', output: 'ಱಂ', description: 'qM for ಱಂ in Kannada transliteration' },
			{ input: 'laM', output: 'ಲಂ', description: 'lM for ಲಂ in Kannada transliteration' },
			{ input: 'vaM', output: 'ವಂ', description: 'vM for ವಂ in Kannada transliteration' },
			{ input: 'SaM', output: 'ಶಂ', description: 'SM for ಶಂ in Kannada transliteration' },
			{ input: 'ShaM', output: 'ಷಂ', description: 'ShM for ಷಂ in Kannada transliteration' },
			{ input: 'saM', output: 'ಸಂ', description: 'sM for ಸಂ in Kannada transliteration' },
			{ input: 'haM', output: 'ಹಂ', description: 'hM for ಹಂ in Kannada transliteration' },
			{ input: 'LaM', output: 'ಳಂ', description: 'LM for ಳಂ in Kannada transliteration' },
			{ input: 'QaM', output: 'ೞಂ', description: 'QM for ೞಂ in Kannada transliteration' },
			{ input: 'aH', output: 'ಅಃ', description: 'aH for ಅಃ in Kannada transliteration' },
			{ input: 'kaH', output: 'ಕಃ', description: 'kH for ಕಃ in Kannada transliteration' },
			{ input: 'KaH', output: 'ಖಃ', description: 'KH for ಖಃ in Kannada transliteration' },
			{ input: 'gaH', output: 'ಗಃ', description: 'gH for ಗಃ in Kannada transliteration' },
			{ input: 'GaH', output: 'ಘಃ', description: 'GH for ಘಃ in Kannada transliteration' },
			{ input: '~gaH', output: 'ಙಃ', description: '~gH for ಙಃ in Kannada transliteration' },
			{ input: 'caH', output: 'ಚಃ', description: 'cH for ಚಃ in Kannada transliteration' },
			{ input: 'CaH', output: 'ಛಃ', description: 'CH for ಛಃ in Kannada transliteration' },
			{ input: 'jaH', output: 'ಜಃ', description: 'jH for ಜಃ in Kannada transliteration' },
			{ input: 'JaH', output: 'ಝಃ', description: 'JH for ಝಃ in Kannada transliteration' },
			{ input: '~jaH', output: 'ಞಃ', description: '~jH for ಞಃ in Kannada transliteration' },
			{ input: 'TaH', output: 'ಟಃ', description: 'TH for ಟಃ in Kannada transliteration' },
			{ input: 'ThaH', output: 'ಠಃ', description: 'ThH for ಠಃ in Kannada transliteration' },
			{ input: 'DaH', output: 'ಡಃ', description: 'DH for ಡಃ in Kannada transliteration' },
			{ input: 'DhaH', output: 'ಢಃ', description: 'DhH for ಢಃ in Kannada transliteration' },
			{ input: 'NaH', output: 'ಣಃ', description: 'NH for ಣಃ in Kannada transliteration' },
			{ input: 'taH', output: 'ತಃ', description: 'tH for ತಃ in Kannada transliteration' },
			{ input: 'thaH', output: 'ಥಃ', description: 'thH for ಥಃ in Kannada transliteration' },
			{ input: 'daH', output: 'ದಃ', description: 'dH for ದಃ in Kannada transliteration' },
			{ input: 'dhaH', output: 'ಧಃ', description: 'dhH for ಧಃ in Kannada transliteration' },
			{ input: 'naH', output: 'ನಃ', description: 'nH for ನಃ in Kannada transliteration' },
			{ input: 'paH', output: 'ಪಃ', description: 'pH for ಪಃ in Kannada transliteration' },
			{ input: 'PaH', output: 'ಫಃ', description: 'PH for ಫಃ in Kannada transliteration' },
			{ input: 'baH', output: 'ಬಃ', description: 'bH for ಬಃ in Kannada transliteration' },
			{ input: 'BaH', output: 'ಭಃ', description: 'BH for ಭಃ in Kannada transliteration' },
			{ input: 'maH', output: 'ಮಃ', description: 'mH for ಮಃ in Kannada transliteration' },
			{ input: 'yaH', output: 'ಯಃ', description: 'yH for ಯಃ in Kannada transliteration' },
			{ input: 'raH', output: 'ರಃ', description: 'rH for ರಃ in Kannada transliteration' },
			{ input: 'qaH', output: 'ಱಃ', description: 'qH for ಱಃ in Kannada transliteration' },
			{ input: 'laH', output: 'ಲಃ', description: 'lH for ಲಃ in Kannada transliteration' },
			{ input: 'vaH', output: 'ವಃ', description: 'vH for ವಃ in Kannada transliteration' },
			{ input: 'SaH', output: 'ಶಃ', description: 'SH for ಶಃ in Kannada transliteration' },
			{ input: 'ShaH', output: 'ಷಃ', description: 'ShH for ಷಃ in Kannada transliteration' },
			{ input: 'saH', output: 'ಸಃ', description: 'sH for ಸಃ in Kannada transliteration' },
			{ input: 'haH', output: 'ಹಃ', description: 'hH for ಹಃ in Kannada transliteration' },
			{ input: 'LaH', output: 'ಳಃ', description: 'LH for ಳಃ in Kannada transliteration' },
			{ input: 'QaH', output: 'ೞಃ', description: 'QH for ೞಃ in Kannada transliteration' },
			{ input: 'k', output: 'ಕ್', description: 'k for ಕ್ in Kannada transliteration' },
			{ input: 'K', output: 'ಖ್', description: 'K for ಖ್ in Kannada transliteration' },
			{ input: 'g', output: 'ಗ್', description: 'g for ಗ್ in Kannada transliteration' },
			{ input: 'G', output: 'ಘ್', description: 'G for ಘ್ in Kannada transliteration' },
			{ input: '~g', output: 'ಙ್', description: '~g for ಙ್ in Kannada transliteration' },
			{ input: 'c', output: 'ಚ್', description: 'c for ಚ್ in Kannada transliteration' },
			{ input: 'C', output: 'ಛ್', description: 'C for ಛ್ in Kannada transliteration' },
			{ input: 'j', output: 'ಜ್', description: 'j for ಜ್ in Kannada transliteration' },
			{ input: 'J', output: 'ಝ್', description: 'J for ಝ್ in Kannada transliteration' },
			{ input: '~j', output: 'ಞ್', description: '~j for ಞ್ in Kannada transliteration' },
			{ input: 'T', output: 'ಟ್', description: 'T for ಟ್ in Kannada transliteration' },
			{ input: 'Th', output: 'ಠ್', description: 'Th for ಠ್ in Kannada transliteration' },
			{ input: 'D', output: 'ಡ್', description: 'D for ಡ್ in Kannada transliteration' },
			{ input: 'Dh', output: 'ಢ್', description: 'Dh for ಢ್ in Kannada transliteration' },
			{ input: 'N', output: 'ಣ್', description: 'N for ಣ್ in Kannada transliteration' },
			{ input: 't', output: 'ತ್', description: 't for ತ್ in Kannada transliteration' },
			{ input: 'th', output: 'ಥ್', description: 'th for ಥ್ in Kannada transliteration' },
			{ input: 'd', output: 'ದ್', description: 'd for ದ್ in Kannada transliteration' },
			{ input: 'dh', output: 'ಧ್', description: 'dh for ಧ್ in Kannada transliteration' },
			{ input: 'n', output: 'ನ್', description: 'n for ನ್ in Kannada transliteration' },
			{ input: 'p', output: 'ಪ್', description: 'p for ಪ್ in Kannada transliteration' },
			{ input: 'P', output: 'ಫ್', description: 'P for ಫ್ in Kannada transliteration' },
			{ input: 'b', output: 'ಬ್', description: 'b for ಬ್ in Kannada transliteration' },
			{ input: 'B', output: 'ಭ್', description: 'B for ಭ್ in Kannada transliteration' },
			{ input: 'm', output: 'ಮ್', description: 'm for ಮ್ in Kannada transliteration' },
			{ input: 'y', output: 'ಯ್', description: 'y for ಯ್ in Kannada transliteration' },
			{ input: 'r', output: 'ರ್', description: 'r for ರ್ in Kannada transliteration' },
			{ input: 'q', output: 'ಱ್', description: 'q for ಱ್ in Kannada transliteration' },
			{ input: 'l', output: 'ಲ್', description: 'l for ಲ್ in Kannada transliteration' },
			{ input: 'v', output: 'ವ್', description: 'v for ವ್ in Kannada transliteration' },
			{ input: 'S', output: 'ಶ್', description: 'S for ಶ್ in Kannada transliteration' },
			{ input: 'Sh', output: 'ಷ್', description: 'Sh for ಷ್ in Kannada transliteration' },
			{ input: 's', output: 'ಸ್', description: 's for ಸ್ in Kannada transliteration' },
			{ input: 'h', output: 'ಹ್', description: 'h for ಹ್ in Kannada transliteration' },
			{ input: 'L', output: 'ಳ್', description: 'L for ಳ್ in Kannada transliteration' },
			{ input: 'Q', output: 'ೞ್', description: 'Q for ೞ್ in Kannada transliteration' },
			{ input: 'd~ha', output: 'ದ್ಹ', description: 'd~ha for ದ್ಹ in Kannada transliteration' }
		]
	},
	{
		description: 'Kanuri tilde test',
		inputmethod: 'kr-tilde',
		tests: [
			{ input: '~E', output: 'Ǝ', description: 'Kanuri tilde ~E -> Ǝ' },
			{ input: '~e', output: 'ǝ', description: 'Kanuri tilde ~e -> ǝ' },
			{ input: '~R', output: 'Ɍ', description: 'Kanuri tilde ~I -> Ɍ' },
			{ input: '~r', output: 'ɍ', description: 'Kanuri tilde ~i -> Ɍ' },
			{ input: 'E~\\', output: 'È', description: 'Kanuri tilde E~\\ -> È' },
			{ input: 'u~^', output: 'û', description: 'Kanuri tilde U~^ -> û' },
			{ input: 'i~/', output: 'í', description: 'Kanuri tilde i~/ -> í' }
		]
	},
	{
		description: 'Kashmiri InScript test',
		inputmethod: 'ks-inscript',
		tests: [
			{ input: '1234567890', output: '१२३४५६७८९०', description: 'Kashmiri InScript 1234567890' },
			{ input: '%', output: 'ज्ञ', description: 'Kashmiri InScript %' },
			{ input: '^', output: 'त्र', description: 'Kashmiri InScript ^' },
			{ input: '&', output: 'क्ष', description: 'Kashmiri InScript &' },
			{ input: '*', output: 'श्र', description: 'Kashmiri InScript *' },
			{ input: 'k_', output: 'कः', description: 'Kashmiri InScript k_' },
			{ input: '+', output: 'ऋ', description: 'Kashmiri InScript +' },
			{ input: 'QWERTYUIOP{}', output: 'औऐआईऊभङघधझढञ', description: 'Kashmiri InScript QWERTYIOP{}' },
			{ input: 'yq', output: 'बौ', description: 'Kashmiri InScript yq' },
			{ input: 'uw', output: 'है', description: 'Kashmiri InScript uw' },
			{ input: 'ie', output: 'गा', description: 'Kashmiri InScript ie' },
			{ input: 'or', output: 'दी', description: 'Kashmiri InScript or' },
			{ input: 'pt', output: 'जू', description: 'Kashmiri InScript pt' },
			{ input: '[]', output: 'ड़', description: 'Kashmiri InScript []' },
			{ input: 'ASDF', output: 'ओएअइ', description: 'Kashmiri InScript ASDF' },
			{ input: 'HJKL:"', output: 'फऱखथछठ', description: 'Kashmiri InScript HJKL:"' },
			{ input: 'ha', output: 'पो', description: 'Kashmiri InScript ha' },
			{ input: 'js', output: 'रे', description: 'Kashmiri InScript js' },
			{ input: 'kd', output: 'क्', description: 'Kashmiri InScript kd' },
			{ input: 'lf', output: 'ति', description: 'Kashmiri InScript lf' },
			{ input: ';\'', output: 'चट', description: 'Kashmiri InScript ;\'' },
			{ input: 'ZCVBNM<>', output: 'ऎणऩऴळशष।', description: 'Kashmiri InScript ZCVBNM<>' },
			{ input: '?', output: 'य़', description: 'Kashmiri InScript ? (yya)' },
			{ input: ';X', output: 'चँ', description: 'Kashmiri InScript ;X' },
			{ input: 'nz', output: 'लॆ', description: 'Kashmiri InScript nz' },
			{ input: 'mx', output: 'सं', description: 'Kashmiri InScript mx' },
			{ input: 'cvb', output: 'मनव', description: 'Kashmiri InScript cvb' },
			{ input: '/', output: 'य', description: 'Kashmiri InScript /' },
			{ input: 'kddj', output: 'क्‌र', description: 'Kashmiri InScript kddj (explicit zwnj)' },
			{ input: 'i_', output: 'ॻ', description: 'Kashmiri InScript i_' },
			{ input: 'p_', output: 'ॼ', description: 'Kashmiri InScript p_' },
			{ input: '[_', output: 'ॾ', description: 'Kashmiri InScript [_' },
			{ input: 'y_', output: 'ॿ', description: 'Kashmiri InScript y_' },
			{ input: '!', output: 'ऍ', description: 'Kashmiri InScript !' },
			{ input: 'k@', output: 'कॅ', description: 'Kashmiri InScript k@' }
		]
	},
	{
		description: 'Kashmiri Arabic kbd test',
		inputmethod: 'ks-kbd',
		tests: [
			{ input: 'br`g', output: 'برٛگ', description: 'Kashmiri kbd br`g -> breg (inverted v)' },
			{ input: '~!@#$-+=/%^&*:"', output: '~!@#$-+=/%^&*:"', description: 'Kashmiri kbd unchanging symbols' },
			{ input: '()', output: ')(', description: 'Kashmiri kbd parentheses' },
			{ input: '[]', output: '][', description: 'Kashmiri kbd square brackets' },
			{ input: '{}', output: '}{', description: 'Kashmiri kbd curlies' },
			{ input: 'S_', output: 'شّ', description: 'Kashmiri kbd shadda' },
			{ input: 'aQ', output: 'آ', description: 'Kashmiri kbd aQ -> alef madda' },
			{ input: 'W', output: 'ۄ', description: 'Kashmiri kbd waw with ring' },
			{ input: 'ERT', output: 'ؠڑٹ', description: 'Kashmiri kbd ERT' },
			{ input: 'bY', output: 'بٖ', description: 'Kashmiri kbd subscript Alef' },
			{ input: 'IO', output: 'ۆٲ', description: 'Kashmiri kbd IO' },
			{ input: 'bP', output: 'بٔ', description: 'Kashmiri kbd P - Hamza above' },
			{ input: 'b\\', output: 'بٗ', description: 'Kashmiri kbd \\ - inverted damma' },
			{ input: 'qwerty', output: 'قوعرتے', description: 'Kashmiri kbd qwerty' },
			{ input: 'uiop', output: 'ءیہپ', description: 'Kashmiri kbd ءیہپ' },
			{ input: 'ASD', output: 'آشڈ', description: 'Kashmiri kbd ASD' },
			{ input: 'jF', output: 'جُ', description: 'Kashmiri kbd damma' },
			{ input: 'GHJK', output: 'غحژخ', description: 'Kashmiri kbd GHJK' },
			{ input: 'bL', output: 'بٕ', description: 'Kashmiri hamza below' },
			{ input: ';', output: '؛', description: 'Kashmiri kbd semicolon' },
			{ input: 'asdfghjkl', output: 'اسدفگھجکل', description: 'Kashmiri kbd اسدفگھجکل' },
			{ input: 'ZXCVBN', output: 'ذضثظأں', description: 'Kashmiri kbd ZXCVBN' },
			{ input: 'bM', output: 'بٟ', description: 'Kashmiri kbd wavy hamza below' },
			{ input: 'zxcvbnm', output: 'زصچطبنم', description: 'Kashmiri kbd zxcvbnm' },
			{ input: 'IyU', output: 'ۆےٚ', description: 'Kashmiri kbd small V above' },
			{ input: 'z<', output: 'زِ', description: 'Kashmiri kbd kasra' },
			{ input: 'z>', output: 'زَ', description: 'Kashmiri kbd fatha' },
			{ input: ',', output: '،', description: 'Kashmiri kbd comma' },
			{ input: '.', output: '۔', description: 'Kashmiri kbd full stop' },
			{ input: '?', output: '؟', description: 'Kashmiri kbd question mark' }
		]
	},
	{
		description: 'Kurdish h test',
		inputmethod: 'ku-h',
		tests: [
			{ input: 'chh', output: 'ch', description: 'chh -> ch' },
			{ input: 'shh', output: 'sh', description: 'shh -> sh' },
			{ input: 'hhh', output: 'hh', description: 'hhh -> hh' },
			{ input: 'xhh', output: 'xh', description: 'xhh -> xh' },
			{ input: 'eee', output: 'ee', description: 'eee -> ee' },
			{ input: 'iii', output: 'ii', description: 'iii -> ii' },
			{ input: 'uuu', output: 'uu', description: 'uuu -> uu' },
			{ input: 'Chh', output: 'Ch', description: 'Chh -> Ch' },
			{ input: 'Shh', output: 'Sh', description: 'Shh -> Sh' },
			{ input: 'Hhh', output: 'Hh', description: 'Hhh -> Hh' },
			{ input: 'Eee', output: 'Ee', description: 'Eee -> ee' },
			{ input: 'Iii', output: 'Ii', description: 'Iii -> Ii' },
			{ input: 'Uuu', output: 'Uu', description: 'Uuu -> Uu' },
			{ input: 'SHH', output: 'SH', description: 'SHH -> SH' },
			{ input: 'HHH', output: 'HH', description: 'HHH -> HH' },
			{ input: 'XHH', output: 'XH', description: 'XHH -> XH' },
			{ input: 'EEE', output: 'EE', description: 'EEE -> EE' },
			{ input: 'III', output: 'II', description: 'III -> II' },
			{ input: 'UUU', output: 'UU', description: 'UUU -> UU' },
			{ input: 'ChH', output: 'CH', description: 'ChH -> CH' },
			{ input: 'ShH', output: 'SH', description: 'ShH -> SH' },
			{ input: 'HhH', output: 'HH', description: 'HhH -> HH' },
			{ input: 'XhH', output: 'XH', description: 'XhH -> XH' },
			{ input: 'EeE', output: 'EE', description: 'EeE -> EE' },
			{ input: 'IiI', output: 'II', description: 'IiI -> II' },
			{ input: 'UuU', output: 'UU', description: 'UuU -> UU' },

			{ input: 'ch', output: 'ç', description: 'ch -> ç' },
			{ input: 'sh', output: 'ş', description: 'sh -> ş' },
			{ input: 'hh', output: 'ḧ', description: 'hh -> ḧ' },
			{ input: 'xh', output: 'ẍ', description: 'xh -> ẍ' },
			{ input: 'ee', output: 'ê', description: 'ee -> ê' },
			{ input: 'ii', output: 'î', description: 'ii -> î' },
			{ input: 'uu', output: 'û', description: 'uu -> û' },
			{ input: 'Ch', output: 'Ç', description: 'Ch -> Ç' },
			{ input: 'Sh', output: 'Ş', description: 'Sh -> Ş' },
			{ input: 'Hh', output: 'Ḧ', description: 'Hh -> Ḧ' },
			{ input: 'Xh', output: 'Ẍ', description: 'Xh -> Ẍ' },
			{ input: 'Ee', output: 'Ê', description: 'Ee -> Ê' },
			{ input: 'Ii', output: 'Î', description: 'Ii -> Î' },
			{ input: 'Uu', output: 'Û', description: 'Uu -> Û' },
			{ input: 'CH', output: 'Ç', description: 'CH -> Ç' },
			{ input: 'SH', output: 'Ş', description: 'SH -> Ş' },
			{ input: 'HH', output: 'Ḧ', description: 'HH -> Ḧ' },
			{ input: 'XH', output: 'Ẍ', description: 'XH -> Ẍ' },
			{ input: 'EE', output: 'Ê', description: 'EE -> Ê' },
			{ input: 'II', output: 'Î', description: 'II -> Î' },
			{ input: 'UU', output: 'Û', description: 'UU -> Û' }
		]
	},
	{
		description: 'Kurdish tr test (for Turkish keyboard)',
		inputmethod: 'ku-tr',
		tests: [
			{ input: 'hhh', output: 'hh', description: 'hhh -> hh' },
			{ input: 'Hhh', output: 'Hh', description: 'Hhh -> Hh' },
			{ input: 'HHH', output: 'HH', description: 'HHH -> HH' },
			{ input: 'HhH', output: 'HH', description: 'HhH -> HH' },

			{ input: 'ğ', output: 'ẍ', description: 'ğ -> ẍ' },
			{ input: 'ı', output: 'i', description: 'ı -> i' },
			{ input: 'i', output: 'î', description: 'i -> î' },
			{ input: 'ö', output: 'ê', description: 'ö -> ê' },
			{ input: 'ü', output: 'û', description: 'ü -> û' },
			{ input: 'hh', output: 'ḧ', description: 'hh -> ḧ' },
			{ input: 'Ğ', output: 'Ẍ', description: 'Ğ -> Ẍ' },
			{ input: 'İ', output: 'Î', description: 'İ -> Î' },
			{ input: 'Ö', output: 'Ê', description: 'Ö -> Ê' },
			{ input: 'Ü', output: 'Û', description: 'Ü -> Û' },
			{ input: 'Hh', output: 'Ḧ', description: 'Hh -> Ḧ' },
			{ input: 'HH', output: 'Ḧ', description: 'HH -> Ḧ' }
		]
	},
	{
		description: 'Kusaal tilde test',
		inputmethod: 'kus-tilde',
		tests: [
			{ input: '~N~n~E~e~I~i~O~o~U~u', output: 'ŊŋƐɛƖɩƆɔƲʋ', description: 'Kusaal tilde ŊŋƐɛƖɩƆɔƲʋ' },
			{ input: 'a~\\e~/i~-o~{', output: 'àéīõ', description: 'Kusaal tilde àéīõ' }
		]
	},
	{
		description: 'Kyrgyz Cyrillic test',
		inputmethod: 'ky-cyrl-alt',
		tests: [
			{ input: [ [ 'н', true ] ], output: 'ң', description: 'Kyrgyz Cyrillic letters, Alt-н' },
			{ input: [ [ 'Н', true ] ], output: 'Ң', description: 'Kyrgyz Cyrillic letters, Alt-Н' },
			{ input: [ [ 'о', true ] ], output: 'ө', description: 'Kyrgyz Cyrillic letters, Alt-о' },
			{ input: [ [ 'О', true ] ], output: 'Ө', description: 'Kyrgyz Cyrillic letters, Alt-О' },
			{ input: [ [ 'у', true ] ], output: 'ү', description: 'Kyrgyz Cyrillic letters, Alt-у' },
			{ input: [ [ 'У', true ] ], output: 'Ү', description: 'Kyrgyz Cyrillic letters, Alt-У' },
			{ input: 'н', output: 'н', description: 'Kyrgyz Cyrillic letters, н does not change' },
			{ input: 'Н', output: 'Н', description: 'Kyrgyz Cyrillic letters, Н does not change' },
			{ input: 'о', output: 'о', description: 'Kyrgyz Cyrillic letters, о does not change' },
			{ input: 'О', output: 'О', description: 'Kyrgyz Cyrillic letters, О does not change' },
			{ input: 'у', output: 'у', description: 'Kyrgyz Cyrillic letters, у does not change' },
			{ input: 'У', output: 'У', description: 'Kyrgyz Cyrillic letters, У does not change' }
		]
	},
	{
		description: 'Luganda tilde test',
		inputmethod: 'lg-tilde',
		tests: [
			{ input: '~N~naano', output: 'Ŋŋaano', description: 'Luganda tilde test Ŋŋaano' }
		]
	},
	{
		description: 'Lingala tilde test',
		inputmethod: 'ln-tilde',
		tests: [
			{ input: 'Mol~ong~o~/', output: 'Molɔngɔ́', description: 'Lingala tilde test ' },
			{ input: 'B~end~e~/l~e ya bise~/', output: 'Bɛndɛ́lɛ ya bisé', description: 'Lingala tilde test Bɛndɛ́lɛ ya bisé' },
			{ input: 'Libi~^ya', output: 'Libîya', description: 'Lingala tilde test Libîya' },
			{ input: 'to~v', output: 'tǒ', description: 'Lingala tilde test tǒ' },
			{ input: 'm~o~vk~o~/', output: 'mɔ̌kɔ́', description: 'Lingala tilde test ' },
			{ input: 'bo~^ngo~/', output: 'bôngó', description: 'Lingala tilde test bôngó' },
			{ input: 'wa~^na~/', output: 'wâná', description: 'Lingala tilde test wâná' }
		]
	},
	{
		description: 'Lao kbd test',
		inputmethod: 'lo-kbd',
		tests: [
			{ input: 'W!@#$&*()_', output: '0123456789', description: 'Lao kbd test 0123456789' },
			{ input: '"', output: '=', description: 'Lao kbd test " -> =' },
			{ input: '%', output: '໌', description: 'Lao kbd test cancellation mark' },
			{ input: '\'', output: 'ງ', description: 'Lao kbd test ngo' },
			{ input: 'd=d+', output: 'ກໍກໍ', description: 'Lao kbd test niggahita' },
			{ input: ',', output: 'ມ', description: 'Lao kbd test mo' },
			{ input: '-', output: 'ຊ', description: 'Lao kbd test so tam' },
			{ input: '.d', output: 'ໃກ', description: 'Lao kbd test rolled' },
			{ input: '01', output: 'ຂຢ', description: 'Lao kbd test 01' },
			{ input: '2/', output: 'ຟຝ', description: 'Lao kbd test fo tam/sung' },
			{ input: '345', output: 'ໂຖຸ', description: 'Lao kbd test 345' },
			{ input: 'd6', output: 'ກູ', description: 'Lao kbd test d6' },
			{ input: '789', output: 'ຄຕຈ', description: 'Lao kbd test 789' },
			{ input: ':;', output: '%ວ', description: 'Lao kbd test :;' },
			{ input: '<', output: 'ໝ', description: 'Lao kbd test <' },
			{ input: '>', output: '$', description: 'Lao kbd test >' },
			{ input: '?', output: ')', description: 'Lao kbd test ?' },
			{ input: 'MA', output: 'ໆັ', description: 'Lao kbd test MA' },
			{ input: 'MB', output: 'ໆຶ', description: 'Lao kbd test MB' },
			{ input: 'C', output: 'ຯ', description: 'Lao kbd test C' },
			{ input: 'DFGKLRSTXZ`', output: '.,:!?_;+("*', description: 'Lao kbd test Western punctuation' },
			{ input: 'ME', output: 'ໆຳ', description: 'Lao kbd test ME' },
			{ input: 'MH', output: 'ໆ໊', description: 'Lao kbd test MH' },
			{ input: 'I', output: 'ຮ', description: 'Lao kbd test I' },
			{ input: 'MJ', output: 'ໆ໋', description: 'Lao kbd test MJ' },
			{ input: 'MN', output: 'ໆື', description: 'Lao kbd test MN' },
			{ input: 'O', output: 'ໜ', description: 'Lao kbd test O' },
			{ input: 'P', output: 'ຽ', description: 'Lao kbd test P' },
			{ input: 'MQ', output: 'ໆົ', description: 'Lao kbd test MQ' },
			{ input: 'MU', output: 'ໆີ', description: 'Lao kbd test ໆີ' },
			{ input: 'V', output: 'x', description: 'Lao kbd test V -> x' },
			{ input: 'MY', output: 'ໆິ', description: 'Lao kbd test ໆິ' },
			{ input: '[]', output: 'ບລ', description: 'Lao kbd test []' },
			{ input: 'd^', output: 'ກຼ', description: 'Lao kbd test d^' },
			{ input: 'dadb', output: 'ກັກຶ', description: 'Lao kbd test dadb' },
			{ input: 'c', output: 'ແ', description: 'Lao kbd test c' },
			{ input: 'fe', output: 'ດຳ', description: 'Lao kbd test fe' },
			{ input: 'gI', output: 'ເຮ', description: 'Lao kbd test gI' },
			{ input: 'ih', output: 'ຣ້', description: 'Lao kbd test ih' },
			{ input: 'ljk', output: 'ສ່າ', description: 'Lao kbd test ljk' },
			{ input: 'mn', output: 'ທື', description: 'Lao kbd test mn' },
			{ input: 'opq', output: 'ນຍົ', description: 'Lao kbd test opq' },
			{ input: 'rsut', output: 'ພຫີະ', description: 'Lao kbd test rsut' },
			{ input: 'vwxyz', output: 'ອໄປິຜ', description: 'Lao kbd test vwxyz' },
			{ input: '{', output: '-', description: 'Lao kbd test {' },
			{ input: '|', output: 'ຫຼ', description: 'Lao kbd test |' },
			{ input: '}', output: '/', description: 'Lao kbd test }' },
			{ input: '\\', output: '\\', description: 'Lao kbd test \\' }
		]
	},
	{
		description: 'Northern Luri keyboard test',
		inputmethod: 'lrc-kbd',
		tests: [
			{ input: '`', output: '\u200c', description: 'Northern Luri Keyboard Layout: ` -> \\u200c' },
			{ input: '1', output: '۱', description: 'Northern Luri Keyboard Layout: 1 -> ۱' },
			{ input: '2', output: '۲', description: 'Northern Luri Keyboard Layout: 2 -> ۲' },
			{ input: '3', output: '۳', description: 'Northern Luri Keyboard Layout: 3 -> ۳' },
			{ input: '4', output: '۴', description: 'Northern Luri Keyboard Layout: 4 -> ۴' },
			{ input: '5', output: '۵', description: 'Northern Luri Keyboard Layout: 5 -> ۵' },
			{ input: '6', output: '۶', description: 'Northern Luri Keyboard Layout: 6 -> ۶' },
			{ input: '7', output: '۷', description: 'Northern Luri Keyboard Layout: 7 -> ۷' },
			{ input: '8', output: '۸', description: 'Northern Luri Keyboard Layout: 8 -> ۸' },
			{ input: '9', output: '۹', description: 'Northern Luri Keyboard Layout: 9 -> ۹' },
			{ input: '0', output: '۰', description: 'Northern Luri Keyboard Layout: 0 -> ۰' },
			{ input: 'q', output: 'ض', description: 'Northern Luri Keyboard Layout: q -> ض' },
			{ input: 'w', output: 'ص', description: 'Northern Luri Keyboard Layout: w -> ص' },
			{ input: 'e', output: 'ث', description: 'Northern Luri Keyboard Layout: e -> ث' },
			{ input: 'r', output: 'ق', description: 'Northern Luri Keyboard Layout: r -> ق' },
			{ input: 't', output: 'ف', description: 'Northern Luri Keyboard Layout: t -> ف' },
			{ input: 'y', output: 'غ', description: 'Northern Luri Keyboard Layout: y -> غ' },
			{ input: 'u', output: 'ع', description: 'Northern Luri Keyboard Layout: u -> ع' },
			{ input: 'i', output: 'ھ', description: 'Northern Luri Keyboard Layout: i -> ھ' },
			{ input: 'o', output: 'خ', description: 'Northern Luri Keyboard Layout: o -> خ' },
			{ input: 'p', output: 'ح', description: 'Northern Luri Keyboard Layout: p -> ح' },
			{ input: '[', output: 'ج', description: 'Northern Luri Keyboard Layout: [ -> ج' },
			{ input: ']', output: 'چ', description: 'Northern Luri Keyboard Layout: ] -> چ' },
			{ input: 'a', output: 'ش', description: 'Northern Luri Keyboard Layout: a -> ش' },
			{ input: 's', output: 'س', description: 'Northern Luri Keyboard Layout: s -> س' },
			{ input: 'd', output: 'ی', description: 'Northern Luri Keyboard Layout: d -> ی' },
			{ input: 'f', output: 'ب', description: 'Northern Luri Keyboard Layout: f -> ب' },
			{ input: 'g', output: 'ل', description: 'Northern Luri Keyboard Layout: g -> ل' },
			{ input: 'h', output: 'ا', description: 'Northern Luri Keyboard Layout: h -> ا' },
			{ input: 'j', output: 'ت', description: 'Northern Luri Keyboard Layout: j -> ت' },
			{ input: 'k', output: 'ن', description: 'Northern Luri Keyboard Layout: k -> ن' },
			{ input: 'l', output: 'م', description: 'Northern Luri Keyboard Layout: l -> م' },
			{ input: ';', output: 'ک', description: 'Northern Luri Keyboard Layout: ; -> ک' },
			{ input: 'z', output: 'ظ', description: 'Northern Luri Keyboard Layout: z -> ظ' },
			{ input: 'x', output: 'ط', description: 'Northern Luri Keyboard Layout: x -> ط' },
			{ input: 'c', output: 'ز', description: 'Northern Luri Keyboard Layout: c -> ز' },
			{ input: 'v', output: 'ر', description: 'Northern Luri Keyboard Layout: v -> ر' },
			{ input: 'b', output: 'ذ', description: 'Northern Luri Keyboard Layout: b -> ذ' },
			{ input: 'n', output: 'د', description: 'Northern Luri Keyboard Layout: n -> د' },
			{ input: 'm', output: 'پ', description: 'Northern Luri Keyboard Layout: m -> پ' },
			{ input: ',', output: 'ڤ', description: 'Northern Luri Keyboard Layout: , -> ڤ' },
			{ input: '~', output: '÷', description: 'Northern Luri Keyboard Layout: ~ -> ÷' },
			{ input: '@', output: '٬', description: 'Northern Luri Keyboard Layout: @ -> ٬' },
			{ input: '#', output: '٫', description: 'Northern Luri Keyboard Layout: # -> ٫' },
			{ input: '%', output: '٪', description: 'Northern Luri Keyboard Layout: % -> ٪' },
			{ input: '^', output: '×', description: 'Northern Luri Keyboard Layout: ^ -> ×' },
			{ input: '&', output: '،', description: 'Northern Luri Keyboard Layout: & -> ،' },
			{ input: '(', output: ')', description: 'Northern Luri Keyboard Layout: ( -> )' },
			{ input: ')', output: '(', description: 'Northern Luri Keyboard Layout: ) -> (' },
			{ input: '_', output: 'ـ', description: 'Northern Luri Keyboard Layout: _ -> ـ' },
			{ input: 'Q', output: 'ۊ', description: 'Northern Luri Keyboard Layout: Q -> ۊ' },
			{ input: 'W', output: 'ۉ', description: 'Northern Luri Keyboard Layout: W -> ۉ' },
			{ input: 'E', output: 'وٙ', description: 'Northern Luri Keyboard Layout: E -> وٙ' },
			{ input: 'R', output: 'ً', description: 'Northern Luri Keyboard Layout: R -> ً' },
			{ input: 'T', output: 'و', description: 'Northern Luri Keyboard Layout: T -> و' },
			{ input: 'Y', output: 'أ', description: 'Northern Luri Keyboard Layout: Y -> أ' },
			{ input: 'U', output: 'ە', description: 'Northern Luri Keyboard Layout: U -> ە' },
			{ input: 'I', output: 'ؤ', description: 'Northern Luri Keyboard Layout: I -> ؤ' },
			{ input: 'O', output: ']', description: 'Northern Luri Keyboard Layout: O -> ]' },
			{ input: 'P', output: '[', description: 'Northern Luri Keyboard Layout: P -> [' },
			{ input: '{', output: '}', description: 'Northern Luri Keyboard Layout: { -> }' },
			{ input: '}', output: '{', description: 'Northern Luri Keyboard Layout: } -> {' },
			{ input: 'A', output: 'اٛ', description: 'Northern Luri Keyboard Layout: A -> اٛ' },
			{ input: 'S', output: 'ئ', description: 'Northern Luri Keyboard Layout: S -> ئ' },
			{ input: 'D', output: 'ئو', description: 'Northern Luri Keyboard Layout: D -> ئو' },
			{ input: 'F', output: 'ئی', description: 'Northern Luri Keyboard Layout: F -> ئی' },
			{ input: 'G', output: 'لٛ', description: 'Northern Luri Keyboard Layout: G -> لٛ' },
			{ input: 'H', output: 'آ', description: 'Northern Luri Keyboard Layout: H -> آ' },
			{ input: 'J', output: 'او', description: 'Northern Luri Keyboard Layout: J -> او' },
			{ input: 'K', output: '»', description: 'Northern Luri Keyboard Layout: K -> »' },
			{ input: 'L', output: '«', description: 'Northern Luri Keyboard Layout: L -> «' },
			{ input: '"', output: '؛', description: 'Northern Luri Keyboard Layout: " -> ؛' },
			{ input: 'Z', output: 'نٛ', description: 'Northern Luri Keyboard Layout: Z -> نٛ' },
			{ input: 'X', output: 'گٛ', description: 'Northern Luri Keyboard Layout: X -> گٛ' },
			{ input: 'C', output: 'ژ', description: 'Northern Luri Keyboard Layout: C -> ژ' },
			{ input: 'V', output: 'ؽ', description: 'Northern Luri Keyboard Layout: V -> ؽ' },
			{ input: 'B', output: 'دٙ', description: 'Northern Luri Keyboard Layout: B -> دٙ' },
			{ input: 'N', output: 'ٔ', description: 'Northern Luri Keyboard Layout: N -> ٔ' },
			{ input: 'M', output: 'ء', description: 'Northern Luri Keyboard Layout: M -> ء' },
			{ input: '<', output: '>', description: 'Northern Luri Keyboard Layout: < -> >' },
			{ input: '>', output: '<', description: 'Northern Luri Keyboard Layout: > -> <' },
			{ input: '?', output: '؟', description: 'Northern Luri Keyboard Layout: ? -> ؟' }
		]
	},
	{
		description: 'Lushootseed Tulalip keyboard test',
		inputmethod: 'lut-tulalip',
		tests: [
			{ input: 'e', output: 'ə', description: 'Lushootseed Tulalip ə' },
			{ input: 'r', output: 'š', description: 'Lushootseed Tulalip š' },
			{ input: 'o', output: 'ʷ', description: 'Lushootseed Tulalip ʷ' },
			{ input: 'f', output: 'ʔ', description: 'Lushootseed Tulalip ʔ' },
			{ input: 'j', output: 'ǰ', description: 'Lushootseed Tulalip ǰ' },
			{ input: ';', output: 'ɬ', description: 'Lushootseed Tulalip ɬ' },
			{ input: 'z', output: 'x̌', description: 'Lushootseed Tulalip x̌' },
			{ input: 'v', output: 'č', description: 'Lushootseed Tulalip č' },
			{ input: 'Q', output: 'q̓', description: 'Lushootseed Tulalip q̓' },
			{ input: 'W', output: 'w̓', description: 'Lushootseed Tulalip w̓' },
			{ input: 'E', output: 'q̓ʷ', description: 'Lushootseed Tulalip q̓ʷ' },
			{ input: 'R', output: '√', description: 'Lushootseed Tulalip √' },
			{ input: 'T', output: 't̕', description: 'Lushootseed Tulalip t̕' },
			{ input: 'Y', output: 'y̓', description: 'Lushootseed Tulalip y̓' },
			{ input: 'I', output: 'kʷ', description: 'Lushootseed Tulalip kʷ' },
			{ input: 'P', output: 'p̓', description: 'Lushootseed Tulalip p̓' },
			{ input: 'A', output: 'qʷ', description: 'Lushootseed Tulalip qʷ' },
			{ input: 'D', output: 'dᶻ', description: 'Lushootseed Tulalip dᶻ' },
			{ input: 'G', output: 'gʷ', description: 'Lushootseed Tulalip gʷ' },
			{ input: 'J', output: 'k̓ʷ', description: 'Lushootseed Tulalip k̓ʷ' },
			{ input: 'K', output: 'k̓', description: 'Lushootseed Tulalip k̓' },
			{ input: 'L', output: 'l̕', description: 'Lushootseed Tulalip l̕' },
			{ input: ':', output: 'ƛ̕', description: 'Lushootseed Tulalip ƛ̕' },
			{ input: 'Z', output: 'x̌ʷ', description: 'Lushootseed Tulalip x̌ʷ' },
			{ input: 'X', output: 'xʷ', description: 'Lushootseed Tulalip xʷ' },
			{ input: 'C', output: 'c̓', description: 'Lushootseed Tulalip c̓' },
			{ input: 'V', output: 'č̓', description: 'Lushootseed Tulalip č̓' },
			{ input: 'B', output: 'b̓', description: 'Lushootseed Tulalip b̓' },
			{ input: 'N', output: 'n̓', description: 'Lushootseed Tulalip n̓' },
			{ input: 'M', output: 'm̓', description: 'Lushootseed Tulalip m̓' }
		]
	},
	{
		description: 'Madurese tilde test',
		inputmethod: 'mad-tilde',
		tests: [
			{ input: '~A', output: 'Â', description: 'Madurese tilde ~A' },
			{ input: '~a', output: 'â', description: 'Madurese tilde ~a' },
			{ input: '~D', output: 'Ḍ', description: 'Madurese tilde ~D' },
			{ input: '~d', output: 'ḍ', description: 'Madurese tilde ~d' },
			{ input: '~E', output: 'È', description: 'Madurese tilde ~E' },
			{ input: '~e', output: 'è', description: 'Madurese tilde ~e' },
			{ input: '~T', output: 'Ṭ', description: 'Madurese tilde ~T' },
			{ input: '~t', output: 'ṭ', description: 'Madurese tilde ~t' }
		]
	},
	{
		description: 'Malagasy tilde test',
		inputmethod: 'mg-tilde',
		tests: [
			{ input: 'taty~\\', output: 'tatỳ', description: 'Malagasy tilde tatỳ' },
			{ input: 'tana~\\na', output: 'tanàna', description: 'Malagasy tilde tanàna' },
			{ input: 'To~^la~naro', output: 'Tôlan̈aro', description: 'Malagasy tilde Tôlan̈aro' }
		]
	},
	{
		description: 'Kajin M̧ajeļ (Marshallese) test',
		inputmethod: 'mh',
		tests: [
			{ input: 'Y', output: 'Ū', description: 'Y for Ū in Marshallese' },
			{ input: 'S', output: 'Ā', description: 'S for Ā in Marshallese' },
			{ input: 'F', output: 'Ņ', description: 'F for Ņ in Marshallese' },
			{ input: 'G', output: 'N̄', description: 'G for N̄ in Marshallese' },
			{ input: 'H', output: 'M̧', description: 'H for M̧ in Marshallese' },
			{ input: 'X', output: 'O̧', description: 'X for O̧ in Marshallese' },
			{ input: 'C', output: 'Ō', description: 'C for Ō in Marshallese' },
			{ input: 'V', output: 'Ļ', description: 'V for Ļ in Marshallese' },
			{ input: 'y', output: 'ū', description: 'y for ū in Marshallese' },
			{ input: 's', output: 'ā', description: 's for ā in Marshallese' },
			{ input: 'f', output: 'ņ', description: 'f for ņ in Marshallese' },
			{ input: 'g', output: 'n̄', description: 'g for n̄ in Marshallese' },
			{ input: 'h', output: 'm̧', description: 'h for m̧ in Marshallese' },
			{ input: 'x', output: 'o̧', description: 'x for o̧ in Marshallese' },
			{ input: 'c', output: 'ō', description: 'c for ō in Marshallese' },
			{ input: 'v', output: 'ļ', description: 'v for ļ in Marshallese' }
		]
	},
	{
		description: 'Malayalam InScript test',
		inputmethod: 'ml-inscript',
		tests: [
			{ input: 'ka', output: 'കോ' }
		]
	},
	{
		description: 'Malayalam Transliteration test',
		inputmethod: 'ml-transliteration',
		tests: [
			{ input: '\\~', output: '~', description: 'Malayalam transliteration - \\~ -> ~' },
			{ input: 'a', output: 'അ', description: 'Malayalam a' },
			{ input: 'ra', output: 'ര', description: 'Malayalam ra' },
			{ input: 'p', output: 'പ്', description: 'Malayalam p' },
			{ input: 'kh', output: 'ഖ്', description: 'Malayalam kh' },
			{ input: 'nch', output: 'ഞ്ച്', description: 'Malayalam nch' },
			{ input: 'au', output: 'ഔ', description: 'Malayalam au' },
			{ input: 'maU', output: 'മൌ', description: 'Malayalam aU' },
			{ input: 'kshau', output: 'ക്ഷൗ', description: 'Malayalam kshau' },
			{ input: 'ram', output: 'രം', description: 'Malayalam ram' },
			{ input: 'rama', output: 'രമ', description: 'Malayalam rama' },
			{ input: 'baH', output: 'ബഃ', description: 'baH' },
			{ input: 'bah', output: 'ബഹ്', description: 'bah' },
			{ input: 'ai', output: 'ഐ', description: 'ai' },
			{ input: 'lai', output: 'ലൈ', description: 'lai' },
			{ input: 'N', output: 'ൺ', description: 'Malayalam N' },
			{ input: 'nta', output: 'ന്റ', description: 'Malayalam nta' },
			{ input: 'r#', output: 'ൎ', description: 'Malayalam dot repha' },
			{ input: 'ar#ththham', output: 'അൎത്ഥം', description: 'Malayalam word with dot repha' },
			{ input: '//', output: 'ഽ', description: 'Malayalam sign Avagraha' }
		]
	},
	{
		description: 'Mongolian mn-todo test',
		inputmethod: 'mn-todo',
		tests: [
			{ input: '<GHJ>', output: '《ᡘᡙᠴ》', description: 'Mongolian mn-todo' }
		]
	},
	{
		description: 'Mongolian mn-todoali test',
		inputmethod: 'mn-todoali',
		tests: [
			{ input: 'kjhg', output: 'ᢑᢘᢏᢎ', description: 'Mongolian mn-todoali' }
		]
	},
	{
		description: 'Mongolian mn-trad test',
		inputmethod: 'mn-trad',
		tests: [
			{ input: '{QWE}', output: '〈᠅ᠸᠧ〉', description: 'Mongolian mn-trad' }
		]
	},
	{
		description: 'Mongolian mn-tradali test',
		inputmethod: 'mn-tradali',
		tests: [
			{ input: 'adgj', output: 'ᢊᢌᢎᢐ', description: 'Mongolian mn-tradali' }
		]
	},
	{
		description: 'Manchu mnc test',
		inputmethod: 'mnc',
		tests: [
			{ input: 'LWE', output: 'ᡀᠸᠧ', description: 'Manchu mnc' }
		]
	},
	{
		description: 'Manchu mnc-ali test',
		inputmethod: 'mnc-ali',
		tests: [
			{ input: 'ASG', output: 'ᢤᢥᢪ', description: 'Manchu mnc-ali' }
		]
	},
	{
		description: 'Manipuri Bengali InScript 2 test',
		inputmethod: 'mni-inscript2',
		tests: [
			{ input: '1234567890', output: '১২৩৪৫৬৭৮৯০', description: 'Manipuri Bengali InScript 2 1234567890' },
			{ input: 'k#', output: 'ক্র', description: 'Manipuri Bengali InScript 2 k#' },
			{ input: '$k', output: 'র্ক', description: 'Manipuri Bengali InScript 2 $k' },
			{ input: '%', output: 'জ্ঞ', description: 'Manipuri Bengali InScript 2 %' },
			{ input: '^', output: 'ত্র', description: 'Manipuri Bengali InScript 2 ^' },
			{ input: '&', output: 'ক্ষ', description: 'Manipuri Bengali InScript 2 &' },
			{ input: '*', output: 'শ্র', description: 'Manipuri Bengali InScript 2 *' },
			{ input: 'k_', output: 'কঃ', description: 'Manipuri Bengali InScript 2 k_' },
			{ input: '+', output: 'ঋ', description: 'Manipuri Bengali InScript 2 +' },
			{ input: 'QWERTYUIOP{}', output: 'ঔঐআঈঊভঙঘধঝঢঞ', description: 'Manipuri Bengali InScript 2 QWERTYIOP{}' },
			{ input: 'yq', output: 'বৌ', description: 'Manipuri Bengali InScript 2 yq' },
			{ input: 'uw', output: 'হৈ', description: 'Manipuri Bengali InScript 2 uw' },
			{ input: 'ie', output: 'গা', description: 'Manipuri Bengali InScript 2 ie' },
			{ input: 'or', output: 'দী', description: 'Manipuri Bengali InScript 2 or' },
			{ input: 'pt', output: 'জূ', description: 'Manipuri Bengali InScript 2 pt' },
			{ input: '[]', output: 'ড়', description: 'Manipuri Bengali InScript 2 []' },
			{ input: 'ASDFGHKL:"', output: 'ওএঅইউফখথছঠ', description: 'Manipuri Bengali InScript 2 ASDFGHKL:"' },
			{ input: 'ha', output: 'পো', description: 'Manipuri Bengali InScript 2 ha' },
			{ input: 'js', output: 'রে', description: 'Manipuri Bengali InScript 2 js' },
			{ input: 'kd', output: 'ক্', description: 'Manipuri Bengali InScript 2 kd' },
			{ input: 'lf', output: 'তি', description: 'Manipuri Bengali InScript 2 lf' },
			// { input: 'l', output: 'ৎ', description: 'Manipuri Bengali InScript 2 l' }, // TODO fix broken rule
			{ input: ';g', output: 'চু', description: 'Manipuri Bengali InScript 2 ;g' },
			{ input: '\'', output: 'ট', description: 'Manipuri Bengali InScript 2 \'' },
			{ input: 'cx', output: 'মং', description: 'Manipuri Bengali InScript 2 cx' },
			{ input: 'vnm', output: 'নলস', description: 'Manipuri Bengali InScript 2 vnm' },
			{ input: 'CX', output: 'ণঁ', description: 'Manipuri Bengali InScript 2 CX' },
			{ input: 'M<?', output: 'শষয', description: 'Manipuri Bengali InScript 2 M<?' }
		]
	},
	{
		description: 'Mon Simplified Anonta test',
		inputmethod: 'mnw-simplified-anonta',
		tests: [
			{ input: '`1234567890', output: 'ၝ၁၂၃၄၅၆၇၈၉၀', description: 'Mon Simplified Anonta - `1234567890' },
			{ input: '~!@#', output: 'ဎဍဏ္ဍဋ', description: 'Mon Simplified Anonta - ~!@#' },
			{ input: 'r$', output: 'မိဲ', description: 'Mon Simplified Anonta - r$' },
			{ input: 'y^', output: 'ပဵ', description: 'Mon Simplified Anonta - y^' },
			{ input: '&*_', output: 'ရဂ×', description: 'Mon Simplified Anonta - &*_' },
			{ input: 'qwertyuiop[]\\', output: 'ဆတနမအပကၚသစဟဩၑ', description: 'Mon Simplified Anonta - qwertyuiop[]\\' },
			{ input: 'za', output: 'ဖေ', description: 'Mon Simplified Anonta - za' },
			{ input: 'xs', output: 'ထျ', description: 'Mon Simplified Anonta - xs' },
			{ input: 'cd', output: 'ခိ', description: 'Mon Simplified Anonta - cd' },
			{ input: 'vf', output: 'လ်', description: 'Mon Simplified Anonta - vf' },
			{ input: 'bg', output: 'ဘါ', description: 'Mon Simplified Anonta - bg' },
			{ input: 'nh', output: 'ညဴ', description: 'Mon Simplified Anonta - nh' },
			{ input: ',m', output: 'ယာ', description: 'Mon Simplified Anonta - ,m' },
			{ input: '.j/', output: 'ၜြ။', description: 'Mon Simplified Anonta - .j/' },
			{ input: 'zkxl;', output: 'ဖုထူး', description: 'Mon Simplified Anonta - zkxl;' },
			{ input: 'QRWT', output: 'ၛၟဝဳ', description: 'Mon Simplified Anonta - QRWT' },
			{ input: 'E', output: 'ဣ', description: 'Mon Simplified Anonta - E' },
			{ input: 'UIOP{}|', output: 'ဥ၎ဿဏဨအဴဋ္ဌ', description: 'Mon Simplified Anonta - UIOP{}|' },
			{ input: 'AY', output: 'ဗၠ', description: 'Mon Simplified Anonta - AY' },
			{ input: 'ZS', output: 'ဇှ', description: 'Mon Simplified Anonta - ZS' },
			{ input: 'XD', output: 'ဌီ', description: 'Mon Simplified Anonta - XD' },
			{ input: 'CF', output: 'ဃ္', description: 'Mon Simplified Anonta - CF' },
			{ input: 'BG', output: 'ၐွ', description: 'Mon Simplified Anonta - BG' },
			{ input: 'VH', output: 'ဠံ', description: 'Mon Simplified Anonta - VH' },
			{ input: 'NJ', output: 'ဉဲ', description: 'Mon Simplified Anonta - NJ' },
			{ input: 'K<ML?', output: 'ဒၞ÷ဓ၊', description: 'Mon Simplified Anonta - K<ML?' }
		]
	},
	{
		description: 'Marathi InScript 2 test',
		inputmethod: 'mr-inscript2',
		tests: [
			{ input: [ [ '1', false ] ], output: '१', description: 'Marathi InScript regular 1 - १' },
			{ input: [ [ '1', true ] ], output: '\u200d', description: 'Marathi InScript regular 1 - ZWJ' },
			{ input: [ [ '2', false ] ], output: '२', description: 'Marathi InScript regular 2 - २' },
			{ input: [ [ '2', true ] ], output: '\u200c', description: 'Marathi InScript regular 2 - ZWNJ' }
		]
	},
	{
		description: 'Marathi Phonetic test',
		inputmethod: 'mr-phonetic',
		inputType: 'input',
		tests: [
			{
				input: 'sfpes deta.',
				output: 'स्पेस देता.',
				description: 'Marathi phonetic "sfpes deta." -> "स्पेस देता." (bug 51285).'
			},
			{
				input: 'stfymffSivmffsuMdrmff',
				output: 'सत्यम्\u200cशिवम्\u200cसुंदरम्\u200c',
				description: 'Marathi phonetic ZWNJ character'
			},

			{ input: 'n"', output: 'नऊ', description: 'Marathi phonetic n" -> नऊ' },
			{ input: '*', output: 'श्र', description: 'Marathi phonetic * -> श्र' }
		]
	},
	{
		description: 'Marathi Transliteration test',
		inputmethod: 'mr-transliteration',
		tests: [
			{ input: '\\~', output: '~', description: 'Marathi transliteration - \\~ -> ~' },
			{ input: 'dny', output: 'ज्ञ्', description: 'dny for ज्ञ् in Marathi transliteration' },
			{ input: 'kOM', output: 'काँ', description: 'kOM for काँ (काँग्रेस) in Marathi transliteration' },
			// bug 38238
			{ input: 'AUM', output: 'ॐ', description: 'AUM - ॐ (OM)' },
			{ input: 'oMkaara', output: 'ओंकार', description: 'oMkaara (testing correct typing of oM as a simple anusvara)' },
			{ input: 'kshha', output: 'क्ष', description: 'kshha for क्ष translitration' },
			{ input: 'mukhapRShTha', output: 'मुखपृष्ठ', description: 'mukhapRShTha for मुखपृष्ठ (Home page) translitration' },
			{ input: 'La', output: 'ळ', description: 'La for ळ translitration' },
			{ input: 'a', output: 'अ', description: 'a for अ translitration' },
			{ input: 'aa', output: 'आ', description: 'aa for आ translitration' },
			{ input: 'i', output: 'इ', description: 'i for इ translitration' },
			{ input: 'I', output: 'ई', description: 'I for ई translitration' },
			{ input: 'u', output: 'उ', description: 'u for U translitration' },
			{ input: 'U', output: 'ऊ', description: 'U for ऊ translitration' },
			{ input: 'e', output: 'ए', description: 'e for ए translitration' },
			{ input: 'ai', output: 'ऐ', description: 'ai for ऐ translitration' },
			{ input: 'o', output: 'ओ', description: 'o for ओ translitration' },
			{ input: 'au', output: 'औ', description: 'au for औ translitration' },
			{ input: 'O', output: 'ऑ', description: 'O for ऑ translitration' },
			{ input: 'E', output: 'ॲ', description: 'E for ॲ translitration' },
			{ input: 'aM', output: 'अं', description: 'aM for अं translitration' },
			{ input: 'aH', output: 'अः', description: 'aH for अः translitration' },
			{ input: 'ka', output: 'क', description: 'ka for क translitration' },
			{ input: 'kha', output: 'ख', description: 'kha for ख translitration' },
			{ input: 'ga', output: 'ग', description: 'ga for ग translitration' },
			{ input: 'gha', output: 'घ', description: 'gha for घ translitration' },
			{ input: 'nga', output: 'ङ', description: 'nga for ङ translitration' },
			{ input: 'cha', output: 'च', description: 'cha for च translitration' },
			{ input: 'chha', output: 'छ', description: 'chha for छ translitration' },
			{ input: 'ja', output: 'ज', description: 'ja for ज translitration' },
			{ input: 'jha', output: 'झ', description: 'jha for झ translitration' },
			{ input: 'nja', output: 'ञ', description: 'nja for ञ translitration' },
			{ input: 'Ta', output: 'ट', description: 'Ta for ट translitration' },
			{ input: 'Tha', output: 'ठ', description: 'Tha for ठ translitration' },
			{ input: 'Da', output: 'ड', description: 'Da for ड translitration' },
			{ input: 'Dha', output: 'ढ', description: 'Dha for ढ translitration' },
			{ input: 'Na', output: 'ण', description: 'Na for ण translitration' },
			{ input: 'ta', output: 'त', description: 'ta for त translitration' },
			{ input: 'tha', output: 'थ', description: 'tha for थ translitration' },
			{ input: 'da', output: 'द', description: 'da for द translitration' },
			{ input: 'dha', output: 'ध', description: 'dha for ध translitration' },
			{ input: 'na', output: 'न', description: 'na for न translitration' },
			{ input: 'pha', output: 'फ', description: 'pha for फ translitration' },
			{ input: 'tha', output: 'थ', description: 'tha for थ translitration' },
			{ input: 'ba', output: 'ब', description: 'ba for ब translitration' },
			{ input: 'bha', output: 'भ', description: 'bha for भ translitration' },
			{ input: 'ma', output: 'म', description: 'ma for म translitration' },
			{ input: 'ya', output: 'य', description: 'ya for य translitration' },
			{ input: 'ra', output: 'र', description: 'ra for र translitration' },
			{ input: 'la', output: 'ल', description: 'la for ल translitration' },
			{ input: 'va', output: 'व', description: 'va for व translitration' },
			{ input: 'sha', output: 'श', description: 'sha for श translitration' },
			{ input: 'ya', output: 'य', description: 'ya for य translitration' },
			{ input: 'Sha', output: 'ष', description: 'Sha for ष translitration' },
			{ input: 'sa', output: 'स', description: 'sa for स translitration' },
			{ input: 'ha', output: 'ह', description: 'ha for ह translitration' },
			{ input: 'sha', output: 'श', description: 'sha for श translitration' },
			{ input: 'R', output: 'ऋ', description: 'R for ऋ translitration' },
			{ input: 'shrI', output: 'श्री', description: 'shrI for श्री translitration' },
			{ input: '0', output: '०', description: '0 for ० translitration' },
			{ input: '1', output: '१', description: '1 for १ translitration' },
			{ input: '2', output: '२', description: '2 for २ translitration' },
			{ input: '3', output: '३', description: '3 for ३ translitration' },
			{ input: '4', output: '४', description: '4 for ४ translitration' },
			{ input: '5', output: '५', description: '5 for ५ translitration' },
			{ input: '6', output: '६', description: '6 for ६ translitration' },
			{ input: '7', output: '७', description: '7 for ७ translitration' },
			{ input: '8', output: '८', description: '8 for ८ translitration' },
			{ input: '9', output: '९', description: '9 for ९ translitration' },
			{ input: '0', output: '०', description: '0 for ० translitration ' },
			{ input: 'aMkita', output: 'अंकित', description: 'aMkita for अंकित translitration' },
			{ input: 'RShi', output: 'ऋषि', description: 'Rshi for ऋषि translitration' },
			{ input: 'vikipIDiyaa', output: 'विकिपीडिया', description: 'vikipIdiya for विकिपीडिया translitration' },
			{ input: 'manaHpUrvahaka', output: 'मनःपूर्वहक', description: 'manaHpUrvaka for मनःपूर्वहक translitration' },
			{ input: 'dhanyavaada', output: 'धन्यवाद', description: 'dhanyavaada for धन्यवाद translitration' },
			{ input: 'laThTha', output: 'लठ्ठ', description: 'laThTha for लठ्ठ translitration' },
			{ input: 'iMgrajI', output: 'इंग्रजी', description: 'iMgrajI for इंग्रजी translitration' },
			{ input: 'nRsiMhasarasvatI', output: 'नृसिंहसरस्वती', description: 'nRsiMhasarasvatI for नृसिंहसरस्वती translitration' },
			{ input: 'agni', output: 'अग्नि', description: 'agni for अग्नि translitration' },
			{ input: 'saMskRta', output: 'संस्कृत', description: 'saMskRta for संस्कृत translitration' },
			{ input: 'dRShTIkona', output: 'दृष्टीकोन', description: 'dRShTIkona for दृष्टीकोन translitration' },
			{ input: 'tryaM', output: 'त्र्यं', description: 'tryaM for त्र्यं translitration' },
			{ input: 'maatRbhaaShaa', output: 'मातृभाषा', description: 'maatRbhaaShaa for मातृभाषा translitration' },
			{ input: 'vakratuNDa', output: 'वक्रतुण्ड', description: 'vakratuNDa for वक्रतुण्ड translitration' },
			{ input: 'ariShTanemiH', output: 'अरिष्टनेमिः', description: 'ariShTanemiH for अरिष्टनेमिः translitration' },
			{ input: 'shiShya', output: 'शिष्य', description: 'shiShya for शिष्य translitration' },
			{ input: 'bramha', output: 'ब्रम्ह', description: 'bramha for ब्रम्ह translitration' },
			{ input: 'dvitIya', output: 'द्वितीय', description: 'dvitIya for द्वितीय translitration' },
			{ input: 'dnyaana', output: 'ज्ञान', description: 'dnyana for ज्ञान translitration' }
		]
	},
	{
		description: 'Burkina Faso tilde keyboard test',
		inputmethod: 'mul-bf',
		tests: [
			{ input: '~B', output: 'Ɓ', description: 'Burkina Faso tilde keyboard - Ɓ' },
			{ input: '~b', output: 'ɓ', description: 'Burkina Faso tilde keyboard - ɓ' },
			{ input: '~C', output: 'Ç', description: 'Burkina Faso tilde keyboard - Ç' },
			{ input: '~c', output: 'ç', description: 'Burkina Faso tilde keyboard - ç' },
			{ input: '~D', output: 'Ɗ', description: 'Burkina Faso tilde keyboard - Ɗ' },
			{ input: '~d', output: 'ɗ', description: 'Burkina Faso tilde keyboard - ɗ' },
			{ input: '~A', output: 'Ǝ', description: 'Burkina Faso tilde keyboard - Ǝ' },
			{ input: '~a', output: 'ǝ', description: 'Burkina Faso tilde keyboard - ǝ' },
			{ input: '~E', output: 'Ɛ', description: 'Burkina Faso tilde keyboard - Ɛ' },
			{ input: '~e', output: 'ɛ', description: 'Burkina Faso tilde keyboard - ɛ' },
			{ input: '~I', output: 'Ɩ', description: 'Burkina Faso tilde keyboard - Ɩ' },
			{ input: '~i', output: 'ɩ', description: 'Burkina Faso tilde keyboard - ɩ' },
			{ input: '~N', output: 'Ŋ', description: 'Burkina Faso tilde keyboard - Ŋ' },
			{ input: '~n', output: 'ŋ', description: 'Burkina Faso tilde keyboard - ŋ' },
			{ input: '~O', output: 'Ɔ', description: 'Burkina Faso tilde keyboard - Ɔ' },
			{ input: '~o', output: 'ɔ', description: 'Burkina Faso tilde keyboard - ɔ' },
			{ input: 'u~:', output: 'ü', description: 'Burkina Faso tilde keyboard - ü' },
			{ input: '~U', output: 'Ʋ', description: 'Burkina Faso tilde keyboard - Ʋ' },
			{ input: '~u', output: 'ʋ', description: 'Burkina Faso tilde keyboard - ʋ' },
			{ input: '~W', output: 'Ⱳ', description: 'Burkina Faso tilde keyboard - Ⱳ' },
			{ input: '~w', output: 'ⱳ', description: 'Burkina Faso tilde keyboard - ⱳ' },
			{ input: '~Y', output: 'Ƴ', description: 'Burkina Faso tilde keyboard - Ƴ' },
			{ input: '~y', output: 'ƴ', description: 'Burkina Faso tilde keyboard - ƴ' },
			{ input: 'a~{', output: 'ã', description: 'Burkina Faso tilde keyboard - ã' }
		]
	},
	{
		description: 'General Alphabet of Cameroon Languages tilde keyboard test',
		inputmethod: 'mul-cm',
		tests: [
			{ input: 'a~/', output: 'á', description: 'General Alphabet of Cameroon Languages tilde keyboard test - á' },
			{ input: 'a~\\', output: 'à', description: 'General Alphabet of Cameroon Languages tilde keyboard test - à' },
			{ input: 'a~^', output: 'â', description: 'General Alphabet of Cameroon Languages tilde keyboard test - â' },
			{ input: 'a~v', output: 'ǎ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ǎ' },
			{ input: 'a~-', output: 'ā', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ā' },
			{ input: 'a~|', output: 'a̍', description: 'General Alphabet of Cameroon Languages tilde keyboard test - a̍' },
			{ input: 'a~e', output: 'ae', description: 'General Alphabet of Cameroon Languages tilde keyboard test - a~e -> ae' },
			{ input: 'A~e', output: 'Ae', description: 'General Alphabet of Cameroon Languages tilde keyboard test - A~e -> Ae' },
			{ input: 'A~E', output: 'AE', description: 'General Alphabet of Cameroon Languages tilde keyboard test - A~E -> AE' },
			{ input: 'ae', output: 'æ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ae -> æ' },
			{ input: 'Ae', output: 'Æ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ae -> Æ' },
			{ input: 'AE', output: 'Æ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - AE -> Æ' },
			{ input: '~a', output: 'ɑ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ɑ' },
			{ input: '~A', output: 'Ɑ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ɑ' },
			{ input: '~b', output: 'ɓ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ɓ' },
			{ input: '~B', output: 'Ɓ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ɓ' },
			{ input: '~d', output: 'ɗ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ɗ' },
			{ input: '~D', output: 'Ɗ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ɗ' },
			{ input: '~c', output: 'ə', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ə' },
			{ input: '~C', output: 'Ə', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ə' },
			{ input: '~e', output: 'ɛ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ɛ' },
			{ input: '~E', output: 'Ɛ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ɛ' },
			{ input: '~x', output: 'ɤ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ɤ' },
			{ input: '~X', output: 'ɤ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ɤ' },
			{ input: 'i~.', output: 'ị', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ị' },
			{ input: '~i', output: 'ɨ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ɨ' },
			{ input: '~I', output: 'Ɨ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ɨ' },
			{ input: '~n', output: 'ŋ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ŋ' },
			{ input: '~N', output: 'Ŋ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ŋ' },
			{ input: '~j', output: 'ø', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ø' },
			{ input: '~J', output: 'Ø', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ø' },
			{ input: 'o~e', output: 'oe', description: 'General Alphabet of Cameroon Languages tilde keyboard test - o~e -> oe' },
			{ input: 'O~e', output: 'Oe', description: 'General Alphabet of Cameroon Languages tilde keyboard test - O~e -> oe' },
			{ input: 'O~E', output: 'OE', description: 'General Alphabet of Cameroon Languages tilde keyboard test - O~E -> OE' },
			{ input: 'oe', output: 'œ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - oe -> œ' },
			{ input: 'Oe', output: 'Œ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Oe -> Œ' },
			{ input: 'OE', output: 'Œ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - OE -> Œ' },
			{ input: '~o', output: 'ɔ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ɔ' },
			{ input: '~O', output: 'Ɔ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ɔ' },
			{ input: 's~,', output: 'ş', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ş' },
			{ input: 't~,', output: 'ţ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ţ' },
			{ input: '~u', output: 'ʉ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ʉ' },
			{ input: '~U', output: 'Ʉ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ʉ' },
			{ input: '~w', output: 'ẅ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ẅ' },
			{ input: '~W', output: 'Ẅ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ẅ' },
			{ input: '~y', output: 'ƴ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - ƴ' },
			{ input: '~Y', output: 'Ƴ', description: 'General Alphabet of Cameroon Languages tilde keyboard test - Ƴ' }
		]
	},
	{
		description: 'Myanmar mm3 test',
		inputmethod: 'my-mm3',
		tests: [
			{ input: 'ujdkqdkygonf>', output: 'ကြိုဆိုပါသည်။', description: 'Myanmar mm3 ကြိုဆိုပါသည်။' }
		]
	},
	{
		description: 'Myanmar xkb test',
		inputmethod: 'my-xkb',
		tests: [
			{ input: 'QWERTYUIOP', output: 'ဈဝဣ၎ဤ၌ဥ၍ဿဏ', description: 'Myanmar xkb QWERTYUIOP' },
			{ input: 'qawsedrftgyhujikolp;', output: 'ဆေတျနိမ်အါပ့ကြငုသူစး', description: 'Myanmar xkb qawsedrftgyhujikolp;' },
			{ input: '[]{}', output: 'ဟဩဧဪ', description: 'Myanmar xkb []{}' },
			{ input: 'ASD', output: 'ဗှီ', description: 'Myanmar xkb ASD' },
			{ input: 'WF', output: 'ဝ္', description: 'Myanmar xkb WF' },
			{ input: 'tG', output: 'အွ', description: 'Myanmar xkb tG' },
			{ input: 'tH', output: 'အံ', description: 'Myanmar xkb tH' },
			{ input: 'tJ', output: 'အဲ', description: 'Myanmar xkb tJ' },
			{ input: 'KL', output: 'ဒဓ', description: 'Myanmar xkb KL' },
			{ input: ':"\'', output: 'ဂ"\'', description: 'Myanmar xkb :"\'' },
			{ input: 'zxcvbnm,./', output: 'ဖထခလဘညာ,./', description: 'Myanmar xkb zxcvbnm,./' },
			{ input: 'ZXCVBNM<>?', output: 'ဇဌဃဠယဉဦ၊။?', description: 'Myanmar xkb ZXCVBNM<>?' },
			{ input: '`~', output: 'ၐဎ', description: 'Myanmar xkb ၐဎ' },
			{ input: '1234567890', output: '၁၂၃၄၅၆၇၈၉၀', description: 'Myanmar xkb 1234567890' },
			{ input: '!@#$%^&*()', output: 'ဍၒဋၓၔၕရ*()', description: 'Myanmar xkb !@#$%^&*()' }
		]
	},
	{
		description: 'Nepali Romanized test',
		inputmethod: 'ne-rom',
		tests: [
			{ input: '!"#()+,-?=', output: '!"#()+,-?=', description: 'Nepali Romanized !"#()+,' },
			{ input: '$', output: 'रु', description: 'Nepali Romanized $' },
			{ input: '.', output: '।', description: 'Nepali Romanized .' },
			{ input: 'g/y', output: 'ग्य', description: 'Nepali Romanized g/y' },
			{ input: 'gy', output: 'गय', description: 'Nepali Romanized गय' },
			{ input: '0123456789', output: '०१२३४५६७८९', description: 'Nepali Romanized 0123456789' },
			{ input: '<>', output: 'ङ॥', description: 'Nepali Romanized <>' },
			{ input: 'ABCDEFGH', output: 'आभचधैऊघअ', description: 'Nepali Romanized ABCDEFGH' },
			{ input: 'JI', output: 'झी', description: 'Nepali Romanized JI' },
			{ input: 'KLMNOPQRSTUVWXYZ', output: 'खळंणओफठृशथूँऔढञऋ', description: 'Nepali Romanized KLMNOPQRSTUVWXYZ' },
			{ input: 'bacdefghijklmnopqrstuvwxyz', output: 'बाछदेउगहिजकलमनोपटरसतुवौडयष', description: 'Nepali Romanized bacdefghijklmnopqrstuvwxyz' },
			{ input: '[]', output: 'इए', description: 'Nepali Romanized []' },
			{ input: 'j`', output: 'ज़', description: 'Nepali Romanized j`' },
			{ input: '{|}', output: 'ईःऐ', description: 'Nepali Romanized {|}' }
		]
	},
	{
		description: 'Nepali trad test',
		inputmethod: 'ne-trad',
		tests: [
			{ input: '#"', output: 'घू', description: 'Nepali trad #"' },
			{ input: '(\')', output: 'ढुण', description: 'Nepali trad (\')' },
			{ input: 'A+', output: 'आं', description: 'Nepali trad A+' },
			{ input: ',', output: 'ऽ', description: 'Nepali trad ऽ' },
			{ input: '-', output: 'औ', description: 'Nepali trad -' },
			{ input: '.', output: '।', description: 'Nepali trad .' },
			{ input: '/', output: 'र', description: 'Nepali trad /' },
			{ input: '1234567890', output: '१२३४५६७८९०', description: 'Nepali trad 1234567890' },
			{ input: 'qwertyuiop', output: 'त्रधभचतथगषयउ', description: 'Nepali trad qwertyuiop' },
			{ input: 'asdfghjkl;\'', output: 'बकमानजवपिसु', description: 'Nepali trad asdfghjkl;\'' },
			{ input: 'zxcvbnm', output: 'शहअखदलः', description: 'Nepali trad zxcvbnm' }
		]
	},
	{
		description: 'Nawdm tilde test',
		inputmethod: 'nmz-tilde',
		tests: [
			{ input: '~e', output: 'ɛ', description: 'Nawdm tilde ɛ' },
			{ input: '~E', output: 'Ɛ', description: 'Nawdm tilde Ɛ' },
			{ input: '~H', output: 'Ĥ', description: 'Nawdm tilde Ĥ' },
			{ input: '~h', output: 'ɦ', description: 'Nawdm tilde ɦ' },
			{ input: '~n', output: 'ŋ', description: 'Nawdm tilde ŋ' },
			{ input: '~N', output: 'Ŋ', description: 'Nawdm tilde Ŋ' },
			{ input: '~o', output: 'ɔ', description: 'Nawdm tilde ɔ' },
			{ input: '~O', output: 'Ɔ', description: 'Nawdm tilde Ɔ' },
			{ input: 'g~:w, g~:b, n~:y, ~n~:m', output: 'g̈w, g̈b, n̈y, ŋ̈m', description: 'Nawdm tilde g̈w, g̈b, n̈y, ŋ̈m' },
			{ input: 'a~/a~\\', output: 'áà', description: 'Nawdm tilde áà' }
		]
	},
	{
		description: "N'Ko standard QWERTY",
		inputmethod: 'nqo-standard-qwerty',
		tests: [
			{ input: '!', output: '߹', description: "N'Ko standard QWERTY !" },
			{ input: '%', output: '%', description: "N'Ko standard QWERTY %" },
			{ input: '*', output: '*', description: "N'Ko standard QWERTY *" },
			{ input: '(', output: '(', description: "N'Ko standard QWERTY (" },
			{ input: ')', output: ')', description: "N'Ko standard QWERTY )" },
			{ input: '_', output: '_', description: "N'Ko standard QWERTY _" },
			{ input: '+', output: '+', description: "N'Ko standard QWERTY +" },
			{ input: 'Q', output: 'ߩ', description: "N'Ko standard QWERTY Q" },
			{ input: 'W', output: 'ߨ', description: "N'Ko standard QWERTY W" },
			{ input: 'Y', output: 'ߚ', description: "N'Ko standard QWERTY Y" },
			{ input: 'I', output: '÷', description: "N'Ko standard QWERTY I" },
			{ input: 'O', output: '×', description: "N'Ko standard QWERTY O" },
			{ input: 'P', output: 'ߪ', description: "N'Ko standard QWERTY P" },
			{ input: 'A', output: '߶', description: "N'Ko standard QWERTY A" },
			{ input: 'D', output: '[', description: "N'Ko standard QWERTY D" },
			{ input: 'F', output: ']', description: "N'Ko standard QWERTY F" },
			{ input: 'G', output: '(', description: "N'Ko standard QWERTY G" },
			{ input: 'H', output: ')', description: "N'Ko standard QWERTY H" },
			{ input: 'J', output: 'ߺ', description: "N'Ko standard QWERTY J" },
			{ input: 'L', output: '/', description: "N'Ko standard QWERTY L" },
			{ input: ':', output: ':', description: "N'Ko standard QWERTY :" },
			{ input: '"', output: '"', description: "N'Ko standard QWERTY \"" },
			{ input: 'uCsZmf/h', output: 'ߗ߭ߎ߳ߟߌߞߊ', description: "N'Ko standard QWERTY uCsZmf/h" },
			{ input: 'ldX', output: 'ߣߍ߱', description: "N'Ko standard QWERTY ldX" },
			{ input: "k.ab'hb;zV", output: 'ߝߘߏ߬ߓߊ߬ߕߐ߮', description: "N'Ko standard QWERTY k,ab'hb;zV" },
			{ input: '.sB,hx', output: 'ߘߎ߰ߛߊ߲', description: "N'Ko standard QWERTY .sB,hx" },
			{ input: 'wgn', output: 'ߧߋ߫', description: "N'Ko standard QWERTY wgn" },
			{ input: ',aNya', output: 'ߛߏ߯ߙߏ', description: "N'Ko standard QWERTY ,aNya" },
			{ input: ',g.<lgf', output: 'ߛߋߘߑߣߋߌ', description: "N'Ko standard QWERTY ,g.<lgf" },
			{ input: '?', output: '؟', description: "N'Ko standard QWERTY ?" },
			{ input: 'q', output: 'ߔ', description: "N'Ko standard QWERTY q" },
			{ input: 'w', output: 'ߧ', description: "N'Ko standard QWERTY w" },
			{ input: 'e', output: 'ߠ', description: "N'Ko standard QWERTY e" },
			{ input: 'r', output: 'ߥ', description: "N'Ko standard QWERTY r" },
			{ input: 't', output: 'ߦ', description: "N'Ko standard QWERTY t" },
			{ input: 'y', output: 'ߙ', description: "N'Ko standard QWERTY y" },
			{ input: 'u', output: 'ߗ', description: "N'Ko standard QWERTY u" },
			{ input: 'i', output: 'ߜ', description: "N'Ko standard QWERTY i" },
			{ input: 'o', output: 'ߢ', description: "N'Ko standard QWERTY o" },
			{ input: 'p', output: 'ߡ', description: "N'Ko standard QWERTY p" },
			{ input: '[', output: 'ߤ', description: "N'Ko standard QWERTY [" },
			{ input: ']', output: 'ߒ', description: "N'Ko standard QWERTY ]" },
			{ input: 'a', output: 'ߏ', description: "N'Ko standard QWERTY a" },
			{ input: 's', output: 'ߎ', description: "N'Ko standard QWERTY s" },
			{ input: 'd', output: 'ߍ', description: "N'Ko standard QWERTY d" },
			{ input: 'f', output: 'ߌ', description: "N'Ko standard QWERTY f" },
			{ input: 'g', output: 'ߋ', description: "N'Ko standard QWERTY g" },
			{ input: 'h', output: 'ߊ', description: "N'Ko standard QWERTY h" },
			{ input: 'j', output: 'ߖ', description: "N'Ko standard QWERTY j" },
			{ input: 'k', output: 'ߝ', description: "N'Ko standard QWERTY k" },
			{ input: 'l', output: 'ߣ', description: "N'Ko standard QWERTY l" },
			{ input: ';', output: 'ߕ', description: "N'Ko standard QWERTY ;" },
			{ input: "'", output: 'ߓ', description: "N'Ko standard QWERTY '" },
			{ input: 'z', output: 'ߐ', description: "N'Ko standard QWERTY z" },
			{ input: 'ophmzxldx', output: 'ߢߡߊߟߐ߲ߣߍ߲', description: "N'Ko standard QWERTY ophmzxldx (testing dot below)" },
			{ input: '/chb', output: 'ߞߵߊ߬', description: "N'Ko standard QWERTY /chb (testing low tone apostrophe and short low tone)" },
			{ input: '.vhb', output: 'ߘߴߊ߬', description: "N'Ko standard QWERTY .vhb (testing high tone apostrophe and short low tone)" },
			{ input: 'kan', output: 'ߝߏ߫', description: "N'Ko standard QWERTY kan (testing short high tone)" },
			{ input: 'm', output: 'ߟ', description: "N'Ko standard QWERTY m" },
			{ input: ',', output: 'ߛ', description: "N'Ko standard QWERTY ," },
			{ input: '.', output: 'ߘ', description: "N'Ko standard QWERTY ." },
			{ input: '/', output: 'ߞ', description: "N'Ko standard QWERTY /" }
		]
	},
	{
		description: "N'Ko transliteration",
		inputmethod: 'nqo-transliteration',
		tests: [
			{ input: 'E', output: 'ߋ', description: "N'Ko transliteration E" },
			{ input: 'e', output: 'ߍ', description: "N'Ko transliteration e" },
			{ input: 'O', output: 'ߏ', description: "N'Ko transliteration O" },
			{ input: 'o', output: 'ߐ', description: "N'Ko transliteration o" },
			{ input: 'R', output: 'ߚ', description: "N'Ko transliteration R" },
			{ input: 'r', output: 'ߙ', description: "N'Ko transliteration r" },
			{ input: 'nn', output: 'ߠ', description: "N'Ko transliteration nn" },
			{ input: 'ny', output: 'ߢ', description: "N'Ko transliteration ny" },
			{ input: 'nyw', output: 'ߧ', description: "N'Ko transliteration nyw" },
			{ input: 'sEd`nEi', output: 'ߛߋߘߑߣߋߌ', description: "N'Ko transliteration sEd`nEi (testing dagbasinna)" },
			{ input: 'NkO', output: 'ߒߞߏ', description: "N'Ko transliteration NkO" },
			{ input: 'nnu~', output: 'ߠߎ߬', description: "N'Ko transliteration nnu~" },
			{ input: 'nymalo.ne.', output: 'ߢߡߊߟߐ߲ߣߍ߲', description: "N'Ko transliteration nymalo.ne." },
			{ input: 'nywE-', output: 'ߧߋ߫', description: "N'Ko transliteration nywE-" },
			{ input: 'j/', output: 'ߨ', description: "N'Ko transliteration j/" },
			{ input: 'c/', output: 'ߩ', description: "N'Ko transliteration c/" },
			{ input: 'r/', output: 'ߪ', description: "N'Ko transliteration r/" },
			{ input: 'to^.', output: 'ߕߐ߭', description: "N'Ko transliteration to^. (testing Combining short rising tone)" },
			{ input: 'fdO~ba~to^', output: 'ߝߘߏ߬ߓߊ߬ߕߐ߮', description: "N'Ko transliteration (testing Combining short low tone and Combining long descending tone)" },
			{ input: '/', output: '߶', description: "N'Ko transliteration /" },
			{ input: '...', output: '߷', description: "N'Ko transliteration ..." },
			{ input: ',', output: '߸', description: "N'Ko transliteration ," },
			{ input: '!', output: '߹', description: "N'Ko transliteration !" },
			{ input: 'sO>rO', output: 'ߛߏ߯ߙߏ', description: "N'Ko transliteration sO>rO (testing Combining long high tone)" },
			{ input: 'ne<', output: 'ߣߍ߱', description: "N'Ko transliteration ne< (testing Combining long rising tone)" },
			{ input: 'du#sa.', output: 'ߘߎ߰ߛߊ߲', description: "N'Ko transliteration du#sa. (testing Combining long low tone)" },
			{ input: 'c^.u%lika', output: 'ߗ߭ߎ߳ߟߌߞߊ', description: "N'Ko transliteration c^.u%lika (testing Combining double dot above)" },
			{ input: ',/', output: 'ߺ', description: "N'Ko transliteration ,/ (testing Lajanyalan)" },
			{ input: 'kO~n"a~lE~', output: 'ߞߏ߬ߣߵߊ߬ߟߋ߬', description: "N'Ko transliteration kO~n\"a~lE~ (testing low tone apostrophe)" },
			{ input: 'k"a~', output: 'ߞߵߊ߬', description: "N'Ko transliteration k\"a~ (testing low tone apostrophe)" },
			{ input: "d'a~", output: 'ߘߴߊ߬', description: "N'Ko transliteration d'a~ (testing high tone apostrophe)" },
			{ input: '1234567890', output: '߁߂߃߄߅߆߇߈߉߀', description: "N'Ko transliteration 1234567890" },
			{ input: '\\?', output: '?', description: "N'Ko transliteration \\?" },
			{ input: '?', output: '؟', description: "N'Ko transliteration ?" },
			{ input: '--', output: '-', description: "N'Ko transliteration --" },
			{ input: '~~', output: '~', description: "N'Ko transliteration ~~" }
		]
	},
	{
		description: 'Nias tilde test',
		inputmethod: 'nia-tilde',
		tests: [
			{ input: '~O moroi', output: 'Ö moroi', description: 'Nias tilde Ö moroi' },
			{ input: 'Sanandr~osa', output: 'Sanandrösa', description: 'Nias tilde Sanandrösa' },
			{ input: 'MIYA~WA', output: 'MIYAŴA', description: 'Nias tilde MIYAŴA' },
			{ input: 'zali~wa-li~wa', output: 'zaliŵa-liŵa', description: 'Nias tilde zaliŵa-liŵa' }
		]
	},
	{
		description: 'Northern Sotho tilde test',
		inputmethod: 'nso-tilde',
		tests: [
			{ input: '~Salang', output: 'Šalang', description: 'Northern Sotho tilde Šalang' },
			{ input: 'let~sat~sing', output: 'letšatšing', description: 'Northern Sotho tilde letšatšing' },
			{ input: 'Gontsha', output: 'Gontsha', description: 'Northern Sotho tilde Gontsha' },
			{ input: '~E', output: 'Ê', description: 'Northern Sotho tilde Ê' },
			{ input: '~e', output: 'ê', description: 'Northern Sotho tilde ê' },
			{ input: '~O', output: 'Ô', description: 'Northern Sotho tilde Ô' },
			{ input: '~o', output: 'ô', description: 'Northern Sotho tilde ô' }
		]
	},
	{
		description: 'Nuer tilde test',
		inputmethod: 'nus-tilde',
		tests: [
			{ input: 'A~_', output: 'A̱', description: 'Nuer tilde A̱' },
			{ input: 'A~:', output: 'Ä', description: 'Nuer tilde Ä' },
			{ input: 'E~_', output: 'E̱', description: 'Nuer tilde E̱' },
			{ input: 'E~:', output: 'Ë', description: 'Nuer tilde Ë' },
			{ input: '~E', output: 'Ɛ', description: 'Nuer tilde Ɛ' },
			{ input: '~E~_', output: 'Ɛ̱', description: 'Nuer tilde Ɛ̱' },
			{ input: '~E~:', output: 'Ɛ̈', description: 'Nuer tilde Ɛ̈' },
			{ input: '~G', output: 'Ɣ', description: 'Nuer tilde Ɣ' },
			{ input: 'I~_', output: 'I̱', description: 'Nuer tilde I̱' },
			{ input: '~N', output: 'Ŋ', description: 'Nuer tilde Ŋ' },
			{ input: 'O~_', output: 'O̱', description: 'Nuer tilde O̱' },
			{ input: 'O~:', output: 'Ö', description: 'Nuer tilde Ö' },
			{ input: '~O', output: 'Ɔ', description: 'Nuer tilde Ɔ' },
			{ input: '~O~_', output: 'Ɔ̱', description: 'Nuer tilde Ɔ̱' },
			{ input: 'a~_', output: 'a̱', description: 'Nuer tilde a̱' },
			{ input: 'a~:', output: 'ä', description: 'Nuer tilde ä' },
			{ input: 'e~_', output: 'e̱', description: 'Nuer tilde e̱' },
			{ input: 'e~:', output: 'ë', description: 'Nuer tilde ë' },
			{ input: '~e', output: 'ɛ', description: 'Nuer tilde ɛ' },
			{ input: '~e~_', output: 'ɛ̱', description: 'Nuer tilde ɛ̱' },
			{ input: '~e~:', output: 'ɛ̈', description: 'Nuer tilde ɛ̈' },
			{ input: '~g', output: 'ɣ', description: 'Nuer tilde ɣ' },
			{ input: 'i~_', output: 'i̱', description: 'Nuer tilde i̱' },
			{ input: '~n', output: 'ŋ', description: 'Nuer tilde ŋ' },
			{ input: 'o~_', output: 'o̱', description: 'Nuer tilde o̱' },
			{ input: 'o~:', output: 'ö', description: 'Nuer tilde ö' },
			{ input: '~o', output: 'ɔ', description: 'Nuer tilde ɔ' },
			{ input: '~o~_', output: 'ɔ̱', description: 'Nuer tilde ɔ̱' }
		]
	},
	{
		description: 'Chichewa / Nyanja tilde test',
		inputmethod: 'ny-tilde',
		tests: [
			{ input: 'Mala~wi', output: 'Malaŵi', description: 'Chichewa / Nyanja tilde test Malaŵi' },
			{ input: '~Wanthu', output: 'Ŵanthu', description: 'Chichewa / Nyanja tilde test Ŵanthu' },
			{ input: 'galu~/', output: 'galú', description: 'Chichewa / Nyanja tilde test galú' }
		]
	},
	{
		description: 'Oriya InScript test',
		inputmethod: 'or-inscript',
		tests: [
			{ input: 'ka', output: 'କୋ', description: 'Odia InScript ka -> କୋ' }
		]
	},
	{
		description: 'Odia InScript 2 test',
		inputmethod: 'or-inscript2',
		tests: [
			{ input: '1234567890', output: '୧୨୩୪୫୬୭୮୯୦', description: 'Odia InScript 2 1234567890' },
			{ input: 'k#', output: 'କ୍ର', description: 'Odia InScript 2 k#' },
			{ input: '$k', output: 'ର୍କ', description: 'Odia InScript 2 $k' },
			{ input: '%', output: 'ଜ୍ଞ', description: 'Odia InScript 2 %' },
			{ input: '^', output: 'ତ୍ର', description: 'Odia InScript 2 ^' },
			{ input: '&', output: 'କ୍ଷ', description: 'Odia InScript 2 &' },
			{ input: '*', output: 'ଶ୍ର', description: 'Odia InScript 2 *' },
			{ input: '+', output: 'ଋ', description: 'Odia InScript 2 +' },
			{ input: 'QWERTYUIOP{}', output: 'ଔଐଆଈଊଭଙଘଧଝଢଞ', description: 'Odia InScript 2 QWERTYIOP{}' },
			{ input: 'yq', output: 'ବୌ', description: 'Odia InScript 2 yq' },
			{ input: 'uw', output: 'ହୈ', description: 'Odia InScript 2 uw' },
			{ input: 'ie', output: 'ଗା', description: 'Odia InScript 2 ie' },
			{ input: 'or', output: 'ଦୀ', description: 'Odia InScript 2 or' },
			{ input: 'pt', output: 'ଜୂ', description: 'Odia InScript 2 pt' },
			{ input: '[]', output: 'ଡ଼', description: 'Odia InScript 2 ড়' },
			{ input: 'ASDFGHKL:"', output: 'ଓଏଅଇଉଫଖଥଛଠ', description: 'Odia InScript 2 ASDFGHKL:"' },
			{ input: 'ha', output: 'ପୋ', description: 'Odia InScript 2 ha' },
			{ input: 'js', output: 'ରେ', description: 'Odia InScript 2 js' },
			{ input: 'kd', output: 'କ୍', description: 'Odia InScript 2 kd' },
			{ input: 'lf', output: 'ତି', description: 'Odia InScript 2 lf' },
			{ input: ';g', output: 'ଚୁ', description: 'Odia InScript 2 ;g' },
			{ input: '\'', output: 'ଟ', description: 'Odia InScript 2 \'' },
			{ input: 'cx', output: 'ମଂ', description: 'Odia InScript 2 cx' },
			{ input: 'vnm', output: 'ନଲସ', description: 'Odia InScript 2 vnm' },
			{ input: 'CX', output: 'ଣଁ', description: 'Odia InScript 2 CX' },
			{ input: 'M<?', output: 'ଶଷଯ', description: 'Odia InScript 2 M<?' }
		]
	},
	{
		description: 'Oriya phonetic test',
		inputmethod: 'or-lekhani',
		tests: [
			{ input: '\\~', output: '~', description: 'Oriya phonetic - \\~ -> ~' },
			{ input: 'a', output: 'ଅ', description: 'Odia phonetic a -> ଅ ' },
			{ input: 'aa', output: 'ଆ', description: 'Odia phonetic aa -> ଆ' },
			{ input: 'A', output: 'ଆ', description: 'Odia phonetic A -> ଆ' },
			{ input: 'i', output: 'ଇ', description: 'Odia phonetic i -> ଇ' },
			{ input: 'I', output: 'ଈ', description: 'Odia phonetic I -> ଈ' },
			{ input: 'u', output: 'ଉ', description: 'Odia phonetic u -> ଉ' },
			{ input: 'U', output: 'ଊ', description: 'Odia phonetic U -> ଊ' },
			{ input: 'r', output: 'ର', description: 'Odia phonetic r -> ର୍' },
			{ input: 'R', output: 'ଋ', description: 'Odia phonetic R -> ଋ' },
			{ input: 'e', output: 'ଏ', description: 'Odia phonetic e -> ଏ' },
			{ input: 'E', output: 'ଐ', description: 'Odia phonetic ai -> ଐ' },
			{ input: 'o', output: 'ଓ', description: 'Odia phonetic o -> ଓ' },
			{ input: 'O', output: 'ଔ', description: 'Odia phonetic O -> ଔ' },
			{ input: 'k', output: 'କ', description: 'Odia phonetic k -> କ' },
			{ input: 'kh', output: 'ଖ', description: 'Odia phonetic kh -> ଖ' },
			{ input: 'g', output: 'ଗ', description: 'Odia phonetic g -> ଗ' },
			{ input: 'gh', output: 'ଘ', description: 'Odia phonetic gh -> ଘ' },
			{ input: 'NG', output: 'ଙ', description: 'Odia phonetic NG -> ଙ' },
			{ input: 'c', output: 'ଚ', description: 'Odia phonetic c -> ଚ' },
			{ input: 'ch', output: 'ଛ', description: 'Odia phonetic ch -> ଛ' },
			{ input: 'j', output: 'ଜ', description: 'Odia phonetic j -> ଜ' },
			{ input: 'jh', output: 'ଝ', description: 'Odia phonetic jh -> ଝ' },
			{ input: 'Ng', output: 'ଞ', description: 'Odia phonetic Ng -> ଞ' },
			{ input: 'T', output: 'ଟ', description: 'Odia phonetic Ta -> ଟ' },
			{ input: 'Th', output: 'ଠ', description: 'Odia phonetic Th -> ଠ' },
			{ input: 'D', output: 'ଡ', description: 'Odia phonetic D -> ଡ' },
			{ input: 'Dh', output: 'ଢ', description: 'Odia phonetic Dh -> ଢ' },
			{ input: 'N', output: 'ଣ', description: 'Odia phonetic n -> ଣ' },
			{ input: 't', output: 'ତ', description: 'Odia phonetic t -> ତ' },
			{ input: 'th', output: 'ଥ', description: 'Odia phonetic th -> ଥ' },
			{ input: 'd', output: 'ଦ', description: 'Odia phonetic d -> ଦ' },
			{ input: 'dh', output: 'ଧ', description: 'Odia phonetic dh -> ଧ' },
			{ input: 'n', output: 'ନ', description: 'Odia phonetic n -> ନ' },
			{ input: 'p', output: 'ପ', description: 'Odia phonetic p -> ପ' },
			{ input: 'ph', output: 'ଫ', description: 'Odia phonetic ph -> ଫ' },
			{ input: 'b', output: 'ବ', description: 'Odia phonetic b -> ବ' },
			{ input: 'bh', output: 'ଭ', description: 'Odia phonetic b -> ଭ' },
			{ input: 'm', output: 'ମ', description: 'Odia phonetic m -> ମ' },
			{ input: 'y', output: 'ଯ', description: 'Odia phonetic y -> ଯ' },
			{ input: 'Y', output: 'ୟ', description: 'Odia phonetic Y -> ୟ' },
			{ input: 'r', output: 'ର', description: 'Odia phonetic r -> ର' },
			{ input: 'l', output: 'ଲ', description: 'Odia phonetic l -> ଲ' },
			{ input: 'L', output: 'ଳ', description: 'Odia phonetic L -> ଳ' },
			{ input: 'S', output: 'ଶ', description: 'Odia phonetic S -> ଶ' },
			{ input: 's', output: 'ସ', description: 'Odia phonetic s -> ସ' },
			{ input: 'sh', output: 'ଷ', description: 'Odia phonetic sh -> ଷ' },
			{ input: 'h', output: 'ହ', description: 'Odia phonetic h -> ହ' },
			{ input: '.', output: '।', description: 'Odia phonetic . -> । ' },
			{ input: 'sainath', output: 'ସାଇନାଥ', description: 'Odia phonetic sainath -> ସାଇନାଥ ' },
			{ input: 'dxiNeSwr', output: 'ଦକ୍ଷିଣେଶ୍ୱର', description: 'Odia phonetic dxiNeSwr -> ଦକ୍ଷିଣେଶ୍ୱର ' },
			{ input: 'kumbhkrzNeshu', output: 'କୁମ୍ଭକର୍ଣେଷୁ', description: 'Odia phonetic kumbhkrzNeshu -> କୁମ୍ଭକର୍ଣେଷୁ' }
		]
	},
	{
		description: 'Oriya OdiScript test',
		inputmethod: 'or-OdiScript',
		tests: [
			{ input: '\'\'', output: '"', description: 'Odia OdiScript \'\' -> "' },
			{ input: '\'\'\'', output: '\'\'\'', description: 'Odia OdiScript \'\' -> \'\'\'' },
			{ input: 'j}', output: 'ର‍୍ୟ', description: 'Odia OdiScript j} -> ର‍୍ୟ' },
			{ input: 'O}', output: 'ଡ୍ୟ', description: 'Odia OdiScript O} -> ଡ୍ୟ' },
			{ input: 's~', output: 'କଃ', description: 'Odia OdiScript j~ -> କଃ' },
			{ input: 'sds@@', output: 'ର୍କ୍କ', description: 'Odia OdiScript sds@@ -> ର୍କ୍କ' },
			{ input: 's@@', output: 'ର୍କ', description: 'Odia OdiScript s@@ -> ର୍କ' },
			{ input: 'sd s', output: 'କ୍‌ କ', description: 'Odia OdiScript sd s -> କ୍‌ କ (zwnj after halant)' },
			{ input: 'sQ', output: 'ତ୍କ', description: 'Odia OdiScript sQ -> ତ୍କ' },
			{ input: 'SQ', output: 'ଖି', description: 'Odia OdiScript SQ -> ଖି' },
			{ input: 'W', output: 'ଫ', description: 'Odia OdiScript W -> ଫ' },
			{ input: 'E', output: 'ଡ଼', description: 'Odia OdiScript E -> ଡ଼' },
			{ input: 'R', output: 'ଧ', description: 'Odia OdiScript R -> ଧ' },
			{ input: 'T', output: 'ଓ', description: 'Odia OdiScript T -> ଓ' },
			{ input: 'Y', output: 'ଔ', description: 'Odia OdiScript Y -> ଔ' },
			{ input: 'U', output: 'ଟ', description: 'Odia OdiScript U -> ଟ' },
			{ input: 'I', output: 'ଠ', description: 'Odia OdiScript I -> ଠ' },
			{ input: 'O', output: 'ଡ', description: 'Odia OdiScript O -> ଡ' },
			{ input: 'P', output: 'ଢ', description: 'Odia OdiScript P -> ଢ' },
			{ input: 'A', output: 'ଢ଼', description: 'Odia OdiScript A -> ଢ଼' },
			{ input: 'S', output: 'ଖ', description: 'Odia OdiScript S -> ଖ' },
			{ input: 'D', output: '‌', description: 'Odia OdiScript D ZWNJ -> ‌' },
			{ input: 'F', output: 'ଥ', description: 'Odia OdiScript F -> ଥ' },
			{ input: 'G', output: 'ଇ', description: 'Odia OdiScript G -> ଇ' },
			{ input: 'H', output: 'ଈ', description: 'Odia OdiScript H -> ଈ' },
			{ input: 'J', output: 'ଣ', description: 'Odia OdiScript J -> ଣ' },
			{ input: 'K', output: 'ଶ', description: 'Odia OdiScript K -> ଶ' },
			{ input: 'L', output: 'ଷ', description: 'Odia OdiScript L -> ଷ' },
			{ input: 'Z', output: 'ଙ', description: 'Odia OdiScript Z -> ଙ' },
			{ input: 'X', output: 'ଘ', description: 'Odia OdiScript X -> ଘ' },
			{ input: 'C', output: 'ଝ', description: 'Odia OdiScript C -> ଝ' },
			{ input: 'V', output: 'ଛ', description: 'Odia OdiScript V -> ଛ' },
			{ input: 'B', output: 'ଉ', description: 'Odia OdiScript B -> ଉ' },
			{ input: 'N', output: 'ଊ', description: 'Odia OdiScript N -> ଊ' },
			{ input: 'M', output: 'ଲ', description: 'Odia OdiScript M -> ଲ' },
			{ input: 'TEgtds]gwdU', output: 'ଓଡ଼ିସ୍କ୍ରିପ୍ଟ', description: 'Odia OdiScript TEgtds]gwdU-> ଓଡ଼ିସ୍କ୍ରିପ୍ଟ' }
		]
	},
	{
		description: 'Oriya transliteration test',
		inputmethod: 'or-transliteration',
		tests: [
			{ input: '\\~', output: '~', description: 'Oriya transliteration - \\~ -> ~' },
			{ input: 'a', output: 'ଅ', description: 'Odia transliteration a -> ଅ ' },
			{ input: 'aa', output: 'ଆ', description: 'Odia transliteration aa -> ଆ' },
			{ input: 'A', output: 'ଆ', description: 'Odia transliteration A -> ଆ' },
			{ input: 'i', output: 'ଇ', description: 'Odia transliteration i -> ଇ' },
			{ input: 'I', output: 'ଈ', description: 'Odia transliteration I -> ଈ' },
			{ input: 'u', output: 'ଉ', description: 'Odia transliteration u -> ଉ' },
			{ input: 'U', output: 'ଊ', description: 'Odia transliteration U -> ଊ' },
			{ input: 'r', output: 'ର୍', description: 'Odia transliteration r -> ର୍' },
			{ input: 'R', output: 'ଋ', description: 'Odia transliteration R -> ଋ' },
			{ input: 'e', output: 'ଏ', description: 'Odia transliteration e -> ଏ' },
			{ input: 'ai', output: 'ଐ', description: 'Odia transliteration ai -> ଐ' },
			{ input: 'o', output: 'ଓ', description: 'Odia transliteration o -> ଓ' },
			{ input: 'O', output: 'ଔ', description: 'Odia transliteration O -> ଔ' },
			{ input: 'k', output: 'କ୍', description: 'Odia transliteration k -> କ୍' },
			{ input: 'kh', output: 'ଖ୍', description: 'Odia transliteration kh -> ଖ୍' },
			{ input: 'g', output: 'ଗ୍', description: 'Odia transliteration g -> ଗ୍' },
			{ input: 'gh', output: 'ଘ୍', description: 'Odia transliteration gh -> ଘ୍' },
			{ input: 'NGa', output: 'ଙ', description: 'Odia transliteration NGa -> ଙ' },
			{ input: 'ca', output: 'ଚ', description: 'Odia transliteration ca -> ଚ' },
			{ input: 'cha', output: 'ଛ', description: 'Odia transliteration cha -> ଛ' },
			{ input: 'ja', output: 'ଜ', description: 'Odia transliteration ja -> ଜ' },
			{ input: 'jha', output: 'ଝ', description: 'Odia transliteration jha -> ଝ' },
			{ input: 'Nga', output: 'ଞ', description: 'Odia transliteration Nga -> ଞ' },
			{ input: 'Ta', output: 'ଟ', description: 'Odia transliteration Ta -> ଟ' },
			{ input: 'Tha', output: 'ଠ', description: 'Odia transliteration Tha -> ଠ' },
			{ input: 'Da', output: 'ଡ', description: 'Odia transliteration Da -> ଡ' },
			{ input: 'Dha', output: 'ଢ', description: 'Odia transliteration Dha -> ଢ' },
			{ input: 'Na', output: 'ଣ', description: 'Odia transliteration na -> ଣ' },
			{ input: 'ta', output: 'ତ', description: 'Odia transliteration ta -> ତ' },
			{ input: 'tha', output: 'ଥ', description: 'Odia transliteration tha -> ଥ' },
			{ input: 'da', output: 'ଦ', description: 'Odia transliteration da -> ଦ' },
			{ input: 'dha', output: 'ଧ', description: 'Odia transliteration dha -> ଧ' },
			{ input: 'na', output: 'ନ', description: 'Odia transliteration na -> ନ' },
			{ input: 'pa', output: 'ପ', description: 'Odia transliteration pa -> ପ' },
			{ input: 'pha', output: 'ଫ', description: 'Odia transliteration pha -> ଫ' },
			{ input: 'ba', output: 'ବ', description: 'Odia transliteration ba -> ବ' },
			{ input: 'bha', output: 'ଭ', description: 'Odia transliteration bha -> ଭ' },
			{ input: 'ma', output: 'ମ', description: 'Odia transliteration ma -> ମ' },
			{ input: 'ya', output: 'ୟ', description: 'Odia transliteration ya -> ୟ' },
			{ input: 'ra', output: 'ର', description: 'Odia transliteration ra -> ର' },
			{ input: 'la', output: 'ଲ', description: 'Odia transliteration la -> ଲ' },
			{ input: 'La', output: 'ଳ', description: 'Odia transliteration La -> ଳ' },
			{ input: 'Sa', output: 'ଶ', description: 'Odia transliteration Sa -> ଶ' },
			{ input: 'sa', output: 'ସ', description: 'Odia transliteration sa -> ସ' },
			{ input: 'sha', output: 'ଷ', description: 'Odia transliteration sha -> ଷ' },
			{ input: 'ha', output: 'ହ', description: 'Odia transliteration ha -> ହ' }
		]
	},
	{
		description: 'Punjabi Gurmukhi Phonetic',
		inputmethod: 'pa-phonetic',
		tests: [
			{ input: 'mu~K', output: 'ਮੁੱਖ', description: 'Punjabi Phonetic test - "mu~K"' },
			{ input: 'p`rIqI', output: 'ਪ੍ਰੀਤੀ', description: 'Punjabi Phonetic test - "p`rIqI (Priti)"' },
			{ input: 'd`', output: 'ਦ੍', description: 'Punjabi Phonetic test - d+halant' },
			{ input: 'd~', output: 'ਦੱ', description: 'Punjabi Phonetic test - d+adhak' },
			{ input: '1', output: '1', description: 'Punjabi Phonetic test - 1' },
			{ input: '!', output: '੧', description: 'Punjabi Phonetic test - Gurmukhi 1' },
			{ input: '2', output: '2', description: 'Punjabi Phonetic test - 2' },
			{ input: '@', output: '੨', description: 'Punjabi Phonetic test - Gurmukhi 2' },
			{ input: '3', output: '3', description: 'Punjabi Phonetic test - 3' },
			{ input: '#', output: '੩', description: 'Punjabi Phonetic test - Gurmukhi 3' },
			{ input: '4', output: '4', description: 'Punjabi Phonetic test - 4' },
			{ input: '$', output: '੪', description: 'Punjabi Phonetic test - Gurmukhi 4' },
			{ input: '5', output: '5', description: 'Punjabi Phonetic test - 5' },
			{ input: '%', output: '੫', description: 'Punjabi Phonetic test - Gurmukhi 5' },
			{ input: '6', output: '6', description: 'Punjabi Phonetic test - 6' },
			{ input: '^', output: '੬', description: 'Punjabi Phonetic test - Gurmukhi 6' },
			{ input: '7', output: '7', description: 'Punjabi Phonetic test - 7' },
			{ input: '&', output: '੭', description: 'Punjabi Phonetic test - Gurmukhi 7' },
			{ input: '8', output: '8', description: 'Punjabi Phonetic test - 8' },
			{ input: '*', output: '੮', description: 'Punjabi Phonetic test - Gurmukhi 8' },
			{ input: '9', output: '9', description: 'Punjabi Phonetic test - 9' },
			{ input: '(', output: '੯', description: 'Punjabi Phonetic test - Gurmukhi 9' },
			{ input: '0', output: '0', description: 'Punjabi Phonetic test - 0' },
			{ input: ')', output: '੦', description: 'Punjabi Phonetic test - Gurmukhi 0' },
			{ input: '-', output: '-', description: 'Punjabi Phonetic test - -' },
			{ input: '_', output: '_', description: 'Punjabi Phonetic test - +' },
			{ input: '=', output: '=', description: 'Punjabi Phonetic test - =' },
			{ input: '+', output: '+', description: 'Punjabi Phonetic test - +' },
			{ input: 'qw', output: 'ਤਾ', description: 'Punjabi Phonetic test - qw' },
			{ input: 'e', output: 'ੲ', description: 'Punjabi Phonetic test - e' },
			{ input: 'r', output: 'ਰ', description: 'Punjabi Phonetic test - r' },
			{ input: 'ty', output: 'ਟੇ', description: 'Punjabi Phonetic test - ty' },
			{ input: 'tu', output: 'ਟੁ', description: 'Punjabi Phonetic test - tu' },
			{ input: 'ti', output: 'ਟਿ', description: 'Punjabi Phonetic test - ti' },
			{ input: 'to', output: 'ਟੋ', description: 'Punjabi Phonetic test - to' },
			{ input: 'p', output: 'ਪ', description: 'Punjabi Phonetic test - p' },
			{ input: '[', output: '[', description: 'Punjabi Phonetic test - [' },
			{ input: ']', output: ']', description: 'Punjabi Phonetic test - ]' },
			{ input: '\\', output: 'ਙ', description: 'Punjabi Phonetic test - \\ -> ਙ' },
			{ input: 'QW', output: 'ਥਾਂ', description: 'Punjabi Phonetic test - QW' },
			{ input: 'E', output: 'ਓ', description: 'Punjabi Phonetic test - E' },
			{ input: 'TY', output: 'ਠੈ', description: 'Punjabi Phonetic test - TY' },
			{ input: 'TU', output: 'ਠੂ', description: 'Punjabi Phonetic test - TU' },
			{ input: 'TI', output: 'ਠੀ', description: 'Punjabi Phonetic test - TI' },
			{ input: 'TO', output: 'ਠੌ', description: 'Punjabi Phonetic test - TO' },
			{ input: 'PR', output: 'ਫ੍ਰ', description: 'Punjabi Phonetic test - PR' },
			{ input: '{', output: '{', description: 'Punjabi Phonetic test - {' },
			{ input: '}', output: '}', description: 'Punjabi Phonetic test - }' },
			{ input: '|', output: '।', description: 'Punjabi Phonetic test - | -> danda' },
			{ input: 'a', output: 'ੳ', description: 'Punjabi Phonetic test - a' },
			{ input: 's', output: 'ਸ', description: 'Punjabi Phonetic test - s' },
			{ input: 'd', output: 'ਦ', description: 'Punjabi Phonetic test - d' },
			{ input: 'f', output: 'ਡ', description: 'Punjabi Phonetic test - f' },
			{ input: 'g', output: 'ਗ', description: 'Punjabi Phonetic test - g' },
			{ input: 'h', output: 'ਹ', description: 'Punjabi Phonetic test - h' },
			{ input: 'j', output: 'ਜ', description: 'Punjabi Phonetic test - j' },
			{ input: 'k', output: 'ਕ', description: 'Punjabi Phonetic test - k' },
			{ input: 'l', output: 'ਲ', description: 'Punjabi Phonetic test - l' },
			{ input: 'A', output: 'ਅ', description: 'Punjabi Phonetic test - A' },
			{ input: 'S', output: 'ਸ਼', description: 'Punjabi Phonetic test - S' },
			{ input: 'D', output: 'ਧ', description: 'Punjabi Phonetic test - D' },
			{ input: 'F', output: 'ਢ', description: 'Punjabi Phonetic test - F' },
			{ input: 'GH', output: 'ਘ੍ਹ', description: 'Punjabi Phonetic test - GH' },
			{ input: 'J', output: 'ਝ', description: 'Punjabi Phonetic test - J' },
			{ input: 'K', output: 'ਖ', description: 'Punjabi Phonetic test - K' },
			{ input: 'L', output: 'ਲ਼', description: 'Punjabi Phonetic test - L' },
			{ input: ';', output: ';', description: 'Punjabi Phonetic test - ;' },
			{ input: ':', output: ':', description: 'Punjabi Phonetic test - :' },
			{ input: '\'', output: '\'', description: 'Punjabi Phonetic test - \'' },
			{ input: '"', output: '"', description: 'Punjabi Phonetic test - "' },
			{ input: 'z', output: 'ਜ਼', description: 'Punjabi Phonetic test - z' },
			{ input: 'x', output: 'ਣ', description: 'Punjabi Phonetic test - x' },
			{ input: 'c', output: 'ਚ', description: 'Punjabi Phonetic test - c' },
			{ input: 'v', output: 'ਵ', description: 'Punjabi Phonetic test - v' },
			{ input: 'b', output: 'ਬ', description: 'Punjabi Phonetic test - b' },
			{ input: 'n', output: 'ਨ', description: 'Punjabi Phonetic test - n' },
			{ input: 'm', output: 'ਮ', description: 'Punjabi Phonetic test - m' },
			{ input: ',', output: ',', description: 'Punjabi Phonetic test - ,' },
			{ input: 'g.', output: 'ਗ਼', description: 'Punjabi Phonetic test - g. -> g+nukta' },
			{ input: '/', output: 'ਞ', description: 'Punjabi Phonetic test - / -> ਞ' },
			{ input: 'Z', output: 'ਗ਼', description: 'Punjabi Phonetic test - Z' },
			{ input: 'X', output: 'ਯ', description: 'Punjabi Phonetic test - X' },
			{ input: 'C', output: 'ਛ', description: 'Punjabi Phonetic test - C' },
			{ input: 'V', output: 'ੜ', description: 'Punjabi Phonetic test - V' },
			{ input: 'B', output: 'ਭ', description: 'Punjabi Phonetic test - B' },
			{ input: 'qoN', output: 'ਤੋਂ', description: 'Punjabi Phonetic test - qoN' },
			{ input: 'hM', output: 'ਹੰ', description: 'Punjabi Phonetic test - hM' },
			{ input: '<', output: 'ਖ਼', description: 'Punjabi Phonetic test - < -> ਖ਼' },
			{ input: '>', output: 'ੴ', description: 'Punjabi Phonetic test - > -> ੴ' },
			{ input: '?', output: '?', description: 'Punjabi Phonetic test - ?' }
		]
	},
	{
		description: 'Punjabi Gurmukhi Transliteration',
		inputmethod: 'pa-transliteration',
		tests: [
			{ input: '\\~', output: '~', description: 'Punjabi Gurmukhi transliteration - \\~ -> ~' },
			{ input: 'kaI', output: 'ਕਈ', description: 'Punjabi Gurmukhi kaI' },
			{ input: 'hoiaa', output: 'ਹੋਇਆ', description: 'Punjabi Gurmukhi hoiaa' },
			{ input: 'ki', output: 'ਕਿ', description: 'Punjabi Gurmukhi ki' },
			{ input: 'kii', output: 'ਕੀ', description: 'Punjabi Gurmukhi kii' },
			{ input: 'kI', output: 'ਕੀ', description: 'Punjabi Gurmukhi kI' },
			{ input: 'kee', output: 'ਕੀ', description: 'Punjabi Gurmukhi kee' },
			{ input: 'ku', output: 'ਕੁ', description: 'Punjabi Gurmukhi ku' },
			{ input: 'kuu', output: 'ਕੂ', description: 'Punjabi Gurmukhi kuu' },
			{ input: 'kU', output: 'ਕੂ', description: 'Punjabi Gurmukhi kU' },
			{ input: 'koo', output: 'ਕੂ', description: 'Punjabi Gurmukhi koo' },
			{ input: 'kai', output: 'ਕੈ', description: 'Punjabi Gurmukhi kai' },
			{ input: 'kE', output: 'ਕੈ', description: 'Punjabi Gurmukhi kE' },
			{ input: 'ko', output: 'ਕੋ', description: 'Punjabi Gurmukhi ko' },
			{ input: 'kO', output: 'ਕੋ', description: 'Punjabi Gurmukhi ko' },
			{ input: 'kau', output: 'ਕੌ', description: 'Punjabi Gurmukhi kau' },
			{ input: 'g`a', output: 'ਗ਼', description: 'Punjabi Gurmukhi g`a (bindi)' },
			{ input: 'u', output: 'ਉ', description: 'Punjabi Gurmukhi u' },
			{ input: 'uu', output: 'ਊ', description: 'Punjabi Gurmukhi uu' },
			{ input: 'oo', output: 'ਊ', description: 'Punjabi Gurmukhi oo' },
			{ input: 'a^', output: 'ੲ', description: 'Punjabi Gurmukhi a^ (iri)' },
			{ input: 'u^', output: 'ੳ', description: 'Punjabi Gurmukhi u^ (ura)' },
			{ input: 'X', output: 'ੴ', description: 'Punjabi Gurmukhi X (Ek onkar)' },
			{ input: 'kaM', output: 'ਕਂ', description: 'Punjabi Gurmukhi kaM (bindi)' },
			{ input: 'kaMM', output: 'ਕਁ', description: 'Punjabi Gurmukhi kaMM (adak bindi)' },
			{ input: 'kaMm', output: 'ਕਁ', description: 'Punjabi Gurmukhi kaMm (adak bindi)' },
			{ input: 'kaM^', output: 'ਕਁ', description: 'Punjabi Gurmukhi kaM^ (adak bindi)' },
			{ input: 'k`haalasaa', output: 'ਖ਼ਾਲਸਾ', description: 'Punjabi Gurmukhi k`haalasaa' },
			{ input: 'raNajiita', output: 'ਰਣਜੀਤ', description: 'Punjabi Gurmukhi raNajiita (testing NNA)' },
			{ input: 'khadeRhana', output: 'ਖਦੇੜ੍ਹਨ', description: 'Punjabi Gurmukhi khadeRhana (testing R and subjoined h)' },
			{ input: 'siNNgha', output: 'ਸਿੰਘ', description: 'Punjabi Gurmukhi siNNgha (testing Tippi)' },
			{ input: 'hai.', output: 'ਹੈ।', description: 'Punjabi Gurmukhi hai. (testing danda)' },
			{ input: 'phaaga..', output: 'ਫਾਗ॥', description: 'Punjabi Gurmukhi phaaga.. (testing double danda)' },
			{ input: 'iiTaanagara', output: 'ਈਟਾਨਗਰ', description: 'Punjabi Gurmukhi iiTaanagara' },
			{ input: 'eeTaanagara', output: 'ਈਟਾਨਗਰ', description: 'Punjabi Gurmukhi eeTaanagara' }
		]
	},
	{
		description: 'Mongolian phags-pa test',
		inputmethod: 'phagspa',
		tests: [
			{ input: 'SFHK', output: 'ꡚꡰꡯꡁ', description: 'Mongolian phags-pa' }
		]
	},
	{
		description: 'Piemontèis input method test',
		inputmethod: 'pms',
		tests: [
			{ input: ':e', output: 'ë', description: 'Piemontèis ë' },
			{ input: ',o', output: 'ó', description: 'Piemontèis ó' },
			{ input: '\\A', output: 'À', description: 'Piemontèis À' },
			{ input: '\\E', output: 'È', description: 'Piemontèis È' },
			{ input: '\\I', output: 'Ì', description: 'Piemontèis Ì' },
			{ input: '\\O', output: 'Ò', description: 'Piemontèis Ò' },
			{ input: '\\U', output: 'Ù', description: 'Piemontèis Ù' },
			{ input: ',E', output: 'É', description: 'Piemontèis É' },
			{ input: ':E', output: 'Ë', description: 'Piemontèis Ë' },
			{ input: ',O', output: 'Ó', description: 'Piemontèis Ó' },
			{ input: '^g', output: 'ĝ', description: 'Piemontèis (local) ĝ' },
			{ input: '^l', output: 'l̂', description: 'Piemontèis (local) l̂̂' },
			{ input: '^r', output: 'r̂', description: 'Piemontèis (local) r̂' },
			{ input: ':a', output: 'ä', description: 'Piemontèis (local) ä' },
			{ input: '^G', output: 'Ĝ', description: 'Piemontèis (local) Ĝ' },
			{ input: '^L', output: 'L̂', description: 'Piemontèis (local) L̂' },
			{ input: '^R', output: 'R̂', description: 'Piemontèis (local) R̂' },
			{ input: ':A', output: 'Ä', description: 'Piemontèis (local) Ä' }
		]
	},
	{
		description: 'Tarandine input method test',
		inputmethod: 'roa-tara-GVU',
		tests: [
			{ input: 'a§', output: 'á', description: 'Tarandine á' },
			{ input: 'o§', output: 'ó', description: 'Tarandine ó' },
			{ input: 'A§', output: 'Á', description: 'Tarandine Á' },
			{ input: 'O§', output: 'Ó', description: 'Tarandine Ó' }
		]
	},
	{
		description: 'Russian kbd keyboard test',
		inputmethod: 'ru-kbd',
		tests: [
			{ input: '~!@#$%^&*()_+', output: 'Ё!"№;%:?*()_+', description: 'Russian kbd - numbers row shifted' },
			{ input: '`1234567890-=', output: 'ё1234567890-=', description: 'Russian kbd - numbers row not shifted' },
			{ input: 'QWERTYUIOP{}', output: 'ЙЦУКЕНГШЩЗХЪ', description: 'Russian kbd - QWERTY row shifted' },
			{ input: 'qwertyuiop[]\\', output: 'йцукенгшщзхъ\\', description: 'Russian kbd - qwerty row not shifted' },
			{ input: 'ASDFGHJKL:"', output: 'ФЫВАПРОЛДЖЭ', description: 'Russian kbd - ASDF row shifted' },
			{ input: 'asdfghjkl;\'', output: 'фывапролджэ', description: 'Russian kbd - asdf row not shifted' },
			{ input: 'ZXCVBNM<>?', output: 'ЯЧСМИТЬБЮ,', description: 'Russian kbd - ZXCV row shifted' },
			{ input: 'zxcvbnm,./', output: 'ячсмитьбю.', description: 'Russian kbd - zxcv row not shifted' }
		]
	},
	{
		description: 'Romanized input method for Sanskrit test',
		inputmethod: 'sa-iast',
		tests: [
			{ input: 'aa', output: 'ā', description: 'Sanskrit transliteration - aa -> ā' },
			{ input: '^a', output: 'â', description: 'Sanskrit transliteration - aa -> â' },
			{ input: '.N', output: 'Ṇ', description: 'Sanskrit transliteration - .N -> Ṇ' },
			{ input: 'ḶL', output: 'Ḹ', description: 'Sanskrit transliteration - ḶL -> Ḹ' }
		]
	},
	{
		description: 'Sanskrit transliteration test',
		inputmethod: 'sa-transliteration',
		tests: [
			{ input: '\\~', output: '~', description: 'Sanskrit transliteration - \\~ -> ~' }
		]
	},
	{
		description: 'Santali InScript 2 Devanagari test',
		inputmethod: 'sat-inscript2',
		tests: [
			{ input: '1234567890', output: '१२३४५६७८९०', description: 'Santali InScript 2 Devanagari 1234567890' },
			{ input: '%', output: 'ज्ञ', description: 'Santali InScript 2 Devanagari %' },
			{ input: '^', output: 'त्र', description: 'Santali InScript 2 Devanagari ^' },
			{ input: '&', output: 'क्ष', description: 'Santali InScript 2 Devanagari &' },
			{ input: '*', output: 'श्र', description: 'Santali InScript 2 Devanagari *' },
			{ input: 'k_', output: 'कः', description: 'Santali InScript 2 Devanagari k_' },
			{ input: 'QWERTYUIOP{}', output: 'औऐआईऊभङघधझढञ', description: 'Santali InScript 2 Devanagari QWERTYIOP{}' },
			{ input: 'yq', output: 'बौ', description: 'Santali InScript 2 Devanagari yq' },
			{ input: 'uw', output: 'है', description: 'Santali InScript 2 Devanagari uw' },
			{ input: 'ie', output: 'गा', description: 'Santali InScript 2 Devanagari ie' },
			{ input: 'or', output: 'दी', description: 'Santali InScript 2 Devanagari or' },
			{ input: 'pt', output: 'जू', description: 'Santali InScript 2 Devanagari pt' },
			{ input: 'ASDFGHKL:"', output: 'ओएअइउफखथछठ', description: 'Santali InScript 2 Devanagari ASDFGHKL:"' },
			{ input: 'ha', output: 'पो', description: 'Santali InScript 2 Devanagari ha' },
			{ input: 'js', output: 'रे', description: 'Santali InScript 2 Devanagari js' },
			{ input: 'kd', output: 'क्', description: 'Santali InScript 2 Devanagari kd' },
			{ input: 'lf', output: 'ति', description: 'Santali InScript 2 Devanagari lf' },
			{ input: ';\'', output: 'चट', description: 'Santali InScript 2 Devanagari ;\'' },
			{ input: 'C>?', output: 'ण।?', description: 'Santali InScript 2 Devanagari C>?' },
			{ input: ';X', output: 'चँ', description: 'Santali InScript 2 Devanagari ;X' },
			{ input: 'z', output: 'ʼ', description: 'Santali InScript 2 Devanagari z' },
			{ input: 'mx', output: 'सं', description: 'Santali InScript 2 Devanagari mx' },
			{ input: 'cvb', output: 'मनव', description: 'Santali InScript 2 Devanagari cvb' },
			{ input: '/', output: 'य', description: 'Santali InScript 2 Devanagari /' }
		]
	},
	{
		description: 'Santali InScript 2 Ol Chiki test',
		inputmethod: 'sat-inscript2-ol-chiki',
		tests: [
			{ input: 'e', output: 'ᱟ', description: 'Santali k -> ᱟ' },
			{ input: 'y', output: 'ᱵ', description: 'Santali y -> ᱵ' },
			{ input: 'U', output: 'ᱝ', description: 'Santali U -> ᱝ' },
			{ input: 'u', output: 'ᱦ', description: 'Santali u -> ᱦ' },
			{ input: 'C', output: 'ᱬ', description: 'Santali C -> ᱬ' },
			{ input: 'c', output: 'ᱢ', description: 'Santali c -> ᱢ' },
			{ input: 'B', output: 'ᱶ', description: 'Santali B -> ᱶ' }
		]
	},
	{
		description: 'Santali Sarjom Baha test',
		inputmethod: 'sat-sarjom-baha',
		tests: [
			{ input: 'a', output: 'ᱟ', description: 'Santali a -> ᱟ' },
			{ input: 'b', output: 'ᱵ', description: 'Santali b -> ᱵ' },
			{ input: 'P', output: 'ᱯ', description: 'Santali P -> ᱯ' },
			{ input: 'Q', output: 'ᱻ', description: 'Santali Q -> ᱻ' },
			{ input: 'W', output: 'ᱣ', description: 'Santali W -> ᱣ' },
			{ input: 'c', output: 'ᱪ', description: 'Santali c -> ᱪ' }
		]
	},
	{
		description: 'Sindhi InScript 2 Devanagari test',
		inputmethod: 'sd-inscript2',
		tests: [
			{ input: '1234567890', output: '१२३४५६७८९०', description: 'Sindhi InScript 2 Devanagari 1234567890' },
			{ input: '%', output: 'ज्ञ', description: 'Sindhi InScript 2 Devanagari %' },
			{ input: '^', output: 'त्र', description: 'Sindhi InScript 2 Devanagari ^' },
			{ input: '&', output: 'क्ष', description: 'Sindhi InScript 2 Devanagari &' },
			{ input: '*', output: 'श्र', description: 'Sindhi InScript 2 Devanagari *' },
			{ input: '+', output: 'ऋ', description: 'Sindhi InScript 2 Devanagari +' },
			{ input: 'k=', output: 'कृ', description: 'Sindhi InScript 2 Devanagari k=' },
			{ input: 'QWERTYUIOP{}', output: 'औऐआईऊभङघधझढञ', description: 'Sindhi InScript 2 Devanagari QWERTYIOP{}' },
			{ input: 'yq', output: 'बौ', description: 'Sindhi InScript 2 Devanagari yq' },
			{ input: 'uw', output: 'है', description: 'Sindhi InScript 2 Devanagari uw' },
			{ input: 'ie', output: 'गा', description: 'Sindhi InScript 2 Devanagari ie' },
			{ input: 'or', output: 'दी', description: 'Sindhi InScript 2 Devanagari or' },
			{ input: 'pt', output: 'जू', description: 'Sindhi InScript 2 Devanagari pt' },
			{ input: 'ASDFGHKL:"', output: 'ओएअइउफखथछठ', description: 'Sindhi InScript 2 Devanagari ASDFGHKL:"' },
			{ input: 'ha', output: 'पो', description: 'Sindhi InScript 2 Devanagari ha' },
			{ input: 'js', output: 'रे', description: 'Sindhi InScript 2 Devanagari js' },
			{ input: 'kd', output: 'क्', description: 'Sindhi InScript 2 Devanagari kd' },
			{ input: 'lf', output: 'ति', description: 'Sindhi InScript 2 Devanagari lf' },
			{ input: ';\'', output: 'चट', description: 'Sindhi InScript 2 Devanagari ;\'' },
			{ input: 'CM<>?', output: 'णशष।?', description: 'Sindhi InScript 2 Devanagari CM<>?' },
			{ input: ';X', output: 'चँ', description: 'Sindhi InScript 2 Devanagari ;X' },
			{ input: 'cvb', output: 'मनव', description: 'Sindhi InScript 2 Devanagari cvb' },
			{ input: '/', output: 'य', description: 'Sindhi InScript 2 Devanagari /' }
		]
	},
	{
		description: 'Southern Kurdish Keyboard test',
		inputmethod: 'sdh-kbd',
		tests: [
			{ input: '`', output: '\u200c', description: 'Southern Kurdish Keyboard Layout: ` -> \u200c' },
			{ input: '1', output: '١', description: 'Southern Kurdish Keyboard Layout: 1 -> ١' },
			{ input: '2', output: '٢', description: 'Southern Kurdish Keyboard Layout: 2 -> ٢' },
			{ input: '3', output: '٣', description: 'Southern Kurdish Keyboard Layout: 3 -> ٣' },
			{ input: '4', output: '٤', description: 'Southern Kurdish Keyboard Layout: 4 -> ٤' },
			{ input: '5', output: '٥', description: 'Southern Kurdish Keyboard Layout: 5 -> ٥' },
			{ input: '6', output: '۶', description: 'Southern Kurdish Keyboard Layout: 6 -> ۶' },
			{ input: '7', output: '٧', description: 'Southern Kurdish Keyboard Layout: 7 -> ٧' },
			{ input: '8', output: '٨', description: 'Southern Kurdish Keyboard Layout: 8 -> ٨' },
			{ input: '9', output: '٩', description: 'Southern Kurdish Keyboard Layout: 9 -> ٩' },
			{ input: '0', output: '٠', description: 'Southern Kurdish Keyboard Layout: 0 -> ٠' },
			{ input: 'q', output: 'ض', description: 'Southern Kurdish Keyboard Layout: q -> ض' },
			{ input: 'w', output: 'ص', description: 'Southern Kurdish Keyboard Layout: w -> ص' },
			{ input: 'e', output: 'ث', description: 'Southern Kurdish Keyboard Layout: e -> ث' },
			{ input: 'r', output: 'ق', description: 'Southern Kurdish Keyboard Layout: r -> ق' },
			{ input: 't', output: 'ف', description: 'Southern Kurdish Keyboard Layout: t -> ف' },
			{ input: 'y', output: 'غ', description: 'Southern Kurdish Keyboard Layout: y -> غ' },
			{ input: 'u', output: 'ع', description: 'Southern Kurdish Keyboard Layout: u -> ع' },
			{ input: 'i', output: 'ھ', description: 'Southern Kurdish Keyboard Layout: i -> ھ' },
			{ input: 'o', output: 'خ', description: 'Southern Kurdish Keyboard Layout: o -> خ' },
			{ input: 'p', output: 'ح', description: 'Southern Kurdish Keyboard Layout: p -> ح' },
			{ input: '[', output: 'ج', description: 'Southern Kurdish Keyboard Layout: [ -> ج' },
			{ input: ']', output: 'چ', description: 'Southern Kurdish Keyboard Layout: ] -> چ' },
			{ input: 'a', output: 'ش', description: 'Southern Kurdish Keyboard Layout: a -> ش' },
			{ input: 's', output: 'س', description: 'Southern Kurdish Keyboard Layout: s -> س' },
			{ input: 'd', output: 'ی', description: 'Southern Kurdish Keyboard Layout: d -> ی' },
			{ input: 'f', output: 'ب', description: 'Southern Kurdish Keyboard Layout: f -> ب' },
			{ input: 'g', output: 'ل', description: 'Southern Kurdish Keyboard Layout: g -> ل' },
			{ input: 'h', output: 'ا', description: 'Southern Kurdish Keyboard Layout: h -> ا' },
			{ input: 'j', output: 'ت', description: 'Southern Kurdish Keyboard Layout: j -> ت' },
			{ input: 'k', output: 'ن', description: 'Southern Kurdish Keyboard Layout: k -> ن' },
			{ input: 'l', output: 'م', description: 'Southern Kurdish Keyboard Layout: l -> م' },
			{ input: ';', output: 'ک', description: 'Southern Kurdish Keyboard Layout: ; -> ک' },
			{ input: 'z', output: 'ظ', description: 'Southern Kurdish Keyboard Layout: z -> ظ' },
			{ input: 'x', output: 'ط', description: 'Southern Kurdish Keyboard Layout: x -> ط' },
			{ input: 'c', output: 'ز', description: 'Southern Kurdish Keyboard Layout: c -> ز' },
			{ input: 'v', output: 'ر', description: 'Southern Kurdish Keyboard Layout: v -> ر' },
			{ input: 'b', output: 'ذ', description: 'Southern Kurdish Keyboard Layout: b -> ذ' },
			{ input: 'n', output: 'د', description: 'Southern Kurdish Keyboard Layout: n -> د' },
			{ input: 'm', output: 'پ', description: 'Southern Kurdish Keyboard Layout: m -> پ' },
			{ input: ',', output: 'و', description: 'Southern Kurdish Keyboard Layout: , -> و' },
			{ input: '~', output: '÷', description: 'Southern Kurdish Keyboard Layout: ~ -> ÷' },
			{ input: '@', output: '٬', description: 'Southern Kurdish Keyboard Layout: @ -> ٬' },
			{ input: '#', output: '٫', description: 'Southern Kurdish Keyboard Layout: # -> ٫' },
			{ input: '%', output: '٪', description: 'Southern Kurdish Keyboard Layout: % -> ٪' },
			{ input: '^', output: '×', description: 'Southern Kurdish Keyboard Layout: ^ -> ×' },
			{ input: '&', output: '،', description: 'Southern Kurdish Keyboard Layout: & -> ،' },
			{ input: '(', output: ')', description: 'Southern Kurdish Keyboard Layout: ( -> )' },
			{ input: ')', output: '(', description: 'Southern Kurdish Keyboard Layout: ) -> (' },
			{ input: '_', output: 'ـ', description: 'Southern Kurdish Keyboard Layout: _ -> ـ' },
			{ input: 'Q', output: 'ْ', description: 'Southern Kurdish Keyboard Layout: Q -> ْ' },
			{ input: 'W', output: 'وو', description: 'Southern Kurdish Keyboard Layout: W -> وو' },
			{ input: 'E', output: 'ڤ', description: 'Southern Kurdish Keyboard Layout: E -> ڤ' },
			{ input: 'R', output: 'ً', description: 'Southern Kurdish Keyboard Layout: R -> ً' },
			{ input: 'T', output: 'ۊ', description: 'Southern Kurdish Keyboard Layout: T -> ۊ' },
			{ input: 'Y', output: 'ئ', description: 'Southern Kurdish Keyboard Layout: Y -> ئ' },
			{ input: 'U', output: 'ە', description: 'Southern Kurdish Keyboard Layout: U -> ە' },
			{ input: 'I', output: 'ّ', description: 'Southern Kurdish Keyboard Layout: I -> ّ' },
			{ input: 'O', output: ']', description: 'Southern Kurdish Keyboard Layout: O -> ]' },
			{ input: 'P', output: '[', description: 'Southern Kurdish Keyboard Layout: P -> [' },
			{ input: '{', output: '}', description: 'Southern Kurdish Keyboard Layout: { -> }' },
			{ input: '}', output: '{', description: 'Southern Kurdish Keyboard Layout: } -> {' },
			{ input: 'A', output: 'ؤ', description: 'Southern Kurdish Keyboard Layout: A -> ؤ' },
			{ input: 'S', output: 'ئ', description: 'Southern Kurdish Keyboard Layout: S -> ئ' },
			{ input: 'D', output: 'ێ', description: 'Southern Kurdish Keyboard Layout: D -> ێ' },
			{ input: 'F', output: 'إ', description: 'Southern Kurdish Keyboard Layout: F -> إ' },
			{ input: 'G', output: 'أ', description: 'Southern Kurdish Keyboard Layout: G -> أ' },
			{ input: 'H', output: 'آ', description: 'Southern Kurdish Keyboard Layout: H -> آ' },
			{ input: 'J', output: 'ة', description: 'Southern Kurdish Keyboard Layout: J -> ة' },
			{ input: 'K', output: '»', description: 'Southern Kurdish Keyboard Layout: K -> »' },
			{ input: 'L', output: '«', description: 'Southern Kurdish Keyboard Layout: L -> «' },
			{ input: '"', output: '؛', description: 'Southern Kurdish Keyboard Layout: " -> ؛' },
			{ input: 'Z', output: 'ۆ', description: 'Southern Kurdish Keyboard Layout: Z -> ۆ' },
			{ input: 'X', output: 'ط', description: 'Southern Kurdish Keyboard Layout: X -> ط' },
			{ input: 'C', output: 'ژ', description: 'Southern Kurdish Keyboard Layout: C -> ژ' },
			{ input: 'V', output: 'ڕ', description: 'Southern Kurdish Keyboard Layout: V -> ڕ' },
			{ input: 'B', output: 'ڵ', description: 'Southern Kurdish Keyboard Layout: B -> ڵ' },
			{ input: 'N', output: 'ٔ', description: 'Southern Kurdish Keyboard Layout: N -> ٔ' },
			{ input: 'M', output: 'ء', description: 'Southern Kurdish Keyboard Layout: M -> ء' },
			{ input: '<', output: '>', description: 'Southern Kurdish Keyboard Layout: < -> >' },
			{ input: '>', output: '<', description: 'Southern Kurdish Keyboard Layout: > -> <' },
			{ input: '?', output: '؟', description: 'Southern Kurdish Keyboard Layout: ? -> ؟' }
		]
	},
	{
		description: 'Koyraboro Senni tilde test',
		inputmethod: 'ses-tilde',
		tests: [
			{ input: 'Zah~o', output: 'Zahõ', description: 'Koyraboro Senni tilde Zahõ' },
			{ input: '~Yaali', output: 'Ɲaali', description: 'Koyraboro Senni tilde Ɲaali' },
			{ input: 'h~aa', output: 'hãa', description: 'Koyraboro Senni tilde hãa' },
			{ input: '~senday', output: 'šenday', description: 'Koyraboro Senni tilde šenday' },
			{ input: 'ka~g', output: 'kaŋ', description: 'Koyraboro Senni tilde kaŋ' },
			{ input: 'KA~G', output: 'KAŊ', description: 'Koyraboro Senni tilde KAŊ' },
			{ input: 'addu~y~yaa', output: 'adduɲɲaa', description: 'Koyraboro Senni tilde adduɲɲaa' },
			{ input: '~Sendaa', output: 'Šendaa', description: 'Koyraboro Senni tilde Šendaa' },
			{ input: 'socie~/te~/', output: 'société', description: 'Koyraboro Senni tilde société' },
			{ input: '~zeenaa', output: 'žeenaa', description: 'Koyraboro Senni tilde žeenaa' }
		]
	},
	{
		description: 'Sängö tilde test',
		inputmethod: 'sg-tilde',
		tests: [
			{ input: 'se~^hi~:nga~:ngo~:', output: 'sêhïngängö', description: 'Sängö tilde test sêhïngängö' },
			{ input: 'angba~^', output: 'angbâ', description: 'Sängö tilde test angbâ' },
			{ input: 'TE~/LE~/CHARGENGO', output: 'TÉLÉCHARGENGO', description: 'Sängö tilde test TÉLÉCHARGENGO' },
			{ input: 'Kembe~/', output: 'Kembé', description: 'Sängö tilde test Kembé' },
			{ input: 'Mbre~\\s', output: 'Mbrès', description: 'Sängö tilde test Mbrès' }
		]
	},
	{
		description: 'Sinhala Wijesekara transliteration tests',
		inputmethod: 'si-wijesekara',
		tests: [
			{ input: '"', output: ',', description: 'Sinhala Wijesekara - " -> ,' },

			// A consonant is entered with a single key.
			{ input: 'l', output: 'ක', description: 'Sinhala Wijesekara - l -> ක (KA)' },

			// A vowel is entered with 1 or 2 keys.
			{ input: 'w', output: 'අ', description: 'Sinhala Wijesekara - w -> අ (A)' },
			{ input: 'wd', output: 'ආ', description: 'Sinhala Wijesekara - wd -> ආ (AA)' },
			{ input: 'we', output: 'ඇ', description: 'Sinhala Wijesekara - wd -> ඇ (AE)' },
			{ input: 'wE', output: 'ඈ', description: 'Sinhala Wijesekara - wd -> ඈ (AAE)' },

			{ input: 'b', output: 'ඉ', description: 'Sinhala Wijesekara - b -> ඉ (I)' },
			{ input: 'B', output: 'ඊ', description: 'Sinhala Wijesekara - B -> ඊ (II)' },

			{ input: 'W', output: 'උ', description: 'Sinhala Wijesekara - W -> උ (U)' },
			{ input: 'WA', output: 'ඌ', description: 'Sinhala Wijesekara - WA -> ඌ (UU)' },

			{ input: 'R', output: 'ඍ', description: 'Sinhala Wijesekara - R -> ඍ (R)' },
			{ input: 'RD', output: 'ඎ', description: 'Sinhala Wijesekara - RD -> ඎ (RR)' },

			{ input: [ [ ',', true ] ], output: 'ඏ', description: 'Sinhala Wijesekara - Alt-, -> ඏ (L)' },
			{ input: [ [ ',', true ], [ 'A', false ] ], output: 'ඐ', description: 'Sinhala Wijesekara - Alt-,+A -> ඐ (LL)' },

			{ input: 't', output: 'එ', description: 'Sinhala Wijesekara - t -> එ (E)' },
			{ input: 'ta', output: 'ඒ', description: 'Sinhala Wijesekara - ta -> ඒ (EE)' },
			{ input: 'ft', output: 'ඓ', description: 'Sinhala Wijesekara - ft -> ඓ (AI)' },

			{ input: 'T', output: 'ඔ', description: 'Sinhala Wijesekara - T -> ඔ (O)' },
			{ input: 'Ta', output: 'ඕ', description: 'Sinhala Wijesekara - Ta -> ඕ (OO)' },
			{ input: 'TA', output: 'ඖ', description: 'Sinhala Wijesekara - TA -> ඖ (AU)' },

			// A pure consonant is entered with 2 keys: cons + al-lakuna.
			{ input: 'la', output: 'ක්', description: 'Sinhala Wijesekara - la -> ක් (K)' },

			// Vowel signs

			// After the consonant
			{ input: 'ld', output: 'කා', description: 'Sinhala Wijesekara - ld -> කා (KAA)' },
			{ input: '.e', output: 'ගැ', description: 'Sinhala Wijesekara - .e -> ගැ (GAE)' },
			{ input: 'gE', output: 'ටෑ', description: 'Sinhala Wijesekara - gE -> ටෑ (TTAAE)' },
			{ input: 'vs', output: 'ඩි', description: 'Sinhala Wijesekara - vs -> ඩි (DDI)' },
			{ input: ';S', output: 'තී', description: 'Sinhala Wijesekara - ;S -> තී (TII)' },
			{ input: 'oq', output: 'දු', description: 'Sinhala Wijesekara - oq -> දු (DU)' },
			{ input: 'mQ', output: 'පූ', description: 'Sinhala Wijesekara - mQ -> පූ (PUU)' },
			{ input: 'nD', output: 'බෘ', description: 'Sinhala Wijesekara - nD -> බෘ (BR)' },
			{ input: 'iDD', output: 'සෲ', description: 'Sinhala Wijesekara - iDD -> සෲ (SRR)' }
		]
	},
	{
		description: 'Xibe sjo test',
		inputmethod: 'sjo',
		tests: [
			{ input: 'WER', output: 'ᠸᠧᡰ', description: 'Xibe sjo 〈ᠴᠣᡝ〉' }
		]
	},
	{
		description: 'Slovak keyboard test',
		inputmethod: 'sk-kbd',
		tests: [
			{ input: '`', output: ';', description: 'Slovak ` -> ;' },
			{ input: '1', output: '+', description: 'Slovak 1 -> +' },
			{ input: '2', output: 'ľ', description: 'Slovak 2 -> ľ' },
			{ input: '3', output: 'š', description: 'Slovak 3 -> š' },
			{ input: '4', output: 'č', description: 'Slovak 4 -> č' },
			{ input: '5', output: 'ť', description: 'Slovak 5 -> ť' },
			{ input: '6', output: 'ž', description: 'Slovak 6 -> ž' },
			{ input: '7', output: 'ý', description: 'Slovak 7 -> ý' },
			{ input: '8', output: 'á', description: 'Slovak 8 -> á' },
			{ input: '9', output: 'í', description: 'Slovak 9 -> í' },
			{ input: '0', output: 'é', description: 'Slovak 0 -> é' },
			{ input: '-', output: '=', description: 'Slovak - -> =' },
			{ input: '=a', output: 'á', description: 'Slovak =a -> á' },
			{ input: '=E', output: 'É', description: 'Slovak =E -> É' },
			{ input: '=l', output: 'ĺ', description: 'Slovak =l -> ĺ' },
			{ input: '=L', output: 'Ĺ', description: 'Slovak =L -> Ĺ' },
			{ input: '=r', output: 'ŕ', description: 'Slovak =r -> ŕ' },
			{ input: '=R', output: 'Ŕ', description: 'Slovak =R -> Ŕ' },
			{
				input: [ [ '3', true ], [ 'O', false ] ],
				output: 'Ô',
				description: 'Slovak AltGr-3 + O -> Ô'
			},
			{
				input: [ [ '=', true ], [ 'A', false ] ],
				output: 'Ä',
				description: 'Slovak AltGr-= + A -> Ä'
			},

			{ input: '~', output: '°', description: 'Slovak ~ -> °' },
			{ input: '!', output: '1', description: 'Slovak ! -> 1' },
			{ input: '@', output: '2', description: 'Slovak @ -> 2' },
			{ input: '#', output: '3', description: 'Slovak # -> 3' },
			{ input: '$', output: '4', description: 'Slovak $ -> 4' },
			{ input: '%', output: '5', description: 'Slovak % -> 5' },
			{ input: '^', output: '6', description: 'Slovak ^ -> 6' },
			{ input: '&', output: '7', description: 'Slovak & -> 7' },
			{ input: '*', output: '8', description: 'Slovak * -> 8' },
			{ input: '(', output: '9', description: 'Slovak ( -> 9' },
			{ input: ')', output: '0', description: 'Slovak ) -> 0' },
			{ input: '_', output: '%', description: 'Slovak _ -> %' },
			{ input: '+c', output: 'č', description: 'Slovak +c -> č' },
			{ input: '+C', output: 'Č', description: 'Slovak +c -> Č' },
			{ input: '+d', output: 'ď', description: 'Slovak +d -> ď' },
			{ input: '+D', output: 'Ď', description: 'Slovak +d -> Ď' },
			{ input: '+l', output: 'ľ', description: 'Slovak +l -> ľ' },
			{ input: '+L', output: 'Ľ', description: 'Slovak +l -> Ľ' },

			// QWERTZ
			{ input: 'y', output: 'z', description: 'Slovak y -> z' },
			{ input: 'z', output: 'y', description: 'Slovak z -> y' },
			{ input: 'Y', output: 'Z', description: 'Slovak Y -> Y' },
			{ input: 'Z', output: 'Y', description: 'Slovak Z -> Z' },

			{ input: 'p', output: 'p', description: 'Slovak p -> p' },
			{ input: '[', output: 'ú', description: 'Slovak [ -> ú' },
			{ input: ']', output: 'ä', description: 'Slovak ] -> ä' },
			{ input: 'P', output: 'P', description: 'Slovak P -> P' },
			{ input: '{', output: '/', description: 'Slovak { -> /' },
			{ input: '}', output: '(', description: 'Slovak } -> (' },

			{ input: 'l', output: 'l', description: 'Slovak l -> l' },
			{ input: ';', output: 'ô', description: 'Slovak ; -> ô' },
			{ input: '\'', output: '§', description: 'Slovak \' -> §' },
			{ input: '\\', output: 'ň', description: 'Slovak \\ -> ň' },

			{ input: 'L', output: 'L', description: 'Slovak L -> L' },
			{ input: ':', output: '"', description: 'Slovak : -> "' },
			{ input: '"', output: '!', description: 'Slovak " -> !' },
			{ input: '|', output: ')', description: 'Slovak | -> )' },

			{ input: 'm', output: 'm', description: 'Slovak m -> m' },
			{ input: ',', output: ',', description: 'Slovak , -> ,' },
			{ input: '.', output: '.', description: 'Slovak . -> .' },
			{ input: '/', output: '-', description: 'Slovak / -> -' },
			{ input: 'M', output: 'M', description: 'Slovak M -> M' },
			{ input: '<', output: '?', description: 'Slovak < -> ?' },
			{ input: '>', output: ':', description: 'Slovak > -> :' },
			{ input: '?', output: '_', description: 'Slovak ? -> _' }
		]
	},
	{
		description: 'Sotho tilde test',
		inputmethod: 'st-tilde',
		tests: [
			{ input: 'loant~sa', output: 'loantša', description: 'Sotho tilde loantša' },
			{ input: 'ro~-na', output: 'rōna', description: 'Sotho tilde rōna' }
		]
	},
	{
		description: 'Sundanese keyboard test',
		inputmethod: 'su-keyboard',
		tests: [
			{ input: '~E', output: 'É', description: 'Sundanese uppercase É' },
			{ input: '~e', output: 'é', description: 'Sundanese lowercase é' }
		]
	},
	{
		description: 'Serbian keyboard test',
		inputmethod: 'sr-kbd',
		tests: [
			{ input: 'ABVGD}E|YIJKLQM', output: 'АБВГДЂЕЖЗИЈКЛЉМ', description: 'Serbian keyboard АБВГДЂЕЖЗИЈКЛЉМ' },
			{ input: 'abvgd]e\\yijklqm', output: 'абвгдђежзијклљм', description: 'Serbian keyboard абвгдђежзијклљм' },
			{ input: 'NWOPRST"UFHC:X{', output: 'НЊОПРСТЋУФХЦЧЏШ', description: 'Serbian keyboard НЊОПРСТЋУФХЦЧЏШ' },
			{ input: 'nwoprst\'ufhc;x[', output: 'нњопрстћуфхцчџш', description: 'Serbian keyboard нњопрстћуфхцчџш' },
			{ input: '-G-KZ', output: 'ЃЌЅ', description: 'Serbian keyboard ЃЌЅ' },
			{ input: '-g-kz', output: 'ѓќѕ', description: 'Serbian keyboard ѓќѕ' },
			{ input: '@^&*()-_=+<>/?', output: '"&/()=\'?+*;:-_', description: 'Serbian keyboard "&/()=\'?+*;:-_' }
		]
	},
	{
		description: 'Tamil 99 test',
		inputmethod: 'ta-99',
		tests: [
			// hfW should give non-conjunct form of ksha க்\u200cஷ (with ZWNJ)
			// T still gives the conjunct form க்ஷ
			{ input: 'I', output: ':', description: 'I in Tamil99 for :' },
			{ input: '"', output: '\'', description: '" in Tamil99 for \'' },
			{ input: 'N', output: 'ௐ', description: 'N in Tamil99 for ௐ' },
			{ input: 'lshfWslf', output: 'திக்\u200cஷித்', description: 'lshfWslf in Tamil99 for திக்\u200cஷித் non conjunct form' }, // (with ZWNJ)
			{ input: 'lsTslf', output: 'திக்ஷித்', description: 'lsTslf in Tamil99 for திக்ஷித் conjunct form' },
			{ input: 'hfWtkakf', output: 'க்\u200cஷேமம்', description: 'hfWtkakf in Tamil99 for க்\u200cஷேமம் hfW -> க்\u200cஷ non conjunct form' }, // (with ZWNJ)
			{ input: 'Ttkakf', output: 'க்ஷேமம்', description: 'Ttkakf in Tamil99 for க்ஷேமம் T -> க்ஷ conjunct form' }
		]
	},
	{
		description: 'Tamil InScript test',
		inputmethod: 'ta-inscript',
		tests: [
			{ input: 'ka', output: 'கோ', description: 'Tamil Inscript கோ' },
			{ input: 'lfkd)<fld', output: 'திக்\u200cஷித்', description: 'Tamil Inscript திக்\u200cஷித் non conjunct form with ZWNJ in between' }, // (with ZWNJ)
			{ input: 'lf&fld', output: 'திக்ஷித்', description: 'Tamil Inscript திக்ஷித் conjunct form' },
			{ input: ';sjVd', output: 'சேரன்', description: 'Tamil Inscript சேரன் Cheran' },
			{ input: ';aBVd', output: 'சோழன்', description: 'Tamil Inscript சோழன் Chozhan' },
			{ input: '/gbjepd', output: 'யுவராஜ்', description: 'Tamil Inscript யுவராஜ் Yuvaraj' },
			{ input: 'heCd\'f/jd', output: 'பாண்டியர்', description: 'Tamil Inscript பாண்டியர் Pandiyar' },
			{ input: 'Ecrjd', output: 'ஆமீர்', description: 'Tamil Inscript ஆமீர் Aamir' },
			{ input: 'Duj`Vf', output: 'அஹரொனி', description: 'Tamil Inscript அஹரொனி Aharoni' },
			{ input: 'md)jrkevdld', output: 'ஸ்\u200cரீகாந்த்', description: 'Tamil Inscript ஸ்\u200cரீகாந்த் with ZWNJ between ஸ் and ரீ Srikanth' }, // (with ZWNJ)
			{ input: 'mdjrkevdld', output: 'ஸ்ரீகாந்த்', description: 'Tamil Inscript ஸ்ரீகாந்த் with SHRI = SA+RII' },
			{ input: 'MdjrjcC', output: 'ஶ்ரீரமண', description: 'Tamil Inscript ஶ்ரீரமண Shriramana with SHRI = SHA+RII' },
			{ input: 'Dnanfle', output: 'அலோலிதா', description: 'Tamil Inscript அலோலிதா Alolitha' },
			{ input: '<jdce', output: 'ஷர்மா', description: 'Tamil Inscript ஷர்மா Sharma' },
			{ input: 'hfjbrVd', output: 'பிரவீன்', description: 'Tamil Inscript பிரவீன் Pravin' },
			{ input: ';vdla<d', output: 'சந்தோஷ்', description: 'Tamil Inscript சந்தோஷ் Santhosh' },
			{ input: 'vfkdnmd', output: 'நிக்லஸ்', description: 'Tamil Inscript நிக்லஸ் Niklas' },
			{ input: ';rhdjCd\'g', output: 'சீப்ரண்டு', description: 'Tamil Inscript சீப்ரண்டு Siebrand' },
			{ input: 'hzUdkNtjg', output: 'பெங்களூரு', description: 'Tamil Inscript பெங்களூரு Bengalooru' },
			{ input: ';qje\'d\'fj', output: 'சௌராட்டிர', description: 'Tamil Inscript சௌராட்டிர Saurattira' }
		]
	},
	{
		description: 'Tamil InScript 2 test',
		inputmethod: 'ta-inscript2',
		tests: [
			{ input: [ [ '.', true ] ], output: '॥', description: 'Tamil InScript 2 AltGr-. -> ॥' }
		]
	},
	{
		description: 'Tamil Transliteration test',
		inputmethod: 'ta-transliteration',
		tests: [
			// (ks|KS)h should give non-conjunct form of ksh க்\u200cஷ் (with ZWNJ)
			// (ks|KS)H should give the conjunct form க்ஷ் (with ZWNJ)
			{ input: 'thikshith', output: 'திக்\u200cஷித்', description: 'thikshith in Tamil transliteration for திக்\u200cஷித் non conjunct form' }, // (with ZWNJ)
			{ input: 'thikShith', output: 'திக்\u200cஷித்', description: 'thikShith in Tamil transliteration for திக்\u200cஷித் non conjunct form' }, // (with ZWNJ)
			{ input: 'thiksHith', output: 'திக்ஷித்', description: 'thiksHith in Tamil transliteration for திக்ஷித் conjunct form' },
			{ input: 'thiKSHith', output: 'திக்ஷித்', description: 'thiKSHith in Tamil transliteration for திக்ஷித் conjunct form' },
			{ input: 'Sri', output: 'ஸ்ரீ', description: 'Sri in Tamil transliteration for ஸ்ரீ Sri' },
			{ input: 'Sruthi', output: 'ஸ்ருதி', description: 'Sruthi in Tamil transliteration for ஸ்ருதி' },
			{ input: 'Sreeyaa', output: 'ஸ்ரேயா', description: 'Sreeyaa in Tamil transliteration for ஸ்ரேயா' },
			{ input: 'shaajakaan', output: 'ஷாஜகான்', description: 'shaajakaan in Tamil transliteration for ஷாஜகான் non conjunct form' },
			{ input: 'anbu', output: 'அன்பு', description: 'anbu in Tamil transliteration for அன்பு non conjunct form' },
			{ input: 'aarvam', output: 'ஆர்வம்', description: 'aarvam in Tamil transliteration for ஆர்வம் non conjunct form' },
			{ input: 'inRu', output: 'இன்று', description: 'inRu in Tamil transliteration for இன்று non conjunct form' },
			{ input: 'iizam', output: 'ஈழம்', description: 'iizam in Tamil transliteration for ஈழம் non conjunct form' },
			{ input: 'iilam', output: 'ஈலம்', description: 'iilam in Tamil transliteration for ஈலம் non conjunct form' },
			{ input: 'iiLam', output: 'ஈளம்', description: 'iiLam in Tamil transliteration for ஈளம் non conjunct form' },
			{ input: 'eNNam', output: 'எண்ணம்', description: 'eNNam in Tamil transliteration for எண்ணம் non conjunct form' },
			{ input: 'eeu', output: 'ஏஉ', description: 'eeu in Tamil transliteration for ஏஉ non conjunct form' },
			{ input: 'uuo', output: 'ஊஒ', description: 'uuo in Tamil transliteration for ஊஒ non conjunct form' },
			{ input: 'ooNam', output: 'ஓணம்', description: 'ooNam in Tamil transliteration for ஓணம் non conjunct form' },
			{ input: 'autatham', output: 'ஔடதம்', description: 'autatham in Tamil transliteration for ஔடதம் non conjunct form' },
			{ input: 'kangkaa', output: 'கங்கா', description: 'kangkaa in Tamil transliteration for கங்கா non conjunct form' },
			{ input: 'ngaasata', output: 'ஙாசட', description: 'ngaasata in Tamil transliteration for ஙாசட non conjunct form' },
			{ input: 'naNawa', output: 'னணந', description: 'naNawa in Tamil transliteration for னணந non conjunct form' },
			{ input: 'njaanam', output: 'ஞானம்', description: 'shajakaan in Tamil transliteration for ஞானம் non conjunct form' },
			{ input: 'thapamayaa', output: 'தபமயா', description: 'thapamayaa in Tamil transliteration for தபமயா non conjunct form' },
			{ input: 'jijigjaa', output: 'ஜிஜிக்ஜா', description: 'jijigjaa in Tamil transliteration for ஜிஜிக்ஜா non conjunct form' },
			{ input: 'vaNNam', output: 'வண்ணம்', description: 'vaNNam in Tamil transliteration for வண்ணம் non conjunct form' },
			{ input: 'haay', output: 'ஹாய்', description: 'haay in Tamil transliteration for ஹாய் non conjunct form' },
			{ input: 'aHku', output: 'அஃகு', description: 'aHku in Tamil transliteration for அஃகு non conjunct form' },
			{ input: 'jijoo', output: 'ஜிஜோ', description: 'jijoo in Tamil transliteration for ஜிஜோ non conjunct form' },
			{ input: 'yarazavalaLaRana', output: 'யரழவலளறன', description: 'yarazavalaLaRana in Tamil transliteration for யரழவலளறன non conjunct form' },
			{ input: 'juuhuu', output: 'ஜூஹூ', description: 'juuhuu in Tamil transliteration for ஜூஹூ non conjunct form' },
			{ input: 'Sashasa', output: 'ஸஷச', description: 'Sashasa in Tamil transliteration for ஸஷச non conjunct form' },
			{ input: 'Shuushaakikuu', output: 'ஷூஷாகிகூ', description: 'Shuushaakikuu in Tamil transliteration for ஷூஷாகிகூ non conjunct form' },
			{ input: 'kEkAkaa', output: 'கேகாகா', description: 'kEkAkaa in Tamil transliteration for கேகாகா non conjunct form' },
			{ input: 'zaazAAraRA', output: 'ழாழாஆரறா', description: 'zaazAAraRA in Tamil transliteration for ழாழாஆரறா non conjunct form' },
			{ input: 'naiwowO', output: 'னைநொநோ', description: 'naiwowO in Tamil transliteration for னைநொநோ non conjunct form' },
			{ input: 'rarAririireerE', output: 'ரராரிரீரேரே', description: 'rarAririireerE in Tamil transliteration for ரராரிரீரேரே non conjunct form' },
			{ input: 'lailOlauLau', output: 'லைலோலௌளௌ', description: 'lailOlauLau in Tamil transliteration for லைலோலௌளௌ non conjunct form' },
			{ input: 'kakaakAkikIkokOkai', output: 'ககாகாகிகீகொகோகை', description: 'kakaakAkikIkokOkai in Tamil transliteration for ககாகாகிகீகொகோகை non conjunct form' },
			{ input: 'kakaakAkikIkiikukUkuukekEkeekaikokookOkau', output: 'ககாகாகிகீகீகுகூகூகெகேகேகைகொகோகோகௌ', description: 'kakaakAkikIkiikukUkuukekEkeekaikokookOkau in Tamil transliteration for ககாகாகிகீகீகுகூகூகெகேகேகைகொகோகோகௌ non conjunct form' },
			{ input: 'ngangAngaangingiingIngungUnguungengEngeengaingongoongOngau', output: 'ஙஙாஙாஙிஙீஙீஙுஙூஙூஙெஙேஙேஙைஙொஙோஙோஙௌ', description: 'ngangAngaangingiingIngungUnguungengEngeengaingongoongOngu in Tamil transliteration for ஙஙாஙாஙிஙீஙீஙுஙூஙூஙெஙேஙேஙைஙொஙோஙோனௌ non conjunct form' },
			{ input: 'sasaasAsisIsiisusUsuusesEseesaisosoosOsau', output: 'சசாசாசிசீசீசுசூசூசெசேசேசைசொசோசோசௌ', description: 'sasaasAsisIsiisusUsuusesEseesaisosoosOsau in Tamil transliteration for சசாசாசிசீசீசுசூசூசெசேசேசைசொசோசோசௌ non conjunct form' },
			{ input: 'njanjaanjAnjinjiinjInjunjuunjUnjenjeenjEnjainjonjoonjOnjau', output: 'ஞஞாஞாஞிஞீஞீஞுஞூஞூஞெஞேஞேஞைஞொஞோஞோஞௌ', description: 'njanjaanjAnjinjiinjInjunjuunjUnjenjeenjEnjainjonjoonjOnjau in Tamil transliteration for ஞஞாஞாஞிஞீஞீஞுஞூஞூஞெஞேஞேஞைஞொஞோஞோஞௌ non conjunct form' },
			{ input: 'cacaacAcicIciicucUcuucecEceecaicocoocOcau', output: 'சசாசாசிசீசீசுசூசூசெசேசேசைசொசோசோசௌ', description: 'cacaacAcicIciicucUcuucecEceecaicocoocOcau in Tamil transliteration for சசாசாசிசீசீசுசூசூசெசேசேசைசொசோசோசௌ non conjunct form' },
			{ input: 'tataatAtitItiitutUtuutetEteetaitotootOtau', output: 'டடாடாடிடீடீடுடூடூடெடேடேடைடொடோடோடௌ', description: 'tataatAtitItiitutUtuutetEteetaitotootOtau in Tamil transliteration for டடாடாடிடீடீடுடூடூடெடேடேடைடொடோடோடௌ non conjunct form' },
			{ input: 'dadaadAdidIdiidudUduudedEdeedaidodoodOdau', output: 'டடாடாடிடீடீடுடூடூடெடேடேடைடொடோடோடௌ', description: 'dadaadAdidIdiidudUduudedEdeedaidodoodOdau in Tamil Transliteration for டடாடாடிடீடீடுடூடூடெடேடேடைடொடோடோடௌ non conjunct form' },
			{ input: 'NaNaaNANiNINiiNuNUNuuNeNENeeNaiNoNooNONau', output: 'ணணாணாணிணீணீணுணூணூணெணேணேணைணொணோணோணௌ', description: 'NaNaaNANiNINiiNuNUNuuNeNENeeNaiNoNooNONau in Tamil transliteration for ணணாணாணிணீணீணுணூணூணெணேணேணைணொணோணோனணௌ non conjunct form' },
			{ input: 'thathaathAthithIthiithuthUthuuthethEtheethaithothoothOthau', output: 'ததாதாதிதீதீதுதூதூதெதேதேதைதொதோதோதௌ', description: 'thathaathAthithIthiithuthUthuuthethEtheethaithothoothOthau in Tamil transliteration for ததாதாதிதீதீதுதூதூதெதேதேதைதொதோதோதௌ non conjunct form' },
			{ input: 'wawaawAwiwIwiiwuwUwuuwewEweewaiwowoowOwau', output: 'நநாநாநிநீநீநுநூநூநெநேநேநைநொநோநோநௌ', description: 'wawaawAwiwIwiiwuwUwuuwewEweewaiwowoowOwau in Tamil transliteration for நநாநிநீநீநுநூநூநெநேநேநைநொநோநோநௌ non conjunct form' },
			{ input: 'papaapApipIpiipupUpuupepEpeepaipopoopOpau', output: 'பபாபாபிபீபீபுபூபூபெபேபேபைபொபோபோபௌ', description: 'papaapApipIpiipupUpuupepEpeepaipopoopOpau in Tamil transliteration for பபாபாபிபீபீபுபூபூபெபேபேபைபொபோபோபௌ non conjunct form' },
			{ input: 'mamaamAmimImiimumUmuumemEmeemaimomoomOmau', output: 'மமாமாமிமீமீமுமூமூமெமேமேமைமொமோமோமௌ', description: 'mamaamAmimImiimumUmuumemEmeemaimomoomOmau in Tamil transliteration for மமாமாமிமீமீமுமூமூமெமேமேமைமொமோமோமௌ non conjunct form' },
			{ input: 'yayaayAyiyIyiiyuyUyuuyeyEyeeyaiyoyooyOyau', output: 'யயாயாயியீயீயுயூயூயெயேயேயையொயோயோயௌ', description: 'yayaayAyiyIyiiyuyUyuuyeyEyeeyaiyoyooyOyau in Tamil transliteration for யயாயாயியீயீயுயூயூயெயேயேயையொயோயோயௌ non conjunct form' },
			{ input: 'raraarArirIriirurUruurerEreerairoroorOrau', output: 'ரராராரிரீரீருரூரூரெரேரேரைரொரோரோரௌ', description: 'raraarArirIriirurUruurerEreerairoroorOrau in Tamil transliteration for ரராராரிரீரீருரூரூரெரேரேரைரொரோரோரௌ non conjunct form' },
			{ input: 'lalaalAlilIliilulUluulelEleelailoloolOlau', output: 'லலாலாலிலீலீலுலூலூலெலேலேலைலொலோலோலௌ', desription: 'lalaalAlilIliilulUluulelEleelailoloolOlau in Tamil transliteration for லலாலாலிலீலீலுலூலூலெலேலேலைலொலோலோலௌ non conjunct form' },
			{ input: 'vavaavAvivIviivuvUvuuvevEveevaivovoovOvau', output: 'வவாவாவிவீவீவுவூவூவெவேவேவைவொவோவோவௌ', description: 'vavaavAvivIviivuvUvuuvevEveevaivovoovOvau in Tamil transliteration for வவாவாவிவீவீவுவூவூவெவேவேவைவொவோவோவௌ non conjunct form' },
			{ input: 'zazaazAzizIziizuzUzuuzezEzeezaizozoozOzau', output: 'ழழாழாழிழீழீழுழூழூழெழேழேழைழொழோழோழௌ', description: 'zazaazAzizIziizuzUzuuzezEzeezaizozoozOzau in Tamil transliteration for ழழாழாழிழீழீழுழூழூழெழேழேழைழொழோழோழௌ non conjunct form' },
			{ input: 'zhazhaazhAzhizhIzhiizhuzhUzhuuzhezhEzheezhaizhozhoozhOzhau', output: 'ழழாழாழிழீழீழுழூழூழெழேழேழைழொழோழோழௌ', description: 'zhazhaazhAzhizhIzhiizhuzhUzhuuzhezhEzheezhaizhozhoozhOzhau in Tamil transliteration for ழழாழாழிழீழீழுழூழூழெழேழேழைழொழோழோழௌ non conjunct form' },
			{ input: 'LaLaaLALiLILiiLuLULuuLeLELeeLaiLoLooLOLau', output: 'ளளாளாளிளீளீளுளூளூளெளேளேளைளொளோளோளௌ', description: 'LaLaaLALiLILiiLuLULuuLeLELeeLaiLoLooLOLau in Tamil transliteration for ளளாளாளிளீளீளுளூளூளெளேளேளைளொளோளோளௌ non conjunct form' },
			{ input: 'RaRaaRARiRIRiiRuRURuuReREReeRaiRoRooRORau', output: 'றறாறாறிறீறீறுறூறூறெறேறேறைறொறோறோறௌ', description: 'RaRaaRARiRIRiiRuRURuuReREReeRaiRoRooRORau in Tamil transliteration for றறாறாறிறீறீறுறூறூறெறேறேறைறொறோறோறௌ non conjunct form' },
			{ input: 'nanaanAninIniinunUnuunenEneenainonoonOnau', output: 'னனானானினீனீனுனூனூனெனேனேனைனொனோனோனௌ', description: 'nanaanAninIniinunUnuunenEneenainonoonOnau in Tamil transliteration for னனானானினீனீனுனூனூனெனேனேனைனொனோனோனௌ non conjunct form' },
			{ input: 'SaSaaSASiSISiiSuSUSuuSeSESeeSaiSoSooSOSau', output: 'ஸஸாஸாஸிஸீஸீஸுஸூஸூஸெஸேஸேஸைஸொஸோஸோஸௌ', description: 'SaSaaSASiSISiiSuSUSuuSeSESeeSaiSoSooSOSau in Tamil transliteration for ஸஸாஸாஸிஸீஸீஸுஸூஸூஸெஸேஸேஸைஸொஸோஸோஸௌ non conjunct form' },
			{ input: 'shashaashAshishIshiishushUshuusheshEsheeshaishoshooshOshau', output: 'ஷஷாஷாஷிஷீஷீஷுஷூஷூஷெஷேஷேஷைஷொஷோஷோஷௌ', description: 'shashaashAshishIshiishushUshuusheshEsheeshaishoshooshOshau in Tamil transliteration for ஷஷாஷாஷிஷீஷீஷுஷூஷூஷெஷேஷேஷைஷொஷோஷோஷௌ non conjunct form' },
			{ input: 'jajaajAjijIjiijujUjuujejEjeejaijojoojOjau', output: 'ஜஜாஜாஜிஜீஜீஜுஜூஜூஜெஜேஜேஜைஜொஜோஜோஜௌ', description: 'jajaajAjijIjiijujUjuujejEjeejaijojoojOjau in Tamil transliteration for ஜஜாஜாஜிஜீஜீஜுஜூஜூஜெஜேஜேஜைஜொஜோஜோஜௌ non conjunct form' },
			{ input: 'hahaahAhihIhiihuhUhuuhehEheehaihohoohOhau', output: 'ஹஹாஹாஹிஹீஹீஹுஹூஹூஹெஹேஹேஹைஹொஹோஹோஹௌ', description: 'hahaahAhihIhiihuhUhuuhehEheehaihohoohOhau in Tamil transliteration for ஹஹாஹாஹிஹீஹீஹுஹூஹூஹெஹேஹேஹைஹொஹோஹோஹௌ non conjunct form' }
		]
	},
	{
		description: 'Telugu Apple test',
		inputmethod: 'te-apple',
		tests: [
			{ input: 'k', output: 'ర', description: 'Telugu ra' },
			{ input: 's', output: 'త', description: 'Telugu tha' },
			{ input: 'zu', output: 'టె', description: 'Telugu te' },
			{ input: 'jW', output: 'కృ', description: 'Telugu kru' },
			{ input: ';i', output: 'పు', description: 'Telugu pu' },
			{ input: 'd$', output: 'ద్పు', description: 'Telugu dpu' },
			{ input: 'Z', output: 'ఠ', description: 'Telugu Ttha' },
			{ input: 'M', output: 'ఛ', description: 'Telugu Ccha' },
			{ input: 'l]', output: 'నౌ', description: 'Telugu now' },
			{ input: 'kiSZWlwjbdys];ze', output: 'రుథఠృనీకమదోతౌపటా', description: 'some paragraph' }
		]
	},
	{
		description: 'Telugu InScript test',
		inputmethod: 'te-inscript',
		tests: [
			{ input: 'k-', output: 'కః', description: 'Telugu k- (visarga)' },
			{ input: '}', output: 'ఞ', description: 'Telugu } (nya)' },
			{ input: 'J', output: 'ఱ', description: 'Telugu J (rra)' },
			{ input: '/', output: 'య', description: 'Telugu / (ya)' },
			{ input: 'pz', output: 'జె', description: 'Telugu pz (je)' },
			{ input: 'p`', output: 'జొ', description: 'Telugu p` (jo)' },
			{ input: 'kX', output: 'కఁ', description: 'Telugu kX (ka@m, candrabindu)' },
			{ input: 'hx', output: 'పం', description: 'Telugu hx (paM, anusvara)' },
			{ input: '>', output: '।', description: 'Telugu > (danda)' },
			{ input: [ [ ';', true ] ], output: 'ౘ', description: 'Telugu Alt ; (tsa)' },
			{ input: [ [ 'p', true ] ], output: 'ౙ', description: 'Telugu Alt p (dza)' },
			{ input: [ [ '4', true ] ], output: '₹', description: 'Alt 4; (rupee sign)' },
			{ input: [ [ '=', true ] ], output: 'ౄ', description: 'Telugu Alt = (RRuu, vowel)' },
			{ input: [ [ '+', true ] ], output: 'ౠ', description: 'Telugu Alt + (RRuu)' }
		]
	},
	{
		description: 'Telugu Modular test',
		inputmethod: 'te-modular',
		tests: [
			{ input: 'H', output: 'ధ', description: 'Telugu dha' },
			{ input: 'e', output: 'క', description: 'Telugu ka' },
			{ input: 'S', output: 'ఇ', description: 'Telugu yi' },
			{ input: 'i', output: 'ల', description: 'Telugu la' },
			{ input: 'fa', output: 'యా', description: 'Telugu yaa' },
			{ input: 'Jd', output: 'భ్', description: 'Telugu Bh' },
			{ input: 'jzgdf', output: 'నృత్య', description: 'word Nruthyam' }
		]
	},
	{
		description: 'Telugu Transliteration test',
		inputmethod: 'te-transliteration',
		tests: [
			{ input: 'c', output: 'చ్', description: 'Telugu c' },
			{ input: 'ch', output: 'చ్', description: 'Telugu ch' },
			{ input: 'j~nu', output: 'జ్ఞు', description: 'Telugu j~nu' },
			{ input: '~naa', output: 'ఞా', description: 'Telugu ~naa' }
		]
	},
	{
		description: 'Thai Kedmanee test',
		inputmethod: 'th-kedmanee',
		tests: [
			{ input: 'QWERTYUIOP{}|', output: '๐"ฎฑธํ๊ณฯญฐ,ฅ', description: 'Thai Kedmanee QWERTYUIOP{}|' },
			{ input: 'ASDFGH', output: 'ฤฆฏโฌ็', description: 'Thai Kedmanee ASDFGH' },
			{ input: 'aJko', output: 'ฟ๋าน', description: 'Thai Kedmanee aJko' },
			{ input: 'KL:"', output: 'ษศซ.', description: 'Thai Kedmanee KL:"' },
			{ input: 'ZXCV', output: '()ฉฮ', description: 'Thai Kedmanee ZXCV' },
			{ input: 'SBv;k,bDb]', output: 'ฆฺอวามิฏิล', description: 'Thai Kedmanee SBv;k,bDb]' },
			{ input: 'vy0CN', output: 'อัจฉ์', description: 'Thai Kedmanee vy0CN' },
			{ input: 'M<>?', output: '?ฒฬฦ', description: 'Thai Kedmanee M<>?' },
			{ input: 'qw', output: 'ๆไ', description: 'Thai Kedmanee qw' },
			{ input: 'z^hreoydmuj', output: 'ผู้พำนักที่', description: 'Thai Kedmanee z^hreoydmuj' },
			{ input: 'tiop[]\\', output: 'ะรนยบลฃ', description: 'Thai Kedmanee tiop[]\\' },
			{ input: 'asdfgh', output: 'ฟหกดเ้', description: 'Thai Kedmanee asdfgh' },
			{ input: 'l;\'', output: 'สวง', description: 'Thai Kedmanee l;\'' },
			{ input: 'zxcvb', output: 'ผปแอิ', description: 'Thai Kedmanee zxcvb' },
			{ input: 'gznvd', output: 'เผือก', description: 'Thai Kedmanee gznvd' },
			{ input: 'm,./', output: 'ทมใฝ', description: 'Thai Kedmanee m,./' },
			{ input: '`12345', output: '_ๅ/-ภถ', description: 'Thai Kedmanee `12345' },
			{ input: 'a6', output: 'ฟุ', description: 'Thai Kedmanee a6' },
			{ input: 'a7o', output: 'ฟึน', description: 'Thai Kedmanee a7o' },
			{ input: '890-=', output: 'คตจขช', description: 'Thai Kedmanee 890-=' },
			{ input: '~!@#$%', output: '%+๑๒๓๔', description: 'Thai Kedmanee ~!@#$%' },
			{ input: '&*()_+', output: '฿๕๖๗๘๙', description: 'Thai Kedmanee &*()_+' }
		]
	},
	{
		description: 'Tigrinya GeezIM test',
		inputmethod: 'ti-geezim',
		tests: [
			{ input: 'hie', output: 'ሄ', description: 'Tigrinya hie -> ሄ' },
			{ input: 'lie', output: 'ሌ', description: 'Tigrinya lie -> ሌ' },
			{ input: 'Hie', output: 'ሔ', description: 'Tigrinya Hie -> ሔ' },
			{ input: 'mie', output: 'ሜ', description: 'Tigrinya Hie -> ሜ' },
			{ input: 'arAaya', output: 'ኣርኣያ', description: 'Tigrinya arAaya -> ኣርኣያ' },
			{ input: 'gua', output: 'ጓ', description: 'Tigrinya gua -> ጓ' },
			{ input: 'gue', output: 'ጐ', description: 'Tigrinya gue -> ጐ' },
			{ input: 'gui', output: 'ጒ', description: 'Tigrinya gui -> ጒ' },
			{ input: 'guie', output: 'ጔ', description: 'Tigrinya guie -> ጔ' },
			{ input: 'gW', output: 'ጕ', description: 'Tigrinya gW -> ጕ' },
			{ input: 'Gui', output: 'ⶔ', description: 'Tigrinya Gui -> ⶔ' },
			{ input: 'Guie', output: 'ⶕ', description: 'Tigrinya Guie -> ⶕ' },
			{ input: 'GW', output: 'ⶖ', description: 'Tigrinya GW -> ⶖ' },
			{ input: '.', output: '።', description: 'Tigrinya . -> ።' },
			{ input: '..', output: '.', description: 'Tigrinya .. -> .' },
			{ input: '.-', output: '፨', description: 'Tigrinya .- -> ፨' },
			{ input: ';;', output: '።', description: 'Tigrinya ;; -> ።' }
		]
	},
	{
		description: 'Tigre GeezIM test',
		inputmethod: 'tig-geezim',
		tests: [
			{ input: 'hie', output: 'ሄ', description: 'Tigre hie -> ሄ' },
			{ input: 'lie', output: 'ሌ', description: 'Tigre lie -> ሌ' },
			{ input: 'Hie', output: 'ሔ', description: 'Tigre Hie -> ሔ' },
			{ input: 'mie', output: 'ሜ', description: 'Tigre Hie -> ሜ' },
			{ input: 'arAaya', output: 'ኣርኣያ', description: 'Tigre arAaya -> ኣርኣያ' },
			{ input: 'gua', output: 'ጓ', description: 'Tigre gua -> ጓ' },
			{ input: 'gue', output: 'ጐ', description: 'Tigre gue -> ጐ' },
			{ input: 'gui', output: 'ጒ', description: 'Tigre gui -> ጒ' },
			{ input: 'guie', output: 'ጔ', description: 'Tigre guie -> ጔ' },
			{ input: 'gW', output: 'ጕ', description: 'Tigre gW -> ጕ' },
			{ input: 'Gui', output: 'ⶔ', description: 'Tigre Gui -> ⶔ' },
			{ input: 'Guie', output: 'ⶕ', description: 'Tigre Guie -> ⶕ' },
			{ input: 'GW', output: 'ⶖ', description: 'Tigre GW -> ⶖ' },
			{ input: '.', output: '።', description: 'Tigre . -> ።' },
			{ input: '..', output: '.', description: 'Tigre .. -> .' },
			{ input: '.-', output: '፨', description: 'Tigre .- -> ፨' },
			{ input: ';;', output: '።', description: 'Tigre ;; -> ።' }
		]
	},
	{
		description: 'Setswana tilde test',
		inputmethod: 'tn-tilde',
		tests: [
			{ input: '~S', output: 'Š', description: 'Setswana tilde ~S' },
			{ input: '~s', output: 'š', description: 'Setswana tilde ~s' },
			{ input: '~E', output: 'Ê', description: 'Setswana tilde ~E' },
			{ input: '~e', output: 'ê', description: 'Setswana tilde ~e' },
			{ input: '~O', output: 'Ô', description: 'Setswana tilde ~O' },
			{ input: '~o', output: 'ô', description: 'Setswana tilde ~o' }
		]
	},
	{
		description: 'ChiTumbuka tilde test',
		inputmethod: 'tum-tilde',
		tests: [
			{ input: 'Mala~wi', output: 'Malaŵi', description: 'ChiTumbuka tilde test Malaŵi' },
			{ input: '~Wanthu', output: 'Ŵanthu', description: 'ChiTumbuka tilde test Ŵanthu' },
			{ input: 'kulimira~^so', output: 'kulimirâso', description: 'ChiTumbuka tilde test kulimirâso' }
		]
	},
	{
		description: 'Udmurt ALT test',
		inputmethod: 'udm-alt',
		tests: [
			{ input: 'ц', output: 'ӵ', description: 'Udmurt letters, ц > ӵ' },
			{ input: 'Ц', output: 'Ӵ', description: 'Udmurt letters, Ц > Ӵ' },
			{ input: 'щ', output: 'ӥ', description: 'Udmurt letters, щ > ӥ' },
			{ input: 'Щ', output: 'Ӥ', description: 'Udmurt letters, Щ > Ӥ' },
			{ input: 'х', output: 'ӟ', description: 'Udmurt letters, х > ӟ' },
			{ input: 'Х', output: 'Ӟ', description: 'Udmurt letters, Х > Ӟ' },
			{ input: 'ф', output: 'ӝ', description: 'Udmurt letters, ф > ӝ' },
			{ input: 'Ф', output: 'Ӝ', description: 'Udmurt letters, Ф > Ӝ' },
			{ input: [ [ 'ц', true ] ], output: 'ц', description: 'Udmurt letters, Alt-ц' },
			{ input: [ [ 'Ц', true ] ], output: 'Ц', description: 'Udmurt letters, Alt-Ц' },
			{ input: [ [ 'щ', true ] ], output: 'щ', description: 'Udmurt letters, Alt-щ' },
			{ input: [ [ 'Щ', true ] ], output: 'Щ', description: 'Udmurt letters, Alt-Щ' },
			{ input: [ [ 'х', true ] ], output: 'х', description: 'Udmurt letters, Alt-х' },
			{ input: [ [ 'Х', true ] ], output: 'Х', description: 'Udmurt letters, Alt-Х' },
			{ input: [ [ 'ф', true ] ], output: 'ф', description: 'Udmurt letters, Alt-ф' },
			{ input: [ [ 'Ф', true ] ], output: 'Ф', description: 'Udmurt letters, Alt-Ф' },
			{ input: 'ё', output: 'ё', description: 'Udmurt letters, ё does not change' },
			{ input: 'Ё', output: 'Ё', description: 'Udmurt letters, Ё does not change' },
			{ input: [ [ 'ё', true ] ], output: 'ӧ', description: 'Udmurt letters, Alt-ё -> ӧ' },
			{ input: [ [ 'Ё', true ] ], output: 'Ӧ', description: 'Udmurt letters, Alt-Ё -> Ӧ' }
		]
	},
	{
		description: 'Ukrainian kbd keyboard test',
		inputmethod: 'uk-kbd',
		tests: [
			{ input: '~!@#$%^&*()_+', output: 'Ґ!"№;%:?*()_+', description: 'Ukrainian kbd - numbers row shifted' },
			{ input: '`1234567890-=', output: 'ґ1234567890-=', description: 'Ukrainian kbd - numbers row not shifted' },
			{ input: 'QWERTYUIOP{}\\', output: 'ЙЦУКЕНГШЩЗХЇ\\', description: 'Ukrainian kbd - ` and QWERTY row shifted' },
			{ input: 'qwertyuiop[]\\', output: 'йцукенгшщзхї\\', description: 'Ukrainian kbd - ` and qwerty row not shifted' },
			{ input: 'ASDFGHJKL:"', output: 'ФІВАПРОЛДЖЄ', description: 'Ukrainian kbd - ASDF row shifted' },
			{ input: 'asdfghjkl;\'', output: 'фівапролджє', description: 'Ukrainian kbd - asdf row not shifted' },
			{ input: 'ZXCVBNM<>?', output: 'ЯЧСМИТЬБЮ,', description: 'Ukrainian kbd - ZXCV row shifted' },
			{ input: 'zxcvbnm,./', output: 'ячсмитьбю.', description: 'Ukrainian kbd - zxcv row not shifted' }
		]
	},
	{
		description: 'Urdu Phonetics',
		inputmethod: 'ur-phonetic',
		tests: [
			{ input: '!', output: '!', description: 'Urdu phonetic !' },
			{ input: '@', output: '@', description: 'Urdu phonetic @' },
			{ input: '#', output: '/', description: 'Urdu phonetic # -> /' },
			{ input: '$', output: 'ئ', description: 'Urdu phonetic yeh hamza' },
			{ input: '()', output: ')(', description: 'Urdu phonetic parentheses' },
			{ input: 's_', output: 'سّ', description: 'Urdu phonetic s+shadda' },
			{ input: '-', output: 'أ', description: 'Urdu phonetic alef hamza' },
			{ input: '+', output: 'آ', description: 'Urdu phonetic alef madda' },
			{ input: '=', output: 'ؤ', description: 'Urdu phonetic waw hamza' },
			{ input: 'dQ', output: 'دْ', description: 'Urdu phonetic d+sukun' },
			{ input: 'qwerty', output: 'قوعرتے', description: 'Urdu phonetic qwerty' },
			{ input: 'u', output: 'ء', description: 'Urdu phonetic u (hamza)' },
			{ input: 'i', output: 'ی', description: 'Urdu phonetic i (yeh)' },
			{ input: 'op', output: 'ہپ', description: 'Urdu phonetic op' },
			{ input: '[]', output: '][', description: 'Urdu phonetic square brackets' },
			{ input: 'W', output: 'ﷺ', description: 'Urdu phonetic sallallahou' },
			{ input: 'E', output: '¥', description: 'Urdu phonetic E -> ¥' },
			{ input: 'RT', output: 'ڑٹ', description: 'Urdu phonetic RT' },
			{ input: 'Y', output: '؁', description: 'Urdu phonetic Y -> sana' },
			{ input: 'U', output: '،', description: 'Urdu phonetic U -> comma' },
			{ input: 'fI', output: 'فٰ', description: 'Urdu phonetic I - superscript alef' },
			{ input: 'O', output: 'ۃ', description: 'Urdu phonetic O' },
			{ input: 'P', output: 'ُ', description: 'Urdu phonetic P -> damma' },
			{ input: 'f{', output: 'فٰ', description: 'Urdu phonetic { -> superscript alef' },
			{ input: '}', output: 'ٰٰ', description: 'Urdu phonetic } -> double superscript alef' },

			{ input: 'aA', output: 'آ', description: 'Urdu phonetic aA' },
			{ input: 'sdfghjkl', output: 'سدفگھجکل', description: 'Urdu phonetic sdfghjkl' },
			{ input: ':', output: ':', description: 'Urdu phonetic :' },
			{ input: ';', output: '؛', description: 'Urdu phonetic ;' },
			{ input: '"', output: '؎', description: 'Urdu phonetic " -> verse sign' },
			{ input: 'SDFGHJK', output: 'صڈغحضخ', description: 'Urdu phonetic ' },
			{ input: 'fL', output: 'فؓ', description: 'Urdu phonetic fL -> f+radi' },
			{ input: 'f\'', output: 'فٰ', description: 'Urdu phonetic \' -> superscript alef' },
			{ input: 'f|', output: 'فؔ', description: 'Urdu phonetic f| -> f+takhallus' },
			{ input: 'd~', output: 'دً', description: 'Urdu phonetic ~ -> fathatan' },
			{ input: 't`', output: 'تٍ', description: 'Urdu phonetic ~ -> kasratan' },

			{ input: 'zxcvbnm', output: 'زشچطبنم', description: 'Urdu phonetic zxcvbnm' },
			{ input: 'ZXCVNM', output: 'ذژثظں', description: 'Urdu phonetic ZXCVNM' },
			{ input: 'rB', output: 'رؒ', description: 'Urdu phonetic rB -> r+rakhmatullah' },
			{ input: 'k<', output: 'کِ', description: 'Urdu phonetic k< -> ki' },
			{ input: ',', output: '،', description: 'Urdu phonetic comma' },
			{ input: 'p>', output: 'پَ', description: 'Urdu phonetic p> -> pa' },
			{ input: '.', output: '۔', description: 'Urdu phonetic .' },
			{ input: '?', output: '؟', description: 'Urdu phonetic ؟' },
			{ input: 'q^', output: 'قۖ', description: 'Urdu phonetic q^ -> q+sla' },
			{ input: 'a&', output: 'أ', description: 'Urdu phonetic a& -> alef hamza' },
			{ input: 'd*', output: 'دٌ', description: 'Urdu phonetic dun' },

			{ input: '1', output: '1', description: 'Urdu phonetic Numeral 1 -> 1' },
			{ input: '2', output: '2', description: 'Urdu phonetic Numeral 2 -> 2' },
			{ input: '3', output: '3', description: 'Urdu phonetic Numeral 3 -> 3' },
			{ input: '4', output: '4', description: 'Urdu phonetic Numeral 4 -> 4' },
			{ input: '5', output: '5', description: 'Urdu phonetic Numeral 5 -> 5' },
			{ input: '6', output: '6', description: 'Urdu phonetic Numeral 6 -> 6' },
			{ input: '7', output: '7', description: 'Urdu phonetic Numeral 7 -> 7' },
			{ input: '8', output: '8', description: 'Urdu phonetic Numeral 8 -> 8' },
			{ input: '9', output: '9', description: 'Urdu phonetic Numeral 9 -> 9' },
			{ input: '0', output: '0', description: 'Urdu phonetic Numeral 0 -> 0' }
		]
	},
	{
		description: 'Urdu transliteration test',
		inputmethod: 'ur-transliteration',
		tests: [
			{ input: 'qwertyuiop', output: 'طصھدٹپتبجح', description: 'Urdu transliteration qwertyuiop' },
			{ input: 'QWERT', output: 'ظضذڈث', description: 'Urdu transliteration QWERT' },
			{ input: 'TY', output: 'ثّ­', description: 'Urdu transliteration fatha' },
			{ input: 'TU', output: 'ثۃ', description: 'Urdu transliteration marbuta' },
			{ input: 'I', output: 'ـ', description: 'Urdu transliteration tatweel' },
			{ input: 'OP', output: 'چخ', description: 'Urdu transliteration OP' },
			{ input: 'asdfghjkl', output: 'مورنلہاکی', description: 'Urdu transliteration asdfghjkl' },
			{ input: 'ASDF', output: 'ژزڑں', description: 'Urdu transliteration ASDF' },
			{ input: 'G', output: 'ۂ', description: 'Urdu transliteration G' },
			{ input: 'HKL', output: 'ءگي', description: 'Urdu transliteration HKL' },
			{ input: ';:\'"', output: '؛:\'"', description: 'Urdu transliteration ;:\'"' },
			{ input: 'xc', output: 'فے', description: 'Urdu transliteration xc' },
			{ input: 'vbnm,.', output: 'سشغع,.', description: 'Urdu transliteration vbnm,.' },
			{ input: 'C', output: 'ۓ', description: 'Urdu transliteration C' },
			{ input: 'N', output: 'ئ', description: 'Urdu transliteration N' },
			{ input: '?', output: '؟', description: 'Urdu transliteration ?' }
		]
	},
	{
		description: 'Uzbek kbd keyboard test',
		inputmethod: 'uz-kbd',
		tests: [
			{ input: '~!@#$%^&*()_+', output: 'Ё!"№;%:?*()ҒҲ', description: 'Uzbek cyrillic kbd - numbers row shifted' },
			{ input: '`1234567890-=', output: 'ё1234567890ғҳ', description: 'Uzbek cyrillic kbd - numbers row not shifted' },
			{ input: 'QWERTYUIOP{}\\', output: 'ЙЦУКЕНГШЎЗХЪ\\', description: 'Uzbek cyrillic kbd - ` and QWERTY row shifted' },
			{ input: 'qwertyuiop[]\\', output: 'йцукенгшўзхъ\\', description: 'Uzbek cyrillic kbd - ` and qwerty row not shifted' },
			{ input: 'ASDFGHJKL:"', output: 'ФҚВАПРОЛДЖЭ', description: 'Uzbek cyrillic kbd - ASDF row shifted' },
			{ input: 'asdfghjkl;\'', output: 'фқвапролджэ', description: 'Uzbek cyrillic kbd - asdf row not shifted' },
			{ input: 'ZXCVBNM<>?', output: 'ЯЧСМИТЬБЮ,', description: 'Uzbek cyrillic kbd - ZXCV row shifted' },
			{ input: 'zxcvbnm,./', output: 'ячсмитьбю.', description: 'Uzbek cyrillic kbd - zxcv row not shifted' }
		]
	},

	{
		description: 'Vai transliteration test',
		inputmethod: 'vai-transliteration',
		tests: [
			{ input: 'e', output: 'ꔀ', description: 'Vai transliteration - e' },
			{ input: 'e~', output: 'ꔁ', description: 'Vai transliteration - e~' },
			{ input: 'he', output: 'ꔂ', description: 'Vai transliteration - he' },
			{ input: 'we', output: 'ꔃ', description: 'Vai transliteration - we' },
			{ input: 'we~', output: 'ꔄ', description: 'Vai transliteration - we~' },
			{ input: 'pe', output: 'ꔅ', description: 'Vai transliteration - pe' },
			{ input: 'bhe', output: 'ꔆ', description: 'Vai transliteration - bhe' },
			{ input: 'be', output: 'ꔇ', description: 'Vai transliteration - be' },
			{ input: 'mbe', output: 'ꔈ', description: 'Vai transliteration - mbe' },
			{ input: 'kpe', output: 'ꔉ', description: 'Vai transliteration - kpe' },
			{ input: 'mgbe', output: 'ꔊ', description: 'Vai transliteration - mgbe' },
			{ input: 'gbe', output: 'ꔋ', description: 'Vai transliteration - gbe' },
			{ input: 'fe', output: 'ꔌ', description: 'Vai transliteration - fe' },
			{ input: 've', output: 'ꔍ', description: 'Vai transliteration - ve' },
			{ input: 'te', output: 'ꔎ', description: 'Vai transliteration - te' },
			{ input: 'the', output: 'ꔏ', description: 'Vai transliteration - the' },
			{ input: 'de', output: 'ꔐ', description: 'Vai transliteration - de' },
			{ input: 'dhe', output: 'ꔑ', description: 'Vai transliteration - dhe' },
			{ input: 'le', output: 'ꔒ', description: 'Vai transliteration - le' },
			{ input: 're', output: 'ꔓ', description: 'Vai transliteration - re' },
			{ input: 'dle', output: 'ꔔ', description: 'Vai transliteration - dle' },
			{ input: 'De', output: 'ꔔ', description: 'Vai transliteration - De' },
			{ input: 'nDe', output: 'ꔕ', description: 'Vai transliteration - nDe' },
			{ input: 'nde', output: 'ꔕ', description: 'Vai transliteration - nde' },
			{ input: 'se', output: 'ꔖ', description: 'Vai transliteration - se' },
			{ input: 'she', output: 'ꔗ', description: 'Vai transliteration - she' },
			{ input: 'ze', output: 'ꔘ', description: 'Vai transliteration - ze' },
			{ input: 'zhe', output: 'ꔙ', description: 'Vai transliteration - zhe' },
			{ input: 'ce', output: 'ꔚ', description: 'Vai transliteration - ce' },
			{ input: 'je', output: 'ꔛ', description: 'Vai transliteration - je' },
			{ input: 'nje', output: 'ꔜ', description: 'Vai transliteration - nje' },
			{ input: 'ye', output: 'ꔝ', description: 'Vai transliteration - ye' },
			{ input: 'ke', output: 'ꔞ', description: 'Vai transliteration - ke' },
			{ input: 'nge', output: 'ꔟ', description: 'Vai transliteration - nge' },
			{ input: 'ge', output: 'ꔠ', description: 'Vai transliteration - ge' },
			{ input: 'me', output: 'ꔡ', description: 'Vai transliteration - me' },
			{ input: 'ne', output: 'ꔢ', description: 'Vai transliteration - ne' },
			{ input: 'nye', output: 'ꔣ', description: 'Vai transliteration - nye' },

			{ input: 'i', output: 'ꔤ', description: 'Vai transliteration - i' },
			{ input: 'i~', output: 'ꔥ', description: 'Vai transliteration - i~' },
			{ input: 'hi', output: 'ꔦ', description: 'Vai transliteration - hi' },
			{ input: 'hi~', output: 'ꔧ', description: 'Vai transliteration - hi~' },
			{ input: 'wi', output: 'ꔨ', description: 'Vai transliteration - wi' },
			{ input: 'wi~', output: 'ꔩ', description: 'Vai transliteration - wi~' },
			{ input: 'pi', output: 'ꔪ', description: 'Vai transliteration - pi' },
			{ input: 'bhi', output: 'ꔫ', description: 'Vai transliteration - bhi' },
			{ input: 'bi', output: 'ꔬ', description: 'Vai transliteration - bi' },
			{ input: 'mbi', output: 'ꔭ', description: 'Vai transliteration - mbi' },
			{ input: 'kpi', output: 'ꔮ', description: 'Vai transliteration - kpi' },
			{ input: 'mgbi', output: 'ꔯ', description: 'Vai transliteration - mgbi' },
			{ input: 'gbi', output: 'ꔰ', description: 'Vai transliteration - gbi' },
			{ input: 'fi', output: 'ꔱ', description: 'Vai transliteration - fi' },
			{ input: 'vi', output: 'ꔲ', description: 'Vai transliteration - vi' },
			{ input: 'ti', output: 'ꔳ', description: 'Vai transliteration - ti' },
			{ input: 'thi', output: 'ꔴ', description: 'Vai transliteration - thi' },
			{ input: 'di', output: 'ꔵ', description: 'Vai transliteration - di' },
			{ input: 'dhi', output: 'ꔶ', description: 'Vai transliteration - dhi' },
			{ input: 'li', output: 'ꔷ', description: 'Vai transliteration - li' },
			{ input: 'ri', output: 'ꔸ', description: 'Vai transliteration - ri' },
			{ input: 'dli', output: 'ꔹ', description: 'Vai transliteration - dli' },
			{ input: 'Di', output: 'ꔹ', description: 'Vai transliteration - Di' },
			{ input: 'nDi', output: 'ꔺ', description: 'Vai transliteration - nDi' },
			{ input: 'ndi', output: 'ꔺ', description: 'Vai transliteration - ndi' },
			{ input: 'si', output: 'ꔻ', description: 'Vai transliteration - si' },
			{ input: 'shi', output: 'ꔼ', description: 'Vai transliteration - shi' },
			{ input: 'zi', output: 'ꔽ', description: 'Vai transliteration - zi' },
			{ input: 'zhi', output: 'ꔾ', description: 'Vai transliteration - zhi' },
			{ input: 'ci', output: 'ꔿ', description: 'Vai transliteration - ci' },
			{ input: 'ji', output: 'ꕀ', description: 'Vai transliteration - ji' },
			{ input: 'nji', output: 'ꕁ', description: 'Vai transliteration - nji' },
			{ input: 'yi', output: 'ꕂ', description: 'Vai transliteration - yi' },
			{ input: 'ki', output: 'ꕃ', description: 'Vai transliteration - ki' },
			{ input: 'ngi', output: 'ꕄ', description: 'Vai transliteration - ngi' },
			{ input: 'gi', output: 'ꕅ', description: 'Vai transliteration - gi' },
			{ input: 'mi', output: 'ꕆ', description: 'Vai transliteration - mi' },
			{ input: 'ni', output: 'ꕇ', description: 'Vai transliteration - ni' },
			{ input: 'nyi', output: 'ꕈ', description: 'Vai transliteration - nyi' },

			{ input: 'a', output: 'ꕉ', description: 'Vai transliteration - a' },
			{ input: 'a~', output: 'ꕊ', description: 'Vai transliteration - a~' },
			{ input: 'nga~', output: 'ꕋ', description: 'Vai transliteration - nga~' },
			{ input: 'ha', output: 'ꕌ', description: 'Vai transliteration - ha' },
			{ input: 'ha~', output: 'ꕍ', description: 'Vai transliteration - ha~' },
			{ input: 'wa', output: 'ꕎ', description: 'Vai transliteration - wa' },
			{ input: 'wa~', output: 'ꕏ', description: 'Vai transliteration - wa~' },
			{ input: 'pa', output: 'ꕐ', description: 'Vai transliteration - pa' },
			{ input: 'bha', output: 'ꕑ', description: 'Vai transliteration - bha' },
			{ input: 'ba', output: 'ꕒ', description: 'Vai transliteration - ba' },
			{ input: 'mba', output: 'ꕓ', description: 'Vai transliteration - mba' },
			{ input: 'kpa', output: 'ꕔ', description: 'Vai transliteration - kpa' },
			{ input: 'kpa~', output: 'ꕕ', description: 'Vai transliteration - kpa~' },
			{ input: 'mgba', output: 'ꕖ', description: 'Vai transliteration - mgba' },
			{ input: 'gba', output: 'ꕗ', description: 'Vai transliteration - gba' },
			{ input: 'fa', output: 'ꕘ', description: 'Vai transliteration - fa' },
			{ input: 'va', output: 'ꕙ', description: 'Vai transliteration - va' },
			{ input: 'ta', output: 'ꕚ', description: 'Vai transliteration - ta' },
			{ input: 'tha', output: 'ꕛ', description: 'Vai transliteration - tha' },
			{ input: 'da', output: 'ꕜ', description: 'Vai transliteration - da' },
			{ input: 'dha', output: 'ꕝ', description: 'Vai transliteration - dha' },
			{ input: 'la', output: 'ꕞ', description: 'Vai transliteration - la' },
			{ input: 'ra', output: 'ꕟ', description: 'Vai transliteration - ra' },
			{ input: 'dla', output: 'ꕠ', description: 'Vai transliteration - dla' },
			{ input: 'Da', output: 'ꕠ', description: 'Vai transliteration - Da' },
			{ input: 'nDa', output: 'ꕡ', description: 'Vai transliteration - nDa' },
			{ input: 'nda', output: 'ꕡ', description: 'Vai transliteration - nda' },
			{ input: 'sa', output: 'ꕢ', description: 'Vai transliteration - sa' },
			{ input: 'sha', output: 'ꕣ', description: 'Vai transliteration - sha' },
			{ input: 'za', output: 'ꕤ', description: 'Vai transliteration - za' },
			{ input: 'zha', output: 'ꕥ', description: 'Vai transliteration - zha' },
			{ input: 'ca', output: 'ꕦ', description: 'Vai transliteration - ca' },
			{ input: 'ja', output: 'ꕧ', description: 'Vai transliteration - ja' },
			{ input: 'nja', output: 'ꕨ', description: 'Vai transliteration - nja' },
			{ input: 'ya', output: 'ꕩ', description: 'Vai transliteration - ya' },
			{ input: 'ka', output: 'ꕪ', description: 'Vai transliteration - ka' },
			{ input: 'ka~', output: 'ꕫ', description: 'Vai transliteration - ka~' },
			{ input: 'nga', output: 'ꕬ', description: 'Vai transliteration - nga' },
			{ input: 'ga', output: 'ꕭ', description: 'Vai transliteration - ga' },
			{ input: 'ma', output: 'ꕮ', description: 'Vai transliteration - ma' },
			{ input: 'na', output: 'ꕯ', description: 'Vai transliteration - na' },
			{ input: 'nya', output: 'ꕰ', description: 'Vai transliteration - nya' },

			{ input: 'o', output: 'ꕱ', description: 'Vai transliteration - o' },
			{ input: 'o~', output: 'ꕲ', description: 'Vai transliteration - o~' },
			{ input: 'ho', output: 'ꕳ', description: 'Vai transliteration - ho' },
			{ input: 'wo', output: 'ꕴ', description: 'Vai transliteration - wo' },
			{ input: 'wo~', output: 'ꕵ', description: 'Vai transliteration - wo~' },
			{ input: 'po', output: 'ꕶ', description: 'Vai transliteration - po' },
			{ input: 'bho', output: 'ꕷ', description: 'Vai transliteration - bho' },
			{ input: 'bo', output: 'ꕸ', description: 'Vai transliteration - bo' },
			{ input: 'mbo', output: 'ꕹ', description: 'Vai transliteration - mbo' },
			{ input: 'kpo', output: 'ꕺ', description: 'Vai transliteration - kpo' },
			{ input: 'mgbo', output: 'ꕻ', description: 'Vai transliteration - mgbo' },
			{ input: 'gbo', output: 'ꕼ', description: 'Vai transliteration - gbo' },
			{ input: 'fo', output: 'ꕽ', description: 'Vai transliteration - fo' },
			{ input: 'vo', output: 'ꕾ', description: 'Vai transliteration - vo' },
			{ input: 'to', output: 'ꕿ', description: 'Vai transliteration - to' },
			{ input: 'tho', output: 'ꖀ', description: 'Vai transliteration - tho' },
			{ input: 'do', output: 'ꖁ', description: 'Vai transliteration - do' },
			{ input: 'dho', output: 'ꖂ', description: 'Vai transliteration - dho' },
			{ input: 'lo', output: 'ꖃ', description: 'Vai transliteration - lo' },
			{ input: 'ro', output: 'ꖄ', description: 'Vai transliteration - ro' },
			{ input: 'dlo', output: 'ꖅ', description: 'Vai transliteration - dlo' },
			{ input: 'Do', output: 'ꖅ', description: 'Vai transliteration - Do' },
			{ input: 'nDo', output: 'ꖆ', description: 'Vai transliteration - nDo' },
			{ input: 'ndo', output: 'ꖆ', description: 'Vai transliteration - ndo' },
			{ input: 'so', output: 'ꖇ', description: 'Vai transliteration - so' },
			{ input: 'sho', output: 'ꖈ', description: 'Vai transliteration - sho' },
			{ input: 'zo', output: 'ꖉ', description: 'Vai transliteration - zo' },
			{ input: 'zho', output: 'ꖊ', description: 'Vai transliteration - zho' },
			{ input: 'co', output: 'ꖋ', description: 'Vai transliteration - co' },
			{ input: 'jo', output: 'ꖌ', description: 'Vai transliteration - jo' },
			{ input: 'njo', output: 'ꖍ', description: 'Vai transliteration - njo' },
			{ input: 'yo', output: 'ꖎ', description: 'Vai transliteration - yo' },
			{ input: 'ko', output: 'ꖏ', description: 'Vai transliteration - ko' },
			{ input: 'ngo', output: 'ꖐ', description: 'Vai transliteration - ngo' },
			{ input: 'go', output: 'ꖑ', description: 'Vai transliteration - go' },
			{ input: 'mo', output: 'ꖒ', description: 'Vai transliteration - mo' },
			{ input: 'no', output: 'ꖓ', description: 'Vai transliteration - no' },
			{ input: 'nyo', output: 'ꖔ', description: 'Vai transliteration - nyo' },

			{ input: 'u', output: 'ꖕ', description: 'Vai transliteration - u' },
			{ input: 'u~', output: 'ꖖ', description: 'Vai transliteration - u~' },
			{ input: 'hu', output: 'ꖗ', description: 'Vai transliteration - hu' },
			{ input: 'hu~', output: 'ꖘ', description: 'Vai transliteration - hu~' },
			{ input: 'wu', output: 'ꖙ', description: 'Vai transliteration - wu' },
			{ input: 'wu~', output: 'ꖚ', description: 'Vai transliteration - wu~' },
			{ input: 'pu', output: 'ꖛ', description: 'Vai transliteration - pu' },
			{ input: 'bhu', output: 'ꖜ', description: 'Vai transliteration - bhu' },
			{ input: 'bu', output: 'ꖝ', description: 'Vai transliteration - bu' },
			{ input: 'mbu', output: 'ꖞ', description: 'Vai transliteration - mbu' },
			{ input: 'kpu', output: 'ꖟ', description: 'Vai transliteration - kpu' },
			{ input: 'mgbu', output: 'ꖠ', description: 'Vai transliteration - mgbu' },
			{ input: 'gbu', output: 'ꖡ', description: 'Vai transliteration - gbu' },
			{ input: 'fu', output: 'ꖢ', description: 'Vai transliteration - fu' },
			{ input: 'vu', output: 'ꖣ', description: 'Vai transliteration - vu' },
			{ input: 'tu', output: 'ꖤ', description: 'Vai transliteration - tu' },
			{ input: 'thu', output: 'ꖥ', description: 'Vai transliteration - thu' },
			{ input: 'du', output: 'ꖦ', description: 'Vai transliteration - du' },
			{ input: 'dhu', output: 'ꖧ', description: 'Vai transliteration - dhu' },
			{ input: 'lu', output: 'ꖨ', description: 'Vai transliteration - lu' },
			{ input: 'ru', output: 'ꖩ', description: 'Vai transliteration - ru' },
			{ input: 'dlu', output: 'ꖪ', description: 'Vai transliteration - dlu' },
			{ input: 'Du', output: 'ꖪ', description: 'Vai transliteration - Du' },
			{ input: 'nDu', output: 'ꖫ', description: 'Vai transliteration - nDu' },
			{ input: 'ndu', output: 'ꖫ', description: 'Vai transliteration - ndu' },
			{ input: 'su', output: 'ꖬ', description: 'Vai transliteration - su' },
			{ input: 'shu', output: 'ꖭ', description: 'Vai transliteration - shu' },
			{ input: 'zu', output: 'ꖮ', description: 'Vai transliteration - zu' },
			{ input: 'zhu', output: 'ꖯ', description: 'Vai transliteration - zhu' },
			{ input: 'cu', output: 'ꖰ', description: 'Vai transliteration - cu' },
			{ input: 'ju', output: 'ꖱ', description: 'Vai transliteration - ju' },
			{ input: 'nju', output: 'ꖲ', description: 'Vai transliteration - nju' },
			{ input: 'yu', output: 'ꖳ', description: 'Vai transliteration - yu' },
			{ input: 'ku', output: 'ꖴ', description: 'Vai transliteration - ku' },
			{ input: 'ngu', output: 'ꖵ', description: 'Vai transliteration - ngu' },
			{ input: 'gu', output: 'ꖶ', description: 'Vai transliteration - gu' },
			{ input: 'mu', output: 'ꖷ', description: 'Vai transliteration - mu' },
			{ input: 'nu', output: 'ꖸ', description: 'Vai transliteration - nu' },
			{ input: 'nyu', output: 'ꖹ', description: 'Vai transliteration - nyu' },

			{ input: 'x', output: 'ꖺ', description: 'Vai transliteration - x' },
			{ input: 'x~', output: 'ꖻ', description: 'Vai transliteration - x~' },
			{ input: 'ngx~', output: 'ꖼ', description: 'Vai transliteration - ngx~' },
			{ input: 'hx', output: 'ꖽ', description: 'Vai transliteration - hx' },
			{ input: 'hx~', output: 'ꖾ', description: 'Vai transliteration - hx~' },
			{ input: 'wx', output: 'ꖿ', description: 'Vai transliteration - wx' },
			{ input: 'wx~', output: 'ꗀ', description: 'Vai transliteration - wx~' },
			{ input: 'px', output: 'ꗁ', description: 'Vai transliteration - px' },
			{ input: 'bhx', output: 'ꗂ', description: 'Vai transliteration - bhx' },
			{ input: 'bx', output: 'ꗃ', description: 'Vai transliteration - bx' },
			{ input: 'mbx', output: 'ꗄ', description: 'Vai transliteration - mbx' },
			{ input: 'kpx', output: 'ꗅ', description: 'Vai transliteration - kpx' },
			{ input: 'mgbx', output: 'ꗆ', description: 'Vai transliteration - mgbx' },
			{ input: 'gbx', output: 'ꗇ', description: 'Vai transliteration - gbx' },
			{ input: 'gbx~', output: 'ꗈ', description: 'Vai transliteration - gbx~' },
			{ input: 'fx', output: 'ꗉ', description: 'Vai transliteration - fx' },
			{ input: 'vx', output: 'ꗊ', description: 'Vai transliteration - vx' },
			{ input: 'tx', output: 'ꗋ', description: 'Vai transliteration - tx' },
			{ input: 'thx', output: 'ꗌ', description: 'Vai transliteration - thx' },
			{ input: 'dx', output: 'ꗍ', description: 'Vai transliteration - dx' },
			{ input: 'dhx', output: 'ꗎ', description: 'Vai transliteration - dhx' },
			{ input: 'lx', output: 'ꗏ', description: 'Vai transliteration - lx' },
			{ input: 'rx', output: 'ꗐ', description: 'Vai transliteration - rx' },
			{ input: 'dlx', output: 'ꗑ', description: 'Vai transliteration - dlx' },
			{ input: 'Dx', output: 'ꗑ', description: 'Vai transliteration - Dx' },
			{ input: 'nDx', output: 'ꗒ', description: 'Vai transliteration - nDx' },
			{ input: 'ndx', output: 'ꗒ', description: 'Vai transliteration - ndx' },
			{ input: 'sx', output: 'ꗓ', description: 'Vai transliteration - sx' },
			{ input: 'shx', output: 'ꗔ', description: 'Vai transliteration - shx' },
			{ input: 'zx', output: 'ꗕ', description: 'Vai transliteration - zx' },
			{ input: 'zhx', output: 'ꗖ', description: 'Vai transliteration - zhx' },
			{ input: 'cx', output: 'ꗗ', description: 'Vai transliteration - cx' },
			{ input: 'jx', output: 'ꗘ', description: 'Vai transliteration - jx' },
			{ input: 'njx', output: 'ꗙ', description: 'Vai transliteration - njx' },
			{ input: 'yx', output: 'ꗚ', description: 'Vai transliteration - yx' },
			{ input: 'kx', output: 'ꗛ', description: 'Vai transliteration - kx' },
			{ input: 'ngx', output: 'ꗜ', description: 'Vai transliteration - ngx' },
			{ input: 'gx', output: 'ꗝ', description: 'Vai transliteration - gx' },
			{ input: 'mx', output: 'ꗞ', description: 'Vai transliteration - mx' },
			{ input: 'nx', output: 'ꗟ', description: 'Vai transliteration - nx' },
			{ input: 'nyx', output: 'ꗠ', description: 'Vai transliteration - nyx' },

			// Same as above, but with O instead of x
			{ input: 'O', output: 'ꖺ', description: 'Vai transliteration - O' },
			{ input: 'O~', output: 'ꖻ', description: 'Vai transliteration - O~' },
			{ input: 'ngO~', output: 'ꖼ', description: 'Vai transliteration - ngO~' },
			{ input: 'hO', output: 'ꖽ', description: 'Vai transliteration - hO' },
			{ input: 'hO~', output: 'ꖾ', description: 'Vai transliteration - hO~' },
			{ input: 'wO', output: 'ꖿ', description: 'Vai transliteration - wO' },
			{ input: 'wO~', output: 'ꗀ', description: 'Vai transliteration - wO~' },
			{ input: 'pO', output: 'ꗁ', description: 'Vai transliteration - pO' },
			{ input: 'bhO', output: 'ꗂ', description: 'Vai transliteration - bhO' },
			{ input: 'bO', output: 'ꗃ', description: 'Vai transliteration - bO' },
			{ input: 'mbO', output: 'ꗄ', description: 'Vai transliteration - mbO' },
			{ input: 'kpO', output: 'ꗅ', description: 'Vai transliteration - kpO' },
			{ input: 'mgbO', output: 'ꗆ', description: 'Vai transliteration - mgbO' },
			{ input: 'gbO', output: 'ꗇ', description: 'Vai transliteration - gbO' },
			{ input: 'gbO~', output: 'ꗈ', description: 'Vai transliteration - gbO~' },
			{ input: 'fO', output: 'ꗉ', description: 'Vai transliteration - fO' },
			{ input: 'vO', output: 'ꗊ', description: 'Vai transliteration - vO' },
			{ input: 'tO', output: 'ꗋ', description: 'Vai transliteration - tO' },
			{ input: 'thO', output: 'ꗌ', description: 'Vai transliteration - thO' },
			{ input: 'dO', output: 'ꗍ', description: 'Vai transliteration - dO' },
			{ input: 'dhO', output: 'ꗎ', description: 'Vai transliteration - dhO' },
			{ input: 'lO', output: 'ꗏ', description: 'Vai transliteration - lO' },
			{ input: 'rO', output: 'ꗐ', description: 'Vai transliteration - rO' },
			{ input: 'dlO', output: 'ꗑ', description: 'Vai transliteration - dlO' },
			{ input: 'DO', output: 'ꗑ', description: 'Vai transliteration - DO' },
			{ input: 'nDO', output: 'ꗒ', description: 'Vai transliteration - nDO' },
			{ input: 'ndO', output: 'ꗒ', description: 'Vai transliteration - ndO' },
			{ input: 'sO', output: 'ꗓ', description: 'Vai transliteration - sO' },
			{ input: 'shO', output: 'ꗔ', description: 'Vai transliteration - shO' },
			{ input: 'zO', output: 'ꗕ', description: 'Vai transliteration - zO' },
			{ input: 'zhO', output: 'ꗖ', description: 'Vai transliteration - zhO' },
			{ input: 'cO', output: 'ꗗ', description: 'Vai transliteration - cO' },
			{ input: 'jO', output: 'ꗘ', description: 'Vai transliteration - jO' },
			{ input: 'njO', output: 'ꗙ', description: 'Vai transliteration - njO' },
			{ input: 'yO', output: 'ꗚ', description: 'Vai transliteration - yO' },
			{ input: 'kO', output: 'ꗛ', description: 'Vai transliteration - kO' },
			{ input: 'ngO', output: 'ꗜ', description: 'Vai transliteration - ngO' },
			{ input: 'gO', output: 'ꗝ', description: 'Vai transliteration - gO' },
			{ input: 'mO', output: 'ꗞ', description: 'Vai transliteration - mO' },
			{ input: 'nO', output: 'ꗟ', description: 'Vai transliteration - nO' },
			{ input: 'nyO', output: 'ꗠ', description: 'Vai transliteration - nyO' },

			{ input: 'q', output: 'ꗡ', description: 'Vai transliteration - q' },
			{ input: 'q~', output: 'ꗢ', description: 'Vai transliteration - q~' },
			{ input: 'ngq~', output: 'ꗣ', description: 'Vai transliteration - ngq~' },
			{ input: 'hq', output: 'ꗤ', description: 'Vai transliteration - hq' },
			{ input: 'hq~', output: 'ꗥ', description: 'Vai transliteration - hq~' },
			{ input: 'wq', output: 'ꗦ', description: 'Vai transliteration - wq' },
			{ input: 'wq~', output: 'ꗧ', description: 'Vai transliteration - wq~' },
			{ input: 'pq', output: 'ꗨ', description: 'Vai transliteration - pq' },
			{ input: 'bhq', output: 'ꗩ', description: 'Vai transliteration - bhq' },
			{ input: 'bq', output: 'ꗪ', description: 'Vai transliteration - bq' },
			{ input: 'mbq', output: 'ꗫ', description: 'Vai transliteration - mbq' },
			{ input: 'kpq', output: 'ꗬ', description: 'Vai transliteration - kpq' },
			{ input: 'kpq~', output: 'ꗭ', description: 'Vai transliteration - kpq~' },
			{ input: 'mgbq', output: 'ꗮ', description: 'Vai transliteration - mgbq' },
			{ input: 'gbq', output: 'ꗯ', description: 'Vai transliteration - gbq' },
			{ input: 'gbq~', output: 'ꗰ', description: 'Vai transliteration - gbq~' },
			{ input: 'fq', output: 'ꗱ', description: 'Vai transliteration - fq' },
			{ input: 'vq', output: 'ꗲ', description: 'Vai transliteration - vq' },
			{ input: 'tq', output: 'ꗳ', description: 'Vai transliteration - tq' },
			{ input: 'thq', output: 'ꗴ', description: 'Vai transliteration - thq' },
			{ input: 'dq', output: 'ꗵ', description: 'Vai transliteration - dq' },
			{ input: 'dhq', output: 'ꗶ', description: 'Vai transliteration - dhq' },
			{ input: 'lq', output: 'ꗷ', description: 'Vai transliteration - lq' },
			{ input: 'rq', output: 'ꗸ', description: 'Vai transliteration - rq' },
			{ input: 'dlq', output: 'ꗹ', description: 'Vai transliteration - dlq' },
			{ input: 'Dq', output: 'ꗹ', description: 'Vai transliteration - Dq' },
			{ input: 'nDq', output: 'ꗺ', description: 'Vai transliteration - nDq' },
			{ input: 'ndq', output: 'ꗺ', description: 'Vai transliteration - ndq' },
			{ input: 'sq', output: 'ꗻ', description: 'Vai transliteration - sq' },
			{ input: 'shq', output: 'ꗼ', description: 'Vai transliteration - shq' },
			{ input: 'zq', output: 'ꗽ', description: 'Vai transliteration - zq' },
			{ input: 'zhq', output: 'ꗾ', description: 'Vai transliteration - zhq' },
			{ input: 'cq', output: 'ꗿ', description: 'Vai transliteration - cq' },
			{ input: 'jq', output: 'ꘀ', description: 'Vai transliteration - jq' },
			{ input: 'njq', output: 'ꘁ', description: 'Vai transliteration - njq' },
			{ input: 'yq', output: 'ꘂ', description: 'Vai transliteration - yq' },
			{ input: 'kq', output: 'ꘃ', description: 'Vai transliteration - kq' },
			{ input: 'ngq', output: 'ꘄ', description: 'Vai transliteration - ngq' },
			{ input: 'nggq~', output: 'ꘅ', description: 'Vai transliteration - nggq~' },
			{ input: 'gq', output: 'ꘆ', description: 'Vai transliteration - gq' },
			{ input: 'gq~', output: 'ꘇ', description: 'Vai transliteration - gq~' },
			{ input: 'mq', output: 'ꘈ', description: 'Vai transliteration - mq' },
			{ input: 'nq', output: 'ꘉ', description: 'Vai transliteration - nq' },
			{ input: 'nyq', output: 'ꘊ', description: 'Vai transliteration - nyq' },

			// Same as above, but with E instead of q
			{ input: 'E', output: 'ꗡ', description: 'Vai transliteration - E' },
			{ input: 'E~', output: 'ꗢ', description: 'Vai transliteration - E~' },
			{ input: 'ngE~', output: 'ꗣ', description: 'Vai transliteration - ngE~' },
			{ input: 'hE', output: 'ꗤ', description: 'Vai transliteration - hE' },
			{ input: 'hE~', output: 'ꗥ', description: 'Vai transliteration - hE~' },
			{ input: 'wE', output: 'ꗦ', description: 'Vai transliteration - wE' },
			{ input: 'wE~', output: 'ꗧ', description: 'Vai transliteration - wE~' },
			{ input: 'pE', output: 'ꗨ', description: 'Vai transliteration - pE' },
			{ input: 'bhE', output: 'ꗩ', description: 'Vai transliteration - bhE' },
			{ input: 'bE', output: 'ꗪ', description: 'Vai transliteration - bE' },
			{ input: 'mbE', output: 'ꗫ', description: 'Vai transliteration - mbE' },
			{ input: 'kpE', output: 'ꗬ', description: 'Vai transliteration - kpE' },
			{ input: 'kpE~', output: 'ꗭ', description: 'Vai transliteration - kpE~' },
			{ input: 'mgbE', output: 'ꗮ', description: 'Vai transliteration - mgbE' },
			{ input: 'gbE', output: 'ꗯ', description: 'Vai transliteration - gbE' },
			{ input: 'gbE~', output: 'ꗰ', description: 'Vai transliteration - gbE~' },
			{ input: 'fE', output: 'ꗱ', description: 'Vai transliteration - fE' },
			{ input: 'vE', output: 'ꗲ', description: 'Vai transliteration - vE' },
			{ input: 'tE', output: 'ꗳ', description: 'Vai transliteration - tE' },
			{ input: 'thE', output: 'ꗴ', description: 'Vai transliteration - thE' },
			{ input: 'dE', output: 'ꗵ', description: 'Vai transliteration - dE' },
			{ input: 'dhE', output: 'ꗶ', description: 'Vai transliteration - dhE' },
			{ input: 'lE', output: 'ꗷ', description: 'Vai transliteration - lE' },
			{ input: 'rE', output: 'ꗸ', description: 'Vai transliteration - rE' },
			{ input: 'dlE', output: 'ꗹ', description: 'Vai transliteration - dlE' },
			{ input: 'DE', output: 'ꗹ', description: 'Vai transliteration - DE' },
			{ input: 'nDE', output: 'ꗺ', description: 'Vai transliteration - nDE' },
			{ input: 'ndE', output: 'ꗺ', description: 'Vai transliteration - ndE' },
			{ input: 'sE', output: 'ꗻ', description: 'Vai transliteration - sE' },
			{ input: 'shE', output: 'ꗼ', description: 'Vai transliteration - shE' },
			{ input: 'zE', output: 'ꗽ', description: 'Vai transliteration - zE' },
			{ input: 'zhE', output: 'ꗾ', description: 'Vai transliteration - zhE' },
			{ input: 'cE', output: 'ꗿ', description: 'Vai transliteration - cE' },
			{ input: 'jE', output: 'ꘀ', description: 'Vai transliteration - jE' },
			{ input: 'njE', output: 'ꘁ', description: 'Vai transliteration - njE' },
			{ input: 'yE', output: 'ꘂ', description: 'Vai transliteration - yE' },
			{ input: 'kE', output: 'ꘃ', description: 'Vai transliteration - kE' },
			{ input: 'ngE', output: 'ꘄ', description: 'Vai transliteration - ngE' },
			{ input: 'nggE~', output: 'ꘅ', description: 'Vai transliteration - nggE~' },
			{ input: 'gE', output: 'ꘆ', description: 'Vai transliteration - gE' },
			{ input: 'gE~', output: 'ꘇ', description: 'Vai transliteration - gE~' },
			{ input: 'mE', output: 'ꘈ', description: 'Vai transliteration - mE' },
			{ input: 'nE', output: 'ꘉ', description: 'Vai transliteration - nE' },
			{ input: 'nyE', output: 'ꘊ', description: 'Vai transliteration - nyE' },

			{ input: 'X', output: 'ꘋ', description: 'Vai transliteration - X' },
			{ input: 'N', output: 'ꘋ', description: 'Vai transliteration - N' },
			{ input: '=', output: 'ꘌ', description: 'Vai transliteration - =' },
			{ input: '==', output: '=', description: 'Vai transliteration - ==' },
			{ input: ',', output: '꘍', description: 'Vai transliteration - ,' },
			{ input: ',,', output: ',', description: 'Vai transliteration - ,,' },
			{ input: '.', output: '꘎', description: 'Vai transliteration - .' },
			{ input: '..', output: '.', description: 'Vai transliteration - ..' },
			{ input: '!', output: '꘎꘎', description: 'Vai transliteration - .' },
			{ input: '!!', output: '!', description: 'Vai transliteration - ..' },
			{ input: '?', output: '꘏', description: 'Vai transliteration - ?' },
			{ input: '??', output: '?', description: 'Vai transliteration - ??' },
			{ input: 'FENG', output: 'ꘓ', description: 'Vai transliteration - FENG' },
			{ input: 'FAA', output: 'ꘘ', description: 'Vai transliteration - FAA' },
			{ input: 'FAHA', output: 'ꘘ', description: 'Vai transliteration - FAHA' },

			{ input: 'pEEzE=', output: 'ꗨꗡꗽꘌ', description: 'Vai transliteration - =' },
			{ input: 'piN', output: 'ꔪꘋ', description: 'Vai transliteration - piN' },
			{ input: 'vai', output: 'ꕙꔤ', description: 'Vai transliteration - vai' },
			{ input: 'cale raili --~~~~', output: 'ꕦꔒ ꕟꔤꔷ --~~~~', description: 'Vai transliteration - cale raili --~~~~' }
		]
	},
	{
		description: 'Venda tilde test',
		inputmethod: 've-tilde',
		tests: [
			{ input: 'Vhaven~da', output: 'Vhavenḓa', description: 'Venda tilde Vhavenḓa' },
			{ input: '~la', output: 'ḽa', description: 'Venda tilde ḽa' },
			{ input: '~Nama', output: 'Ṋama', description: 'Venda tilde Ṋama' },
			{ input: '~nama', output: 'ṋama', description: 'Venda tilde ṋama' },
			{ input: '~Thaluso', output: 'Ṱhaluso', description: 'Venda tilde Ṱhaluso' },
			{ input: 'Vha`nwali', output: 'Vhaṅwali', description: 'Venda tilde Vhaṅwali' }
		]
	},
	{
		description: 'Venetian vec-GVU input method test',
		inputmethod: 'vec-GVU',
		tests: [
			{ input: 'dh', output: 'đ', description: 'Venetian đ' },
			{ input: 'lh', output: 'ł', description: 'Venetian ł' },
			{ input: 'òò', output: 'ó', description: 'Venetian ó' },
			{ input: 'zh', output: 'ẑ', description: 'Venetian ẑ' },
			{ input: 'đh', output: 'dh', description: 'Venetian dh' },
			{ input: 'łh', output: 'lh', description: 'Venetian lh' },
			{ input: 'ẑh', output: 'zh', description: 'Venetian zh' },
			{ input: 'Dh', output: 'Đ', description: 'Venetian Đ' },
			{ input: 'Lh', output: 'Ł', description: 'Venetian Ł' },
			{ input: 'Òò', output: 'Ó', description: 'Venetian Ó' },
			{ input: 'Zh', output: 'Ẑ', description: 'Venetian Ẑ' },
			{ input: 'Đh', output: 'Dh', description: 'Venetian Dh' },
			{ input: 'Łh', output: 'Lh', description: 'Venetian Lh' },
			{ input: 'Ẑh', output: 'Zh', description: 'Venetian Zh' }
		]
	},
	{
		description: 'Wolof Alt input method test',
		inputmethod: 'wo-alt',
		tests: [
			{
				input: [
					[ 'A', false ],
					[ '\\', true ]
				],
				output: 'À',
				description: 'Wolof À'
			},
			{
				input: [
					[ 'a', false ],
					[ '/', true ]
				],
				output: 'á',
				description: 'Wolof á'
			},
			{ input: [ [ 'e', true ] ], output: 'ë', description: 'Wolof ë' },
			{ input: [ [ 'E', true ] ], output: 'Ë', description: 'Wolof Ë' },
			{ input: [ [ 'n', true ] ], output: 'ŋ', description: 'Wolof ŋ' },
			{ input: [ [ 'N', true ] ], output: 'Ŋ', description: 'Wolof Ŋ' },
			{ input: 'e', output: 'e', description: 'Wolof e' },
			{ input: 'E', output: 'E', description: 'Wolof E' },
			{ input: 'n', output: 'n', description: 'Wolof n' },
			{ input: 'N', output: 'N', description: 'Wolof N' },
			{ input: 'N~', output: 'Ñ', description: 'Wolof Ñ' },
			{ input: 'n~', output: 'ñ', description: 'Wolof ñ' },
			{ input: 'N~~', output: 'N~', description: 'Wolof N~' },
			{ input: 'n~~', output: 'n~', description: 'Wolof n~' }
		]
	},
	{
		description: 'Wolof tilde test',
		inputmethod: 'wo-tilde',
		tests: [
			{ input: '~n~ew~el', output: 'ñëwël', description: 'Wolof tilde ~n~ew~el' },
			{ input: '~E', output: 'Ë', description: 'Wolof tilde ~E' },
			{ input: 'Pe~/nc', output: 'Pénc', description: 'Wolof tilde Pe~/nc' },
			{ input: 'ja~\\mm', output: 'jàmm', description: 'Wolof tilde ja~\\mm' },
			{ input: '~goy', output: 'ŋoy', description: 'Wolof tilde ~goy' },
			{ input: '~G', output: 'Ŋ', description: 'Wolof tilde ~G' }
		]
	},
	{
		description: 'Yoruba yo-alt input method test',
		inputmethod: 'yo-alt',
		tests: [
			{
				input: [
					[ 'a', false ],
					[ '\\', true ]
				], output: 'à', description: 'Yoruba a + alt-\\'
			},
			{
				input: [
					[ 'a', false ],
					[ '/', true ]
				], output: 'á', description: 'Yoruba a + alt-/'
			},
			{
				input: [
					[ 'e', false ],
					[ '\\', true ]
				], output: 'è', description: 'Yoruba e + alt-\\'
			},
			{
				input: [
					[ 'e', false ],
					[ '/', true ]
				], output: 'é', description: 'Yoruba e + alt-/'
			},
			{
				input: [
					[ 'e', false ],
					[ '.', true ]
				], output: 'ẹ', description: 'Yoruba e + alt-.'
			},
			{
				input: [
					[ 'e', false ],
					[ '.', true ],
					[ '\\', true ]
				], output: 'ẹ̀', description: 'Yoruba e + alt-. + alt-\\'
			},
			{
				input: [
					[ 'e', false ],
					[ '.', true ],
					[ '/', true ]
				], output: 'ẹ́', description: 'Yoruba e + alt-. + alt-/'
			},
			{
				input: [
					[ 'i', false ],
					[ '\\', true ]
				], output: 'ì', description: 'Yoruba i + alt-\\'
			},
			{
				input: [
					[ 'i', false ],
					[ '/', true ]
				], output: 'í', description: 'Yoruba i + alt-/'
			},
			{
				input: [
					[ 'o', false ],
					[ '\\', true ]
				], output: 'ò', description: 'Yoruba o + alt-\\'
			},
			{
				input: [
					[ 'o', false ],
					[ '/', true ]
				], output: 'ó', description: 'Yoruba o + alt-/'
			},
			{
				input: [
					[ 'o', false ],
					[ '.', true ]
				], output: 'ọ', description: 'Yoruba o + alt-.'
			},
			{
				input: [
					[ 'o', false ],
					[ '.', true ],
					[ '\\', true ]
				], output: 'ọ̀', description: 'Yoruba a + alt-. + alt-\\'
			},
			{
				input: [
					[ 'o', false ],
					[ '.', true ],
					[ '/', true ]
				], output: 'ọ́', description: 'Yoruba a + alt-. + alt-/'
			},
			{
				input: [
					[ 'u', false ],
					[ '\\', true ]
				], output: 'ù', description: 'Yoruba u + alt-\\'
			},
			{
				input: [
					[ 'u', false ],
					[ '/', true ]
				], output: 'ú', description: 'Yoruba u + alt-/'
			}
		]
	},
	{
		description: 'Yoruba tilde test',
		inputmethod: 'yo-tilde',
		tests: [
			{ input: '~E', output: 'Ẹ', description: 'Yoruba tilde ~E -> Ẹ' },
			{ input: '~e', output: 'ẹ', description: 'Yoruba tilde ~e -> ẹ' },
			{ input: '~O', output: 'Ọ', description: 'Yoruba tilde ~O -> Ọ' },
			{ input: '~o', output: 'ọ', description: 'Yoruba tilde ~o -> ọ' },
			{ input: '~S', output: 'Ṣ', description: 'Yoruba tilde ~S -> Ṣ' },
			{ input: '~s', output: 'ṣ', description: 'Yoruba tilde ~s -> ṣ' },
			{ input: '~e~-', output: 'ẹ̄', description: 'Yoruba tilde ~e~- -> ẹ̄' },
			{ input: '~E~\\', output: 'Ẹ̀', description: 'Yoruba tilde ~E~\\ -> Ẹ̀' },
			{ input: '~e~/', output: 'ẹ́', description: 'Yoruba tilde ~e~/ -> ẹ́' },
			{ input: '~O~^', output: 'Ộ', description: 'Yoruba tilde ~O~^ -> Ộ' },
			{ input: '~o~v', output: 'ọ̌', description: 'Yoruba tilde ~o~v -> ọ̌' }
		]
	},
	{
		description: 'Chinese Pinyin test',
		inputmethod: 'zh-pinyin-transliteration',
		tests: [
			{ input: 'wen2', output: 'wén', description: 'Chinese Pinyin wén' },
			{ input: 'lv3', output: 'lǚ', description: 'Chinese Pinyin lǚ' },
			{ input: 'hua4', output: 'huà', description: 'Chinese Pinyin huà' },
			{ input: 'liou2', output: 'liú', description: 'Chinese Pinyin liú' },
			{ input: 'jv', output: 'ju', description: 'Chinese Pinyin ju' },
			{ input: 'xiao4', output: 'xiào', description: 'Chinese Pinyin xiào' },
			{ input: 'jv1', output: 'jū', description: 'Chinese Pinyin jū' },
			{ input: 'wang3', output: 'wǎng', description: 'Chinese Pinyin wǎng' }
		]
	}
];
